(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1759835,      56729]*)
(*NotebookOutlinePosition[   1760765,      56761]*)
(*  CellTagsIndexPosition[   1760673,      56755]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "A Simple Mesh Generator in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Title"],

Cell["Version 0.1", "Subtitle"],

Cell["\<\
Zhe Hu
huzhe@iit.edu
Illinois Institute of Technology
September, 2004\
\>", "Author"],

Cell[TextData[{
  "In this notebook we experiment with Persson and Strang's mesh generation \
algorithm in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The algorithm was implemented in MATLAB in their original paper [1], \
which is highly recommended to be read along with this notebook."
}], "Abstract"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook is an effort to transcribe the MATLAB code of a 2-D mesh \
generation algorithm as described explicitly in Persson and Strang's paper \
[1]. The goal is to make the algorithm executable in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " so that its users can also experiment with the algorithm."
}], "Text"],

Cell[TextData[{
  "Since the algorithm was expressed very clearly from their original paper \
[1] including the MATLAB code, which is a perfect example of literate \
programming in MATLAB, it is pretty easy to translate the MATLAB code \
\"literally\" into ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  "  Such translation is virtually always possible in either direction even \
without human interference. And such a Rosetta Stone kind of translation \
might be useful if one species of people coding in either MATLAB or ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " were to disappear, future generations would still be able to rediscover \
one programming language by reading its interpretation in the other one."
}], "Text"],

Cell[TextData[{
  "However, it is so tempting to present the literate programming capability \
of ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "by following its general principles; that is, (a) documentation mingles \
with code and both get pretty-printed; (b) shuffle code pieces for human \
readability. I decided to transcribe the code manually."
}], "Text"],

Cell["\<\
The original MATLAB code was documented as 8 steps (sections) in sequential \
order, which is easy to follow because the ideas behind the code were \
explained beforehand in early parts of the paper. So it is recommended that \
you read part 1 and 2 of the original paper. Instead of following the MATLAB \
code literally in 8 steps, this notebook breaks the code pieces apart and \
examines each of them separately. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overview", "Section"],

Cell[TextData[{
  "In order to generate a triangular mesh, in the 2-D case, one needs to find \
locations of the meshpoints ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["p",
            FontWeight->"Bold"], "(", \(x, y\), ")"}], TraditionalForm]]],
  ". Then both MATALB and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " have built-in Delaunay triangulation function of generating the \
triangular mesh from these meshpoints. "
}], "Text"],

Cell[TextData[{
  "In Persson and Strang's algorithm [1], user specifies the relative size of \
the mesh triangles by the size function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ". In order to generate mesh triangles as well as the edges of them \
(meshbars) according to ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ", an objective function using \"force\" analogy is proposed, in which the \
meshbars act like springs exerting forces that move the meshpoints around \
until an equilibrium (zero force) is reached. This \"force\" related \
objective function is difficult to minimize (or zero) because it is not \
continuous as stated in the paper, \"The force vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["F",
            FontWeight->"Bold"], "(", 
          StyleBox["p",
            FontWeight->"Bold"], ")"}], TraditionalForm]]],
  " is not a continuous function of ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold"], TraditionalForm]]],
  ", since the topology (the presence or absence of connecting bars) is \
changed by Delaunay as the points move.\"\nSo the algorithm, in general, \
turns into an iterative process of minimizing the objective function"
}], "Text"],

Cell["NestWhile[moveMeshpoints, initpoints, !(goodEnough[#])&]", "Program"],

Cell[TextData[{
  "The initial locations of the meshpoints can be randomly distributed or \
chosen according to ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " is a relative measure, one doesn't need to define the exact size of each \
mesh triangle at location ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  ".\nThe function ",
  StyleBox["moveMeshpoints",
    FontFamily->"Courier"],
  " keeps changing the locations of meshpoints so as to minimize this \"force\
\" related objective function until the result is regarded by function ",
  StyleBox["goodEnough",
    FontFamily->"Courier"],
  " to be so."
}], "Text"],

Cell[TextData[{
  "In practice, meshpoints always have to reside within certain geometric \
region. User also needs to define this bounded region by a distance function \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(d(x, y)\)\(.\)\)\)]],
  " And one difficult task is to maintain the meshpoints within the 2-D \
region (whether it is a disk or a rectangle with a hole in it) during the \
iterative process. After each move, if some meshpoints are pushed out of the \
2-D region, they need to be brought back onto its boundary, which is carried \
out using this distance function ",
  Cell[BoxData[
      \(TraditionalForm\`d(x, y)\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Using the Distance Function ",
  Cell[BoxData[
      \(TraditionalForm\`d(x, y)\)]]
}], "Section"],

Cell["\<\
Since distance function determines the shape for the algorithm, Let's start \
from it. Each distance function returns negative for points within the \
defined region; positive or zero otherwise. Here is a distance function for a \
disk, bounded by the circle. \
\>", "Text"],

Cell[BoxData[
    \(dcircle[{x_, y_}, {cx_, cy_, 
          r_}] := \((x - cx)\)\^2 + \((y - cy)\)\^2 - r\^2\)], "Input",
  CellLabel->"In[3]:="],

Cell[TextData[{
  "Here is another example of a rectangular region, defined by the lower left \
point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_1, \ y\_1)\)\)]],
  " and the upper right point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_2, \ y\_2)\)\)]],
  ". (This is the typical mathematical way of defining coordinates for a \
rectangular region, which is different from the one for drawing rectangles on \
the computer screen.)"
}], "Text"],

Cell[BoxData[
    \(drectangle[{x_, y_}, {x1_, y1_, x2_, y2_}] := \(-Min[
          Min[Min[\(-y1\) + y, y2 - y], \(-x1\) + x], x2 - x]\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[TextData[{
  "To test if these distance functions can distinguish points within or out \
of the defined region, we start by seeding meshpoints in a rectangular \
region, still defined by the lower left point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_1, \ y\_1)\)\)]],
  " and the upper right point ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_2, \ y\_2)\)\)]],
  ". And points in every other row are shifted so that the distance between \
every two points is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h\_0\)\(\ \ \)\)\)]],
  "(corresponding to ",
  StyleBox["step 1",
    FontSlant->"Italic"],
  " in the paper)."
}], "Text"],

Cell[BoxData[
    \(seedMeshpoints[{x1_, y1_, x2_, y2_}, h0_] := 
      Table[{x + \(\(1 - \((\(-1\))\)\^Quotient[y - y2, h0 \@ 3\/2]\)\/4\) 
                h0, y}, {y, y1, y2, \(\@3\/2\) h0}, {x, x1, x2, h0}] // 
        Flatten[#, 1] &\)], "Input",
  CellLabel->"In[5]:="],

Cell[TextData[{
  "Try to seed meshpoints in a rectangle between ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(-2\), \(-1\))\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((2, 1)\)\)]],
  " with distance ",
  Cell[BoxData[
      \(TraditionalForm\`0.1\)]],
  " between every two meshpoints."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(seedMeshpoints[{\(-2\), \(-1\), \ 2, 1}, 0.1] // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[6]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49182 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.494121 0.235156 0.246866 0.235156 [
[.02381 .23437 -6 -9 ]
[.02381 .23437 6 0 ]
[.25897 .23437 -6 -9 ]
[.25897 .23437 6 0 ]
[.72928 .23437 -3 -9 ]
[.72928 .23437 3 0 ]
[.96443 .23437 -3 -9 ]
[.96443 .23437 3 0 ]
[.48162 .01171 -12 -4.5 ]
[.48162 .01171 0 4.5 ]
[.48162 .12929 -24 -4.5 ]
[.48162 .12929 0 4.5 ]
[.48162 .36444 -18 -4.5 ]
[.48162 .36444 0 4.5 ]
[.48162 .48202 -6 -4.5 ]
[.48162 .48202 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .49182 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24687 m
.02381 .25312 L
s
[(-2)] .02381 .23437 0 1 Mshowa
.25897 .24687 m
.25897 .25312 L
s
[(-1)] .25897 .23437 0 1 Mshowa
.72928 .24687 m
.72928 .25312 L
s
[(1)] .72928 .23437 0 1 Mshowa
.96443 .24687 m
.96443 .25312 L
s
[(2)] .96443 .23437 0 1 Mshowa
.125 Mabswid
.07084 .24687 m
.07084 .25062 L
s
.11787 .24687 m
.11787 .25062 L
s
.1649 .24687 m
.1649 .25062 L
s
.21193 .24687 m
.21193 .25062 L
s
.306 .24687 m
.306 .25062 L
s
.35303 .24687 m
.35303 .25062 L
s
.40006 .24687 m
.40006 .25062 L
s
.44709 .24687 m
.44709 .25062 L
s
.54115 .24687 m
.54115 .25062 L
s
.58818 .24687 m
.58818 .25062 L
s
.63521 .24687 m
.63521 .25062 L
s
.68225 .24687 m
.68225 .25062 L
s
.77631 .24687 m
.77631 .25062 L
s
.82334 .24687 m
.82334 .25062 L
s
.87037 .24687 m
.87037 .25062 L
s
.9174 .24687 m
.9174 .25062 L
s
.25 Mabswid
0 .24687 m
1 .24687 L
s
.49412 .01171 m
.50037 .01171 L
s
[(-1)] .48162 .01171 1 0 Mshowa
.49412 .12929 m
.50037 .12929 L
s
[(-0.5)] .48162 .12929 1 0 Mshowa
.49412 .36444 m
.50037 .36444 L
s
[(0.5)] .48162 .36444 1 0 Mshowa
.49412 .48202 m
.50037 .48202 L
s
[(1)] .48162 .48202 1 0 Mshowa
.125 Mabswid
.49412 .03523 m
.49787 .03523 L
s
.49412 .05874 m
.49787 .05874 L
s
.49412 .08226 m
.49787 .08226 L
s
.49412 .10577 m
.49787 .10577 L
s
.49412 .1528 m
.49787 .1528 L
s
.49412 .17632 m
.49787 .17632 L
s
.49412 .19983 m
.49787 .19983 L
s
.49412 .22335 m
.49787 .22335 L
s
.49412 .27038 m
.49787 .27038 L
s
.49412 .2939 m
.49787 .2939 L
s
.49412 .31741 m
.49787 .31741 L
s
.49412 .34093 m
.49787 .34093 L
s
.49412 .38796 m
.49787 .38796 L
s
.49412 .41147 m
.49787 .41147 L
s
.49412 .43499 m
.49787 .43499 L
s
.49412 .45851 m
.49787 .45851 L
s
.25 Mabswid
.49412 0 m
.49412 .49182 L
s
0 0 m
1 0 L
1 .49182 L
0 .49182 L
closepath
clip
newpath
.01 w
.02381 .01171 Mdot
.04733 .01171 Mdot
.07084 .01171 Mdot
.09436 .01171 Mdot
.11787 .01171 Mdot
.14139 .01171 Mdot
.1649 .01171 Mdot
.18842 .01171 Mdot
.21193 .01171 Mdot
.23545 .01171 Mdot
.25897 .01171 Mdot
.28248 .01171 Mdot
.306 .01171 Mdot
.32951 .01171 Mdot
.35303 .01171 Mdot
.37654 .01171 Mdot
.40006 .01171 Mdot
.42357 .01171 Mdot
.44709 .01171 Mdot
.47061 .01171 Mdot
.49412 .01171 Mdot
.51764 .01171 Mdot
.54115 .01171 Mdot
.56467 .01171 Mdot
.58818 .01171 Mdot
.6117 .01171 Mdot
.63521 .01171 Mdot
.65873 .01171 Mdot
.68225 .01171 Mdot
.70576 .01171 Mdot
.72928 .01171 Mdot
.75279 .01171 Mdot
.77631 .01171 Mdot
.79982 .01171 Mdot
.82334 .01171 Mdot
.84685 .01171 Mdot
.87037 .01171 Mdot
.89389 .01171 Mdot
.9174 .01171 Mdot
.94092 .01171 Mdot
.96443 .01171 Mdot
.03557 .03208 Mdot
.05908 .03208 Mdot
.0826 .03208 Mdot
.10611 .03208 Mdot
.12963 .03208 Mdot
.15315 .03208 Mdot
.17666 .03208 Mdot
.20018 .03208 Mdot
.22369 .03208 Mdot
.24721 .03208 Mdot
.27072 .03208 Mdot
.29424 .03208 Mdot
.31775 .03208 Mdot
.34127 .03208 Mdot
.36479 .03208 Mdot
.3883 .03208 Mdot
.41182 .03208 Mdot
.43533 .03208 Mdot
.45885 .03208 Mdot
.48236 .03208 Mdot
.50588 .03208 Mdot
.52939 .03208 Mdot
.55291 .03208 Mdot
.57643 .03208 Mdot
.59994 .03208 Mdot
.62346 .03208 Mdot
.64697 .03208 Mdot
.67049 .03208 Mdot
.694 .03208 Mdot
.71752 .03208 Mdot
.74103 .03208 Mdot
.76455 .03208 Mdot
.78807 .03208 Mdot
.81158 .03208 Mdot
.8351 .03208 Mdot
.85861 .03208 Mdot
.88213 .03208 Mdot
.90564 .03208 Mdot
.92916 .03208 Mdot
.95267 .03208 Mdot
.97619 .03208 Mdot
.02381 .05244 Mdot
.04733 .05244 Mdot
.07084 .05244 Mdot
.09436 .05244 Mdot
.11787 .05244 Mdot
.14139 .05244 Mdot
.1649 .05244 Mdot
.18842 .05244 Mdot
.21193 .05244 Mdot
.23545 .05244 Mdot
.25897 .05244 Mdot
.28248 .05244 Mdot
.306 .05244 Mdot
.32951 .05244 Mdot
.35303 .05244 Mdot
.37654 .05244 Mdot
.40006 .05244 Mdot
.42357 .05244 Mdot
.44709 .05244 Mdot
.47061 .05244 Mdot
.49412 .05244 Mdot
.51764 .05244 Mdot
.54115 .05244 Mdot
.56467 .05244 Mdot
.58818 .05244 Mdot
.6117 .05244 Mdot
.63521 .05244 Mdot
.65873 .05244 Mdot
.68225 .05244 Mdot
.70576 .05244 Mdot
.72928 .05244 Mdot
.75279 .05244 Mdot
.77631 .05244 Mdot
.79982 .05244 Mdot
.82334 .05244 Mdot
.84685 .05244 Mdot
.87037 .05244 Mdot
.89389 .05244 Mdot
.9174 .05244 Mdot
.94092 .05244 Mdot
.96443 .05244 Mdot
.03557 .07281 Mdot
.05908 .07281 Mdot
.0826 .07281 Mdot
.10611 .07281 Mdot
.12963 .07281 Mdot
.15315 .07281 Mdot
.17666 .07281 Mdot
.20018 .07281 Mdot
.22369 .07281 Mdot
.24721 .07281 Mdot
.27072 .07281 Mdot
.29424 .07281 Mdot
.31775 .07281 Mdot
.34127 .07281 Mdot
.36479 .07281 Mdot
.3883 .07281 Mdot
.41182 .07281 Mdot
.43533 .07281 Mdot
.45885 .07281 Mdot
.48236 .07281 Mdot
.50588 .07281 Mdot
.52939 .07281 Mdot
.55291 .07281 Mdot
.57643 .07281 Mdot
.59994 .07281 Mdot
.62346 .07281 Mdot
.64697 .07281 Mdot
.67049 .07281 Mdot
.694 .07281 Mdot
.71752 .07281 Mdot
.74103 .07281 Mdot
.76455 .07281 Mdot
.78807 .07281 Mdot
.81158 .07281 Mdot
.8351 .07281 Mdot
.85861 .07281 Mdot
.88213 .07281 Mdot
.90564 .07281 Mdot
.92916 .07281 Mdot
.95267 .07281 Mdot
.97619 .07281 Mdot
.02381 .09317 Mdot
.04733 .09317 Mdot
.07084 .09317 Mdot
.09436 .09317 Mdot
.11787 .09317 Mdot
.14139 .09317 Mdot
.1649 .09317 Mdot
.18842 .09317 Mdot
.21193 .09317 Mdot
.23545 .09317 Mdot
.25897 .09317 Mdot
.28248 .09317 Mdot
.306 .09317 Mdot
.32951 .09317 Mdot
.35303 .09317 Mdot
.37654 .09317 Mdot
.40006 .09317 Mdot
.42357 .09317 Mdot
.44709 .09317 Mdot
.47061 .09317 Mdot
.49412 .09317 Mdot
.51764 .09317 Mdot
.54115 .09317 Mdot
.56467 .09317 Mdot
.58818 .09317 Mdot
.6117 .09317 Mdot
.63521 .09317 Mdot
.65873 .09317 Mdot
.68225 .09317 Mdot
.70576 .09317 Mdot
.72928 .09317 Mdot
.75279 .09317 Mdot
.77631 .09317 Mdot
.79982 .09317 Mdot
.82334 .09317 Mdot
.84685 .09317 Mdot
.87037 .09317 Mdot
.89389 .09317 Mdot
.9174 .09317 Mdot
.94092 .09317 Mdot
.96443 .09317 Mdot
.03557 .11354 Mdot
.05908 .11354 Mdot
.0826 .11354 Mdot
.10611 .11354 Mdot
.12963 .11354 Mdot
.15315 .11354 Mdot
.17666 .11354 Mdot
.20018 .11354 Mdot
.22369 .11354 Mdot
.24721 .11354 Mdot
.27072 .11354 Mdot
.29424 .11354 Mdot
.31775 .11354 Mdot
.34127 .11354 Mdot
.36479 .11354 Mdot
.3883 .11354 Mdot
.41182 .11354 Mdot
.43533 .11354 Mdot
.45885 .11354 Mdot
.48236 .11354 Mdot
.50588 .11354 Mdot
.52939 .11354 Mdot
.55291 .11354 Mdot
.57643 .11354 Mdot
.59994 .11354 Mdot
.62346 .11354 Mdot
.64697 .11354 Mdot
.67049 .11354 Mdot
.694 .11354 Mdot
.71752 .11354 Mdot
.74103 .11354 Mdot
.76455 .11354 Mdot
.78807 .11354 Mdot
.81158 .11354 Mdot
.8351 .11354 Mdot
.85861 .11354 Mdot
.88213 .11354 Mdot
.90564 .11354 Mdot
.92916 .11354 Mdot
.95267 .11354 Mdot
.97619 .11354 Mdot
.02381 .1339 Mdot
.04733 .1339 Mdot
.07084 .1339 Mdot
.09436 .1339 Mdot
.11787 .1339 Mdot
.14139 .1339 Mdot
.1649 .1339 Mdot
.18842 .1339 Mdot
.21193 .1339 Mdot
.23545 .1339 Mdot
.25897 .1339 Mdot
.28248 .1339 Mdot
.306 .1339 Mdot
.32951 .1339 Mdot
.35303 .1339 Mdot
.37654 .1339 Mdot
.40006 .1339 Mdot
.42357 .1339 Mdot
.44709 .1339 Mdot
.47061 .1339 Mdot
.49412 .1339 Mdot
.51764 .1339 Mdot
.54115 .1339 Mdot
.56467 .1339 Mdot
.58818 .1339 Mdot
.6117 .1339 Mdot
.63521 .1339 Mdot
.65873 .1339 Mdot
.68225 .1339 Mdot
.70576 .1339 Mdot
.72928 .1339 Mdot
.75279 .1339 Mdot
.77631 .1339 Mdot
.79982 .1339 Mdot
.82334 .1339 Mdot
.84685 .1339 Mdot
.87037 .1339 Mdot
.89389 .1339 Mdot
.9174 .1339 Mdot
.94092 .1339 Mdot
.96443 .1339 Mdot
.03557 .15427 Mdot
.05908 .15427 Mdot
.0826 .15427 Mdot
.10611 .15427 Mdot
.12963 .15427 Mdot
.15315 .15427 Mdot
.17666 .15427 Mdot
.20018 .15427 Mdot
.22369 .15427 Mdot
.24721 .15427 Mdot
.27072 .15427 Mdot
.29424 .15427 Mdot
.31775 .15427 Mdot
.34127 .15427 Mdot
.36479 .15427 Mdot
.3883 .15427 Mdot
.41182 .15427 Mdot
.43533 .15427 Mdot
.45885 .15427 Mdot
.48236 .15427 Mdot
.50588 .15427 Mdot
.52939 .15427 Mdot
.55291 .15427 Mdot
.57643 .15427 Mdot
.59994 .15427 Mdot
.62346 .15427 Mdot
.64697 .15427 Mdot
.67049 .15427 Mdot
.694 .15427 Mdot
.71752 .15427 Mdot
.74103 .15427 Mdot
.76455 .15427 Mdot
.78807 .15427 Mdot
.81158 .15427 Mdot
.8351 .15427 Mdot
.85861 .15427 Mdot
.88213 .15427 Mdot
.90564 .15427 Mdot
.92916 .15427 Mdot
.95267 .15427 Mdot
.97619 .15427 Mdot
.02381 .17463 Mdot
.04733 .17463 Mdot
.07084 .17463 Mdot
.09436 .17463 Mdot
.11787 .17463 Mdot
.14139 .17463 Mdot
.1649 .17463 Mdot
.18842 .17463 Mdot
.21193 .17463 Mdot
.23545 .17463 Mdot
.25897 .17463 Mdot
.28248 .17463 Mdot
.306 .17463 Mdot
.32951 .17463 Mdot
.35303 .17463 Mdot
.37654 .17463 Mdot
.40006 .17463 Mdot
.42357 .17463 Mdot
.44709 .17463 Mdot
.47061 .17463 Mdot
.49412 .17463 Mdot
.51764 .17463 Mdot
.54115 .17463 Mdot
.56467 .17463 Mdot
.58818 .17463 Mdot
.6117 .17463 Mdot
.63521 .17463 Mdot
.65873 .17463 Mdot
.68225 .17463 Mdot
.70576 .17463 Mdot
.72928 .17463 Mdot
.75279 .17463 Mdot
.77631 .17463 Mdot
.79982 .17463 Mdot
.82334 .17463 Mdot
.84685 .17463 Mdot
.87037 .17463 Mdot
.89389 .17463 Mdot
.9174 .17463 Mdot
.94092 .17463 Mdot
.96443 .17463 Mdot
.03557 .195 Mdot
.05908 .195 Mdot
.0826 .195 Mdot
.10611 .195 Mdot
.12963 .195 Mdot
.15315 .195 Mdot
.17666 .195 Mdot
.20018 .195 Mdot
.22369 .195 Mdot
.24721 .195 Mdot
.27072 .195 Mdot
.29424 .195 Mdot
.31775 .195 Mdot
.34127 .195 Mdot
.36479 .195 Mdot
.3883 .195 Mdot
.41182 .195 Mdot
.43533 .195 Mdot
.45885 .195 Mdot
.48236 .195 Mdot
.50588 .195 Mdot
.52939 .195 Mdot
.55291 .195 Mdot
.57643 .195 Mdot
.59994 .195 Mdot
.62346 .195 Mdot
.64697 .195 Mdot
.67049 .195 Mdot
.694 .195 Mdot
.71752 .195 Mdot
.74103 .195 Mdot
.76455 .195 Mdot
.78807 .195 Mdot
.81158 .195 Mdot
.8351 .195 Mdot
.85861 .195 Mdot
.88213 .195 Mdot
.90564 .195 Mdot
.92916 .195 Mdot
.95267 .195 Mdot
.97619 .195 Mdot
.02381 .21536 Mdot
.04733 .21536 Mdot
.07084 .21536 Mdot
.09436 .21536 Mdot
.11787 .21536 Mdot
.14139 .21536 Mdot
.1649 .21536 Mdot
.18842 .21536 Mdot
.21193 .21536 Mdot
.23545 .21536 Mdot
.25897 .21536 Mdot
.28248 .21536 Mdot
.306 .21536 Mdot
.32951 .21536 Mdot
.35303 .21536 Mdot
.37654 .21536 Mdot
.40006 .21536 Mdot
.42357 .21536 Mdot
.44709 .21536 Mdot
.47061 .21536 Mdot
.49412 .21536 Mdot
.51764 .21536 Mdot
.54115 .21536 Mdot
.56467 .21536 Mdot
.58818 .21536 Mdot
.6117 .21536 Mdot
.63521 .21536 Mdot
.65873 .21536 Mdot
.68225 .21536 Mdot
.70576 .21536 Mdot
.72928 .21536 Mdot
.75279 .21536 Mdot
.77631 .21536 Mdot
.79982 .21536 Mdot
.82334 .21536 Mdot
.84685 .21536 Mdot
.87037 .21536 Mdot
.89389 .21536 Mdot
.9174 .21536 Mdot
.94092 .21536 Mdot
.96443 .21536 Mdot
.03557 .23573 Mdot
.05908 .23573 Mdot
.0826 .23573 Mdot
.10611 .23573 Mdot
.12963 .23573 Mdot
.15315 .23573 Mdot
.17666 .23573 Mdot
.20018 .23573 Mdot
.22369 .23573 Mdot
.24721 .23573 Mdot
.27072 .23573 Mdot
.29424 .23573 Mdot
.31775 .23573 Mdot
.34127 .23573 Mdot
.36479 .23573 Mdot
.3883 .23573 Mdot
.41182 .23573 Mdot
.43533 .23573 Mdot
.45885 .23573 Mdot
.48236 .23573 Mdot
.50588 .23573 Mdot
.52939 .23573 Mdot
.55291 .23573 Mdot
.57643 .23573 Mdot
.59994 .23573 Mdot
.62346 .23573 Mdot
.64697 .23573 Mdot
.67049 .23573 Mdot
.694 .23573 Mdot
.71752 .23573 Mdot
.74103 .23573 Mdot
.76455 .23573 Mdot
.78807 .23573 Mdot
.81158 .23573 Mdot
.8351 .23573 Mdot
.85861 .23573 Mdot
.88213 .23573 Mdot
.90564 .23573 Mdot
.92916 .23573 Mdot
.95267 .23573 Mdot
.97619 .23573 Mdot
.02381 .25609 Mdot
.04733 .25609 Mdot
.07084 .25609 Mdot
.09436 .25609 Mdot
.11787 .25609 Mdot
.14139 .25609 Mdot
.1649 .25609 Mdot
.18842 .25609 Mdot
.21193 .25609 Mdot
.23545 .25609 Mdot
.25897 .25609 Mdot
.28248 .25609 Mdot
.306 .25609 Mdot
.32951 .25609 Mdot
.35303 .25609 Mdot
.37654 .25609 Mdot
.40006 .25609 Mdot
.42357 .25609 Mdot
.44709 .25609 Mdot
.47061 .25609 Mdot
.49412 .25609 Mdot
.51764 .25609 Mdot
.54115 .25609 Mdot
.56467 .25609 Mdot
.58818 .25609 Mdot
.6117 .25609 Mdot
.63521 .25609 Mdot
.65873 .25609 Mdot
.68225 .25609 Mdot
.70576 .25609 Mdot
.72928 .25609 Mdot
.75279 .25609 Mdot
.77631 .25609 Mdot
.79982 .25609 Mdot
.82334 .25609 Mdot
.84685 .25609 Mdot
.87037 .25609 Mdot
.89389 .25609 Mdot
.9174 .25609 Mdot
.94092 .25609 Mdot
.96443 .25609 Mdot
.03557 .27646 Mdot
.05908 .27646 Mdot
.0826 .27646 Mdot
.10611 .27646 Mdot
.12963 .27646 Mdot
.15315 .27646 Mdot
.17666 .27646 Mdot
.20018 .27646 Mdot
.22369 .27646 Mdot
.24721 .27646 Mdot
.27072 .27646 Mdot
.29424 .27646 Mdot
.31775 .27646 Mdot
.34127 .27646 Mdot
.36479 .27646 Mdot
.3883 .27646 Mdot
.41182 .27646 Mdot
.43533 .27646 Mdot
.45885 .27646 Mdot
.48236 .27646 Mdot
.50588 .27646 Mdot
.52939 .27646 Mdot
.55291 .27646 Mdot
.57643 .27646 Mdot
.59994 .27646 Mdot
.62346 .27646 Mdot
.64697 .27646 Mdot
.67049 .27646 Mdot
.694 .27646 Mdot
.71752 .27646 Mdot
.74103 .27646 Mdot
.76455 .27646 Mdot
.78807 .27646 Mdot
.81158 .27646 Mdot
.8351 .27646 Mdot
.85861 .27646 Mdot
.88213 .27646 Mdot
.90564 .27646 Mdot
.92916 .27646 Mdot
.95267 .27646 Mdot
.97619 .27646 Mdot
.02381 .29682 Mdot
.04733 .29682 Mdot
.07084 .29682 Mdot
.09436 .29682 Mdot
.11787 .29682 Mdot
.14139 .29682 Mdot
.1649 .29682 Mdot
.18842 .29682 Mdot
.21193 .29682 Mdot
.23545 .29682 Mdot
.25897 .29682 Mdot
.28248 .29682 Mdot
.306 .29682 Mdot
.32951 .29682 Mdot
.35303 .29682 Mdot
.37654 .29682 Mdot
.40006 .29682 Mdot
.42357 .29682 Mdot
.44709 .29682 Mdot
.47061 .29682 Mdot
.49412 .29682 Mdot
.51764 .29682 Mdot
.54115 .29682 Mdot
.56467 .29682 Mdot
.58818 .29682 Mdot
.6117 .29682 Mdot
.63521 .29682 Mdot
.65873 .29682 Mdot
.68225 .29682 Mdot
.70576 .29682 Mdot
.72928 .29682 Mdot
.75279 .29682 Mdot
.77631 .29682 Mdot
.79982 .29682 Mdot
.82334 .29682 Mdot
.84685 .29682 Mdot
.87037 .29682 Mdot
.89389 .29682 Mdot
.9174 .29682 Mdot
.94092 .29682 Mdot
.96443 .29682 Mdot
.03557 .31719 Mdot
.05908 .31719 Mdot
.0826 .31719 Mdot
.10611 .31719 Mdot
.12963 .31719 Mdot
.15315 .31719 Mdot
.17666 .31719 Mdot
.20018 .31719 Mdot
.22369 .31719 Mdot
.24721 .31719 Mdot
.27072 .31719 Mdot
.29424 .31719 Mdot
.31775 .31719 Mdot
.34127 .31719 Mdot
.36479 .31719 Mdot
.3883 .31719 Mdot
.41182 .31719 Mdot
.43533 .31719 Mdot
.45885 .31719 Mdot
.48236 .31719 Mdot
.50588 .31719 Mdot
.52939 .31719 Mdot
.55291 .31719 Mdot
.57643 .31719 Mdot
.59994 .31719 Mdot
.62346 .31719 Mdot
.64697 .31719 Mdot
.67049 .31719 Mdot
.694 .31719 Mdot
.71752 .31719 Mdot
.74103 .31719 Mdot
.76455 .31719 Mdot
.78807 .31719 Mdot
.81158 .31719 Mdot
.8351 .31719 Mdot
.85861 .31719 Mdot
.88213 .31719 Mdot
.90564 .31719 Mdot
.92916 .31719 Mdot
.95267 .31719 Mdot
.97619 .31719 Mdot
.02381 .33755 Mdot
.04733 .33755 Mdot
.07084 .33755 Mdot
.09436 .33755 Mdot
.11787 .33755 Mdot
.14139 .33755 Mdot
.1649 .33755 Mdot
.18842 .33755 Mdot
.21193 .33755 Mdot
.23545 .33755 Mdot
.25897 .33755 Mdot
.28248 .33755 Mdot
.306 .33755 Mdot
.32951 .33755 Mdot
.35303 .33755 Mdot
.37654 .33755 Mdot
.40006 .33755 Mdot
.42357 .33755 Mdot
.44709 .33755 Mdot
.47061 .33755 Mdot
.49412 .33755 Mdot
.51764 .33755 Mdot
.54115 .33755 Mdot
.56467 .33755 Mdot
.58818 .33755 Mdot
.6117 .33755 Mdot
.63521 .33755 Mdot
.65873 .33755 Mdot
.68225 .33755 Mdot
.70576 .33755 Mdot
.72928 .33755 Mdot
.75279 .33755 Mdot
.77631 .33755 Mdot
.79982 .33755 Mdot
.82334 .33755 Mdot
.84685 .33755 Mdot
.87037 .33755 Mdot
.89389 .33755 Mdot
.9174 .33755 Mdot
.94092 .33755 Mdot
.96443 .33755 Mdot
.03557 .35792 Mdot
.05908 .35792 Mdot
.0826 .35792 Mdot
.10611 .35792 Mdot
.12963 .35792 Mdot
.15315 .35792 Mdot
.17666 .35792 Mdot
.20018 .35792 Mdot
.22369 .35792 Mdot
.24721 .35792 Mdot
.27072 .35792 Mdot
.29424 .35792 Mdot
.31775 .35792 Mdot
.34127 .35792 Mdot
.36479 .35792 Mdot
.3883 .35792 Mdot
.41182 .35792 Mdot
.43533 .35792 Mdot
.45885 .35792 Mdot
.48236 .35792 Mdot
.50588 .35792 Mdot
.52939 .35792 Mdot
.55291 .35792 Mdot
.57643 .35792 Mdot
.59994 .35792 Mdot
.62346 .35792 Mdot
.64697 .35792 Mdot
.67049 .35792 Mdot
.694 .35792 Mdot
.71752 .35792 Mdot
.74103 .35792 Mdot
.76455 .35792 Mdot
.78807 .35792 Mdot
.81158 .35792 Mdot
.8351 .35792 Mdot
.85861 .35792 Mdot
.88213 .35792 Mdot
.90564 .35792 Mdot
.92916 .35792 Mdot
.95267 .35792 Mdot
.97619 .35792 Mdot
.02381 .37828 Mdot
.04733 .37828 Mdot
.07084 .37828 Mdot
.09436 .37828 Mdot
.11787 .37828 Mdot
.14139 .37828 Mdot
.1649 .37828 Mdot
.18842 .37828 Mdot
.21193 .37828 Mdot
.23545 .37828 Mdot
.25897 .37828 Mdot
.28248 .37828 Mdot
.306 .37828 Mdot
.32951 .37828 Mdot
.35303 .37828 Mdot
.37654 .37828 Mdot
.40006 .37828 Mdot
.42357 .37828 Mdot
.44709 .37828 Mdot
.47061 .37828 Mdot
.49412 .37828 Mdot
.51764 .37828 Mdot
.54115 .37828 Mdot
.56467 .37828 Mdot
.58818 .37828 Mdot
.6117 .37828 Mdot
.63521 .37828 Mdot
.65873 .37828 Mdot
.68225 .37828 Mdot
.70576 .37828 Mdot
.72928 .37828 Mdot
.75279 .37828 Mdot
.77631 .37828 Mdot
.79982 .37828 Mdot
.82334 .37828 Mdot
.84685 .37828 Mdot
.87037 .37828 Mdot
.89389 .37828 Mdot
.9174 .37828 Mdot
.94092 .37828 Mdot
.96443 .37828 Mdot
.03557 .39865 Mdot
.05908 .39865 Mdot
.0826 .39865 Mdot
.10611 .39865 Mdot
.12963 .39865 Mdot
.15315 .39865 Mdot
.17666 .39865 Mdot
.20018 .39865 Mdot
.22369 .39865 Mdot
.24721 .39865 Mdot
.27072 .39865 Mdot
.29424 .39865 Mdot
.31775 .39865 Mdot
.34127 .39865 Mdot
.36479 .39865 Mdot
.3883 .39865 Mdot
.41182 .39865 Mdot
.43533 .39865 Mdot
.45885 .39865 Mdot
.48236 .39865 Mdot
.50588 .39865 Mdot
.52939 .39865 Mdot
.55291 .39865 Mdot
.57643 .39865 Mdot
.59994 .39865 Mdot
.62346 .39865 Mdot
.64697 .39865 Mdot
.67049 .39865 Mdot
.694 .39865 Mdot
.71752 .39865 Mdot
.74103 .39865 Mdot
.76455 .39865 Mdot
.78807 .39865 Mdot
.81158 .39865 Mdot
.8351 .39865 Mdot
.85861 .39865 Mdot
.88213 .39865 Mdot
.90564 .39865 Mdot
.92916 .39865 Mdot
.95267 .39865 Mdot
.97619 .39865 Mdot
.02381 .41901 Mdot
.04733 .41901 Mdot
.07084 .41901 Mdot
.09436 .41901 Mdot
.11787 .41901 Mdot
.14139 .41901 Mdot
.1649 .41901 Mdot
.18842 .41901 Mdot
.21193 .41901 Mdot
.23545 .41901 Mdot
.25897 .41901 Mdot
.28248 .41901 Mdot
.306 .41901 Mdot
.32951 .41901 Mdot
.35303 .41901 Mdot
.37654 .41901 Mdot
.40006 .41901 Mdot
.42357 .41901 Mdot
.44709 .41901 Mdot
.47061 .41901 Mdot
.49412 .41901 Mdot
.51764 .41901 Mdot
.54115 .41901 Mdot
.56467 .41901 Mdot
.58818 .41901 Mdot
.6117 .41901 Mdot
.63521 .41901 Mdot
.65873 .41901 Mdot
.68225 .41901 Mdot
.70576 .41901 Mdot
.72928 .41901 Mdot
.75279 .41901 Mdot
.77631 .41901 Mdot
.79982 .41901 Mdot
.82334 .41901 Mdot
.84685 .41901 Mdot
.87037 .41901 Mdot
.89389 .41901 Mdot
.9174 .41901 Mdot
.94092 .41901 Mdot
.96443 .41901 Mdot
.03557 .43938 Mdot
.05908 .43938 Mdot
.0826 .43938 Mdot
.10611 .43938 Mdot
.12963 .43938 Mdot
.15315 .43938 Mdot
.17666 .43938 Mdot
.20018 .43938 Mdot
.22369 .43938 Mdot
.24721 .43938 Mdot
.27072 .43938 Mdot
.29424 .43938 Mdot
.31775 .43938 Mdot
.34127 .43938 Mdot
.36479 .43938 Mdot
.3883 .43938 Mdot
.41182 .43938 Mdot
.43533 .43938 Mdot
.45885 .43938 Mdot
.48236 .43938 Mdot
.50588 .43938 Mdot
.52939 .43938 Mdot
.55291 .43938 Mdot
.57643 .43938 Mdot
.59994 .43938 Mdot
.62346 .43938 Mdot
.64697 .43938 Mdot
.67049 .43938 Mdot
.694 .43938 Mdot
.71752 .43938 Mdot
.74103 .43938 Mdot
.76455 .43938 Mdot
.78807 .43938 Mdot
.81158 .43938 Mdot
.8351 .43938 Mdot
.85861 .43938 Mdot
.88213 .43938 Mdot
.90564 .43938 Mdot
.92916 .43938 Mdot
.95267 .43938 Mdot
.97619 .43938 Mdot
.02381 .45974 Mdot
.04733 .45974 Mdot
.07084 .45974 Mdot
.09436 .45974 Mdot
.11787 .45974 Mdot
.14139 .45974 Mdot
.1649 .45974 Mdot
.18842 .45974 Mdot
.21193 .45974 Mdot
.23545 .45974 Mdot
.25897 .45974 Mdot
.28248 .45974 Mdot
.306 .45974 Mdot
.32951 .45974 Mdot
.35303 .45974 Mdot
.37654 .45974 Mdot
.40006 .45974 Mdot
.42357 .45974 Mdot
.44709 .45974 Mdot
.47061 .45974 Mdot
.49412 .45974 Mdot
.51764 .45974 Mdot
.54115 .45974 Mdot
.56467 .45974 Mdot
.58818 .45974 Mdot
.6117 .45974 Mdot
.63521 .45974 Mdot
.65873 .45974 Mdot
.68225 .45974 Mdot
.70576 .45974 Mdot
.72928 .45974 Mdot
.75279 .45974 Mdot
.77631 .45974 Mdot
.79982 .45974 Mdot
.82334 .45974 Mdot
.84685 .45974 Mdot
.87037 .45974 Mdot
.89389 .45974 Mdot
.9174 .45974 Mdot
.94092 .45974 Mdot
.96443 .45974 Mdot
.03557 .48011 Mdot
.05908 .48011 Mdot
.0826 .48011 Mdot
.10611 .48011 Mdot
.12963 .48011 Mdot
.15315 .48011 Mdot
.17666 .48011 Mdot
.20018 .48011 Mdot
.22369 .48011 Mdot
.24721 .48011 Mdot
.27072 .48011 Mdot
.29424 .48011 Mdot
.31775 .48011 Mdot
.34127 .48011 Mdot
.36479 .48011 Mdot
.3883 .48011 Mdot
.41182 .48011 Mdot
.43533 .48011 Mdot
.45885 .48011 Mdot
.48236 .48011 Mdot
.50588 .48011 Mdot
.52939 .48011 Mdot
.55291 .48011 Mdot
.57643 .48011 Mdot
.59994 .48011 Mdot
.62346 .48011 Mdot
.64697 .48011 Mdot
.67049 .48011 Mdot
.694 .48011 Mdot
.71752 .48011 Mdot
.74103 .48011 Mdot
.76455 .48011 Mdot
.78807 .48011 Mdot
.81158 .48011 Mdot
.8351 .48011 Mdot
.85861 .48011 Mdot
.88213 .48011 Mdot
.90564 .48011 Mdot
.92916 .48011 Mdot
.95267 .48011 Mdot
.97619 .48011 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[6]:=",
  ImageSize->{288, 141.625},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000e1000`40O003h00Oofmk/Fmk003oKg^a
Kg/00=E_N`03001_Nfmk0=Q_N`00afmk1`001fmk00<006mkKg/0f6mk003:Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`3HKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40005Kg/60005Kg/40006Kg/50005Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000i_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`00bVmk
00<006mkKg/026mk00<006mkKg/0f6mk0038Kg/3000:Kg/00`00Kg]_N`3HKg/00<Y_N`03001_Nfmk
00Q_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_
NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/20002
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
0=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk000>Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10004fmk000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/2000DKg/00=E_N`800=U_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3H
Kg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_N`004Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk
10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk
000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00
eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk
000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000DKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000m_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/4
0006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_Nfmk
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00]Vmk10001Vmk0P001Vmk10002Fmk00<006mkKg/0f6mk
002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`3HKg/00;E_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk00I_N`03001_Nfmk
0=Q_N`00]Fmk00<006mkKg/00Vmk00<006mkKg/03fmk00<006mkKg/01Vmk0`00f6mk000>Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/60003Kg/30002Kg/00`00Kg]_N`03Kg/20008
Kg/30007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_
N`@00003Kg/006mk00=_N`@000E_N`D000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Fmk10001Vmk10001Vmk100000=_N`00Kg/00fmk10001Fmk1@001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20007Kg/30002Kg/00`00Kg]_N`03Kg/2
0006Kg/01000Kg/0000026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0056mk002fKg/4000>Kg/50008Kg/00`00Kg]_N`3HKg/00=E_N`03
001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000=_N`800003Kg/00000008000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/01000Kg]_
Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk
003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000e_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<0
06mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00m_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`80009_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_
N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0011_N`H005e_N`L005]_N`03001_Nfmk
05a_N`L005a_N`H001=_N`0046mk00<006mkKg/00Vmk00<006mkKg/0GVmk00<006mkKg/0G6mk00<0
06mkKg/0Gfmk00<006mkKg/0GFmk00<006mkKg/00Vmk00<006mkKg/04Fmk000>Kg/200000fmk001_
N`05Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0003Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20006Kg/01000Kg/0000056mk000=Kg/400000fmk001_N`03Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40002Kg/01000Kg]_Nfmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk0007Kg/:
0002Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk3P000Vmk00@006mkKg]_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@001=_N`003Vmk0P0016mk00@006mkKg]_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000=_N`03001_Nfmk009_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`0046mk00<0
06mkKg/00Vmk00<006mkKg/0GVmk00<006mkKg/0G6mk00<006mkKg/0Gfmk00<006mkKg/0GFmk00<0
06mkKg/00Vmk00<006mkKg/04Fmk000@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`1LKg/3001NKg/2001N
Kg/3001OKg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/0015_N`@0065_N`03001_Nfmk05a_N`03001_
Nfmk05m_N`03001_Nfmk05i_N`@001A_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
01=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk
10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk
000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`001Fmk
o`00YP001Vmk000?Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0CKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/0
00i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8001A_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/2003IKg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000=_N`03001_
Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P00
26mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00
Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
00i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`00eFmk00<006mkKg/0f6mk
003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00
Kg]_N`3HKg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000=_N`800003Kg/00000008000I_N`@000I_N`@0
00I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<0
06mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_
Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00
3Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0056mk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/4000CKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/0
0=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_
NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0009_N`P0
009_N`80009_N`P0009_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk100000=_N`00Kg/00fmk10000Vmk0P000Vmk100016mk00<006mk0000
0`000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008
Kg/20002Kg/00`00Kg]_N`02Kg/30008Kg/20005Kg/00`00Kg]_N`020004Kg/01000Kg]_Nfmk0P00
26mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
3fmk002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/3003HKg/00;E_N`03001_
Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk00I_N`03001_Nfmk0=Q_N`00]Fmk00<006mkKg/00Vmk
00<006mkKg/02fmk10002Fmk00<006mkKg/0f6mk002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`3HKg/00;E_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk
00Y_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk10001Vmk0P001Vmk1@001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000e_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Vmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk
003EKg/00`00Kg]_N`3HKg/00=E_N`800=U_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3H
Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_
N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/01000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
3Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00
eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
000CKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`80009_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_N`004Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<0
06mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/2
0008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/00=E_N`03
001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000D
Kg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00<M_N`L0
00M_N`03001_Nfmk0=Q_N`00bVmk00<006mkKg/026mk00<006mkKg/0f6mk000CKg/20008Kg/20008
Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20003Kg/00`00Kg]_N`02Kg/20004
Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P003fmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/4
0006Kg/40006Kg/40002Kg/01000Kg]_Nfmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40002Kg/01000Kg]_Nfmk1000
0fmk1`001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20003Kg/00`00Kg]_N`02Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003:Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`3HKg/00<Q_N`<000Y_N`03001_Nfmk0=Q_N`00bVmk00<006mkKg/026mk00<006mkKg/0
f6mk003oKg^aKg/00?m_Nk5_N`00\
\>"],
  ImageRangeCache->{{{0, 431}, {211.438, 0}} -> {-2.15247, -1.06821, \
0.0151564, 0.0151564}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  "Function ",
  StyleBox["selectMeshpoints",
    FontFamily->"Courier"],
  " use the distance function to select only meshpoints within the defined \
region (corresponding to part of ",
  StyleBox["step 2",
    FontSlant->"Italic"],
  " in the paper)."
}], "Text"],

Cell[BoxData[
    \(\(selectMeshpoints[d_, \ {x1_, y1_, x2_, y2_}, h0_] := 
        Select[seedMeshpoints[{x1, y1, x2, y2}, h0], 
          d[#] < 0 &];\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[TextData[{
  "The distance function ",
  StyleBox["dcircle",
    FontFamily->"Courier"],
  " selects meshpoints within a disk."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(selectMeshpoints[dcircle[#, {0, 0, 0.5}] &, {\(-2\), \(-1\), \ 2, 1}, 
        0.1] // ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[8]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.05848 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.0582 0.533545 1.0582 [
[.07672 .52105 -12 -9 ]
[.07672 .52105 12 0 ]
[.28836 .52105 -12 -9 ]
[.28836 .52105 12 0 ]
[.71164 .52105 -9 -9 ]
[.71164 .52105 9 0 ]
[.92328 .52105 -9 -9 ]
[.92328 .52105 9 0 ]
[.4875 .11027 -24 -4.5 ]
[.4875 .11027 0 4.5 ]
[.4875 .32191 -24 -4.5 ]
[.4875 .32191 0 4.5 ]
[.4875 .74519 -18 -4.5 ]
[.4875 .74519 0 4.5 ]
[.4875 .95683 -18 -4.5 ]
[.4875 .95683 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.05848 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07672 .53355 m
.07672 .5398 L
s
[(-0.4)] .07672 .52105 0 1 Mshowa
.28836 .53355 m
.28836 .5398 L
s
[(-0.2)] .28836 .52105 0 1 Mshowa
.71164 .53355 m
.71164 .5398 L
s
[(0.2)] .71164 .52105 0 1 Mshowa
.92328 .53355 m
.92328 .5398 L
s
[(0.4)] .92328 .52105 0 1 Mshowa
.125 Mabswid
.12963 .53355 m
.12963 .5373 L
s
.18254 .53355 m
.18254 .5373 L
s
.23545 .53355 m
.23545 .5373 L
s
.34127 .53355 m
.34127 .5373 L
s
.39418 .53355 m
.39418 .5373 L
s
.44709 .53355 m
.44709 .5373 L
s
.55291 .53355 m
.55291 .5373 L
s
.60582 .53355 m
.60582 .5373 L
s
.65873 .53355 m
.65873 .5373 L
s
.76455 .53355 m
.76455 .5373 L
s
.81746 .53355 m
.81746 .5373 L
s
.87037 .53355 m
.87037 .5373 L
s
.02381 .53355 m
.02381 .5373 L
s
.97619 .53355 m
.97619 .5373 L
s
.25 Mabswid
0 .53355 m
1 .53355 L
s
.5 .11027 m
.50625 .11027 L
s
[(-0.4)] .4875 .11027 1 0 Mshowa
.5 .32191 m
.50625 .32191 L
s
[(-0.2)] .4875 .32191 1 0 Mshowa
.5 .74519 m
.50625 .74519 L
s
[(0.2)] .4875 .74519 1 0 Mshowa
.5 .95683 m
.50625 .95683 L
s
[(0.4)] .4875 .95683 1 0 Mshowa
.125 Mabswid
.5 .16318 m
.50375 .16318 L
s
.5 .21609 m
.50375 .21609 L
s
.5 .269 m
.50375 .269 L
s
.5 .37482 m
.50375 .37482 L
s
.5 .42773 m
.50375 .42773 L
s
.5 .48064 m
.50375 .48064 L
s
.5 .58646 m
.50375 .58646 L
s
.5 .63937 m
.50375 .63937 L
s
.5 .69228 m
.50375 .69228 L
s
.5 .7981 m
.50375 .7981 L
s
.5 .85101 m
.50375 .85101 L
s
.5 .90392 m
.50375 .90392 L
s
.5 .05735 m
.50375 .05735 L
s
.5 .00444 m
.50375 .00444 L
s
.5 1.00974 m
.50375 1.00974 L
s
.25 Mabswid
.5 0 m
.5 1.05848 L
s
0 0 m
1 0 L
1 1.05848 L
0 1.05848 L
closepath
clip
newpath
.01 w
.39418 .0252 Mdot
.5 .0252 Mdot
.60582 .0252 Mdot
.23545 .11684 Mdot
.34127 .11684 Mdot
.44709 .11684 Mdot
.55291 .11684 Mdot
.65873 .11684 Mdot
.76455 .11684 Mdot
.18254 .20849 Mdot
.28836 .20849 Mdot
.39418 .20849 Mdot
.5 .20849 Mdot
.60582 .20849 Mdot
.71164 .20849 Mdot
.81746 .20849 Mdot
.12963 .30013 Mdot
.23545 .30013 Mdot
.34127 .30013 Mdot
.44709 .30013 Mdot
.55291 .30013 Mdot
.65873 .30013 Mdot
.76455 .30013 Mdot
.87037 .30013 Mdot
.07672 .39177 Mdot
.18254 .39177 Mdot
.28836 .39177 Mdot
.39418 .39177 Mdot
.5 .39177 Mdot
.60582 .39177 Mdot
.71164 .39177 Mdot
.81746 .39177 Mdot
.92328 .39177 Mdot
.02381 .48342 Mdot
.12963 .48342 Mdot
.23545 .48342 Mdot
.34127 .48342 Mdot
.44709 .48342 Mdot
.55291 .48342 Mdot
.65873 .48342 Mdot
.76455 .48342 Mdot
.87037 .48342 Mdot
.97619 .48342 Mdot
.07672 .57506 Mdot
.18254 .57506 Mdot
.28836 .57506 Mdot
.39418 .57506 Mdot
.5 .57506 Mdot
.60582 .57506 Mdot
.71164 .57506 Mdot
.81746 .57506 Mdot
.92328 .57506 Mdot
.02381 .6667 Mdot
.12963 .6667 Mdot
.23545 .6667 Mdot
.34127 .6667 Mdot
.44709 .6667 Mdot
.55291 .6667 Mdot
.65873 .6667 Mdot
.76455 .6667 Mdot
.87037 .6667 Mdot
.97619 .6667 Mdot
.07672 .75834 Mdot
.18254 .75834 Mdot
.28836 .75834 Mdot
.39418 .75834 Mdot
.5 .75834 Mdot
.60582 .75834 Mdot
.71164 .75834 Mdot
.81746 .75834 Mdot
.92328 .75834 Mdot
.12963 .84999 Mdot
.23545 .84999 Mdot
.34127 .84999 Mdot
.44709 .84999 Mdot
.55291 .84999 Mdot
.65873 .84999 Mdot
.76455 .84999 Mdot
.87037 .84999 Mdot
.18254 .94163 Mdot
.28836 .94163 Mdot
.39418 .94163 Mdot
.5 .94163 Mdot
.60582 .94163 Mdot
.71164 .94163 Mdot
.81746 .94163 Mdot
.34127 1.03327 Mdot
.44709 1.03327 Mdot
.55291 1.03327 Mdot
.65873 1.03327 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[8]:=",
  ImageSize->{288, 304.813},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001bA000`40O003h00Oefmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk002YKg/2000[Kg/2000/Kg/2002ZKg/00:Q_N`@0
02U_N`@002Y_N`@00:U_N`00Z6mk1000:Fmk1000:Vmk1000ZFmk002YKg/2000[Kg/2000/Kg/2002Z
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00;U_N`@000I_N`8000M_N`@000M_N`03001_Nfmk0=I_
N`00^6mk00<006mkKg/00Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/01Vmk00<006mkKg/0eVmk
002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`3FKg/00;Q_N`03
001_Nfmk009_N`03001_Nfmk00Y_N`H000M_N`03001_Nfmk0=I_N`00[fmk1P000fmk00<006mkKg/0
0Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`@00=E_N`00I6mk0P00;6mk0P0096mk00<006mkKg/0
0Vmk00<006mkKg/00P002Fmk00@006mkKg/000Q_N`03001_Nfmk01=_N`8002a_N`8002]_N`8006I_
N`00Hfmk1000:Vmk10008fmk00<006mkKg/00Vmk00<006mk00000`002Fmk00<006mk000026mk00<0
06mkKg/04Vmk1000:Vmk1000:Fmk1000IFmk001SKg/4000ZKg/4000SKg/00`00Kg]_N`02Kg/00`00
Kg/000030009Kg/00`00Kg/00008Kg/00`00Kg]_N`0BKg/4000ZKg/4000YKg/4001UKg/006A_N`80
02a_N`8002E_N`@000=_N`8000]_N`8000Q_N`03001_Nfmk01=_N`8002a_N`8002]_N`8006I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk0`00eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00CVmk0P00:fmk0P00;6mk0P00:fmk0P00;6mk0P00;6mk0P00:fmk0P00Cfmk001=Kg/4000Y
Kg/4000ZKg/4000YKg/4000ZKg/4000ZKg/4000YKg/4001>Kg/004e_N`@002U_N`@002Y_N`@002U_
N`@002Y_N`@002Y_N`@002U_N`@004i_N`00CVmk0P00:fmk0P00;6mk0P00:fmk0P00;6mk0P00;6mk
0P00:fmk0P00Cfmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk0`00eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00=fmk
0P00:fmk0P00;6mk0P00;6mk0P005Fmk00<006mkKg/04fmk0P00;6mk0P00:fmk0P00;6mk0P00>6mk
000fKg/4000YKg/4000ZKg/4000ZKg/4000DKg/00`00Kg]_N`0BKg/4000ZKg/4000YKg/4000ZKg/4
000gKg/003I_N`@002U_N`@002Y_N`@002Y_N`@001A_N`03001_Nfmk019_N`@002Y_N`@002U_N`@0
02Y_N`@003M_N`00=fmk0P00:fmk0P00;6mk0P00;6mk0P005Fmk00<006mkKg/04fmk0P00;6mk0P00
:fmk0P00;6mk0P00>6mk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00;U_N`@000I_N`8000E_N`H000M_N`03001_Nfmk0=I_N`00
^6mk00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<0
06mkKg/0eVmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/00`00Kg]_N`3F
Kg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk00Q_N`@00=E_N`00[fmk1P000fmk
00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/01fmk00<006mkKg/0eVmk002hKg/00`00Kg]_
N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03
001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/0
0Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0eVmk002iKg/4000>
Kg/40008Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk000PKg/2000/Kg/2000[
Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000[Kg/2000/Kg/2000QKg/001m_N`@002Y_N`@002U_
N`@002Y_N`@002U_N`@002Y_N`@002Y_N`@002U_N`@002Y_N`@0021_N`007fmk1000:Vmk1000:Fmk
1000:Vmk1000:Fmk1000:Vmk1000:Vmk1000:Fmk1000:Vmk100086mk000PKg/2000/Kg/2000[Kg/2
000/Kg/2000[Kg/2000/Kg/2000/Kg/2000[Kg/2000/Kg/2000QKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk0`00eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_
Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk0009Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2
000EKg/3000CKg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000:Kg/000Q_N`@002Y_N`@002U_N`@0
02Y_N`@002Y_N`@001A_N`03001_Nfmk019_N`@002Y_N`@002U_N`@002Y_N`@002Y_N`@000U_N`00
26mk1000:Vmk1000:Fmk1000:Vmk1000:Vmk100056mk00<006mkKg/04Vmk1000:Vmk1000:Fmk1000
:Vmk1000:Vmk10002Fmk0009Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000EKg/00`00Kg]_N`0C
Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000:Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk000JKg/40006Kg/20007Kg/40014Kg/40006Kg/20005Kg/6001;Kg/00`00Kg]_N`1=Kg/4
0006Kg/20005Kg/60014Kg/40006Kg/20007Kg/4000GKg/001U_N`03001_Nfmk009_N`03001_Nfmk
00=_N`8000U_N`03001_Nfmk049_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000E_N`03001_Nfmk
009_N`03001_Nfmk04U_N`03001_Nfmk04a_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000E_N`03
001_Nfmk009_N`03001_Nfmk045_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000U_N`03001_Nfmk
01I_N`006Fmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/0@Vmk00<006mkKg/00Vmk00<0
06mkKg/02fmk00<006mkKg/0CFmk00<006mkKg/0C6mk00<006mkKg/00Vmk00<006mkKg/02fmk00<0
06mkKg/0AFmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/05Vmk000IKg/00`00Kg]_N`02
Kg/00`00Kg]_N`0:Kg/60013Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`1<Kg/00`00
Kg]_N`1<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`14Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0:Kg/6000GKg/0011_N`H000=_N`03001_Nfmk009_N`03001_Nfmk00]_N`04001_Nfmk000k
Kg/60003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`1;Kg/00`00Kg]_N`1<Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`13Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/01000
Kg]_N`0066mk000IKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/01000Kg]_N`00A6mk00<006mkKg/0
0Vmk00<006mkKg/03Vmk00<006mkKg/0BVmk00<006mkKg/0C6mk00<006mkKg/00Vmk00<006mkKg/0
3Vmk00<006mkKg/0@Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/001Q_N`006Fmk00<0
06mkKg/00Vmk00<006mkKg/036mk00<006mk0000A6mk00<006mkKg/00Vmk00<006mkKg/02Vmk00<0
06mkKg/00Vmk00<006mkKg/0BFmk00<006mkKg/0C6mk00<006mkKg/00Vmk00<006mkKg/02Vmk00<0
06mkKg/00Vmk00<006mkKg/0@Fmk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk000066mk000I
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg/00014Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`19Kg/00`00Kg]_N`1<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`11Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg/0000H
Kg/001Y_N`@0011_N`8004E_N`@000i_N`@004a_N`03001_Nfmk04e_N`@000i_N`@004E_N`@0011_
N`8001Q_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00?l00;00005_N`002Vmk00<006mkKg/056mk00<006mkKg/0
4fmk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/0
4fmk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/0
4fmk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/056mk00<006mkKg/0
4fmk00<006mkKg/056mk00<006mkKg/02Fmk000:Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0CKg/00`00
Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0CKg/00`00
Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0CKg/00`00
Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0DKg/00`00Kg]_N`0CKg/00`00
Kg]_N`0DKg/00`00Kg]_N`09Kg/0025_N`03001_Nfmk05Q_N`03001_Nfmk05Q_N`03001_Nfmk05Q_
N`03001_Nfmk05Q_N`03001_Nfmk021_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/0
0=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_
Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk000PKg/2000/Kg/2000[Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000[Kg/2000/Kg/2
000QKg/001m_N`@002Y_N`@002U_N`@002Y_N`@002U_N`@002Y_N`@002Y_N`@002U_N`@002Y_N`@0
021_N`007fmk1000:Vmk1000:Fmk1000:Vmk1000:Fmk1000:Vmk1000:Vmk1000:Fmk1000:Vmk1000
86mk000PKg/2000/Kg/2000[Kg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000[Kg/2000/Kg/2000Q
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/3003FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk0`00eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk0009Kg/2000/Kg/2000[
Kg/2000/Kg/2000/Kg/2000EKg/00`00Kg]_N`0CKg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000:
Kg/000Q_N`@002Y_N`@002U_N`@002Y_N`@002Y_N`@001A_N`03001_Nfmk019_N`@002Y_N`@002U_
N`@002Y_N`@002Y_N`@000U_N`0026mk1000:Vmk1000:Fmk1000:Vmk1000:Vmk100056mk00<006mk
Kg/04Vmk1000:Vmk1000:Fmk1000:Vmk1000:Vmk10002Fmk0009Kg/2000/Kg/2000[Kg/2000/Kg/2
000/Kg/2000EKg/00`00Kg]_N`0CKg/2000/Kg/2000[Kg/2000/Kg/2000/Kg/2000:Kg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00^Fmk10001Vmk0P001Fmk
1P001fmk00<006mkKg/0eVmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00]_N`03
001_Nfmk00U_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/036mk00<006mkKg/0
26mk1000eFmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`07Kg/00`00Kg]_N`3F
Kg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk0=I_N`00^6mk
00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0eVmk
002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`3FKg/0021_N`8002a_N`8002]_N`8002a_N`8000i_N`@000i_N`@000M_N`8002a_N`8002a_N`80
02]_N`8002a_N`80025_N`007fmk1000:Vmk1000:Fmk1000:Vmk1000:Fmk1000:Vmk1000:Vmk1000
:Fmk1000:Vmk100086mk000OKg/4000ZKg/4000YKg/4000ZKg/4000YKg/4000ZKg/4000ZKg/4000Y
Kg/4000ZKg/4000PKg/0021_N`8002a_N`8002]_N`8002a_N`8002]_N`8002a_N`8002a_N`8002]_
N`8002a_N`80025_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/003M_N`8002]_N`8002a_N`8002a_N`8001E_N`03001_Nfmk01=_N`8002a_N`8002]_N`8002a_
N`8003Q_N`00=Vmk1000:Fmk1000:Vmk1000:Vmk100056mk00<006mkKg/04Vmk1000:Vmk1000:Fmk
1000:Vmk1000=fmk000fKg/4000YKg/4000ZKg/4000ZKg/4000DKg/3000BKg/4000ZKg/4000YKg/4
000ZKg/4000gKg/003M_N`8002]_N`8002a_N`8002a_N`8001E_N`03001_Nfmk01=_N`8002a_N`80
02]_N`8002a_N`8003Q_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_
Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk0`00eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00CVmk0P00:fmk0P00;6mk0P00:fmk0P00;6mk0P00;6mk0P00
:fmk0P00Cfmk001=Kg/4000YKg/4000ZKg/4000YKg/4000ZKg/4000ZKg/4000YKg/4001>Kg/004e_
N`@002U_N`@002Y_N`@002U_N`@002Y_N`@002Y_N`@002U_N`@004i_N`00CVmk0P00:fmk0P00;6mk
0P00:fmk0P00;6mk0P00;6mk0P00:fmk0P00Cfmk002iKg/40006Kg/20007Kg/40007Kg/00`00Kg]_
N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000U_N`03001_Nfmk00I_N`03001_Nfmk
0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/0eVmk002h
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/60007Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_
N`03001_Nfmk00]_N`04001_Nfmk0008Kg/4003EKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00]_
N`04001_Nfmk0008Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_
N`0000Q_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk000026mk
00<006mkKg/0eVmk002iKg/4000@Kg/20008Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk002B
Kg/2000/Kg/2000EKg/00`00Kg]_N`0CKg/2000/Kg/2002CKg/0095_N`@002Y_N`@001A_N`03001_
Nfmk019_N`@002Y_N`@0099_N`00TFmk1000:Vmk100056mk00<006mkKg/04Vmk1000:Vmk1000TVmk
002BKg/2000/Kg/2000EKg/00`00Kg]_N`0CKg/2000/Kg/2002CKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/00001\
\>"],
  ImageRangeCache->{{{0, 431}, {456.188, 0}} -> {-0.472523, -0.504206, \
0.00328902, 0.00328902}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "The distance function ",
  StyleBox["drectangle",
    FontFamily->"Courier"],
  " selects meshpoints within a rectangle. You may notice from its definition \
that the four corner points may not be included. This glitch can be fixed \
later."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(selectMeshpoints[
        drectangle[#, {\(-1\), \(-0.5\), 1, 0.5}] &, {\(-2\), \(-1\), \ 2, 
          1}, 0.1] // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .50138 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.501253 0.252732 0.501253 [
[.12406 .24023 -15 -9 ]
[.12406 .24023 15 0 ]
[.24937 .24023 -12 -9 ]
[.24937 .24023 12 0 ]
[.37469 .24023 -15 -9 ]
[.37469 .24023 15 0 ]
[.62531 .24023 -12 -9 ]
[.62531 .24023 12 0 ]
[.75063 .24023 -9 -9 ]
[.75063 .24023 9 0 ]
[.87594 .24023 -12 -9 ]
[.87594 .24023 12 0 ]
[.4875 .05223 -24 -4.5 ]
[.4875 .05223 0 4.5 ]
[.4875 .15248 -24 -4.5 ]
[.4875 .15248 0 4.5 ]
[.4875 .35298 -18 -4.5 ]
[.4875 .35298 0 4.5 ]
[.4875 .45323 -18 -4.5 ]
[.4875 .45323 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .50138 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12406 .25273 m
.12406 .25898 L
s
[(-0.75)] .12406 .24023 0 1 Mshowa
.24937 .25273 m
.24937 .25898 L
s
[(-0.5)] .24937 .24023 0 1 Mshowa
.37469 .25273 m
.37469 .25898 L
s
[(-0.25)] .37469 .24023 0 1 Mshowa
.62531 .25273 m
.62531 .25898 L
s
[(0.25)] .62531 .24023 0 1 Mshowa
.75063 .25273 m
.75063 .25898 L
s
[(0.5)] .75063 .24023 0 1 Mshowa
.87594 .25273 m
.87594 .25898 L
s
[(0.75)] .87594 .24023 0 1 Mshowa
.125 Mabswid
.02381 .25273 m
.02381 .25648 L
s
.04887 .25273 m
.04887 .25648 L
s
.07393 .25273 m
.07393 .25648 L
s
.099 .25273 m
.099 .25648 L
s
.14912 .25273 m
.14912 .25648 L
s
.17419 .25273 m
.17419 .25648 L
s
.19925 .25273 m
.19925 .25648 L
s
.22431 .25273 m
.22431 .25648 L
s
.27444 .25273 m
.27444 .25648 L
s
.2995 .25273 m
.2995 .25648 L
s
.32456 .25273 m
.32456 .25648 L
s
.34962 .25273 m
.34962 .25648 L
s
.39975 .25273 m
.39975 .25648 L
s
.42481 .25273 m
.42481 .25648 L
s
.44987 .25273 m
.44987 .25648 L
s
.47494 .25273 m
.47494 .25648 L
s
.52506 .25273 m
.52506 .25648 L
s
.55013 .25273 m
.55013 .25648 L
s
.57519 .25273 m
.57519 .25648 L
s
.60025 .25273 m
.60025 .25648 L
s
.65038 .25273 m
.65038 .25648 L
s
.67544 .25273 m
.67544 .25648 L
s
.7005 .25273 m
.7005 .25648 L
s
.72556 .25273 m
.72556 .25648 L
s
.77569 .25273 m
.77569 .25648 L
s
.80075 .25273 m
.80075 .25648 L
s
.82581 .25273 m
.82581 .25648 L
s
.85088 .25273 m
.85088 .25648 L
s
.901 .25273 m
.901 .25648 L
s
.92607 .25273 m
.92607 .25648 L
s
.95113 .25273 m
.95113 .25648 L
s
.97619 .25273 m
.97619 .25648 L
s
.25 Mabswid
0 .25273 m
1 .25273 L
s
.5 .05223 m
.50625 .05223 L
s
[(-0.4)] .4875 .05223 1 0 Mshowa
.5 .15248 m
.50625 .15248 L
s
[(-0.2)] .4875 .15248 1 0 Mshowa
.5 .35298 m
.50625 .35298 L
s
[(0.2)] .4875 .35298 1 0 Mshowa
.5 .45323 m
.50625 .45323 L
s
[(0.4)] .4875 .45323 1 0 Mshowa
.125 Mabswid
.5 .07729 m
.50375 .07729 L
s
.5 .10236 m
.50375 .10236 L
s
.5 .12742 m
.50375 .12742 L
s
.5 .17754 m
.50375 .17754 L
s
.5 .20261 m
.50375 .20261 L
s
.5 .22767 m
.50375 .22767 L
s
.5 .27779 m
.50375 .27779 L
s
.5 .30286 m
.50375 .30286 L
s
.5 .32792 m
.50375 .32792 L
s
.5 .37805 m
.50375 .37805 L
s
.5 .40311 m
.50375 .40311 L
s
.5 .42817 m
.50375 .42817 L
s
.5 .02717 m
.50375 .02717 L
s
.5 .00211 m
.50375 .00211 L
s
.5 .4783 m
.50375 .4783 L
s
.25 Mabswid
.5 0 m
.5 .50138 L
s
0 0 m
1 0 L
1 .50138 L
0 .50138 L
closepath
clip
newpath
.01 w
.04887 .01194 Mdot
.099 .01194 Mdot
.14912 .01194 Mdot
.19925 .01194 Mdot
.24937 .01194 Mdot
.2995 .01194 Mdot
.34962 .01194 Mdot
.39975 .01194 Mdot
.44987 .01194 Mdot
.5 .01194 Mdot
.55013 .01194 Mdot
.60025 .01194 Mdot
.65038 .01194 Mdot
.7005 .01194 Mdot
.75063 .01194 Mdot
.80075 .01194 Mdot
.85088 .01194 Mdot
.901 .01194 Mdot
.95113 .01194 Mdot
.02381 .05535 Mdot
.07393 .05535 Mdot
.12406 .05535 Mdot
.17419 .05535 Mdot
.22431 .05535 Mdot
.27444 .05535 Mdot
.32456 .05535 Mdot
.37469 .05535 Mdot
.42481 .05535 Mdot
.47494 .05535 Mdot
.52506 .05535 Mdot
.57519 .05535 Mdot
.62531 .05535 Mdot
.67544 .05535 Mdot
.72556 .05535 Mdot
.77569 .05535 Mdot
.82581 .05535 Mdot
.87594 .05535 Mdot
.92607 .05535 Mdot
.97619 .05535 Mdot
.04887 .09876 Mdot
.099 .09876 Mdot
.14912 .09876 Mdot
.19925 .09876 Mdot
.24937 .09876 Mdot
.2995 .09876 Mdot
.34962 .09876 Mdot
.39975 .09876 Mdot
.44987 .09876 Mdot
.5 .09876 Mdot
.55013 .09876 Mdot
.60025 .09876 Mdot
.65038 .09876 Mdot
.7005 .09876 Mdot
.75063 .09876 Mdot
.80075 .09876 Mdot
.85088 .09876 Mdot
.901 .09876 Mdot
.95113 .09876 Mdot
.02381 .14217 Mdot
.07393 .14217 Mdot
.12406 .14217 Mdot
.17419 .14217 Mdot
.22431 .14217 Mdot
.27444 .14217 Mdot
.32456 .14217 Mdot
.37469 .14217 Mdot
.42481 .14217 Mdot
.47494 .14217 Mdot
.52506 .14217 Mdot
.57519 .14217 Mdot
.62531 .14217 Mdot
.67544 .14217 Mdot
.72556 .14217 Mdot
.77569 .14217 Mdot
.82581 .14217 Mdot
.87594 .14217 Mdot
.92607 .14217 Mdot
.97619 .14217 Mdot
.04887 .18558 Mdot
.099 .18558 Mdot
.14912 .18558 Mdot
.19925 .18558 Mdot
.24937 .18558 Mdot
.2995 .18558 Mdot
.34962 .18558 Mdot
.39975 .18558 Mdot
.44987 .18558 Mdot
.5 .18558 Mdot
.55013 .18558 Mdot
.60025 .18558 Mdot
.65038 .18558 Mdot
.7005 .18558 Mdot
.75063 .18558 Mdot
.80075 .18558 Mdot
.85088 .18558 Mdot
.901 .18558 Mdot
.95113 .18558 Mdot
.02381 .22899 Mdot
.07393 .22899 Mdot
.12406 .22899 Mdot
.17419 .22899 Mdot
.22431 .22899 Mdot
.27444 .22899 Mdot
.32456 .22899 Mdot
.37469 .22899 Mdot
.42481 .22899 Mdot
.47494 .22899 Mdot
.52506 .22899 Mdot
.57519 .22899 Mdot
.62531 .22899 Mdot
.67544 .22899 Mdot
.72556 .22899 Mdot
.77569 .22899 Mdot
.82581 .22899 Mdot
.87594 .22899 Mdot
.92607 .22899 Mdot
.97619 .22899 Mdot
.04887 .2724 Mdot
.099 .2724 Mdot
.14912 .2724 Mdot
.19925 .2724 Mdot
.24937 .2724 Mdot
.2995 .2724 Mdot
.34962 .2724 Mdot
.39975 .2724 Mdot
.44987 .2724 Mdot
.5 .2724 Mdot
.55013 .2724 Mdot
.60025 .2724 Mdot
.65038 .2724 Mdot
.7005 .2724 Mdot
.75063 .2724 Mdot
.80075 .2724 Mdot
.85088 .2724 Mdot
.901 .2724 Mdot
.95113 .2724 Mdot
.02381 .31581 Mdot
.07393 .31581 Mdot
.12406 .31581 Mdot
.17419 .31581 Mdot
.22431 .31581 Mdot
.27444 .31581 Mdot
.32456 .31581 Mdot
.37469 .31581 Mdot
.42481 .31581 Mdot
.47494 .31581 Mdot
.52506 .31581 Mdot
.57519 .31581 Mdot
.62531 .31581 Mdot
.67544 .31581 Mdot
.72556 .31581 Mdot
.77569 .31581 Mdot
.82581 .31581 Mdot
.87594 .31581 Mdot
.92607 .31581 Mdot
.97619 .31581 Mdot
.04887 .35922 Mdot
.099 .35922 Mdot
.14912 .35922 Mdot
.19925 .35922 Mdot
.24937 .35922 Mdot
.2995 .35922 Mdot
.34962 .35922 Mdot
.39975 .35922 Mdot
.44987 .35922 Mdot
.5 .35922 Mdot
.55013 .35922 Mdot
.60025 .35922 Mdot
.65038 .35922 Mdot
.7005 .35922 Mdot
.75063 .35922 Mdot
.80075 .35922 Mdot
.85088 .35922 Mdot
.901 .35922 Mdot
.95113 .35922 Mdot
.02381 .40263 Mdot
.07393 .40263 Mdot
.12406 .40263 Mdot
.17419 .40263 Mdot
.22431 .40263 Mdot
.27444 .40263 Mdot
.32456 .40263 Mdot
.37469 .40263 Mdot
.42481 .40263 Mdot
.47494 .40263 Mdot
.52506 .40263 Mdot
.57519 .40263 Mdot
.62531 .40263 Mdot
.67544 .40263 Mdot
.72556 .40263 Mdot
.77569 .40263 Mdot
.82581 .40263 Mdot
.87594 .40263 Mdot
.92607 .40263 Mdot
.97619 .40263 Mdot
.04887 .44604 Mdot
.099 .44604 Mdot
.14912 .44604 Mdot
.19925 .44604 Mdot
.24937 .44604 Mdot
.2995 .44604 Mdot
.34962 .44604 Mdot
.39975 .44604 Mdot
.44987 .44604 Mdot
.5 .44604 Mdot
.55013 .44604 Mdot
.60025 .44604 Mdot
.65038 .44604 Mdot
.7005 .44604 Mdot
.75063 .44604 Mdot
.80075 .44604 Mdot
.85088 .44604 Mdot
.901 .44604 Mdot
.95113 .44604 Mdot
.02381 .48945 Mdot
.07393 .48945 Mdot
.12406 .48945 Mdot
.17419 .48945 Mdot
.22431 .48945 Mdot
.27444 .48945 Mdot
.32456 .48945 Mdot
.37469 .48945 Mdot
.42481 .48945 Mdot
.47494 .48945 Mdot
.52506 .48945 Mdot
.57519 .48945 Mdot
.62531 .48945 Mdot
.67544 .48945 Mdot
.72556 .48945 Mdot
.77569 .48945 Mdot
.82581 .48945 Mdot
.87594 .48945 Mdot
.92607 .48945 Mdot
.97619 .48945 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{288, 144.375},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000f1000`40O003h00Oefmk00<006mkKg/0
eVmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk000DKg/2000DKg/2
000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2
000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/001=_N`@0019_N`@0
019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0
019_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@001E_N`004fmk10004Vmk1000
4Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk1000
4Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10005Fmk000DKg/2000DKg/2000D
Kg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000D
Kg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk0`00
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk002iKg/40006Kg/20007
Kg/40007Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000U_N`03001_
Nfmk00I_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/01Vmk
00<006mkKg/0eVmk000:Kg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2
000CKg/30004Kg/00`00Kg]_N`0:Kg/60007Kg/40006Kg/2000DKg/2000CKg/2000DKg/2000CKg/2
000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000;Kg/000U_N`@0015_N`@0019_N`@0015_N`@0
019_N`@0015_N`@0019_N`@0019_N`@000]_N`X000A_N`03001_Nfmk00]_N`@000Q_N`03001_Nfmk
00I_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`@0
00Y_N`002Fmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk1000
16mk00<006mkKg/02fmk100026mk00<006mkKg/01Vmk10004Vmk10004Fmk10004Vmk10004Fmk1000
4Vmk10004Fmk10004Vmk10004Vmk10004Fmk10002Vmk000:Kg/2000CKg/2000DKg/2000CKg/2000D
Kg/2000CKg/2000DKg/2000DKg/2000CKg/30004Kg/00`00Kg]_N`0<Kg/30008Kg/00`00Kg]_N`07
Kg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000;
Kg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_N`0000Q_N`03001_Nfmk0=I_N`00^Fmk
100046mk0P0026mk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk0`00eVmk
003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00
Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/0
01A_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`80
01A_N`8001=_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001I_N`00
4fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk1000
4Vmk10004Fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10005Fmk000C
Kg/4000BKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000B
Kg/4000AKg/4000BKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000EKg/001A_
N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`@0019_
N`8001=_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/3003FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`002Vmk0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P00
56mk0P002Fmk00<006mkKg/01fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P00
56mk0P0056mk0P004fmk0P002fmk0009Kg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000B
Kg/4000BKg/4000AKg/4000BKg/40008Kg/00`00Kg]_N`06Kg/4000BKg/4000AKg/4000BKg/4000A
Kg/4000BKg/4000AKg/4000BKg/4000BKg/4000AKg/4000:Kg/000U_N`@0015_N`@0019_N`@0015_
N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`P000I_N`8000E_N`H000M_N`03001_Nfmk00I_
N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`@000Y_
N`002Vmk0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0`0016mk
00<006mkKg/00fmk0P001Fmk00H006mk000006mk0007Kg/00`00Kg]_N`07Kg/2000DKg/2000CKg/2
000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000;Kg/00;Q_N`03001_Nfmk
009_N`03001_Nfmk00]_N`03001_Nfmk00U_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<0
06mkKg/036mk00<006mkKg/026mk1000eFmk002_Kg/60003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_
Nfmk00I_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk
00<006mkKg/01Fmk00<006mkKg/0eVmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`3FKg/00;U_N`@000i_N`@000Q_N`03001_Nfmk0=I_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk000DKg/2000D
Kg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000C
Kg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/001=_N`@0019_
N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_
N`@0019_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@001E_N`004fmk10004Vmk
10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk
10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10005Fmk000DKg/2000DKg/2
000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2
000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/3003FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003G
Kg/00`00Kg]_N`3FKg/002Y_N`@000I_N`8000Q_N`03001_Nfmk00A_N`@001]_N`@000I_N`8000I_
N`@001a_N`@000I_N`8000E_N`H000A_N`@0029_N`03001_Nfmk02=_N`@000I_N`8000E_N`H000A_
N`@001]_N`@000I_N`8000I_N`@001a_N`@000I_N`8000Q_N`03001_Nfmk00A_N`@002Q_N`00:Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk0P0026mk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mk
Kg/05fmk00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/066mk
00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00D006mkKg]_N`0000A_N`03
001_Nfmk01m_N`03001_Nfmk029_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000E_N`03001_Nfmk
009_N`05001_NfmkKg/00004Kg/00`00Kg]_N`0GKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0HKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20008Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0UKg/002U_N`03001_Nfmk009_N`03001_Nfmk00e_
N`03001_Nfmk00Q_N`03001_Nfmk01M_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk01Q_
N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00Y_N`03001_Nfmk01m_N`03001_Nfmk029_
N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00Y_N`03001_Nfmk01M_N`03001_Nfmk009_
N`03001_Nfmk00m_N`03001_Nfmk01Q_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk00Q_
N`03001_Nfmk02E_N`00:Fmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/01fmk00<006mk
Kg/05fmk00<006mkKg/00Vmk00<006mkKg/03fmk00<006mkKg/066mk00<006mkKg/00Vmk00<006mk
Kg/036mk00<006mkKg/02Fmk00<006mkKg/07fmk00<006mkKg/08Vmk00<006mkKg/00Vmk00<006mk
Kg/036mk00<006mkKg/02Fmk00<006mkKg/05fmk00<006mkKg/00Vmk00<006mkKg/03fmk00<006mk
Kg/066mk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/01fmk00<006mkKg/09Fmk000PKg/6
0003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/60003Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0?Kg/60003Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0=Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0OKg/00`00Kg]_N`0RKg/00`00Kg]_N`02Kg/00`00Kg]_
N`0=Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0GKg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/00`00Kg]_
N`0HKg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0UKg/002U_N`03
001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00=_N`@001Y_N`03001_Nfmk009_N`03001_Nfmk
00]_N`@001]_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00=_N`@0029_N`03001_Nfmk
029_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00=_N`@001Y_N`03001_Nfmk009_N`03
001_Nfmk00]_N`@001]_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00=_N`@002Q_N`00
2Vmk0P004fmk0P0026mk00<006mkKg/00Vmk00<006mkKg/016mk0P002Fmk00<006mkKg/00Vmk00<0
06mkKg/00Vmk0P0056mk0P0000=_N`00Kg/00fmk00<006mkKg/02Vmk0P0056mk0P0026mk00<006mk
Kg/00Vmk00<006mkKg/016mk0P0016mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk
0P0056mk0P002Fmk00<006mkKg/01fmk0P0056mk0P000fmk00<006mkKg/00Vmk00<006mkKg/026mk
0`0016mk00<006mkKg/00Vmk00<006mkKg/01fmk0P004Vmk0`000Vmk00<006mkKg/02fmk00@006mk
Kg]_N`8001=_N`8000A_N`03001_Nfmk009_N`03001_Nfmk00Q_N`8000E_N`03001_Nfmk009_N`03
001_Nfmk00M_N`8001=_N`8000]_N`002Fmk10004Fmk10001fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk10000fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00@006mkKg]_N`@0019_N`D000A_N`03001_
Nfmk00U_N`@0019_N`@000M_N`03001_Nfmk009_N`03001_Nfmk00=_N`@000=_N`03001_Nfmk009_
N`03001_Nfmk009_N`04001_NfmkKg/4000BKg/40008Kg/30006Kg/4000BKg/40002Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`07Kg/40004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/4000AKg/400000fmk
001_N`0<Kg/00`00Kg]_N`04000AKg/40003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/40004Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`06Kg/4000AKg/4000:Kg/000U_N`@0015_N`@000Q_N`@000I_N`@0
00=_N`H000A_N`P0019_N`@00003Kg/00000008000a_N`L000m_N`@000Q_N`@000I_N`@000A_N`@0
00E_N`P0019_N`@000Q_N`03001_Nfmk00I_N`@0019_N`@000=_N`@000Y_N`P000E_N`D000A_N`@0
015_N`D000i_N`L0015_N`@000A_N`@000Y_N`T000A_N`D000A_N`@0015_N`@000Y_N`002Vmk0P00
4fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P0056mk0P002Fmk00<0
06mkKg/01fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P00
4fmk0P002fmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk
003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00
Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00o`00/0000Fmk000:Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/003E_N`03001_Nfmk03=_N`03001_Nfmk03=_N`03
001_Nfmk03=_N`03001_Nfmk03=_N`03001_Nfmk03=_N`03001_Nfmk03=_N`03001_Nfmk03A_N`00
efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk000DKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2
000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2
000FKg/001=_N`@0019_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0
015_N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0
01E_N`004fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk1000
4Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk1000
5Fmk000DKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000C
Kg/4000BKg/2000CKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk0`00
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk000:Kg/2
000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000DKg/20009Kg/0
0`00Kg]_N`07Kg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2
000CKg/2000;Kg/000U_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0019_N`@0
015_N`@0019_N`@000Q_N`03001_Nfmk00I_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_N`@0
015_N`@0019_N`@0019_N`@0015_N`@000Y_N`002Fmk10004Fmk10004Vmk10004Fmk10004Vmk1000
4Fmk10004Vmk10004Vmk10004Fmk10004Vmk100026mk00<006mkKg/01Vmk10004Vmk10004Fmk1000
4Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk10002Vmk000:Kg/2000CKg/2000D
Kg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000DKg/20009Kg/00`00Kg]_N`07
Kg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000;
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`<0
0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00^Fmk10001Vmk0P00
1Fmk1P001fmk00<006mkKg/0eVmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`3FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk00]_
N`03001_Nfmk00U_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk
Kg/026mk00<006mkKg/0eVmk002hKg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`07Kg/4
003EKg/001A_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8000]_N`03
001_Nfmk009_N`04001_NfmkKg/2000;Kg/00`00Kg]_N`05Kg/2000DKg/2000CKg/2000DKg/2000D
Kg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/001=_N`@0019_N`@0019_N`@0015_
N`@0019_N`@0015_N`@0019_N`@0015_N`@000Y_N`03001_Nfmk009_N`03001_Nfmk00@000I_N`03
001_Nfmk009_N`03001_Nfmk00=_N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`@0019_N`@0
015_N`@0019_N`@0015_N`@001E_N`004fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk1000
4Vmk10004Fmk10002Vmk00<006mkKg/00Vmk00<006mkKg/010001Vmk00<006mkKg/00Vmk00<006mk
Kg/00fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk
10005Fmk000DKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000<Kg/4
0004Kg/20008Kg/40007Kg/2000DKg/2000CKg/2000DKg/2000DKg/2000CKg/2000DKg/2000CKg/2
000DKg/2000CKg/2000FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00
Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/3003FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<0
06mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/000Y_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_
N`8001A_N`8001A_N`8001=_N`8001A_N`8000U_N`03001_Nfmk00M_N`8001A_N`8001=_N`8001A_
N`8001=_N`8001A_N`8001=_N`8001A_N`8001A_N`8001=_N`8000]_N`002Fmk10004Fmk10004Vmk
10004Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk10004Vmk100026mk0`001Vmk10004Vmk
10004Fmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk10002Vmk0009Kg/4
000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000BKg/4000AKg/4000BKg/40008Kg/0
0`00Kg]_N`06Kg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000BKg/4
000AKg/4000:Kg/000Y_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001A_N`80
01=_N`8001A_N`8000U_N`03001_Nfmk00M_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`80
01=_N`8001A_N`8001A_N`8001=_N`8000]_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk
00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/001A_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_
N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_
N`8001A_N`8001=_N`8001I_N`004fmk10004Vmk10004Vmk10004Fmk10004Vmk10004Fmk10004Vmk
10004Fmk10002fmk10000fmk1@001fmk10001Fmk10004Vmk10004Fmk10004Vmk10004Vmk10004Fmk
10004Vmk10004Fmk10004Vmk10004Fmk10005Fmk000CKg/4000BKg/4000BKg/4000AKg/4000BKg/4
000AKg/4000BKg/4000AKg/4000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`050009Kg/00`00Kg]_N`04
Kg/4000BKg/4000AKg/4000BKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000E
Kg/001A_N`8001A_N`8001A_N`8001=_N`8001A_N`8001=_N`8001A_N`8001=_N`8000]_N`03001_
Nfmk009_N`04001_NfmkKg/2000;Kg/00`00Kg]_N`05Kg/2000DKg/2000CKg/2000DKg/2000DKg/2
000CKg/2000DKg/2000CKg/2000DKg/2000CKg/2000FKg/00;Q_N`03001_Nfmk009_N`03001_Nfmk
00Y_N`H000M_N`03001_Nfmk0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/0
00Q_N`@00=E_N`00^6mk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03001_Nfmk
0=I_N`00^6mk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk000026mk00<006mkKg/0eVmk002h
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg/00008Kg/00`00Kg]_N`3FKg/00;U_N`@0011_
N`8000Q_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_
N`00efmk0`00eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`002Vmk0P004fmk0P00
56mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P0056mk0P002Fmk00<006mkKg/0
1fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P00
2fmk0009Kg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000BKg/4000AKg/4000B
Kg/40008Kg/00`00Kg]_N`06Kg/4000BKg/4000AKg/4000BKg/4000AKg/4000BKg/4000AKg/4000B
Kg/4000BKg/4000AKg/4000:Kg/000U_N`@0015_N`@0019_N`@0015_N`@0019_N`@0015_N`@0019_
N`@0019_N`@0015_N`@0019_N`@000Q_N`03001_Nfmk00I_N`@0019_N`@0015_N`@0019_N`@0015_
N`@0019_N`@0015_N`@0019_N`@0019_N`@0015_N`@000Y_N`002Vmk0P004fmk0P0056mk0P004fmk
0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P0056mk0P002Fmk00<006mkKg/01fmk0P0056mk
0P004fmk0P0056mk0P004fmk0P0056mk0P004fmk0P0056mk0P0056mk0P004fmk0P002fmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk0000\
\>"],
  ImageRangeCache->{{{0, 431}, {215.563, 0}} -> {-0.999973, -0.504205, \
0.00696037, 0.00696037}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "How to define the distance function of a rectangle with a hole in the \
center? There are ways to combine distance functions of simple geometric \
shapes to form more complex ones. For example, ",
  StyleBox["ddiff",
    FontFamily->"Courier"],
  " takes one shape out of the other. "
}], "Text"],

Cell[BoxData[
    \(ddiff[d1_, d2_] := Max[d1, \(-d2\)]\)], "Input",
  CellLabel->"In[10]:="],

Cell[TextData[{
  "For more ways of combining distance functions, see ",
  StyleBox["Figure 4.1",
    FontSlant->"Italic"],
  " in the paper. Here is a disk taken out of a rectangle"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(selectMeshpoints[
        ddiff[drectangle[#, {\(-2\), \(-1\), 2, 1}], \ 
            dcircle[#, \ {0, 0, 0.5}]] &, {\(-2\), \(-1\), \ 2, 1}, 0.1] // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[12]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .48853 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.2442 0.234683 0.2442 [
[.0116 .22218 -6 -9 ]
[.0116 .22218 6 0 ]
[.2558 .22218 -6 -9 ]
[.2558 .22218 6 0 ]
[.7442 .22218 -3 -9 ]
[.7442 .22218 3 0 ]
[.9884 .22218 -3 -9 ]
[.9884 .22218 3 0 ]
[.4875 .11258 -24 -4.5 ]
[.4875 .11258 0 4.5 ]
[.4875 .35678 -18 -4.5 ]
[.4875 .35678 0 4.5 ]
[.4875 .47888 -6 -4.5 ]
[.4875 .47888 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .48853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0116 .23468 m
.0116 .24093 L
s
[(-2)] .0116 .22218 0 1 Mshowa
.2558 .23468 m
.2558 .24093 L
s
[(-1)] .2558 .22218 0 1 Mshowa
.7442 .23468 m
.7442 .24093 L
s
[(1)] .7442 .22218 0 1 Mshowa
.9884 .23468 m
.9884 .24093 L
s
[(2)] .9884 .22218 0 1 Mshowa
.125 Mabswid
.06044 .23468 m
.06044 .23843 L
s
.10928 .23468 m
.10928 .23843 L
s
.15812 .23468 m
.15812 .23843 L
s
.20696 .23468 m
.20696 .23843 L
s
.30464 .23468 m
.30464 .23843 L
s
.35348 .23468 m
.35348 .23843 L
s
.40232 .23468 m
.40232 .23843 L
s
.45116 .23468 m
.45116 .23843 L
s
.54884 .23468 m
.54884 .23843 L
s
.59768 .23468 m
.59768 .23843 L
s
.64652 .23468 m
.64652 .23843 L
s
.69536 .23468 m
.69536 .23843 L
s
.79304 .23468 m
.79304 .23843 L
s
.84188 .23468 m
.84188 .23843 L
s
.89072 .23468 m
.89072 .23843 L
s
.93956 .23468 m
.93956 .23843 L
s
.25 Mabswid
0 .23468 m
1 .23468 L
s
.5 .11258 m
.50625 .11258 L
s
[(-0.5)] .4875 .11258 1 0 Mshowa
.5 .35678 m
.50625 .35678 L
s
[(0.5)] .4875 .35678 1 0 Mshowa
.5 .47888 m
.50625 .47888 L
s
[(1)] .4875 .47888 1 0 Mshowa
.125 Mabswid
.5 .137 m
.50375 .137 L
s
.5 .16142 m
.50375 .16142 L
s
.5 .18584 m
.50375 .18584 L
s
.5 .21026 m
.50375 .21026 L
s
.5 .2591 m
.50375 .2591 L
s
.5 .28352 m
.50375 .28352 L
s
.5 .30794 m
.50375 .30794 L
s
.5 .33236 m
.50375 .33236 L
s
.5 .3812 m
.50375 .3812 L
s
.5 .40562 m
.50375 .40562 L
s
.5 .43004 m
.50375 .43004 L
s
.5 .45446 m
.50375 .45446 L
s
.5 .08816 m
.50375 .08816 L
s
.5 .06374 m
.50375 .06374 L
s
.5 .03932 m
.50375 .03932 L
s
.5 .0149 m
.50375 .0149 L
s
.25 Mabswid
.5 0 m
.5 .48853 L
s
0 0 m
1 0 L
1 .48853 L
0 .48853 L
closepath
clip
newpath
.01 w
.02381 .01163 Mdot
.04823 .01163 Mdot
.07265 .01163 Mdot
.09707 .01163 Mdot
.12149 .01163 Mdot
.14591 .01163 Mdot
.17033 .01163 Mdot
.19475 .01163 Mdot
.21917 .01163 Mdot
.24359 .01163 Mdot
.26801 .01163 Mdot
.29243 .01163 Mdot
.31685 .01163 Mdot
.34127 .01163 Mdot
.36569 .01163 Mdot
.39011 .01163 Mdot
.41453 .01163 Mdot
.43895 .01163 Mdot
.46337 .01163 Mdot
.48779 .01163 Mdot
.51221 .01163 Mdot
.53663 .01163 Mdot
.56105 .01163 Mdot
.58547 .01163 Mdot
.60989 .01163 Mdot
.63431 .01163 Mdot
.65873 .01163 Mdot
.68315 .01163 Mdot
.70757 .01163 Mdot
.73199 .01163 Mdot
.75641 .01163 Mdot
.78083 .01163 Mdot
.80525 .01163 Mdot
.82967 .01163 Mdot
.85409 .01163 Mdot
.87851 .01163 Mdot
.90293 .01163 Mdot
.92735 .01163 Mdot
.95177 .01163 Mdot
.97619 .01163 Mdot
.03602 .03278 Mdot
.06044 .03278 Mdot
.08486 .03278 Mdot
.10928 .03278 Mdot
.1337 .03278 Mdot
.15812 .03278 Mdot
.18254 .03278 Mdot
.20696 .03278 Mdot
.23138 .03278 Mdot
.2558 .03278 Mdot
.28022 .03278 Mdot
.30464 .03278 Mdot
.32906 .03278 Mdot
.35348 .03278 Mdot
.3779 .03278 Mdot
.40232 .03278 Mdot
.42674 .03278 Mdot
.45116 .03278 Mdot
.47558 .03278 Mdot
.5 .03278 Mdot
.52442 .03278 Mdot
.54884 .03278 Mdot
.57326 .03278 Mdot
.59768 .03278 Mdot
.6221 .03278 Mdot
.64652 .03278 Mdot
.67094 .03278 Mdot
.69536 .03278 Mdot
.71978 .03278 Mdot
.7442 .03278 Mdot
.76862 .03278 Mdot
.79304 .03278 Mdot
.81746 .03278 Mdot
.84188 .03278 Mdot
.8663 .03278 Mdot
.89072 .03278 Mdot
.91514 .03278 Mdot
.93956 .03278 Mdot
.96398 .03278 Mdot
.02381 .05393 Mdot
.04823 .05393 Mdot
.07265 .05393 Mdot
.09707 .05393 Mdot
.12149 .05393 Mdot
.14591 .05393 Mdot
.17033 .05393 Mdot
.19475 .05393 Mdot
.21917 .05393 Mdot
.24359 .05393 Mdot
.26801 .05393 Mdot
.29243 .05393 Mdot
.31685 .05393 Mdot
.34127 .05393 Mdot
.36569 .05393 Mdot
.39011 .05393 Mdot
.41453 .05393 Mdot
.43895 .05393 Mdot
.46337 .05393 Mdot
.48779 .05393 Mdot
.51221 .05393 Mdot
.53663 .05393 Mdot
.56105 .05393 Mdot
.58547 .05393 Mdot
.60989 .05393 Mdot
.63431 .05393 Mdot
.65873 .05393 Mdot
.68315 .05393 Mdot
.70757 .05393 Mdot
.73199 .05393 Mdot
.75641 .05393 Mdot
.78083 .05393 Mdot
.80525 .05393 Mdot
.82967 .05393 Mdot
.85409 .05393 Mdot
.87851 .05393 Mdot
.90293 .05393 Mdot
.92735 .05393 Mdot
.95177 .05393 Mdot
.97619 .05393 Mdot
.03602 .07508 Mdot
.06044 .07508 Mdot
.08486 .07508 Mdot
.10928 .07508 Mdot
.1337 .07508 Mdot
.15812 .07508 Mdot
.18254 .07508 Mdot
.20696 .07508 Mdot
.23138 .07508 Mdot
.2558 .07508 Mdot
.28022 .07508 Mdot
.30464 .07508 Mdot
.32906 .07508 Mdot
.35348 .07508 Mdot
.3779 .07508 Mdot
.40232 .07508 Mdot
.42674 .07508 Mdot
.45116 .07508 Mdot
.47558 .07508 Mdot
.5 .07508 Mdot
.52442 .07508 Mdot
.54884 .07508 Mdot
.57326 .07508 Mdot
.59768 .07508 Mdot
.6221 .07508 Mdot
.64652 .07508 Mdot
.67094 .07508 Mdot
.69536 .07508 Mdot
.71978 .07508 Mdot
.7442 .07508 Mdot
.76862 .07508 Mdot
.79304 .07508 Mdot
.81746 .07508 Mdot
.84188 .07508 Mdot
.8663 .07508 Mdot
.89072 .07508 Mdot
.91514 .07508 Mdot
.93956 .07508 Mdot
.96398 .07508 Mdot
.02381 .09623 Mdot
.04823 .09623 Mdot
.07265 .09623 Mdot
.09707 .09623 Mdot
.12149 .09623 Mdot
.14591 .09623 Mdot
.17033 .09623 Mdot
.19475 .09623 Mdot
.21917 .09623 Mdot
.24359 .09623 Mdot
.26801 .09623 Mdot
.29243 .09623 Mdot
.31685 .09623 Mdot
.34127 .09623 Mdot
.36569 .09623 Mdot
.39011 .09623 Mdot
.41453 .09623 Mdot
.43895 .09623 Mdot
.46337 .09623 Mdot
.48779 .09623 Mdot
.51221 .09623 Mdot
.53663 .09623 Mdot
.56105 .09623 Mdot
.58547 .09623 Mdot
.60989 .09623 Mdot
.63431 .09623 Mdot
.65873 .09623 Mdot
.68315 .09623 Mdot
.70757 .09623 Mdot
.73199 .09623 Mdot
.75641 .09623 Mdot
.78083 .09623 Mdot
.80525 .09623 Mdot
.82967 .09623 Mdot
.85409 .09623 Mdot
.87851 .09623 Mdot
.90293 .09623 Mdot
.92735 .09623 Mdot
.95177 .09623 Mdot
.97619 .09623 Mdot
.03602 .11737 Mdot
.06044 .11737 Mdot
.08486 .11737 Mdot
.10928 .11737 Mdot
.1337 .11737 Mdot
.15812 .11737 Mdot
.18254 .11737 Mdot
.20696 .11737 Mdot
.23138 .11737 Mdot
.2558 .11737 Mdot
.28022 .11737 Mdot
.30464 .11737 Mdot
.32906 .11737 Mdot
.35348 .11737 Mdot
.3779 .11737 Mdot
.40232 .11737 Mdot
.42674 .11737 Mdot
.45116 .11737 Mdot
.54884 .11737 Mdot
.57326 .11737 Mdot
.59768 .11737 Mdot
.6221 .11737 Mdot
.64652 .11737 Mdot
.67094 .11737 Mdot
.69536 .11737 Mdot
.71978 .11737 Mdot
.7442 .11737 Mdot
.76862 .11737 Mdot
.79304 .11737 Mdot
.81746 .11737 Mdot
.84188 .11737 Mdot
.8663 .11737 Mdot
.89072 .11737 Mdot
.91514 .11737 Mdot
.93956 .11737 Mdot
.96398 .11737 Mdot
.02381 .13852 Mdot
.04823 .13852 Mdot
.07265 .13852 Mdot
.09707 .13852 Mdot
.12149 .13852 Mdot
.14591 .13852 Mdot
.17033 .13852 Mdot
.19475 .13852 Mdot
.21917 .13852 Mdot
.24359 .13852 Mdot
.26801 .13852 Mdot
.29243 .13852 Mdot
.31685 .13852 Mdot
.34127 .13852 Mdot
.36569 .13852 Mdot
.39011 .13852 Mdot
.41453 .13852 Mdot
.58547 .13852 Mdot
.60989 .13852 Mdot
.63431 .13852 Mdot
.65873 .13852 Mdot
.68315 .13852 Mdot
.70757 .13852 Mdot
.73199 .13852 Mdot
.75641 .13852 Mdot
.78083 .13852 Mdot
.80525 .13852 Mdot
.82967 .13852 Mdot
.85409 .13852 Mdot
.87851 .13852 Mdot
.90293 .13852 Mdot
.92735 .13852 Mdot
.95177 .13852 Mdot
.97619 .13852 Mdot
.03602 .15967 Mdot
.06044 .15967 Mdot
.08486 .15967 Mdot
.10928 .15967 Mdot
.1337 .15967 Mdot
.15812 .15967 Mdot
.18254 .15967 Mdot
.20696 .15967 Mdot
.23138 .15967 Mdot
.2558 .15967 Mdot
.28022 .15967 Mdot
.30464 .15967 Mdot
.32906 .15967 Mdot
.35348 .15967 Mdot
.3779 .15967 Mdot
.40232 .15967 Mdot
.59768 .15967 Mdot
.6221 .15967 Mdot
.64652 .15967 Mdot
.67094 .15967 Mdot
.69536 .15967 Mdot
.71978 .15967 Mdot
.7442 .15967 Mdot
.76862 .15967 Mdot
.79304 .15967 Mdot
.81746 .15967 Mdot
.84188 .15967 Mdot
.8663 .15967 Mdot
.89072 .15967 Mdot
.91514 .15967 Mdot
.93956 .15967 Mdot
.96398 .15967 Mdot
.02381 .18082 Mdot
.04823 .18082 Mdot
.07265 .18082 Mdot
.09707 .18082 Mdot
.12149 .18082 Mdot
.14591 .18082 Mdot
.17033 .18082 Mdot
.19475 .18082 Mdot
.21917 .18082 Mdot
.24359 .18082 Mdot
.26801 .18082 Mdot
.29243 .18082 Mdot
.31685 .18082 Mdot
.34127 .18082 Mdot
.36569 .18082 Mdot
.39011 .18082 Mdot
.60989 .18082 Mdot
.63431 .18082 Mdot
.65873 .18082 Mdot
.68315 .18082 Mdot
.70757 .18082 Mdot
.73199 .18082 Mdot
.75641 .18082 Mdot
.78083 .18082 Mdot
.80525 .18082 Mdot
.82967 .18082 Mdot
.85409 .18082 Mdot
.87851 .18082 Mdot
.90293 .18082 Mdot
.92735 .18082 Mdot
.95177 .18082 Mdot
.97619 .18082 Mdot
.03602 .20197 Mdot
.06044 .20197 Mdot
.08486 .20197 Mdot
.10928 .20197 Mdot
.1337 .20197 Mdot
.15812 .20197 Mdot
.18254 .20197 Mdot
.20696 .20197 Mdot
.23138 .20197 Mdot
.2558 .20197 Mdot
.28022 .20197 Mdot
.30464 .20197 Mdot
.32906 .20197 Mdot
.35348 .20197 Mdot
.3779 .20197 Mdot
.6221 .20197 Mdot
.64652 .20197 Mdot
.67094 .20197 Mdot
.69536 .20197 Mdot
.71978 .20197 Mdot
.7442 .20197 Mdot
.76862 .20197 Mdot
.79304 .20197 Mdot
.81746 .20197 Mdot
.84188 .20197 Mdot
.8663 .20197 Mdot
.89072 .20197 Mdot
.91514 .20197 Mdot
.93956 .20197 Mdot
.96398 .20197 Mdot
.02381 .22312 Mdot
.04823 .22312 Mdot
.07265 .22312 Mdot
.09707 .22312 Mdot
.12149 .22312 Mdot
.14591 .22312 Mdot
.17033 .22312 Mdot
.19475 .22312 Mdot
.21917 .22312 Mdot
.24359 .22312 Mdot
.26801 .22312 Mdot
.29243 .22312 Mdot
.31685 .22312 Mdot
.34127 .22312 Mdot
.36569 .22312 Mdot
.63431 .22312 Mdot
.65873 .22312 Mdot
.68315 .22312 Mdot
.70757 .22312 Mdot
.73199 .22312 Mdot
.75641 .22312 Mdot
.78083 .22312 Mdot
.80525 .22312 Mdot
.82967 .22312 Mdot
.85409 .22312 Mdot
.87851 .22312 Mdot
.90293 .22312 Mdot
.92735 .22312 Mdot
.95177 .22312 Mdot
.97619 .22312 Mdot
.03602 .24426 Mdot
.06044 .24426 Mdot
.08486 .24426 Mdot
.10928 .24426 Mdot
.1337 .24426 Mdot
.15812 .24426 Mdot
.18254 .24426 Mdot
.20696 .24426 Mdot
.23138 .24426 Mdot
.2558 .24426 Mdot
.28022 .24426 Mdot
.30464 .24426 Mdot
.32906 .24426 Mdot
.35348 .24426 Mdot
.3779 .24426 Mdot
.6221 .24426 Mdot
.64652 .24426 Mdot
.67094 .24426 Mdot
.69536 .24426 Mdot
.71978 .24426 Mdot
.7442 .24426 Mdot
.76862 .24426 Mdot
.79304 .24426 Mdot
.81746 .24426 Mdot
.84188 .24426 Mdot
.8663 .24426 Mdot
.89072 .24426 Mdot
.91514 .24426 Mdot
.93956 .24426 Mdot
.96398 .24426 Mdot
.02381 .26541 Mdot
.04823 .26541 Mdot
.07265 .26541 Mdot
.09707 .26541 Mdot
.12149 .26541 Mdot
.14591 .26541 Mdot
.17033 .26541 Mdot
.19475 .26541 Mdot
.21917 .26541 Mdot
.24359 .26541 Mdot
.26801 .26541 Mdot
.29243 .26541 Mdot
.31685 .26541 Mdot
.34127 .26541 Mdot
.36569 .26541 Mdot
.63431 .26541 Mdot
.65873 .26541 Mdot
.68315 .26541 Mdot
.70757 .26541 Mdot
.73199 .26541 Mdot
.75641 .26541 Mdot
.78083 .26541 Mdot
.80525 .26541 Mdot
.82967 .26541 Mdot
.85409 .26541 Mdot
.87851 .26541 Mdot
.90293 .26541 Mdot
.92735 .26541 Mdot
.95177 .26541 Mdot
.97619 .26541 Mdot
.03602 .28656 Mdot
.06044 .28656 Mdot
.08486 .28656 Mdot
.10928 .28656 Mdot
.1337 .28656 Mdot
.15812 .28656 Mdot
.18254 .28656 Mdot
.20696 .28656 Mdot
.23138 .28656 Mdot
.2558 .28656 Mdot
.28022 .28656 Mdot
.30464 .28656 Mdot
.32906 .28656 Mdot
.35348 .28656 Mdot
.3779 .28656 Mdot
.6221 .28656 Mdot
.64652 .28656 Mdot
.67094 .28656 Mdot
.69536 .28656 Mdot
.71978 .28656 Mdot
.7442 .28656 Mdot
.76862 .28656 Mdot
.79304 .28656 Mdot
.81746 .28656 Mdot
.84188 .28656 Mdot
.8663 .28656 Mdot
.89072 .28656 Mdot
.91514 .28656 Mdot
.93956 .28656 Mdot
.96398 .28656 Mdot
.02381 .30771 Mdot
.04823 .30771 Mdot
.07265 .30771 Mdot
.09707 .30771 Mdot
.12149 .30771 Mdot
.14591 .30771 Mdot
.17033 .30771 Mdot
.19475 .30771 Mdot
.21917 .30771 Mdot
.24359 .30771 Mdot
.26801 .30771 Mdot
.29243 .30771 Mdot
.31685 .30771 Mdot
.34127 .30771 Mdot
.36569 .30771 Mdot
.39011 .30771 Mdot
.60989 .30771 Mdot
.63431 .30771 Mdot
.65873 .30771 Mdot
.68315 .30771 Mdot
.70757 .30771 Mdot
.73199 .30771 Mdot
.75641 .30771 Mdot
.78083 .30771 Mdot
.80525 .30771 Mdot
.82967 .30771 Mdot
.85409 .30771 Mdot
.87851 .30771 Mdot
.90293 .30771 Mdot
.92735 .30771 Mdot
.95177 .30771 Mdot
.97619 .30771 Mdot
.03602 .32886 Mdot
.06044 .32886 Mdot
.08486 .32886 Mdot
.10928 .32886 Mdot
.1337 .32886 Mdot
.15812 .32886 Mdot
.18254 .32886 Mdot
.20696 .32886 Mdot
.23138 .32886 Mdot
.2558 .32886 Mdot
.28022 .32886 Mdot
.30464 .32886 Mdot
.32906 .32886 Mdot
.35348 .32886 Mdot
.3779 .32886 Mdot
.40232 .32886 Mdot
.59768 .32886 Mdot
.6221 .32886 Mdot
.64652 .32886 Mdot
.67094 .32886 Mdot
.69536 .32886 Mdot
.71978 .32886 Mdot
.7442 .32886 Mdot
.76862 .32886 Mdot
.79304 .32886 Mdot
.81746 .32886 Mdot
.84188 .32886 Mdot
.8663 .32886 Mdot
.89072 .32886 Mdot
.91514 .32886 Mdot
.93956 .32886 Mdot
.96398 .32886 Mdot
.02381 .35001 Mdot
.04823 .35001 Mdot
.07265 .35001 Mdot
.09707 .35001 Mdot
.12149 .35001 Mdot
.14591 .35001 Mdot
.17033 .35001 Mdot
.19475 .35001 Mdot
.21917 .35001 Mdot
.24359 .35001 Mdot
.26801 .35001 Mdot
.29243 .35001 Mdot
.31685 .35001 Mdot
.34127 .35001 Mdot
.36569 .35001 Mdot
.39011 .35001 Mdot
.41453 .35001 Mdot
.43895 .35001 Mdot
.56105 .35001 Mdot
.58547 .35001 Mdot
.60989 .35001 Mdot
.63431 .35001 Mdot
.65873 .35001 Mdot
.68315 .35001 Mdot
.70757 .35001 Mdot
.73199 .35001 Mdot
.75641 .35001 Mdot
.78083 .35001 Mdot
.80525 .35001 Mdot
.82967 .35001 Mdot
.85409 .35001 Mdot
.87851 .35001 Mdot
.90293 .35001 Mdot
.92735 .35001 Mdot
.95177 .35001 Mdot
.97619 .35001 Mdot
.03602 .37115 Mdot
.06044 .37115 Mdot
.08486 .37115 Mdot
.10928 .37115 Mdot
.1337 .37115 Mdot
.15812 .37115 Mdot
.18254 .37115 Mdot
.20696 .37115 Mdot
.23138 .37115 Mdot
.2558 .37115 Mdot
.28022 .37115 Mdot
.30464 .37115 Mdot
.32906 .37115 Mdot
.35348 .37115 Mdot
.3779 .37115 Mdot
.40232 .37115 Mdot
.42674 .37115 Mdot
.45116 .37115 Mdot
.47558 .37115 Mdot
.5 .37115 Mdot
.52442 .37115 Mdot
.54884 .37115 Mdot
.57326 .37115 Mdot
.59768 .37115 Mdot
.6221 .37115 Mdot
.64652 .37115 Mdot
.67094 .37115 Mdot
.69536 .37115 Mdot
.71978 .37115 Mdot
.7442 .37115 Mdot
.76862 .37115 Mdot
.79304 .37115 Mdot
.81746 .37115 Mdot
.84188 .37115 Mdot
.8663 .37115 Mdot
.89072 .37115 Mdot
.91514 .37115 Mdot
.93956 .37115 Mdot
.96398 .37115 Mdot
.02381 .3923 Mdot
.04823 .3923 Mdot
.07265 .3923 Mdot
.09707 .3923 Mdot
.12149 .3923 Mdot
.14591 .3923 Mdot
.17033 .3923 Mdot
.19475 .3923 Mdot
.21917 .3923 Mdot
.24359 .3923 Mdot
.26801 .3923 Mdot
.29243 .3923 Mdot
.31685 .3923 Mdot
.34127 .3923 Mdot
.36569 .3923 Mdot
.39011 .3923 Mdot
.41453 .3923 Mdot
.43895 .3923 Mdot
.46337 .3923 Mdot
.48779 .3923 Mdot
.51221 .3923 Mdot
.53663 .3923 Mdot
.56105 .3923 Mdot
.58547 .3923 Mdot
.60989 .3923 Mdot
.63431 .3923 Mdot
.65873 .3923 Mdot
.68315 .3923 Mdot
.70757 .3923 Mdot
.73199 .3923 Mdot
.75641 .3923 Mdot
.78083 .3923 Mdot
.80525 .3923 Mdot
.82967 .3923 Mdot
.85409 .3923 Mdot
.87851 .3923 Mdot
.90293 .3923 Mdot
.92735 .3923 Mdot
.95177 .3923 Mdot
.97619 .3923 Mdot
.03602 .41345 Mdot
.06044 .41345 Mdot
.08486 .41345 Mdot
.10928 .41345 Mdot
.1337 .41345 Mdot
.15812 .41345 Mdot
.18254 .41345 Mdot
.20696 .41345 Mdot
.23138 .41345 Mdot
.2558 .41345 Mdot
.28022 .41345 Mdot
.30464 .41345 Mdot
.32906 .41345 Mdot
.35348 .41345 Mdot
.3779 .41345 Mdot
.40232 .41345 Mdot
.42674 .41345 Mdot
.45116 .41345 Mdot
.47558 .41345 Mdot
.5 .41345 Mdot
.52442 .41345 Mdot
.54884 .41345 Mdot
.57326 .41345 Mdot
.59768 .41345 Mdot
.6221 .41345 Mdot
.64652 .41345 Mdot
.67094 .41345 Mdot
.69536 .41345 Mdot
.71978 .41345 Mdot
.7442 .41345 Mdot
.76862 .41345 Mdot
.79304 .41345 Mdot
.81746 .41345 Mdot
.84188 .41345 Mdot
.8663 .41345 Mdot
.89072 .41345 Mdot
.91514 .41345 Mdot
.93956 .41345 Mdot
.96398 .41345 Mdot
.02381 .4346 Mdot
.04823 .4346 Mdot
.07265 .4346 Mdot
.09707 .4346 Mdot
.12149 .4346 Mdot
.14591 .4346 Mdot
.17033 .4346 Mdot
.19475 .4346 Mdot
.21917 .4346 Mdot
.24359 .4346 Mdot
.26801 .4346 Mdot
.29243 .4346 Mdot
.31685 .4346 Mdot
.34127 .4346 Mdot
.36569 .4346 Mdot
.39011 .4346 Mdot
.41453 .4346 Mdot
.43895 .4346 Mdot
.46337 .4346 Mdot
.48779 .4346 Mdot
.51221 .4346 Mdot
.53663 .4346 Mdot
.56105 .4346 Mdot
.58547 .4346 Mdot
.60989 .4346 Mdot
.63431 .4346 Mdot
.65873 .4346 Mdot
.68315 .4346 Mdot
.70757 .4346 Mdot
.73199 .4346 Mdot
.75641 .4346 Mdot
.78083 .4346 Mdot
.80525 .4346 Mdot
.82967 .4346 Mdot
.85409 .4346 Mdot
.87851 .4346 Mdot
.90293 .4346 Mdot
.92735 .4346 Mdot
.95177 .4346 Mdot
.97619 .4346 Mdot
.03602 .45575 Mdot
.06044 .45575 Mdot
.08486 .45575 Mdot
.10928 .45575 Mdot
.1337 .45575 Mdot
.15812 .45575 Mdot
.18254 .45575 Mdot
.20696 .45575 Mdot
.23138 .45575 Mdot
.2558 .45575 Mdot
.28022 .45575 Mdot
.30464 .45575 Mdot
.32906 .45575 Mdot
.35348 .45575 Mdot
.3779 .45575 Mdot
.40232 .45575 Mdot
.42674 .45575 Mdot
.45116 .45575 Mdot
.47558 .45575 Mdot
.5 .45575 Mdot
.52442 .45575 Mdot
.54884 .45575 Mdot
.57326 .45575 Mdot
.59768 .45575 Mdot
.6221 .45575 Mdot
.64652 .45575 Mdot
.67094 .45575 Mdot
.69536 .45575 Mdot
.71978 .45575 Mdot
.7442 .45575 Mdot
.76862 .45575 Mdot
.79304 .45575 Mdot
.81746 .45575 Mdot
.84188 .45575 Mdot
.8663 .45575 Mdot
.89072 .45575 Mdot
.91514 .45575 Mdot
.93956 .45575 Mdot
.96398 .45575 Mdot
.02381 .4769 Mdot
.04823 .4769 Mdot
.07265 .4769 Mdot
.09707 .4769 Mdot
.12149 .4769 Mdot
.14591 .4769 Mdot
.17033 .4769 Mdot
.19475 .4769 Mdot
.21917 .4769 Mdot
.24359 .4769 Mdot
.26801 .4769 Mdot
.29243 .4769 Mdot
.31685 .4769 Mdot
.34127 .4769 Mdot
.36569 .4769 Mdot
.39011 .4769 Mdot
.41453 .4769 Mdot
.43895 .4769 Mdot
.46337 .4769 Mdot
.48779 .4769 Mdot
.51221 .4769 Mdot
.53663 .4769 Mdot
.56105 .4769 Mdot
.58547 .4769 Mdot
.60989 .4769 Mdot
.63431 .4769 Mdot
.65873 .4769 Mdot
.68315 .4769 Mdot
.70757 .4769 Mdot
.73199 .4769 Mdot
.75641 .4769 Mdot
.78083 .4769 Mdot
.80525 .4769 Mdot
.82967 .4769 Mdot
.85409 .4769 Mdot
.87851 .4769 Mdot
.90293 .4769 Mdot
.92735 .4769 Mdot
.95177 .4769 Mdot
.97619 .4769 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[12]:=",
  ImageSize->{288, 140.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000da000`40O003h00OfFmk00<006mkKg/0
e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk000>Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20004Kg/0
0`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/2000;Kg/000e_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00I_N`@000I_N`@000=_N`04001_NfmkKg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000e_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000M_N`@000I_N`@000I_N`@000=_N`04001_NfmkKg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000i_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000A_N`<0009_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk
003IKg/00`00Kg]_N`3DKg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`80015_N`004fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10001Vmk100046mk000CKg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/4000@Kg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`80015_N`00fFmk0`00e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00
fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000A_N`03001_Nfmk009_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`003Fmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10000fmk00@006mk
Kg]_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00Y_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1Vmk10000fmk00@006mkKg]_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000M_N`@000Y_N`003Vmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P0026mk0P0016mk00<006mkKg/00Vmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P002fmk003IKg/00`00Kg]_N`3DKg/00=U_N`03
001_Nfmk0=A_N`00fFmk0`00e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`0056mk
0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P004Fmk000CKg/4
0006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000@Kg/001=_N`@0
00I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@0
00M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@0
00I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@0011_N`0056mk0P00
26mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
2Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P004Fmk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/3003DKg/00=U_N`03
001_Nfmk0=A_N`003Vmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00
26mk0P0026mk0P0016mk00<006mkKg/00Vmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P002fmk000=Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40003Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/40006Kg/4
0006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40003Kg/01000Kg]_Nfmk1000
1Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000>
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20004
Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/2000;Kg/00=U_N`03001_Nfmk0=A_N`00^fmk10001Vmk0P001Vmk100026mk00<006mk
Kg/0e6mk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`3DKg/00;Y_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk00E_N`03
001_Nfmk0=A_N`00^Vmk00<006mkKg/00Vmk00<006mkKg/03fmk00<006mkKg/01Fmk1000dfmk000D
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/80002Kg/20004Kg/00`00Kg]_N`02Kg/2000;
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0AKg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20008Kg/2000AKg/001=_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000=_
N`04001_NfmkKg/40006Kg/40008Kg/00`00Kg]_N`0@Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/4000@Kg/001=_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000=_N`04001_NfmkKg/40006Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0@Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000@Kg/001A_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000A_N`03001_Nfmk009_N`8000M_N`03001_Nfmk00U_N`03001_
Nfmk015_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80015_N`00^fmk
10003Vmk1@001fmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00
fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8002=_N`03001_Nfmk025_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000]_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10008Vmk
0`0086mk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4000RKg/00`00Kg]_N`0PKg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4
0006Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8002=_N`03001_Nfmk025_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000]_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_
N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/001A_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8002Q_N`03001_Nfmk02I_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
015_N`004fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10009fmk00<006mkKg/09Fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001Vmk100046mk000CKg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/4000WKg/3000UKg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000@Kg/001A_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8002Q_N`03001_Nfmk02I_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`80015_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/0
0=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8002e_N`03001_Nfmk02]_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000]_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000;6mk
00<006mkKg/0:Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/4000/Kg/00`00Kg]_N`0ZKg/40006Kg/40007Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/4000:Kg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8002e_N`<0
02]_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`00fFmk00<006mkKg/0e6mk003I
Kg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`002fmk1P00HFmk1`00H6mk00<006mkKg/0HFmk
1`00HFmk1P001Fmk000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`1RKg/00`00Kg]_N`1QKg/00`00Kg]_
N`1TKg/00`00Kg]_N`1RKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/000a_N`03001_Nfmk00E_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80009_N`03
001_Nfmk00=_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80039_N`03001_Nfmk031_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000M_N`03001_Nfmk00M_N`003Fmk00<006mkKg/00fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk100000=_N`00Kg/00fmk
10001fmk10001Vmk10001Vmk10001fmk1000<Fmk00<006mkKg/0;fmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk00<006mkKg/01Vmk0002Kg/60006Kg/00`00Kg]_N`02Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/:00000fmk0000000200000fmk001_N`03
Kg/40007Kg/40006Kg/40006Kg/40007Kg/4000aKg/00`00Kg]_N`0_Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40008Kg/00`00Kg]_N`05Kg/000m_N`03001_Nfmk009_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80009_N`03001_Nfmk00=_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`80039_N`03001_Nfmk031_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000Y_N`03001_Nfmk00A_N`002fmk00<006mkKg/00Vmk00<006mkKg/0HVmk00<006mkKg/0HFmk
00<006mkKg/0I6mk00<006mkKg/0HVmk00<006mkKg/00Vmk00<006mkKg/00fmk000;Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`1PKg/3001SKg/3001RKg/3001TKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
00a_N`@006E_N`03001_Nfmk065_N`03001_Nfmk06A_N`03001_Nfmk06=_N`@000I_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8003Q_
N`03001_Nfmk03E_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`003Fmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001Vmk1000=fmk00<006mkKg/0=6mk10001fmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk
000=Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000gKg/00`00Kg]_N`0dKg/40007Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/4000:Kg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8003Q_N`03001_Nfmk
03E_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`00fFmk00<006mkKg/0e6mk003IKg/00`00
Kg]_N`3DKg/000E_Nol00:X0009_N`002Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/0
4Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/0
4Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/0
4Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/0
4Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/01Fmk000:Kg/00`00Kg]_N`0AKg/00`00
Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00
Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00
Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00
Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`05Kg/000Y_
N`03001_Nfmk00M_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80039_N`03001_Nfmk031_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`03001_Nfmk00E_N`004fmk10001Vmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk1000<Fmk00<006mkKg/0;fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk100046mk000CKg/4
0006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/4000aKg/00`00Kg]_N`0_Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4
0006Kg/4000@Kg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80039_N`03001_Nfmk031_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`80015_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00fFmk0`00e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8003Q_N`03001_Nfmk03E_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00]_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000=fmk00<006mkKg/0=6mk10001fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000gKg/00`00
Kg]_N`0dKg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000i_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8003Q_N`03001_Nfmk03E_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`00fFmk
00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0
e6mk003IKg/00`00Kg]_N`3DKg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80039_N`<0031_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80015_N`004fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
1000<Fmk00<006mkKg/0;fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk100046mk000CKg/40006Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/4000aKg/00`00Kg]_N`0_Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
000@Kg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80039_N`03001_Nfmk031_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`80015_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_
N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8002e_N`03001_Nfmk02]_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000]_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000;6mk0`00
:Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/4000/Kg/00`00Kg]_N`0ZKg/40006Kg/40007Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/4000:Kg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8002e_N`03001_Nfmk02]_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000]_N`00fFmk00<006mkKg/0e6mk003IKg/0
0`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8002Q_N`03001_Nfmk02I_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80015_N`004fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10009fmk00<006mkKg/09Fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk100046mk
000CKg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4000WKg/00`00Kg]_N`0UKg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/4000@Kg/001A_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8002Q_N`<002I_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80015_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk
003IKg/00`00Kg]_N`3DKg/000i_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00E_N`H000A_N`8000I_N`@000Q_N`03001_Nfmk01I_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000]_N`003Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10000fmk00@006mkKg]_N`@000=_N`8000E_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_
Nfmk01E_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000Y_N`003Fmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10000fmk00@006mkKg]_N`@000m_N`03
001_Nfmk00E_N`03001_Nfmk01E_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@0
00M_N`@000Y_N`003Vmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0016mk00<0
06mkKg/00Vmk0P0046mk00<006mkKg/01Fmk00<006mkKg/05Vmk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P002fmk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/00`00
Kg]_N`05Kg/4003CKg/00;Y_N`03001_Nfmk009_N`03001_Nfmk00]_N`@000Q_N`03001_Nfmk0=A_
N`00^Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mkKg/0e6mk002jKg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/00`00Kg]_N`3DKg/00;]_N`@000i_N`D0
00M_N`03001_Nfmk0=A_N`0056mk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P0026mk0P004Fmk000CKg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/4000@Kg/001=_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000I_N`@0011_N`0056mk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk
0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P0026mk0P004Fmk003IKg/00`00Kg]_N`3DKg/00=U_N`<00=A_N`00fFmk00<006mkKg/0e6mk003I
Kg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`003Vmk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P0016mk00<006mkKg/00Vmk0P0026mk0P0026mk
0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P002fmk000=Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40003Kg/01000Kg]_
Nfmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
2Vmk000=Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40003Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001fmk10002Vmk000>Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/20004Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000;Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`<00=A_N`00fFmk00<006mkKg/0e6mk000DKg/2
0008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000AKg/001=_N`@0
00I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@0
00M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@0
00I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@0011_N`004fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk100046mk000DKg/20008
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000AKg/00=U_N`03001_
Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00
fFmk0`00e6mk000>Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20004Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/20009Kg/2000;Kg/000e_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000M_N`@000I_N`@000I_N`@000=_N`04001_NfmkKg/40006Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000e_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@0
00I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000=_N`04001_NfmkKg/40006
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4000:Kg/000i_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000A_
N`03001_Nfmk009_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000]_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk
0=A_N`00fFmk00<006mkKg/0e6mk000DKg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20008Kg/2000AKg/001=_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000M_N`@000I_N`@000I_N`D000I_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000I_N`@0011_N`004fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001Vmk100046mk000DKg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/2000AKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00c6mk1`001Vmk00<006mkKg/0e6mk000>Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20004Kg/01000Kg]_Nfmk0P00
16mk00<006mkKg/00Vmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
2Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P002fmk000=Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40003Kg/00`00Kg]_N`040003Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Vmk000=Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40003Kg/00`00Kg]_N`040003Kg/01000Kg]_
Nfmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
2Vmk000>Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20004
Kg/01000Kg]_Nfmk0P0016mk100000=_N`00000026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P002fmk003?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`3DKg/00<m_
N`03001_Nfmk00M_N`03001_Nfmk0=A_N`00cFmk0`002Fmk00<006mkKg/0e6mk003?Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`3DKg/00?m_Nk5_N`00ofmk/Fmk0000\
\>"],
  ImageRangeCache->{{{0, 431}, {210, 0}} -> {-2.09889, -0.961038, 0.0144726, \
0.0144726}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "There are two other places where the distance function is used. One is to \
select interior meshbars (discussed later). The other is to move meshpoints \
back onto the boundary (",
  StyleBox["step 7",
    FontSlant->"Italic"],
  "), if they were pushed out."
}], "Text"],

Cell[TextData[{
  "The closest boundary point to an outsider is along the gradient direction \
of the distance function. The function ",
  StyleBox["NGrad",
    FontFamily->"Courier"],
  " calculates numerically the gradient for a given distance function at a \
specific point. "
}], "Text"],

Cell[BoxData[
    \(NGrad[d_, {x0_, y0_}] := {ND[d[{x, y0}], x, x0], 
        ND[d[{x0, y}], y, y0]}\)], "Input",
  CellLabel->"In[13]:="],

Cell[TextData[{
  "Then the function ",
  StyleBox["backtoBoundary",
    FontFamily->"Courier"],
  " moves an outsider onto the closest boundary point. (",
  StyleBox["FindRoot",
    FontFamily->"Courier"],
  " is used to find the boundary point, which is a little bit different from \
",
  StyleBox["step 7",
    FontSlant->"Italic"],
  " in paper.)"
}], "Text"],

Cell[BoxData[
    \(backtoBoundary[d_, {x_, y_}] := 
      Module[{expr}, 
        expr = {x, y} - 
            s\ NGrad[d, {x, y}]; \[IndentingNewLine]expr /. \((FindRoot[
              d[expr], \ {s, 0}])\)]\)], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
To test this function, let's move all these points in a rectangle onto a \
circular boundary.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((pointseverywhere = seedMeshpoints[{\(-2\), \(-1\), \ 2, 1}, 0.1])\) // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[15]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .49182 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.494121 0.235156 0.246866 0.235156 [
[.02381 .23437 -6 -9 ]
[.02381 .23437 6 0 ]
[.25897 .23437 -6 -9 ]
[.25897 .23437 6 0 ]
[.72928 .23437 -3 -9 ]
[.72928 .23437 3 0 ]
[.96443 .23437 -3 -9 ]
[.96443 .23437 3 0 ]
[.48162 .01171 -12 -4.5 ]
[.48162 .01171 0 4.5 ]
[.48162 .12929 -24 -4.5 ]
[.48162 .12929 0 4.5 ]
[.48162 .36444 -18 -4.5 ]
[.48162 .36444 0 4.5 ]
[.48162 .48202 -6 -4.5 ]
[.48162 .48202 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .49182 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .24687 m
.02381 .25312 L
s
[(-2)] .02381 .23437 0 1 Mshowa
.25897 .24687 m
.25897 .25312 L
s
[(-1)] .25897 .23437 0 1 Mshowa
.72928 .24687 m
.72928 .25312 L
s
[(1)] .72928 .23437 0 1 Mshowa
.96443 .24687 m
.96443 .25312 L
s
[(2)] .96443 .23437 0 1 Mshowa
.125 Mabswid
.07084 .24687 m
.07084 .25062 L
s
.11787 .24687 m
.11787 .25062 L
s
.1649 .24687 m
.1649 .25062 L
s
.21193 .24687 m
.21193 .25062 L
s
.306 .24687 m
.306 .25062 L
s
.35303 .24687 m
.35303 .25062 L
s
.40006 .24687 m
.40006 .25062 L
s
.44709 .24687 m
.44709 .25062 L
s
.54115 .24687 m
.54115 .25062 L
s
.58818 .24687 m
.58818 .25062 L
s
.63521 .24687 m
.63521 .25062 L
s
.68225 .24687 m
.68225 .25062 L
s
.77631 .24687 m
.77631 .25062 L
s
.82334 .24687 m
.82334 .25062 L
s
.87037 .24687 m
.87037 .25062 L
s
.9174 .24687 m
.9174 .25062 L
s
.25 Mabswid
0 .24687 m
1 .24687 L
s
.49412 .01171 m
.50037 .01171 L
s
[(-1)] .48162 .01171 1 0 Mshowa
.49412 .12929 m
.50037 .12929 L
s
[(-0.5)] .48162 .12929 1 0 Mshowa
.49412 .36444 m
.50037 .36444 L
s
[(0.5)] .48162 .36444 1 0 Mshowa
.49412 .48202 m
.50037 .48202 L
s
[(1)] .48162 .48202 1 0 Mshowa
.125 Mabswid
.49412 .03523 m
.49787 .03523 L
s
.49412 .05874 m
.49787 .05874 L
s
.49412 .08226 m
.49787 .08226 L
s
.49412 .10577 m
.49787 .10577 L
s
.49412 .1528 m
.49787 .1528 L
s
.49412 .17632 m
.49787 .17632 L
s
.49412 .19983 m
.49787 .19983 L
s
.49412 .22335 m
.49787 .22335 L
s
.49412 .27038 m
.49787 .27038 L
s
.49412 .2939 m
.49787 .2939 L
s
.49412 .31741 m
.49787 .31741 L
s
.49412 .34093 m
.49787 .34093 L
s
.49412 .38796 m
.49787 .38796 L
s
.49412 .41147 m
.49787 .41147 L
s
.49412 .43499 m
.49787 .43499 L
s
.49412 .45851 m
.49787 .45851 L
s
.25 Mabswid
.49412 0 m
.49412 .49182 L
s
0 0 m
1 0 L
1 .49182 L
0 .49182 L
closepath
clip
newpath
.01 w
.02381 .01171 Mdot
.04733 .01171 Mdot
.07084 .01171 Mdot
.09436 .01171 Mdot
.11787 .01171 Mdot
.14139 .01171 Mdot
.1649 .01171 Mdot
.18842 .01171 Mdot
.21193 .01171 Mdot
.23545 .01171 Mdot
.25897 .01171 Mdot
.28248 .01171 Mdot
.306 .01171 Mdot
.32951 .01171 Mdot
.35303 .01171 Mdot
.37654 .01171 Mdot
.40006 .01171 Mdot
.42357 .01171 Mdot
.44709 .01171 Mdot
.47061 .01171 Mdot
.49412 .01171 Mdot
.51764 .01171 Mdot
.54115 .01171 Mdot
.56467 .01171 Mdot
.58818 .01171 Mdot
.6117 .01171 Mdot
.63521 .01171 Mdot
.65873 .01171 Mdot
.68225 .01171 Mdot
.70576 .01171 Mdot
.72928 .01171 Mdot
.75279 .01171 Mdot
.77631 .01171 Mdot
.79982 .01171 Mdot
.82334 .01171 Mdot
.84685 .01171 Mdot
.87037 .01171 Mdot
.89389 .01171 Mdot
.9174 .01171 Mdot
.94092 .01171 Mdot
.96443 .01171 Mdot
.03557 .03208 Mdot
.05908 .03208 Mdot
.0826 .03208 Mdot
.10611 .03208 Mdot
.12963 .03208 Mdot
.15315 .03208 Mdot
.17666 .03208 Mdot
.20018 .03208 Mdot
.22369 .03208 Mdot
.24721 .03208 Mdot
.27072 .03208 Mdot
.29424 .03208 Mdot
.31775 .03208 Mdot
.34127 .03208 Mdot
.36479 .03208 Mdot
.3883 .03208 Mdot
.41182 .03208 Mdot
.43533 .03208 Mdot
.45885 .03208 Mdot
.48236 .03208 Mdot
.50588 .03208 Mdot
.52939 .03208 Mdot
.55291 .03208 Mdot
.57643 .03208 Mdot
.59994 .03208 Mdot
.62346 .03208 Mdot
.64697 .03208 Mdot
.67049 .03208 Mdot
.694 .03208 Mdot
.71752 .03208 Mdot
.74103 .03208 Mdot
.76455 .03208 Mdot
.78807 .03208 Mdot
.81158 .03208 Mdot
.8351 .03208 Mdot
.85861 .03208 Mdot
.88213 .03208 Mdot
.90564 .03208 Mdot
.92916 .03208 Mdot
.95267 .03208 Mdot
.97619 .03208 Mdot
.02381 .05244 Mdot
.04733 .05244 Mdot
.07084 .05244 Mdot
.09436 .05244 Mdot
.11787 .05244 Mdot
.14139 .05244 Mdot
.1649 .05244 Mdot
.18842 .05244 Mdot
.21193 .05244 Mdot
.23545 .05244 Mdot
.25897 .05244 Mdot
.28248 .05244 Mdot
.306 .05244 Mdot
.32951 .05244 Mdot
.35303 .05244 Mdot
.37654 .05244 Mdot
.40006 .05244 Mdot
.42357 .05244 Mdot
.44709 .05244 Mdot
.47061 .05244 Mdot
.49412 .05244 Mdot
.51764 .05244 Mdot
.54115 .05244 Mdot
.56467 .05244 Mdot
.58818 .05244 Mdot
.6117 .05244 Mdot
.63521 .05244 Mdot
.65873 .05244 Mdot
.68225 .05244 Mdot
.70576 .05244 Mdot
.72928 .05244 Mdot
.75279 .05244 Mdot
.77631 .05244 Mdot
.79982 .05244 Mdot
.82334 .05244 Mdot
.84685 .05244 Mdot
.87037 .05244 Mdot
.89389 .05244 Mdot
.9174 .05244 Mdot
.94092 .05244 Mdot
.96443 .05244 Mdot
.03557 .07281 Mdot
.05908 .07281 Mdot
.0826 .07281 Mdot
.10611 .07281 Mdot
.12963 .07281 Mdot
.15315 .07281 Mdot
.17666 .07281 Mdot
.20018 .07281 Mdot
.22369 .07281 Mdot
.24721 .07281 Mdot
.27072 .07281 Mdot
.29424 .07281 Mdot
.31775 .07281 Mdot
.34127 .07281 Mdot
.36479 .07281 Mdot
.3883 .07281 Mdot
.41182 .07281 Mdot
.43533 .07281 Mdot
.45885 .07281 Mdot
.48236 .07281 Mdot
.50588 .07281 Mdot
.52939 .07281 Mdot
.55291 .07281 Mdot
.57643 .07281 Mdot
.59994 .07281 Mdot
.62346 .07281 Mdot
.64697 .07281 Mdot
.67049 .07281 Mdot
.694 .07281 Mdot
.71752 .07281 Mdot
.74103 .07281 Mdot
.76455 .07281 Mdot
.78807 .07281 Mdot
.81158 .07281 Mdot
.8351 .07281 Mdot
.85861 .07281 Mdot
.88213 .07281 Mdot
.90564 .07281 Mdot
.92916 .07281 Mdot
.95267 .07281 Mdot
.97619 .07281 Mdot
.02381 .09317 Mdot
.04733 .09317 Mdot
.07084 .09317 Mdot
.09436 .09317 Mdot
.11787 .09317 Mdot
.14139 .09317 Mdot
.1649 .09317 Mdot
.18842 .09317 Mdot
.21193 .09317 Mdot
.23545 .09317 Mdot
.25897 .09317 Mdot
.28248 .09317 Mdot
.306 .09317 Mdot
.32951 .09317 Mdot
.35303 .09317 Mdot
.37654 .09317 Mdot
.40006 .09317 Mdot
.42357 .09317 Mdot
.44709 .09317 Mdot
.47061 .09317 Mdot
.49412 .09317 Mdot
.51764 .09317 Mdot
.54115 .09317 Mdot
.56467 .09317 Mdot
.58818 .09317 Mdot
.6117 .09317 Mdot
.63521 .09317 Mdot
.65873 .09317 Mdot
.68225 .09317 Mdot
.70576 .09317 Mdot
.72928 .09317 Mdot
.75279 .09317 Mdot
.77631 .09317 Mdot
.79982 .09317 Mdot
.82334 .09317 Mdot
.84685 .09317 Mdot
.87037 .09317 Mdot
.89389 .09317 Mdot
.9174 .09317 Mdot
.94092 .09317 Mdot
.96443 .09317 Mdot
.03557 .11354 Mdot
.05908 .11354 Mdot
.0826 .11354 Mdot
.10611 .11354 Mdot
.12963 .11354 Mdot
.15315 .11354 Mdot
.17666 .11354 Mdot
.20018 .11354 Mdot
.22369 .11354 Mdot
.24721 .11354 Mdot
.27072 .11354 Mdot
.29424 .11354 Mdot
.31775 .11354 Mdot
.34127 .11354 Mdot
.36479 .11354 Mdot
.3883 .11354 Mdot
.41182 .11354 Mdot
.43533 .11354 Mdot
.45885 .11354 Mdot
.48236 .11354 Mdot
.50588 .11354 Mdot
.52939 .11354 Mdot
.55291 .11354 Mdot
.57643 .11354 Mdot
.59994 .11354 Mdot
.62346 .11354 Mdot
.64697 .11354 Mdot
.67049 .11354 Mdot
.694 .11354 Mdot
.71752 .11354 Mdot
.74103 .11354 Mdot
.76455 .11354 Mdot
.78807 .11354 Mdot
.81158 .11354 Mdot
.8351 .11354 Mdot
.85861 .11354 Mdot
.88213 .11354 Mdot
.90564 .11354 Mdot
.92916 .11354 Mdot
.95267 .11354 Mdot
.97619 .11354 Mdot
.02381 .1339 Mdot
.04733 .1339 Mdot
.07084 .1339 Mdot
.09436 .1339 Mdot
.11787 .1339 Mdot
.14139 .1339 Mdot
.1649 .1339 Mdot
.18842 .1339 Mdot
.21193 .1339 Mdot
.23545 .1339 Mdot
.25897 .1339 Mdot
.28248 .1339 Mdot
.306 .1339 Mdot
.32951 .1339 Mdot
.35303 .1339 Mdot
.37654 .1339 Mdot
.40006 .1339 Mdot
.42357 .1339 Mdot
.44709 .1339 Mdot
.47061 .1339 Mdot
.49412 .1339 Mdot
.51764 .1339 Mdot
.54115 .1339 Mdot
.56467 .1339 Mdot
.58818 .1339 Mdot
.6117 .1339 Mdot
.63521 .1339 Mdot
.65873 .1339 Mdot
.68225 .1339 Mdot
.70576 .1339 Mdot
.72928 .1339 Mdot
.75279 .1339 Mdot
.77631 .1339 Mdot
.79982 .1339 Mdot
.82334 .1339 Mdot
.84685 .1339 Mdot
.87037 .1339 Mdot
.89389 .1339 Mdot
.9174 .1339 Mdot
.94092 .1339 Mdot
.96443 .1339 Mdot
.03557 .15427 Mdot
.05908 .15427 Mdot
.0826 .15427 Mdot
.10611 .15427 Mdot
.12963 .15427 Mdot
.15315 .15427 Mdot
.17666 .15427 Mdot
.20018 .15427 Mdot
.22369 .15427 Mdot
.24721 .15427 Mdot
.27072 .15427 Mdot
.29424 .15427 Mdot
.31775 .15427 Mdot
.34127 .15427 Mdot
.36479 .15427 Mdot
.3883 .15427 Mdot
.41182 .15427 Mdot
.43533 .15427 Mdot
.45885 .15427 Mdot
.48236 .15427 Mdot
.50588 .15427 Mdot
.52939 .15427 Mdot
.55291 .15427 Mdot
.57643 .15427 Mdot
.59994 .15427 Mdot
.62346 .15427 Mdot
.64697 .15427 Mdot
.67049 .15427 Mdot
.694 .15427 Mdot
.71752 .15427 Mdot
.74103 .15427 Mdot
.76455 .15427 Mdot
.78807 .15427 Mdot
.81158 .15427 Mdot
.8351 .15427 Mdot
.85861 .15427 Mdot
.88213 .15427 Mdot
.90564 .15427 Mdot
.92916 .15427 Mdot
.95267 .15427 Mdot
.97619 .15427 Mdot
.02381 .17463 Mdot
.04733 .17463 Mdot
.07084 .17463 Mdot
.09436 .17463 Mdot
.11787 .17463 Mdot
.14139 .17463 Mdot
.1649 .17463 Mdot
.18842 .17463 Mdot
.21193 .17463 Mdot
.23545 .17463 Mdot
.25897 .17463 Mdot
.28248 .17463 Mdot
.306 .17463 Mdot
.32951 .17463 Mdot
.35303 .17463 Mdot
.37654 .17463 Mdot
.40006 .17463 Mdot
.42357 .17463 Mdot
.44709 .17463 Mdot
.47061 .17463 Mdot
.49412 .17463 Mdot
.51764 .17463 Mdot
.54115 .17463 Mdot
.56467 .17463 Mdot
.58818 .17463 Mdot
.6117 .17463 Mdot
.63521 .17463 Mdot
.65873 .17463 Mdot
.68225 .17463 Mdot
.70576 .17463 Mdot
.72928 .17463 Mdot
.75279 .17463 Mdot
.77631 .17463 Mdot
.79982 .17463 Mdot
.82334 .17463 Mdot
.84685 .17463 Mdot
.87037 .17463 Mdot
.89389 .17463 Mdot
.9174 .17463 Mdot
.94092 .17463 Mdot
.96443 .17463 Mdot
.03557 .195 Mdot
.05908 .195 Mdot
.0826 .195 Mdot
.10611 .195 Mdot
.12963 .195 Mdot
.15315 .195 Mdot
.17666 .195 Mdot
.20018 .195 Mdot
.22369 .195 Mdot
.24721 .195 Mdot
.27072 .195 Mdot
.29424 .195 Mdot
.31775 .195 Mdot
.34127 .195 Mdot
.36479 .195 Mdot
.3883 .195 Mdot
.41182 .195 Mdot
.43533 .195 Mdot
.45885 .195 Mdot
.48236 .195 Mdot
.50588 .195 Mdot
.52939 .195 Mdot
.55291 .195 Mdot
.57643 .195 Mdot
.59994 .195 Mdot
.62346 .195 Mdot
.64697 .195 Mdot
.67049 .195 Mdot
.694 .195 Mdot
.71752 .195 Mdot
.74103 .195 Mdot
.76455 .195 Mdot
.78807 .195 Mdot
.81158 .195 Mdot
.8351 .195 Mdot
.85861 .195 Mdot
.88213 .195 Mdot
.90564 .195 Mdot
.92916 .195 Mdot
.95267 .195 Mdot
.97619 .195 Mdot
.02381 .21536 Mdot
.04733 .21536 Mdot
.07084 .21536 Mdot
.09436 .21536 Mdot
.11787 .21536 Mdot
.14139 .21536 Mdot
.1649 .21536 Mdot
.18842 .21536 Mdot
.21193 .21536 Mdot
.23545 .21536 Mdot
.25897 .21536 Mdot
.28248 .21536 Mdot
.306 .21536 Mdot
.32951 .21536 Mdot
.35303 .21536 Mdot
.37654 .21536 Mdot
.40006 .21536 Mdot
.42357 .21536 Mdot
.44709 .21536 Mdot
.47061 .21536 Mdot
.49412 .21536 Mdot
.51764 .21536 Mdot
.54115 .21536 Mdot
.56467 .21536 Mdot
.58818 .21536 Mdot
.6117 .21536 Mdot
.63521 .21536 Mdot
.65873 .21536 Mdot
.68225 .21536 Mdot
.70576 .21536 Mdot
.72928 .21536 Mdot
.75279 .21536 Mdot
.77631 .21536 Mdot
.79982 .21536 Mdot
.82334 .21536 Mdot
.84685 .21536 Mdot
.87037 .21536 Mdot
.89389 .21536 Mdot
.9174 .21536 Mdot
.94092 .21536 Mdot
.96443 .21536 Mdot
.03557 .23573 Mdot
.05908 .23573 Mdot
.0826 .23573 Mdot
.10611 .23573 Mdot
.12963 .23573 Mdot
.15315 .23573 Mdot
.17666 .23573 Mdot
.20018 .23573 Mdot
.22369 .23573 Mdot
.24721 .23573 Mdot
.27072 .23573 Mdot
.29424 .23573 Mdot
.31775 .23573 Mdot
.34127 .23573 Mdot
.36479 .23573 Mdot
.3883 .23573 Mdot
.41182 .23573 Mdot
.43533 .23573 Mdot
.45885 .23573 Mdot
.48236 .23573 Mdot
.50588 .23573 Mdot
.52939 .23573 Mdot
.55291 .23573 Mdot
.57643 .23573 Mdot
.59994 .23573 Mdot
.62346 .23573 Mdot
.64697 .23573 Mdot
.67049 .23573 Mdot
.694 .23573 Mdot
.71752 .23573 Mdot
.74103 .23573 Mdot
.76455 .23573 Mdot
.78807 .23573 Mdot
.81158 .23573 Mdot
.8351 .23573 Mdot
.85861 .23573 Mdot
.88213 .23573 Mdot
.90564 .23573 Mdot
.92916 .23573 Mdot
.95267 .23573 Mdot
.97619 .23573 Mdot
.02381 .25609 Mdot
.04733 .25609 Mdot
.07084 .25609 Mdot
.09436 .25609 Mdot
.11787 .25609 Mdot
.14139 .25609 Mdot
.1649 .25609 Mdot
.18842 .25609 Mdot
.21193 .25609 Mdot
.23545 .25609 Mdot
.25897 .25609 Mdot
.28248 .25609 Mdot
.306 .25609 Mdot
.32951 .25609 Mdot
.35303 .25609 Mdot
.37654 .25609 Mdot
.40006 .25609 Mdot
.42357 .25609 Mdot
.44709 .25609 Mdot
.47061 .25609 Mdot
.49412 .25609 Mdot
.51764 .25609 Mdot
.54115 .25609 Mdot
.56467 .25609 Mdot
.58818 .25609 Mdot
.6117 .25609 Mdot
.63521 .25609 Mdot
.65873 .25609 Mdot
.68225 .25609 Mdot
.70576 .25609 Mdot
.72928 .25609 Mdot
.75279 .25609 Mdot
.77631 .25609 Mdot
.79982 .25609 Mdot
.82334 .25609 Mdot
.84685 .25609 Mdot
.87037 .25609 Mdot
.89389 .25609 Mdot
.9174 .25609 Mdot
.94092 .25609 Mdot
.96443 .25609 Mdot
.03557 .27646 Mdot
.05908 .27646 Mdot
.0826 .27646 Mdot
.10611 .27646 Mdot
.12963 .27646 Mdot
.15315 .27646 Mdot
.17666 .27646 Mdot
.20018 .27646 Mdot
.22369 .27646 Mdot
.24721 .27646 Mdot
.27072 .27646 Mdot
.29424 .27646 Mdot
.31775 .27646 Mdot
.34127 .27646 Mdot
.36479 .27646 Mdot
.3883 .27646 Mdot
.41182 .27646 Mdot
.43533 .27646 Mdot
.45885 .27646 Mdot
.48236 .27646 Mdot
.50588 .27646 Mdot
.52939 .27646 Mdot
.55291 .27646 Mdot
.57643 .27646 Mdot
.59994 .27646 Mdot
.62346 .27646 Mdot
.64697 .27646 Mdot
.67049 .27646 Mdot
.694 .27646 Mdot
.71752 .27646 Mdot
.74103 .27646 Mdot
.76455 .27646 Mdot
.78807 .27646 Mdot
.81158 .27646 Mdot
.8351 .27646 Mdot
.85861 .27646 Mdot
.88213 .27646 Mdot
.90564 .27646 Mdot
.92916 .27646 Mdot
.95267 .27646 Mdot
.97619 .27646 Mdot
.02381 .29682 Mdot
.04733 .29682 Mdot
.07084 .29682 Mdot
.09436 .29682 Mdot
.11787 .29682 Mdot
.14139 .29682 Mdot
.1649 .29682 Mdot
.18842 .29682 Mdot
.21193 .29682 Mdot
.23545 .29682 Mdot
.25897 .29682 Mdot
.28248 .29682 Mdot
.306 .29682 Mdot
.32951 .29682 Mdot
.35303 .29682 Mdot
.37654 .29682 Mdot
.40006 .29682 Mdot
.42357 .29682 Mdot
.44709 .29682 Mdot
.47061 .29682 Mdot
.49412 .29682 Mdot
.51764 .29682 Mdot
.54115 .29682 Mdot
.56467 .29682 Mdot
.58818 .29682 Mdot
.6117 .29682 Mdot
.63521 .29682 Mdot
.65873 .29682 Mdot
.68225 .29682 Mdot
.70576 .29682 Mdot
.72928 .29682 Mdot
.75279 .29682 Mdot
.77631 .29682 Mdot
.79982 .29682 Mdot
.82334 .29682 Mdot
.84685 .29682 Mdot
.87037 .29682 Mdot
.89389 .29682 Mdot
.9174 .29682 Mdot
.94092 .29682 Mdot
.96443 .29682 Mdot
.03557 .31719 Mdot
.05908 .31719 Mdot
.0826 .31719 Mdot
.10611 .31719 Mdot
.12963 .31719 Mdot
.15315 .31719 Mdot
.17666 .31719 Mdot
.20018 .31719 Mdot
.22369 .31719 Mdot
.24721 .31719 Mdot
.27072 .31719 Mdot
.29424 .31719 Mdot
.31775 .31719 Mdot
.34127 .31719 Mdot
.36479 .31719 Mdot
.3883 .31719 Mdot
.41182 .31719 Mdot
.43533 .31719 Mdot
.45885 .31719 Mdot
.48236 .31719 Mdot
.50588 .31719 Mdot
.52939 .31719 Mdot
.55291 .31719 Mdot
.57643 .31719 Mdot
.59994 .31719 Mdot
.62346 .31719 Mdot
.64697 .31719 Mdot
.67049 .31719 Mdot
.694 .31719 Mdot
.71752 .31719 Mdot
.74103 .31719 Mdot
.76455 .31719 Mdot
.78807 .31719 Mdot
.81158 .31719 Mdot
.8351 .31719 Mdot
.85861 .31719 Mdot
.88213 .31719 Mdot
.90564 .31719 Mdot
.92916 .31719 Mdot
.95267 .31719 Mdot
.97619 .31719 Mdot
.02381 .33755 Mdot
.04733 .33755 Mdot
.07084 .33755 Mdot
.09436 .33755 Mdot
.11787 .33755 Mdot
.14139 .33755 Mdot
.1649 .33755 Mdot
.18842 .33755 Mdot
.21193 .33755 Mdot
.23545 .33755 Mdot
.25897 .33755 Mdot
.28248 .33755 Mdot
.306 .33755 Mdot
.32951 .33755 Mdot
.35303 .33755 Mdot
.37654 .33755 Mdot
.40006 .33755 Mdot
.42357 .33755 Mdot
.44709 .33755 Mdot
.47061 .33755 Mdot
.49412 .33755 Mdot
.51764 .33755 Mdot
.54115 .33755 Mdot
.56467 .33755 Mdot
.58818 .33755 Mdot
.6117 .33755 Mdot
.63521 .33755 Mdot
.65873 .33755 Mdot
.68225 .33755 Mdot
.70576 .33755 Mdot
.72928 .33755 Mdot
.75279 .33755 Mdot
.77631 .33755 Mdot
.79982 .33755 Mdot
.82334 .33755 Mdot
.84685 .33755 Mdot
.87037 .33755 Mdot
.89389 .33755 Mdot
.9174 .33755 Mdot
.94092 .33755 Mdot
.96443 .33755 Mdot
.03557 .35792 Mdot
.05908 .35792 Mdot
.0826 .35792 Mdot
.10611 .35792 Mdot
.12963 .35792 Mdot
.15315 .35792 Mdot
.17666 .35792 Mdot
.20018 .35792 Mdot
.22369 .35792 Mdot
.24721 .35792 Mdot
.27072 .35792 Mdot
.29424 .35792 Mdot
.31775 .35792 Mdot
.34127 .35792 Mdot
.36479 .35792 Mdot
.3883 .35792 Mdot
.41182 .35792 Mdot
.43533 .35792 Mdot
.45885 .35792 Mdot
.48236 .35792 Mdot
.50588 .35792 Mdot
.52939 .35792 Mdot
.55291 .35792 Mdot
.57643 .35792 Mdot
.59994 .35792 Mdot
.62346 .35792 Mdot
.64697 .35792 Mdot
.67049 .35792 Mdot
.694 .35792 Mdot
.71752 .35792 Mdot
.74103 .35792 Mdot
.76455 .35792 Mdot
.78807 .35792 Mdot
.81158 .35792 Mdot
.8351 .35792 Mdot
.85861 .35792 Mdot
.88213 .35792 Mdot
.90564 .35792 Mdot
.92916 .35792 Mdot
.95267 .35792 Mdot
.97619 .35792 Mdot
.02381 .37828 Mdot
.04733 .37828 Mdot
.07084 .37828 Mdot
.09436 .37828 Mdot
.11787 .37828 Mdot
.14139 .37828 Mdot
.1649 .37828 Mdot
.18842 .37828 Mdot
.21193 .37828 Mdot
.23545 .37828 Mdot
.25897 .37828 Mdot
.28248 .37828 Mdot
.306 .37828 Mdot
.32951 .37828 Mdot
.35303 .37828 Mdot
.37654 .37828 Mdot
.40006 .37828 Mdot
.42357 .37828 Mdot
.44709 .37828 Mdot
.47061 .37828 Mdot
.49412 .37828 Mdot
.51764 .37828 Mdot
.54115 .37828 Mdot
.56467 .37828 Mdot
.58818 .37828 Mdot
.6117 .37828 Mdot
.63521 .37828 Mdot
.65873 .37828 Mdot
.68225 .37828 Mdot
.70576 .37828 Mdot
.72928 .37828 Mdot
.75279 .37828 Mdot
.77631 .37828 Mdot
.79982 .37828 Mdot
.82334 .37828 Mdot
.84685 .37828 Mdot
.87037 .37828 Mdot
.89389 .37828 Mdot
.9174 .37828 Mdot
.94092 .37828 Mdot
.96443 .37828 Mdot
.03557 .39865 Mdot
.05908 .39865 Mdot
.0826 .39865 Mdot
.10611 .39865 Mdot
.12963 .39865 Mdot
.15315 .39865 Mdot
.17666 .39865 Mdot
.20018 .39865 Mdot
.22369 .39865 Mdot
.24721 .39865 Mdot
.27072 .39865 Mdot
.29424 .39865 Mdot
.31775 .39865 Mdot
.34127 .39865 Mdot
.36479 .39865 Mdot
.3883 .39865 Mdot
.41182 .39865 Mdot
.43533 .39865 Mdot
.45885 .39865 Mdot
.48236 .39865 Mdot
.50588 .39865 Mdot
.52939 .39865 Mdot
.55291 .39865 Mdot
.57643 .39865 Mdot
.59994 .39865 Mdot
.62346 .39865 Mdot
.64697 .39865 Mdot
.67049 .39865 Mdot
.694 .39865 Mdot
.71752 .39865 Mdot
.74103 .39865 Mdot
.76455 .39865 Mdot
.78807 .39865 Mdot
.81158 .39865 Mdot
.8351 .39865 Mdot
.85861 .39865 Mdot
.88213 .39865 Mdot
.90564 .39865 Mdot
.92916 .39865 Mdot
.95267 .39865 Mdot
.97619 .39865 Mdot
.02381 .41901 Mdot
.04733 .41901 Mdot
.07084 .41901 Mdot
.09436 .41901 Mdot
.11787 .41901 Mdot
.14139 .41901 Mdot
.1649 .41901 Mdot
.18842 .41901 Mdot
.21193 .41901 Mdot
.23545 .41901 Mdot
.25897 .41901 Mdot
.28248 .41901 Mdot
.306 .41901 Mdot
.32951 .41901 Mdot
.35303 .41901 Mdot
.37654 .41901 Mdot
.40006 .41901 Mdot
.42357 .41901 Mdot
.44709 .41901 Mdot
.47061 .41901 Mdot
.49412 .41901 Mdot
.51764 .41901 Mdot
.54115 .41901 Mdot
.56467 .41901 Mdot
.58818 .41901 Mdot
.6117 .41901 Mdot
.63521 .41901 Mdot
.65873 .41901 Mdot
.68225 .41901 Mdot
.70576 .41901 Mdot
.72928 .41901 Mdot
.75279 .41901 Mdot
.77631 .41901 Mdot
.79982 .41901 Mdot
.82334 .41901 Mdot
.84685 .41901 Mdot
.87037 .41901 Mdot
.89389 .41901 Mdot
.9174 .41901 Mdot
.94092 .41901 Mdot
.96443 .41901 Mdot
.03557 .43938 Mdot
.05908 .43938 Mdot
.0826 .43938 Mdot
.10611 .43938 Mdot
.12963 .43938 Mdot
.15315 .43938 Mdot
.17666 .43938 Mdot
.20018 .43938 Mdot
.22369 .43938 Mdot
.24721 .43938 Mdot
.27072 .43938 Mdot
.29424 .43938 Mdot
.31775 .43938 Mdot
.34127 .43938 Mdot
.36479 .43938 Mdot
.3883 .43938 Mdot
.41182 .43938 Mdot
.43533 .43938 Mdot
.45885 .43938 Mdot
.48236 .43938 Mdot
.50588 .43938 Mdot
.52939 .43938 Mdot
.55291 .43938 Mdot
.57643 .43938 Mdot
.59994 .43938 Mdot
.62346 .43938 Mdot
.64697 .43938 Mdot
.67049 .43938 Mdot
.694 .43938 Mdot
.71752 .43938 Mdot
.74103 .43938 Mdot
.76455 .43938 Mdot
.78807 .43938 Mdot
.81158 .43938 Mdot
.8351 .43938 Mdot
.85861 .43938 Mdot
.88213 .43938 Mdot
.90564 .43938 Mdot
.92916 .43938 Mdot
.95267 .43938 Mdot
.97619 .43938 Mdot
.02381 .45974 Mdot
.04733 .45974 Mdot
.07084 .45974 Mdot
.09436 .45974 Mdot
.11787 .45974 Mdot
.14139 .45974 Mdot
.1649 .45974 Mdot
.18842 .45974 Mdot
.21193 .45974 Mdot
.23545 .45974 Mdot
.25897 .45974 Mdot
.28248 .45974 Mdot
.306 .45974 Mdot
.32951 .45974 Mdot
.35303 .45974 Mdot
.37654 .45974 Mdot
.40006 .45974 Mdot
.42357 .45974 Mdot
.44709 .45974 Mdot
.47061 .45974 Mdot
.49412 .45974 Mdot
.51764 .45974 Mdot
.54115 .45974 Mdot
.56467 .45974 Mdot
.58818 .45974 Mdot
.6117 .45974 Mdot
.63521 .45974 Mdot
.65873 .45974 Mdot
.68225 .45974 Mdot
.70576 .45974 Mdot
.72928 .45974 Mdot
.75279 .45974 Mdot
.77631 .45974 Mdot
.79982 .45974 Mdot
.82334 .45974 Mdot
.84685 .45974 Mdot
.87037 .45974 Mdot
.89389 .45974 Mdot
.9174 .45974 Mdot
.94092 .45974 Mdot
.96443 .45974 Mdot
.03557 .48011 Mdot
.05908 .48011 Mdot
.0826 .48011 Mdot
.10611 .48011 Mdot
.12963 .48011 Mdot
.15315 .48011 Mdot
.17666 .48011 Mdot
.20018 .48011 Mdot
.22369 .48011 Mdot
.24721 .48011 Mdot
.27072 .48011 Mdot
.29424 .48011 Mdot
.31775 .48011 Mdot
.34127 .48011 Mdot
.36479 .48011 Mdot
.3883 .48011 Mdot
.41182 .48011 Mdot
.43533 .48011 Mdot
.45885 .48011 Mdot
.48236 .48011 Mdot
.50588 .48011 Mdot
.52939 .48011 Mdot
.55291 .48011 Mdot
.57643 .48011 Mdot
.59994 .48011 Mdot
.62346 .48011 Mdot
.64697 .48011 Mdot
.67049 .48011 Mdot
.694 .48011 Mdot
.71752 .48011 Mdot
.74103 .48011 Mdot
.76455 .48011 Mdot
.78807 .48011 Mdot
.81158 .48011 Mdot
.8351 .48011 Mdot
.85861 .48011 Mdot
.88213 .48011 Mdot
.90564 .48011 Mdot
.92916 .48011 Mdot
.95267 .48011 Mdot
.97619 .48011 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[15]:=",
  ImageSize->{288, 141.625},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000e1000`40O003h00Oofmk/Fmk003oKg^a
Kg/00=E_N`03001_Nfmk0=Q_N`00afmk1`001fmk00<006mkKg/0f6mk003:Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`3HKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40005Kg/60005Kg/40006Kg/50005Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000i_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`00bVmk
00<006mkKg/026mk00<006mkKg/0f6mk0038Kg/3000:Kg/00`00Kg]_N`3HKg/00<Y_N`03001_Nfmk
00Q_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_
NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/20002
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
0=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk000>Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10004fmk000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/2000DKg/00=E_N`800=U_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3H
Kg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_N`004Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk
10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk
000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00
eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk
000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000DKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000m_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/4
0006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_Nfmk
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/2000?Kg/00=E_N`03001_Nfmk0=Q_N`00]Vmk10001Vmk0P001Vmk10002Fmk00<006mkKg/0f6mk
002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`3HKg/00;E_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk00I_N`03001_Nfmk
0=Q_N`00]Fmk00<006mkKg/00Vmk00<006mkKg/03fmk00<006mkKg/01Vmk0`00f6mk000>Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/60003Kg/30002Kg/00`00Kg]_N`03Kg/20008
Kg/30007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_
N`@00003Kg/006mk00=_N`@000E_N`D000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Fmk10001Vmk10001Vmk100000=_N`00Kg/00fmk10001Fmk1@001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20007Kg/30002Kg/00`00Kg]_N`03Kg/2
0006Kg/01000Kg/0000026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0056mk002fKg/4000>Kg/50008Kg/00`00Kg]_N`3HKg/00=E_N`03
001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000=_N`800003Kg/00000008000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/01000Kg]_
Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk
003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000e_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<0
06mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`004fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0016mk00@006mkKg]_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00m_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`80009_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_
N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0011_N`H005e_N`L005]_N`03001_Nfmk
05a_N`L005a_N`H001=_N`0046mk00<006mkKg/00Vmk00<006mkKg/0GVmk00<006mkKg/0G6mk00<0
06mkKg/0Gfmk00<006mkKg/0GFmk00<006mkKg/00Vmk00<006mkKg/04Fmk000>Kg/200000fmk001_
N`05Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0003Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20006Kg/01000Kg/0000056mk000=Kg/400000fmk001_N`03Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40002Kg/01000Kg]_Nfmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk0007Kg/:
0002Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk3P000Vmk00@006mkKg]_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@001=_N`003Vmk0P0016mk00@006mkKg]_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000=_N`03001_Nfmk009_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`0046mk00<0
06mkKg/00Vmk00<006mkKg/0GVmk00<006mkKg/0G6mk00<006mkKg/0Gfmk00<006mkKg/0GFmk00<0
06mkKg/00Vmk00<006mkKg/04Fmk000@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`1LKg/3001NKg/2001N
Kg/3001OKg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/0015_N`@0065_N`03001_Nfmk05a_N`03001_
Nfmk05m_N`03001_Nfmk05i_N`@001A_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
01=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/010001Vmk
10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk
000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`001Fmk
o`00YP001Vmk000?Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0A
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0CKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/0
00i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8001A_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/2003IKg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008
Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000=_N`03001_
Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P00
26mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00
Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/0
00i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8001A_N`003Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10004fmk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000i_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8001A_N`00eFmk00<006mkKg/0f6mk
003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00
Kg]_N`3HKg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000=_N`800003Kg/00000008000I_N`@000I_N`@0
00I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<0
06mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_
Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00
3Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0056mk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006
Kg/40006Kg/40006Kg/4000CKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/0
0=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_
NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@0009_N`P0
009_N`80009_N`P0009_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk100000=_N`00Kg/00fmk10000Vmk0P000Vmk100016mk00<006mk0000
0`000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008
Kg/20002Kg/00`00Kg]_N`02Kg/30008Kg/20005Kg/00`00Kg]_N`020004Kg/01000Kg]_Nfmk0P00
26mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
26mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P00
3fmk002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/3003HKg/00;E_N`03001_
Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk00I_N`03001_Nfmk0=Q_N`00]Fmk00<006mkKg/00Vmk
00<006mkKg/02fmk10002Fmk00<006mkKg/0f6mk002eKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`3HKg/00;E_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk
00Y_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk10001Vmk0P001Vmk1@001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006
Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000CKg/000e_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_
N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Vmk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk
003EKg/00`00Kg]_N`3HKg/00=E_N`800=U_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3H
Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/2000?Kg/0019_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000=_N`03001_Nfmk00@000I_N`@000I_N`@000I_N`@000I_
N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_
N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000i_N`004Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<006mkKg/01000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
3Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P003fmk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_N`00
eFmk00<006mkKg/0f6mk003EKg/2003IKg/00=E_N`03001_Nfmk0=Q_N`003Vmk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0056mk000=Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
000CKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000E_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000I_N`@001=_N`003Vmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P00
26mk0P0026mk0P0026mk0P0026mk0P0056mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/001=_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`80009_N`8000Q_N`8000Q_N`80
00Q_N`8000Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`80
00Q_N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000m_N`004Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10000fmk00<0
06mkKg/010001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Vmk10003Vmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40003Kg/00`00Kg]_N`040006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006
Kg/40006Kg/40006Kg/40006Kg/40006Kg/4000>Kg/001=_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000Q_
N`8000M_N`8000Q_N`8000Q_N`8000Q_N`8000Q_N`8000A_N`04001_NfmkKg/20008Kg/20008Kg/2
0008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2
0008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000?Kg/00=E_N`03
001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00=E_N`03001_Nfmk0=Q_
N`00eFmk00<006mkKg/0f6mk000>Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/2
0008Kg/20008Kg/20008Kg/20008Kg/2000DKg/000e_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00I_N`@000E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@0
00E_N`@000I_N`@000I_N`@000I_N`@000I_N`@000I_N`@001=_N`003Fmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10004fmk000>Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/2000D
Kg/00=E_N`03001_Nfmk0=Q_N`00eFmk00<006mkKg/0f6mk003EKg/00`00Kg]_N`3HKg/00<M_N`L0
00M_N`03001_Nfmk0=Q_N`00bVmk00<006mkKg/026mk00<006mkKg/0f6mk000CKg/20008Kg/20008
Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008Kg/20003Kg/00`00Kg]_N`02Kg/20004
Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk
0P0026mk0P0026mk0P003fmk000BKg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40005Kg/40006Kg/4
0006Kg/40006Kg/40002Kg/01000Kg]_Nfmk10000fmk00<006mkKg/010001Vmk10001Vmk10001Vmk
10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk
10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk10003Vmk000BKg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/40006Kg/4
0006Kg/40006Kg/40006Kg/40005Kg/40006Kg/40006Kg/40006Kg/40002Kg/01000Kg]_Nfmk1000
0fmk1`001Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10001Vmk10001Vmk10001Vmk10001Fmk10001Vmk10001Vmk10001Vmk10001Vmk10001Vmk1000
1Vmk10003Vmk000CKg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20008Kg/20007Kg/20008Kg/20008Kg/20008
Kg/20003Kg/00`00Kg]_N`02Kg/20004Kg/01000Kg]_Nfmk0P0026mk0P0026mk0P0026mk0P0026mk
0P001fmk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P001fmk
0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P0026mk0P003fmk003:Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`3HKg/00<Q_N`<000Y_N`03001_Nfmk0=Q_N`00bVmk00<006mkKg/026mk00<006mkKg/0
f6mk003oKg^aKg/00?m_Nk5_N`00\
\>"],
  ImageRangeCache->{{{0, 431}, {211.438, 0}} -> {-2.15247, -1.06821, \
0.0151564, 0.0151564}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["It's going to be very crowded.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\(backtoBoundary[dcircle[#, {0, 0, 0.5}] &, #] &\) /@ 
          pointseverywhere)\) // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[16]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00019 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952564 0.500096 0.952564 [
[.11897 .4876 -12 -9 ]
[.11897 .4876 12 0 ]
[.30949 .4876 -12 -9 ]
[.30949 .4876 12 0 ]
[.69051 .4876 -9 -9 ]
[.69051 .4876 9 0 ]
[.88103 .4876 -9 -9 ]
[.88103 .4876 9 0 ]
[.4875 .11907 -24 -4.5 ]
[.4875 .11907 0 4.5 ]
[.4875 .30958 -24 -4.5 ]
[.4875 .30958 0 4.5 ]
[.4875 .69061 -18 -4.5 ]
[.4875 .69061 0 4.5 ]
[.4875 .88112 -18 -4.5 ]
[.4875 .88112 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.00019 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11897 .5001 m
.11897 .50635 L
s
[(-0.4)] .11897 .4876 0 1 Mshowa
.30949 .5001 m
.30949 .50635 L
s
[(-0.2)] .30949 .4876 0 1 Mshowa
.69051 .5001 m
.69051 .50635 L
s
[(0.2)] .69051 .4876 0 1 Mshowa
.88103 .5001 m
.88103 .50635 L
s
[(0.4)] .88103 .4876 0 1 Mshowa
.125 Mabswid
.1666 .5001 m
.1666 .50385 L
s
.21423 .5001 m
.21423 .50385 L
s
.26186 .5001 m
.26186 .50385 L
s
.35712 .5001 m
.35712 .50385 L
s
.40474 .5001 m
.40474 .50385 L
s
.45237 .5001 m
.45237 .50385 L
s
.54763 .5001 m
.54763 .50385 L
s
.59526 .5001 m
.59526 .50385 L
s
.64288 .5001 m
.64288 .50385 L
s
.73814 .5001 m
.73814 .50385 L
s
.78577 .5001 m
.78577 .50385 L
s
.8334 .5001 m
.8334 .50385 L
s
.07135 .5001 m
.07135 .50385 L
s
.02372 .5001 m
.02372 .50385 L
s
.92865 .5001 m
.92865 .50385 L
s
.97628 .5001 m
.97628 .50385 L
s
.25 Mabswid
0 .5001 m
1 .5001 L
s
.5 .11907 m
.50625 .11907 L
s
[(-0.4)] .4875 .11907 1 0 Mshowa
.5 .30958 m
.50625 .30958 L
s
[(-0.2)] .4875 .30958 1 0 Mshowa
.5 .69061 m
.50625 .69061 L
s
[(0.2)] .4875 .69061 1 0 Mshowa
.5 .88112 m
.50625 .88112 L
s
[(0.4)] .4875 .88112 1 0 Mshowa
.125 Mabswid
.5 .1667 m
.50375 .1667 L
s
.5 .21433 m
.50375 .21433 L
s
.5 .26196 m
.50375 .26196 L
s
.5 .35721 m
.50375 .35721 L
s
.5 .40484 m
.50375 .40484 L
s
.5 .45247 m
.50375 .45247 L
s
.5 .54772 m
.50375 .54772 L
s
.5 .59535 m
.50375 .59535 L
s
.5 .64298 m
.50375 .64298 L
s
.5 .73824 m
.50375 .73824 L
s
.5 .78587 m
.50375 .78587 L
s
.5 .83349 m
.50375 .83349 L
s
.5 .07144 m
.50375 .07144 L
s
.5 .02381 m
.50375 .02381 L
s
.5 .92875 m
.50375 .92875 L
s
.5 .97638 m
.50375 .97638 L
s
.25 Mabswid
.5 0 m
.5 1.00019 L
s
0 0 m
1 0 L
1 1.00019 L
0 1.00019 L
closepath
clip
newpath
.01 w
.074 .2871 Mdot
.07853 .27827 Mdot
.08365 .26879 Mdot
.08948 .25861 Mdot
.09611 .24767 Mdot
.10371 .2359 Mdot
.11243 .22326 Mdot
.12249 .2097 Mdot
.13411 .19519 Mdot
.14758 .17971 Mdot
.16322 .16331 Mdot
.18138 .14608 Mdot
.20247 .12818 Mdot
.22687 .10991 Mdot
.25495 .09169 Mdot
.287 .0741 Mdot
.32311 .05788 Mdot
.36314 .0439 Mdot
.40659 .03306 Mdot
.45261 .02618 Mdot
.5 .02381 Mdot
.54739 .02618 Mdot
.59341 .03306 Mdot
.63686 .0439 Mdot
.67689 .05788 Mdot
.713 .0741 Mdot
.74505 .09169 Mdot
.77313 .10991 Mdot
.79753 .12818 Mdot
.81862 .14608 Mdot
.83678 .16331 Mdot
.85242 .17971 Mdot
.86589 .19519 Mdot
.87751 .2097 Mdot
.88757 .22326 Mdot
.89629 .2359 Mdot
.90389 .24767 Mdot
.91052 .25861 Mdot
.91635 .26879 Mdot
.92147 .27827 Mdot
.926 .2871 Mdot
.06869 .29807 Mdot
.07293 .28924 Mdot
.07777 .27972 Mdot
.0833 .26942 Mdot
.08967 .25829 Mdot
.09701 .24624 Mdot
.10553 .2332 Mdot
.11544 .21909 Mdot
.12704 .20387 Mdot
.14065 .1875 Mdot
.15667 .16999 Mdot
.17554 .15143 Mdot
.19775 .132 Mdot
.22385 .11204 Mdot
.25431 .09207 Mdot
.28951 .07285 Mdot
.32958 .05535 Mdot
.37426 .04071 Mdot
.42282 .03011 Mdot
.47397 .02453 Mdot
.52603 .02453 Mdot
.57718 .03011 Mdot
.62574 .04071 Mdot
.67042 .05535 Mdot
.71049 .07285 Mdot
.74569 .09207 Mdot
.77615 .11204 Mdot
.80225 .132 Mdot
.82446 .15143 Mdot
.84333 .16999 Mdot
.85935 .1875 Mdot
.87296 .20387 Mdot
.88456 .21909 Mdot
.89447 .2332 Mdot
.90299 .24624 Mdot
.91033 .25829 Mdot
.9167 .26942 Mdot
.92223 .27972 Mdot
.92707 .28924 Mdot
.93131 .29807 Mdot
.93505 .30625 Mdot
.05985 .31814 Mdot
.06328 .31005 Mdot
.06719 .30129 Mdot
.07169 .29179 Mdot
.07687 .28145 Mdot
.08289 .27018 Mdot
.08989 .2579 Mdot
.09811 .2445 Mdot
.1078 .22987 Mdot
.11927 .21393 Mdot
.13293 .19661 Mdot
.14926 .17788 Mdot
.16881 .15781 Mdot
.19225 .1366 Mdot
.22026 .11462 Mdot
.25353 .09254 Mdot
.29258 .07135 Mdot
.33755 .05238 Mdot
.38802 .03717 Mdot
.44281 .02726 Mdot
.5 .02381 Mdot
.55719 .02726 Mdot
.61198 .03717 Mdot
.66245 .05238 Mdot
.70742 .07135 Mdot
.74647 .09254 Mdot
.77974 .11462 Mdot
.80775 .1366 Mdot
.83119 .15781 Mdot
.85074 .17788 Mdot
.86707 .19661 Mdot
.88073 .21393 Mdot
.8922 .22987 Mdot
.90189 .2445 Mdot
.91011 .2579 Mdot
.91711 .27018 Mdot
.92313 .28145 Mdot
.92831 .29179 Mdot
.93281 .30129 Mdot
.93672 .31005 Mdot
.94015 .31814 Mdot
.05472 .33107 Mdot
.0578 .32317 Mdot
.06134 .31456 Mdot
.06544 .30515 Mdot
.07021 .29485 Mdot
.07579 .28355 Mdot
.08237 .27112 Mdot
.09018 .25742 Mdot
.09951 .24232 Mdot
.11072 .22568 Mdot
.1243 .20737 Mdot
.14082 .18731 Mdot
.16101 .16554 Mdot
.18573 .14222 Mdot
.21593 .1178 Mdot
.25258 .09312 Mdot
.2964 .06952 Mdot
.34759 .04886 Mdot
.4054 .0333 Mdot
.4679 .0249 Mdot
.5321 .0249 Mdot
.5946 .0333 Mdot
.65241 .04886 Mdot
.7036 .06952 Mdot
.74742 .09312 Mdot
.78407 .1178 Mdot
.81427 .14222 Mdot
.83899 .16554 Mdot
.85918 .18731 Mdot
.8757 .20737 Mdot
.88928 .22568 Mdot
.90049 .24232 Mdot
.90982 .25742 Mdot
.91763 .27112 Mdot
.92421 .28355 Mdot
.92979 .29485 Mdot
.93456 .30515 Mdot
.93866 .31456 Mdot
.9422 .32317 Mdot
.94528 .33107 Mdot
.94797 .33835 Mdot
.04728 .35215 Mdot
.04962 .34517 Mdot
.05232 .33754 Mdot
.05544 .32918 Mdot
.05909 .31999 Mdot
.06337 .30984 Mdot
.06843 .29862 Mdot
.07447 .28616 Mdot
.08173 .27228 Mdot
.09054 .25681 Mdot
.10132 .23952 Mdot
.11462 .22023 Mdot
.13116 .19876 Mdot
.15188 .17505 Mdot
.17791 .14924 Mdot
.21061 .12181 Mdot
.25138 .09385 Mdot
.30132 .06723 Mdot
.36064 .04466 Mdot
.42797 .02929 Mdot
.5 .02381 Mdot
.57203 .02929 Mdot
.63936 .04466 Mdot
.69868 .06723 Mdot
.74862 .09385 Mdot
.78939 .12181 Mdot
.82209 .14924 Mdot
.84812 .17505 Mdot
.86884 .19876 Mdot
.88538 .22023 Mdot
.89868 .23952 Mdot
.90946 .25681 Mdot
.91827 .27228 Mdot
.92553 .28616 Mdot
.93157 .29862 Mdot
.93663 .30984 Mdot
.94091 .31999 Mdot
.94456 .32918 Mdot
.94768 .33754 Mdot
.95038 .34517 Mdot
.95272 .35215 Mdot
.04266 .36712 Mdot
.04462 .36053 Mdot
.04691 .3533 Mdot
.04957 .34532 Mdot
.0527 .33648 Mdot
.05642 .32665 Mdot
.06087 .31567 Mdot
.06625 .30335 Mdot
.07282 .28948 Mdot
.08091 .2738 Mdot
.09102 .25601 Mdot
.10378 .2358 Mdot
.12007 .21287 Mdot
.14108 .18701 Mdot
.16838 .15823 Mdot
.20391 .12703 Mdot
.24982 .09481 Mdot
.30784 .0643 Mdot
.37819 .03965 Mdot
.45816 .02566 Mdot
.54184 .02566 Mdot
.62181 .03965 Mdot
.69216 .0643 Mdot
.75018 .09481 Mdot
.79609 .12703 Mdot
.83162 .15823 Mdot
.85892 .18701 Mdot
.87993 .21287 Mdot
.89622 .2358 Mdot
.90898 .25601 Mdot
.91909 .2738 Mdot
.92718 .28948 Mdot
.93375 .30335 Mdot
.93913 .31567 Mdot
.94358 .32665 Mdot
.9473 .33648 Mdot
.95043 .34532 Mdot
.95309 .3533 Mdot
.95538 .36053 Mdot
.95734 .36712 Mdot
.95905 .37313 Mdot
.03689 .38886 Mdot
.03825 .38335 Mdot
.03982 .37728 Mdot
.04167 .37058 Mdot
.04383 .36314 Mdot
.04641 .35483 Mdot
.0495 .34552 Mdot
.05324 .33501 Mdot
.05783 .32309 Mdot
.06352 .30948 Mdot
.07069 .29386 Mdot
.07983 .27582 Mdot
.09168 .25491 Mdot
.1073 .2306 Mdot
.1282 .20242 Mdot
.15655 .17012 Mdot
.19524 .13409 Mdot
.24772 .09612 Mdot
.31694 .0604 Mdot
.40293 .03381 Mdot
.5 .02381 Mdot
.59707 .03381 Mdot
.68306 .0604 Mdot
.75228 .09612 Mdot
.80476 .13409 Mdot
.84345 .17012 Mdot
.8718 .20242 Mdot
.8927 .2306 Mdot
.90832 .25491 Mdot
.92017 .27582 Mdot
.92931 .29386 Mdot
.93648 .30948 Mdot
.94217 .32309 Mdot
.94676 .33501 Mdot
.9505 .34552 Mdot
.95359 .35483 Mdot
.95617 .36314 Mdot
.95833 .37058 Mdot
.96018 .37728 Mdot
.96175 .38335 Mdot
.96311 .38886 Mdot
.03314 .40582 Mdot
.03415 .40094 Mdot
.03534 .39554 Mdot
.03673 .38953 Mdot
.03838 .38282 Mdot
.04037 .37527 Mdot
.04277 .36673 Mdot
.04573 .35699 Mdot
.0494 .3458 Mdot
.05405 .33285 Mdot
.06002 .31772 Mdot
.06784 .29989 Mdot
.07831 .27869 Mdot
.09264 .25331 Mdot
.11274 .22283 Mdot
.14157 .18645 Mdot
.18359 .14411 Mdot
.24472 .098 Mdot
.33046 .05501 Mdot
.44001 .02761 Mdot
.55999 .02761 Mdot
.66954 .05501 Mdot
.75528 .098 Mdot
.81641 .14411 Mdot
.85843 .18645 Mdot
.88726 .22283 Mdot
.90736 .25331 Mdot
.92169 .27869 Mdot
.93216 .29989 Mdot
.93998 .31772 Mdot
.94595 .33285 Mdot
.9506 .3458 Mdot
.95427 .35699 Mdot
.95723 .36673 Mdot
.95963 .37527 Mdot
.96162 .38282 Mdot
.96327 .38953 Mdot
.96466 .39554 Mdot
.96585 .40094 Mdot
.96686 .40582 Mdot
.96773 .41025 Mdot
.02924 .42779 Mdot
.02982 .42408 Mdot
.03051 .41997 Mdot
.03131 .41541 Mdot
.03226 .4103 Mdot
.0334 .40454 Mdot
.03478 .39802 Mdot
.03648 .39057 Mdot
.0386 .38198 Mdot
.04127 .37199 Mdot
.04471 .36024 Mdot
.04925 .34625 Mdot
.05537 .32937 Mdot
.06386 .30871 Mdot
.07605 .28305 Mdot
.09418 .25078 Mdot
.12225 .21001 Mdot
.16722 .15936 Mdot
.24013 .10096 Mdot
.35257 .04721 Mdot
.5 .02381 Mdot
.64743 .04721 Mdot
.75987 .10096 Mdot
.83278 .15936 Mdot
.87775 .21001 Mdot
.90582 .25078 Mdot
.92395 .28305 Mdot
.93614 .30871 Mdot
.94463 .32937 Mdot
.95075 .34625 Mdot
.95529 .36024 Mdot
.95873 .37199 Mdot
.9614 .38198 Mdot
.96352 .39057 Mdot
.96522 .39802 Mdot
.9666 .40454 Mdot
.96774 .4103 Mdot
.96869 .41541 Mdot
.96949 .41997 Mdot
.97018 .42408 Mdot
.97076 .42779 Mdot
.02674 .44656 Mdot
.02707 .44371 Mdot
.02746 .44053 Mdot
.02792 .43699 Mdot
.02847 .43299 Mdot
.02913 .42847 Mdot
.02995 .42329 Mdot
.03096 .41733 Mdot
.03224 .41038 Mdot
.03389 .40218 Mdot
.03606 .39238 Mdot
.03899 .38046 Mdot
.04307 .36571 Mdot
.04898 .34704 Mdot
.05794 .32281 Mdot
.07233 .29047 Mdot
.09706 .24616 Mdot
.14286 .18499 Mdot
.23217 .10625 Mdot
.39471 .0356 Mdot
.60529 .0356 Mdot
.76783 .10625 Mdot
.85714 .18499 Mdot
.90294 .24616 Mdot
.92767 .29047 Mdot
.94206 .32281 Mdot
.95102 .34704 Mdot
.95693 .36571 Mdot
.96101 .38046 Mdot
.96394 .39238 Mdot
.96611 .40218 Mdot
.96776 .41038 Mdot
.96904 .41733 Mdot
.97005 .42329 Mdot
.97087 .42847 Mdot
.97153 .43299 Mdot
.97208 .43699 Mdot
.97254 .44053 Mdot
.97293 .44371 Mdot
.97326 .44656 Mdot
.97355 .44914 Mdot
.02478 .46826 Mdot
.0249 .4666 Mdot
.02503 .46474 Mdot
.02519 .46268 Mdot
.02538 .46035 Mdot
.02561 .45773 Mdot
.02588 .45473 Mdot
.02623 .45127 Mdot
.02666 .44725 Mdot
.02721 .44251 Mdot
.02794 .43685 Mdot
.02891 .42997 Mdot
.03026 .42143 Mdot
.03221 .41056 Mdot
.03517 .3963 Mdot
.03995 .37683 Mdot
.04838 .34883 Mdot
.06511 .30588 Mdot
.1043 .23502 Mdot
.21511 .11841 Mdot
.5 .02381 Mdot
.78489 .11841 Mdot
.8957 .23502 Mdot
.93489 .30588 Mdot
.95162 .34883 Mdot
.96005 .37683 Mdot
.96483 .3963 Mdot
.96779 .41056 Mdot
.96974 .42143 Mdot
.97109 .42997 Mdot
.97206 .43685 Mdot
.97279 .44251 Mdot
.97334 .44725 Mdot
.97377 .45127 Mdot
.97412 .45473 Mdot
.97439 .45773 Mdot
.97462 .46035 Mdot
.97481 .46268 Mdot
.97497 .46474 Mdot
.9751 .4666 Mdot
.97522 .46826 Mdot
.02386 .48853 Mdot
.02387 .4879 Mdot
.02389 .48721 Mdot
.02391 .48643 Mdot
.02394 .48555 Mdot
.02397 .48454 Mdot
.02401 .48339 Mdot
.02406 .48206 Mdot
.02412 .48049 Mdot
.0242 .47863 Mdot
.02431 .47638 Mdot
.02446 .47359 Mdot
.02467 .47007 Mdot
.02498 .46548 Mdot
.02547 .45922 Mdot
.02634 .45023 Mdot
.02802 .43621 Mdot
.03204 .41142 Mdot
.04583 .35666 Mdot
.15425 .17252 Mdot
.84575 .17252 Mdot
.95417 .35666 Mdot
.96796 .41142 Mdot
.97198 .43621 Mdot
.97366 .45023 Mdot
.97453 .45922 Mdot
.97502 .46548 Mdot
.97533 .47007 Mdot
.97554 .47359 Mdot
.97569 .47638 Mdot
.9758 .47863 Mdot
.97588 .48049 Mdot
.97594 .48206 Mdot
.97599 .48339 Mdot
.97603 .48454 Mdot
.97606 .48555 Mdot
.97609 .48643 Mdot
.97611 .48721 Mdot
.97613 .4879 Mdot
.97614 .48853 Mdot
.97615 .48909 Mdot
.02381 .50944 Mdot
.02382 .50993 Mdot
.02383 .51047 Mdot
.02384 .51108 Mdot
.02386 .51177 Mdot
.02388 .51255 Mdot
.0239 .51344 Mdot
.02393 .51446 Mdot
.02397 .51566 Mdot
.02402 .51707 Mdot
.02408 .51877 Mdot
.02417 .52084 Mdot
.02429 .52342 Mdot
.02446 .52675 Mdot
.02473 .53117 Mdot
.02518 .53735 Mdot
.02599 .54659 Mdot
.02774 .56185 Mdot
.03262 .59177 Mdot
.05662 .67404 Mdot
.5 .97638 Mdot
.94338 .67404 Mdot
.96738 .59177 Mdot
.97226 .56185 Mdot
.97401 .54659 Mdot
.97482 .53735 Mdot
.97527 .53117 Mdot
.97554 .52675 Mdot
.97571 .52342 Mdot
.97583 .52084 Mdot
.97592 .51877 Mdot
.97598 .51707 Mdot
.97603 .51566 Mdot
.97607 .51446 Mdot
.9761 .51344 Mdot
.97612 .51255 Mdot
.97614 .51177 Mdot
.97616 .51108 Mdot
.97617 .51047 Mdot
.97618 .50993 Mdot
.97619 .50944 Mdot
.02471 .53077 Mdot
.02482 .53242 Mdot
.02494 .53425 Mdot
.0251 .53631 Mdot
.02528 .53864 Mdot
.0255 .54127 Mdot
.02577 .5443 Mdot
.02611 .5478 Mdot
.02654 .5519 Mdot
.0271 .55677 Mdot
.02784 .56264 Mdot
.02885 .56984 Mdot
.03028 .5789 Mdot
.0324 .59062 Mdot
.03571 .60632 Mdot
.04131 .62836 Mdot
.0518 .66123 Mdot
.07457 .71423 Mdot
.13511 .8062 Mdot
.32412 .94272 Mdot
.67588 .94272 Mdot
.86489 .8062 Mdot
.92543 .71423 Mdot
.9482 .66123 Mdot
.95869 .62836 Mdot
.96429 .60632 Mdot
.9676 .59062 Mdot
.96972 .5789 Mdot
.97115 .56984 Mdot
.97216 .56264 Mdot
.9729 .55677 Mdot
.97346 .5519 Mdot
.97389 .5478 Mdot
.97423 .5443 Mdot
.9745 .54127 Mdot
.97472 .53864 Mdot
.9749 .53631 Mdot
.97506 .53425 Mdot
.97518 .53242 Mdot
.97529 .53077 Mdot
.97539 .52928 Mdot
.02638 .5504 Mdot
.02667 .55302 Mdot
.027 .55592 Mdot
.02739 .55915 Mdot
.02786 .56278 Mdot
.02842 .56688 Mdot
.02911 .57155 Mdot
.02995 .57691 Mdot
.03101 .58312 Mdot
.03236 .59041 Mdot
.03411 .59907 Mdot
.03646 .60951 Mdot
.03967 .62233 Mdot
.04424 .63841 Mdot
.05103 .65906 Mdot
.06164 .68634 Mdot
.07936 .72349 Mdot
.1113 .77534 Mdot
.17352 .84688 Mdot
.29715 .93102 Mdot
.5 .97638 Mdot
.70285 .93102 Mdot
.82648 .84688 Mdot
.8887 .77534 Mdot
.92064 .72349 Mdot
.93836 .68634 Mdot
.94897 .65906 Mdot
.95576 .63841 Mdot
.96033 .62233 Mdot
.96354 .60951 Mdot
.96589 .59907 Mdot
.96764 .59041 Mdot
.96899 .58312 Mdot
.97005 .57691 Mdot
.97089 .57155 Mdot
.97158 .56688 Mdot
.97214 .56278 Mdot
.97261 .55915 Mdot
.973 .55592 Mdot
.97333 .55302 Mdot
.97362 .5504 Mdot
.02922 .57229 Mdot
.02982 .5761 Mdot
.03052 .58032 Mdot
.03135 .58503 Mdot
.03234 .59032 Mdot
.03353 .5963 Mdot
.03499 .6031 Mdot
.03679 .61091 Mdot
.03905 .61996 Mdot
.04193 .63055 Mdot
.04569 .6431 Mdot
.05071 .65816 Mdot
.05759 .67649 Mdot
.06731 .69916 Mdot
.08157 .7276 Mdot
.10332 .7637 Mdot
.13789 .80948 Mdot
.19451 .8655 Mdot
.28645 .92582 Mdot
.42145 .96986 Mdot
.57855 .96986 Mdot
.71355 .92582 Mdot
.80549 .8655 Mdot
.86211 .80948 Mdot
.89668 .7637 Mdot
.91843 .7276 Mdot
.93269 .69916 Mdot
.94241 .67649 Mdot
.94929 .65816 Mdot
.95431 .6431 Mdot
.95807 .63055 Mdot
.96095 .61996 Mdot
.96321 .61091 Mdot
.96501 .6031 Mdot
.96647 .5963 Mdot
.96766 .59032 Mdot
.96865 .58503 Mdot
.96948 .58032 Mdot
.97018 .5761 Mdot
.97078 .57229 Mdot
.97129 .56884 Mdot
.03233 .59027 Mdot
.03324 .59483 Mdot
.03429 .59987 Mdot
.03552 .60546 Mdot
.03698 .6117 Mdot
.03872 .61869 Mdot
.04082 .62658 Mdot
.04339 .63555 Mdot
.04656 .64582 Mdot
.05054 .65767 Mdot
.05562 .67147 Mdot
.06221 .68768 Mdot
.07096 .70691 Mdot
.08284 .72992 Mdot
.09934 .75761 Mdot
.12286 .79098 Mdot
.15712 .83067 Mdot
.20756 .87602 Mdot
.28073 .9229 Mdot
.38045 .96113 Mdot
.5 .97638 Mdot
.61955 .96113 Mdot
.71927 .9229 Mdot
.79244 .87602 Mdot
.84288 .83067 Mdot
.87714 .79098 Mdot
.90066 .75761 Mdot
.91716 .72992 Mdot
.92904 .70691 Mdot
.93779 .68768 Mdot
.94438 .67147 Mdot
.94946 .65767 Mdot
.95344 .64582 Mdot
.95661 .63555 Mdot
.95918 .62658 Mdot
.96128 .61869 Mdot
.96302 .6117 Mdot
.96448 .60546 Mdot
.96571 .59987 Mdot
.96676 .59483 Mdot
.96767 .59027 Mdot
.0371 .6122 Mdot
.03852 .6179 Mdot
.04017 .62418 Mdot
.0421 .63115 Mdot
.04439 .63891 Mdot
.04713 .64759 Mdot
.05043 .65736 Mdot
.05445 .66842 Mdot
.05942 .68102 Mdot
.06563 .69546 Mdot
.07351 .71211 Mdot
.08366 .73141 Mdot
.09696 .75387 Mdot
.11468 .78004 Mdot
.13864 .81036 Mdot
.17144 .8449 Mdot
.2164 .88274 Mdot
.27716 .92103 Mdot
.35582 .95403 Mdot
.44985 .97373 Mdot
.55015 .97373 Mdot
.64418 .95403 Mdot
.72284 .92103 Mdot
.7836 .88274 Mdot
.82856 .8449 Mdot
.86136 .81036 Mdot
.88532 .78004 Mdot
.90304 .75387 Mdot
.91634 .73141 Mdot
.92649 .71211 Mdot
.93437 .69546 Mdot
.94058 .68102 Mdot
.94555 .66842 Mdot
.94957 .65736 Mdot
.95287 .64759 Mdot
.95561 .63891 Mdot
.9579 .63115 Mdot
.95983 .62418 Mdot
.96148 .6179 Mdot
.9629 .6122 Mdot
.96413 .60701 Mdot
.04129 .62827 Mdot
.04307 .63449 Mdot
.04514 .64132 Mdot
.04754 .64884 Mdot
.05036 .65715 Mdot
.05369 .66638 Mdot
.05766 .67667 Mdot
.06244 .6882 Mdot
.06824 .70117 Mdot
.07537 .71582 Mdot
.08424 .73244 Mdot
.09538 .75134 Mdot
.10955 .77285 Mdot
.12779 .79725 Mdot
.15148 .82471 Mdot
.18242 .85505 Mdot
.22279 .88739 Mdot
.27473 .91974 Mdot
.33952 .94853 Mdot
.41611 .96893 Mdot
.5 .97638 Mdot
.58389 .96893 Mdot
.66048 .94853 Mdot
.72527 .91974 Mdot
.77721 .88739 Mdot
.81758 .85505 Mdot
.84852 .82471 Mdot
.87221 .79725 Mdot
.89045 .77285 Mdot
.90462 .75134 Mdot
.91576 .73244 Mdot
.92463 .71582 Mdot
.93176 .70117 Mdot
.93756 .6882 Mdot
.94234 .67667 Mdot
.94631 .66638 Mdot
.94964 .65715 Mdot
.95246 .64884 Mdot
.95486 .64132 Mdot
.95693 .63449 Mdot
.95871 .62827 Mdot
.04784 .64976 Mdot
.0503 .65699 Mdot
.05314 .66491 Mdot
.05645 .67361 Mdot
.06032 .68319 Mdot
.06488 .69378 Mdot
.0703 .70554 Mdot
.07681 .71862 Mdot
.08466 .73321 Mdot
.09425 .74952 Mdot
.10604 .76776 Mdot
.12068 .78813 Mdot
.139 .81077 Mdot
.16204 .83569 Mdot
.19109 .86261 Mdot
.22761 .8908 Mdot
.27296 .91878 Mdot
.32798 .94423 Mdot
.39219 .96402 Mdot
.46321 .97496 Mdot
.53679 .97496 Mdot
.60781 .96402 Mdot
.67202 .94423 Mdot
.72704 .91878 Mdot
.77239 .8908 Mdot
.80891 .86261 Mdot
.83796 .83569 Mdot
.861 .81077 Mdot
.87932 .78813 Mdot
.89396 .76776 Mdot
.90575 .74952 Mdot
.91534 .73321 Mdot
.92319 .71862 Mdot
.9297 .70554 Mdot
.93512 .69378 Mdot
.93968 .68319 Mdot
.94355 .67361 Mdot
.94686 .66491 Mdot
.9497 .65699 Mdot
.95216 .64976 Mdot
.9543 .64313 Mdot
.05274 .66381 Mdot
.05556 .67133 Mdot
.05881 .67953 Mdot
.06255 .68847 Mdot
.0669 .69825 Mdot
.07197 .70899 Mdot
.07794 .72079 Mdot
.08499 .73379 Mdot
.0934 .74814 Mdot
.1035 .76397 Mdot
.11569 .78143 Mdot
.13051 .80063 Mdot
.14863 .82163 Mdot
.17084 .84433 Mdot
.19808 .86846 Mdot
.23137 .89339 Mdot
.27162 .91805 Mdot
.31939 .94081 Mdot
.37448 .95954 Mdot
.43554 .972 Mdot
.5 .97638 Mdot
.56446 .972 Mdot
.62552 .95954 Mdot
.68061 .94081 Mdot
.72838 .91805 Mdot
.76863 .89339 Mdot
.80192 .86846 Mdot
.82916 .84433 Mdot
.85137 .82163 Mdot
.86949 .80063 Mdot
.88431 .78143 Mdot
.8965 .76397 Mdot
.9066 .74814 Mdot
.91501 .73379 Mdot
.92206 .72079 Mdot
.92803 .70899 Mdot
.9331 .69825 Mdot
.93745 .68847 Mdot
.94119 .67953 Mdot
.94444 .67133 Mdot
.94726 .66381 Mdot
.06085 .68446 Mdot
.06446 .69283 Mdot
.06859 .70191 Mdot
.07335 .71178 Mdot
.07885 .72253 Mdot
.08525 .73426 Mdot
.09275 .74706 Mdot
.10156 .76104 Mdot
.11199 .77631 Mdot
.12439 .79295 Mdot
.1392 .81101 Mdot
.15695 .83049 Mdot
.17827 .85128 Mdot
.20384 .8731 Mdot
.23439 .89544 Mdot
.27057 .91748 Mdot
.31277 .93803 Mdot
.36089 .95561 Mdot
.41416 .96858 Mdot
.47096 .97549 Mdot
.52904 .97549 Mdot
.58584 .96858 Mdot
.63911 .95561 Mdot
.68723 .93803 Mdot
.72943 .91748 Mdot
.76561 .89544 Mdot
.79616 .8731 Mdot
.82173 .85128 Mdot
.84305 .83049 Mdot
.8608 .81101 Mdot
.87561 .79295 Mdot
.88801 .77631 Mdot
.89844 .76104 Mdot
.90725 .74706 Mdot
.91475 .73426 Mdot
.92115 .72253 Mdot
.92665 .71178 Mdot
.93141 .70191 Mdot
.93554 .69283 Mdot
.93915 .68446 Mdot
.94232 .67673 Mdot
.0661 .69649 Mdot
.07003 .70496 Mdot
.0745 .71409 Mdot
.07961 .72396 Mdot
.08547 .73463 Mdot
.09222 .74619 Mdot
.10005 .75871 Mdot
.10915 .77227 Mdot
.11978 .78693 Mdot
.13224 .80275 Mdot
.14691 .81974 Mdot
.1642 .83786 Mdot
.18461 .85699 Mdot
.20865 .87687 Mdot
.23687 .89709 Mdot
.26973 .91701 Mdot
.3075 .93574 Mdot
.35017 .9522 Mdot
.39725 .96516 Mdot
.44771 .9735 Mdot
.5 .97638 Mdot
.55229 .9735 Mdot
.60275 .96516 Mdot
.64983 .9522 Mdot
.6925 .93574 Mdot
.73027 .91701 Mdot
.76313 .89709 Mdot
.79135 .87687 Mdot
.81539 .85699 Mdot
.8358 .83786 Mdot
.85309 .81974 Mdot
.86776 .80275 Mdot
.88022 .78693 Mdot
.89085 .77227 Mdot
.89995 .75871 Mdot
.90778 .74619 Mdot
.91453 .73463 Mdot
.92039 .72396 Mdot
.9255 .71409 Mdot
.92997 .70496 Mdot
.9339 .69649 Mdot
.07548 .71603 Mdot
.08024 .72515 Mdot
.08564 .73494 Mdot
.09179 .74548 Mdot
.09882 .75681 Mdot
.10689 .769 Mdot
.11618 .7821 Mdot
.1269 .79614 Mdot
.13933 .81117 Mdot
.15377 .82716 Mdot
.17055 .84406 Mdot
.19007 .86175 Mdot
.21274 .88 Mdot
.23894 .89846 Mdot
.26903 .91663 Mdot
.30322 .93383 Mdot
.34151 .94924 Mdot
.38359 .96193 Mdot
.42878 .97102 Mdot
.47602 .97577 Mdot
.52398 .97577 Mdot
.57122 .97102 Mdot
.61641 .96193 Mdot
.65849 .94924 Mdot
.69678 .93383 Mdot
.73097 .91663 Mdot
.76106 .89846 Mdot
.78726 .88 Mdot
.80993 .86175 Mdot
.82945 .84406 Mdot
.84623 .82716 Mdot
.86067 .81117 Mdot
.8731 .79614 Mdot
.88382 .7821 Mdot
.89311 .769 Mdot
.90118 .75681 Mdot
.90821 .74548 Mdot
.91436 .73494 Mdot
.91976 .72515 Mdot
.92452 .71603 Mdot
.92874 .70753 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[16]:=",
  ImageSize->{287.938, 287.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006_0001[a000`40O003h00Oefmk00<006mkKg/0
eFmk003GKg/00`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00efmk00<006mkKg/0eFmk003GKg/0
0`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00efmk00<006mkKg/0eFmk003GKg/00`00Kg]_N`3E
Kg/00=M_N`03001_Nfmk0=E_N`00a6mk0P000Vmk0P0000=_N`0000002Fmk0P002Vmk10000Vmk0P00
aFmk002lKg/40002Kg/<0007Kg/50007Kg/<0002Kg/3002mKg/00;E_N`@0009_Na<000M_N`@000Q_
Na80009_N`800003Kg/000000;E_N`00[Vmk0P0016mk1P0000=_N`0000002@000Vmk0P0000=_N`00
00002Fmk0P002Vmk10000Vmk2`0000=_N`0000001@0016mk0P00[Vmk002/Kg/50003Kg/60002Kg/4
0002Kg/2000CKg/00`00Kg]_N`0AKg/20002Kg/30002Kg/70003Kg/4002]Kg/00:I_N`800003Kg/0
000000H000A_N`@001i_N`03001_Nfmk01]_N`800003Kg/0000000A_N`D00004Kg/00000Kg/2002V
Kg/00:9_N`800003Kg/0000000X002I_N`03001_Nfmk02A_N``00003Kg/000000:9_N`00X6mk4000
9fmk00<006mkKg/09Fmk0`0000=_N`0000002@00XFmk002JKg/30002Kg/6000016mk000006mk0P00
;6mk00<006mkKg/0:Vmk0P0000A_N`00001_N`D0009_N`<009]_N`00VFmk1@0000=_N`0000000`00
<fmk00<006mkKg/0<Fmk100000=_N`0000000`00VVmk002EKg/90002Kg/2000eKg/00`00Kg]_N`0b
Kg/20002Kg/500000fmk00000002002EKg/009A_N`T003Y_N`03001_Nfmk03M_N`<00003Kg/00000
00@009A_N`00T6mk0P000Vmk1P00?Fmk00<006mkKg/0>fmk1P0000=_N`000000TFmk002=Kg/60002
Kg/4000nKg/00`00Kg]_N`0lKg/400000fmk00000005002=Kg/008Y_N`T004A_N`03001_Nfmk045_
N`X008Y_N`00Qfmk2`00AFmk00<006mkKg/0@Vmk2`00R6mk0026Kg/90018Kg/00`00Kg]_N`15Kg/9
0027Kg/008A_N`P004]_N`03001_Nfmk04U_N`D00003Kg/0000008A_N`00PFmk2000CVmk00<006mk
Kg/0Bfmk0P0000=_N`0000001000PFmk001oKg/8001@Kg/00`00Kg]_N`1>Kg/8001oKg/007e_N`T0
055_N`03001_Nfmk04m_N`T007e_N`00Nfmk2000E6mk0`00DVmk2000Nfmk001jKg/7001FKg/00`00
Kg]_N`1DKg/7001jKg/007Y_N`D005Q_N`03001_Nfmk05I_N`D007Y_N`00Nfmk0`00FFmk00<006mk
Kg/0Efmk0`00Nfmk003GKg/00`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00efmk00<006mkKg/0
eFmk003GKg/00`00Kg]_N`3EKg/006a_N`<006Q_N`03001_Nfmk06I_N`<006a_N`00Jfmk1@00Ifmk
00<006mkKg/0IFmk1@00Jfmk001XKg/8001WKg/00`00Kg]_N`1UKg/7001YKg/006M_N`P006Q_N`03
001_Nfmk06I_N`L006Q_N`00IVmk1`00JVmk00<006mkKg/0Ifmk1`00Ifmk001UKg/7001[Kg/00`00
Kg]_N`1YKg/6001VKg/006=_N`H006i_N`03001_Nfmk06]_N`@00003Kg/0000006=_N`00HVmk1P00
Kfmk00<006mkKg/0K6mk0P0000=_N`0000000P00HVmk001QKg/5001aKg/00`00Kg]_N`1_Kg/5001Q
Kg/005m_N`H005A_N`@000I_N`8000M_N`@000M_N`03001_Nfmk071_N`D0061_N`00GVmk1P00E6mk
00<006mkKg/00Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/01Vmk00<006mkKg/0LFmk1P00GVmk
001LKg/7001EKg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`1bKg/7
001LKg/005]_N`H005M_N`03001_Nfmk009_N`03001_Nfmk00Y_N`H000M_N`03001_Nfmk07=_N`L0
05]_N`00FVmk1P00Cfmk1P000fmk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`@0
07A_N`H005Y_N`00FFmk1@00FVmk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03
001_Nfmk07M_N`D005U_N`00EVmk1`00Ffmk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk0000
26mk00<006mkKg/0N6mk1P00Efmk001EKg/7001LKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00
Kg/00008Kg/00`00Kg]_N`1iKg/6001FKg/005A_N`H005m_N`@0011_N`8000Q_N`03001_Nfmk07]_
N`H005A_N`00Dfmk1P00OVmk00<006mkKg/0O6mk1P00Dfmk001BKg/50020Kg/00`00Kg]_N`1nKg/5
001BKg/0055_N`D0085_N`03001_Nfmk07m_N`D0055_N`00DFmk1000PVmk00<006mkKg/0P6mk1000
DFmk001>Kg/300000fmk00000023Kg/00`00Kg]_N`21Kg/2000016mk00000000CVmk001=Kg/50025
Kg/00`00Kg]_N`23Kg/5001=Kg/004a_N`H008E_N`03001_Nfmk08=_N`H004a_N`00Bfmk1P00QVmk
00<006mkKg/0Q6mk1P00Bfmk001:Kg/50028Kg/00`00Kg]_N`26Kg/5001:Kg/004Y_N`D008Q_N`03
001_Nfmk08I_N`D004Y_N`00Afmk0`0000A_N`00000008U_N`03001_Nfmk08M_N`<00003Kg/00000
04Q_N`00AVmk1@00S6mk00<006mkKg/0RVmk1000Afmk0016Kg/5002<Kg/00`00Kg]_N`2:Kg/50016
Kg/004E_N`D008e_N`03001_Nfmk08]_N`@004I_N`00A6mk1@00SVmk00<006mkKg/0S6mk1000AFmk
0012Kg/6002?Kg/3002<Kg/60013Kg/0045_N`H0091_N`03001_Nfmk08e_N`H0049_N`00@Fmk1@00
TFmk00<006mkKg/0SVmk1@00@Vmk0010Kg/5002BKg/00`00Kg]_N`2?Kg/50011Kg/003m_N`D009=_
N`03001_Nfmk091_N`D0041_N`00?Vmk1@00U6mk00<006mkKg/0TFmk1@00?fmk000mKg/5002EKg/0
0`00Kg]_N`2BKg/5000nKg/003a_N`D009I_N`03001_Nfmk09=_N`D003e_N`00>fmk1@00Ufmk00<0
06mkKg/0U6mk1@00?6mk000kKg/4002HKg/00`00Kg]_N`2EKg/5000kKg/003]_N`@009Q_N`03001_
Nfmk09I_N`@003]_N`00>Fmk0P0000=_N`000000VFmk00<006mkKg/0Ufmk0P0000=_N`000000>Fmk
000hKg/4002KKg/00`00Kg]_N`2IKg/4000hKg/003M_N`D009]_N`03001_Nfmk09U_N`@003Q_N`00
=Vmk1@00W6mk00<006mkKg/0VFmk1@00=fmk000eKg/5002MKg/00`00Kg]_N`2JKg/5000fKg/003E_
N`@009i_N`03001_Nfmk09]_N`D003E_N`00=6mk1@00WVmk00<006mkKg/0W6mk1000=Fmk000cKg/5
002OKg/00`00Kg]_N`2MKg/4000dKg/0039_N`D00:1_N`03001_Nfmk09e_N`D003=_N`00<Fmk1P00
X6mk00<006mkKg/0WVmk1@00<Vmk000aKg/5002QKg/3002OKg/4000bKg/0031_N`D00:9_N`03001_
Nfmk0:1_N`@0035_N`00;fmk1@00Xfmk00<006mkKg/0XFmk1000<6mk000^Kg/6002SKg/00`00Kg]_
N`2QKg/5000_Kg/002i_N`D00:A_N`03001_Nfmk0:9_N`D002i_N`00;Fmk1@00YFmk00<006mkKg/0
Xfmk1000;Vmk000/Kg/5002VKg/00`00Kg]_N`2TKg/4000]Kg/002a_N`@00:M_N`03001_Nfmk0:A_
N`D002a_N`00:fmk1@00Yfmk00<006mkKg/0Y6mk1P00:fmk000[Kg/4002XKg/00`00Kg]_N`2UKg/5
000[Kg/002Y_N`D00:Q_N`03001_Nfmk0:I_N`D002Y_N`00:Vmk1000ZFmk00<006mkKg/0Yfmk1000
:Vmk000YKg/4002ZKg/00`00Kg]_N`2XKg/4000YKg/002Q_N`D00:Y_N`03001_Nfmk0:Q_N`D002Q_
N`009fmk1@00Zfmk00<006mkKg/0Z6mk1@00:6mk000VKg/5002/Kg/00`00Kg]_N`2YKg/5000WKg/0
02I_N`@00:e_N`03001_Nfmk0:Y_N`D002I_N`009Fmk1@00[Fmk00<006mkKg/0Zfmk10009Vmk000U
Kg/4002^Kg/00`00Kg]_N`2[Kg/5000UKg/002A_N`D00:i_N`03001_Nfmk0:]_N`D002E_N`0096mk
1@00[Vmk0`00[6mk10009Fmk000UKg/3002_Kg/00`00Kg]_N`2]Kg/2000VKg/002=_N`800;9_N`03
001_Nfmk0;1_N`8002=_N`008Vmk1000/Fmk00<006mkKg/0[fmk10008Vmk000QKg/5002aKg/00`00
Kg]_N`2_Kg/4000RKg/0025_N`D00;5_N`03001_Nfmk0:m_N`D0025_N`0086mk1@00/Vmk00<006mk
Kg/0/6mk10008Fmk000PKg/4002cKg/00`00Kg]_N`2`Kg/5000PKg/001m_N`D00;=_N`03001_Nfmk
0;5_N`D001m_N`007fmk1000]6mk00<006mkKg/0/Fmk1@007fmk000OKg/4002dKg/00`00Kg]_N`2b
Kg/4000OKg/001i_N`@00;E_N`03001_Nfmk0;=_N`@001i_N`007Fmk1@00]Fmk00<006mkKg/0/fmk
1@007Fmk000MKg/4002fKg/00`00Kg]_N`2cKg/5000MKg/001a_N`D00;I_N`03001_Nfmk0;A_N`@0
01e_N`0076mk1000]fmk00<006mkKg/0]6mk10007Fmk000KKg/5002gKg/00`00Kg]_N`2eKg/4000L
Kg/001]_N`D009U_N`@000I_N`8000E_N`H000M_N`03001_Nfmk0;E_N`D001]_N`006Vmk1@00VFmk
00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mk
Kg/0]Vmk10006fmk000JKg/4002JKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`2fKg/5000JKg/001U_N`D009Y_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk
00Q_N`03001_Nfmk0;M_N`@001Y_N`006Fmk1000TVmk1P000fmk00<006mkKg/00Vmk00<006mkKg/0
3Fmk00<006mkKg/01fmk1000]Vmk10006Vmk000IKg/4002KKg/00`00Kg]_N`02Kg/00`00Kg]_N`0>
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`2gKg/4000JKg/001Q_N`@009a_N`03001_Nfmk009_N`03001_
Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0;Q_N`@001U_N`0066mk1000W6mk
00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0^6mk
1@0066mk000GKg/5002MKg/4000>Kg/40008Kg/00`00Kg]_N`2iKg/4000HKg/001M_N`@00;a_N`03
001_Nfmk0;U_N`D001M_N`005fmk1000_6mk00<006mkKg/0^Vmk10005fmk000FKg/4002mKg/00`00
Kg]_N`2jKg/4000GKg/001I_N`@00;e_N`03001_Nfmk0;Y_N`D001I_N`005Fmk1@00_Fmk00<006mk
Kg/0^fmk10005Vmk000EKg/4002nKg/00`00Kg]_N`2kKg/4000FKg/001E_N`@00;i_N`03001_Nfmk
0;]_N`D001E_N`0056mk1@00_Vmk00<006mkKg/0_6mk10005Fmk000DKg/4002oKg/00`00Kg]_N`2l
Kg/4000EKg/001A_N`<00<1_N`03001_Nfmk0;e_N`<001E_N`004fmk1000`6mk00<006mkKg/0_Fmk
100056mk000CKg/40030Kg/00`00Kg]_N`2mKg/5000CKg/001=_N`@00<1_N`03001_Nfmk0;i_N`@0
01=_N`004Vmk1@00`6mk00<006mkKg/0_Vmk1@004Vmk000BKg/40031Kg/00`00Kg]_N`2nKg/5000B
Kg/0019_N`@00<5_N`03001_Nfmk0;m_N`@0019_N`004Fmk1@00`Fmk0`00_fmk10004Vmk000AKg/4
0032Kg/00`00Kg]_N`2oKg/4000BKg/0015_N`@00<9_N`03001_Nfmk0;m_N`D0015_N`0046mk1@00
`Vmk00<006mkKg/0`6mk10004Fmk000@Kg/40033Kg/00`00Kg]_N`30Kg/4000AKg/0011_N`@00<=_
N`03001_Nfmk0<5_N`@0011_N`0046mk1000`fmk00<006mkKg/0`Fmk100046mk000?Kg/40034Kg/0
0`00Kg]_N`31Kg/4000@Kg/000m_N`@00<A_N`03001_Nfmk0<5_N`D000m_N`003fmk1000a6mk00<0
06mkKg/0`Fmk1@003fmk000>Kg/50034Kg/00`00Kg]_N`32Kg/4000?Kg/000i_N`D00<A_N`03001_
Nfmk0<9_N`@000m_N`003fmk0`00aFmk00<006mkKg/0`fmk0`003fmk000>Kg/40035Kg/00`00Kg]_
N`33Kg/4000>Kg/000e_N`D00<E_N`03001_Nfmk0<=_N`@000i_N`003Fmk1@00aFmk00<006mkKg/0
`fmk10003Vmk000=Kg/40036Kg/00`00Kg]_N`33Kg/5000=Kg/000e_N`@00<I_N`03001_Nfmk0<=_
N`D000e_N`003Fmk1000aVmk00<006mkKg/0a6mk10003Fmk000=Kg/40036Kg/00`00Kg]_N`34Kg/4
000=Kg/000a_N`D00<I_N`<00<A_N`@000e_N`0036mk1000afmk00<006mkKg/0a6mk10003Fmk000<
Kg/40037Kg/00`00Kg]_N`35Kg/4000<Kg/000a_N`@00<M_N`03001_Nfmk0<E_N`@000a_N`002fmk
1000b6mk00<006mkKg/0aFmk100036mk000;Kg/40038Kg/00`00Kg]_N`35Kg/4000<Kg/000]_N`@0
0<Q_N`03001_Nfmk0<E_N`D000]_N`002fmk1000b6mk00<006mkKg/0aVmk10002fmk000;Kg/40038
Kg/00`00Kg]_N`36Kg/4000;Kg/000]_N`@00<Q_N`03001_Nfmk0<I_N`@000]_N`002Vmk1@00b6mk
00<006mkKg/0aVmk10002fmk000:Kg/50038Kg/00`00Kg]_N`36Kg/4000;Kg/000Y_N`@00<U_N`03
001_Nfmk0<I_N`@000]_N`002Vmk1000bFmk00<006mkKg/0aVmk1@002Vmk000:Kg/40039Kg/00`00
Kg]_N`37Kg/4000:Kg/000Y_N`@00<U_N`03001_Nfmk0<M_N`@000Y_N`002Vmk1000bFmk00<006mk
Kg/0afmk10002Vmk000:Kg/40039Kg/00`00Kg]_N`37Kg/4000:Kg/000U_N`@00<Y_N`03001_Nfmk
0<M_N`@000Y_N`002Fmk1000bVmk00<006mkKg/0afmk10002Vmk0009Kg/4003:Kg/00`00Kg]_N`37
Kg/4000:Kg/000U_N`@00<Y_N`<00<M_N`D000U_N`002Fmk1000bVmk00<006mkKg/0b6mk10002Fmk
0009Kg/4003:Kg/00`00Kg]_N`38Kg/40009Kg/000U_N`@001m_N`@000I_N`8000M_N`@003]_N`@0
00I_N`8000E_N`H0049_N`03001_Nfmk04A_N`@000I_N`8000E_N`H003]_N`@000I_N`8000M_N`@0
01]_N`@000U_N`002Fmk10007Vmk00<006mkKg/00Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/0
>Fmk00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/0@6mk00<0
06mkKg/0@fmk00<006mkKg/00Vmk00<006mkKg/00fmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/0
>6mk00<006mkKg/00Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/06Vmk10002Fmk0009Kg/4000N
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0iKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`14Kg/00`00Kg]_N`13Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0l
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0JKg/40009Kg/000U_N`@001i_N`03001_
Nfmk009_N`03001_Nfmk00Y_N`H003Y_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk04=_
N`03001_Nfmk04=_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk03]_N`03001_Nfmk009_
N`03001_Nfmk00Y_N`H001]_N`@000U_N`002Fmk10005Fmk1P000fmk00<006mkKg/00Vmk00<006mk
Kg/02fmk00@006mkKg/0039_N`H000=_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk049_
N`03001_Nfmk04=_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk03Y_N`03001_Nfmk009_
N`03001_Nfmk00]_N`04001_Nfmk000LKg/40009Kg/000Q_N`D001i_N`03001_Nfmk009_N`03001_
Nfmk00]_N`04001_Nfmk000kKg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`11Kg/00`00
Kg]_N`13Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0iKg/00`00Kg]_N`02Kg/00`00
Kg]_N`0;Kg/01000Kg]_N`0076mk10002Fmk0008Kg/4000OKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<
Kg/00`00Kg/0000kKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`10
Kg/00`00Kg]_N`13Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0h
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg/0000LKg/40009Kg/000Q_N`@001m_N`03001_
Nfmk009_N`03001_Nfmk00a_N`03001_N`0003]_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_
Nfmk009_N`03001_Nfmk041_N`03001_Nfmk04=_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_
Nfmk009_N`03001_Nfmk03Q_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_N`0001a_N`@000U_
N`0026mk100086mk100046mk0P00?6mk10003Vmk1000@fmk00<006mkKg/0A6mk10003Vmk1000?6mk
100046mk0P0076mk10002Fmk0008Kg/4003;Kg/00`00Kg]_N`38Kg/40009Kg/000Q_N`@00<]_N`03
001_Nfmk0<Q_N`@000U_N`0026mk1000bfmk00<006mkKg/0b6mk10002Fmk0008Kg/4003;Kg/00`00
Kg]_N`38Kg/40009Kg/000Q_N`@00<]_N`03001_Nfmk0<Q_N`@000U_N`002Fmk0P00c6mk00<006mk
Kg/0bFmk0P002Vmk003GKg/00`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00o`00/000000:Kg/0
0`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/0
0`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/0
0`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/0
0`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0AKg/0
0`00Kg]_N`08Kg/000Y_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk
019_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk
015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk
019_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk
019_N`03001_Nfmk015_N`03001_Nfmk00Q_N`002Fmk0P00:6mk00<006mkKg/0Cfmk00<006mkKg/0
Cfmk00<006mkKg/0Cfmk00<006mkKg/0Cfmk00<006mkKg/09Fmk0P002Vmk0008Kg/4003;Kg/00`00
Kg]_N`38Kg/40009Kg/000Q_N`@00<]_N`03001_Nfmk0<Q_N`@000U_N`0026mk1000bfmk00<006mk
Kg/0b6mk10002Fmk0008Kg/4003;Kg/00`00Kg]_N`38Kg/40009Kg/000Q_N`@00<]_N`03001_Nfmk
0<Q_N`@000U_N`0026mk1000bfmk00<006mkKg/0b6mk10002Fmk0008Kg/4003;Kg/00`00Kg]_N`38
Kg/40009Kg/000Q_N`@00<]_N`03001_Nfmk0<Q_N`@000U_N`0026mk1000bfmk00<006mkKg/0b6mk
10002Fmk0009Kg/4003:Kg/00`00Kg]_N`38Kg/40009Kg/000U_N`@00<Y_N`03001_Nfmk0<Q_N`@0
00U_N`002Fmk1000bVmk00<006mkKg/0b6mk10002Fmk0009Kg/4003:Kg/00`00Kg]_N`38Kg/40009
Kg/000U_N`@00<Y_N`03001_Nfmk0<Q_N`@000U_N`002Fmk1000bVmk00<006mkKg/0b6mk10002Fmk
0009Kg/4003:Kg/00`00Kg]_N`38Kg/40009Kg/000U_N`@00<Y_N`03001_Nfmk0<M_N`D000U_N`00
2Fmk1000bVmk0`00afmk1@002Fmk0009Kg/4003:Kg/00`00Kg]_N`37Kg/4000:Kg/000U_N`@00<Y_
N`03001_Nfmk0<M_N`@000Y_N`002Vmk1000bFmk00<006mkKg/0afmk10002Vmk000:Kg/40039Kg/0
0`00Kg]_N`37Kg/4000:Kg/000Y_N`@00<U_N`03001_Nfmk0<M_N`@000Y_N`002Vmk1000bFmk00<0
06mkKg/0afmk10002Vmk000:Kg/40039Kg/00`00Kg]_N`36Kg/5000:Kg/000Y_N`@00<U_N`03001_
Nfmk0<I_N`@000]_N`002Vmk1000bFmk00<006mkKg/0aVmk10002fmk000:Kg/50038Kg/00`00Kg]_
N`36Kg/4000;Kg/000]_N`@00<Q_N`03001_Nfmk0<I_N`@000]_N`002fmk1000b6mk00<006mkKg/0
aVmk10002fmk000;Kg/40038Kg/00`00Kg]_N`36Kg/4000;Kg/000]_N`@00<Q_N`03001_Nfmk0<E_
N`D000]_N`002fmk1000b6mk00<006mkKg/0aFmk100036mk000;Kg/40038Kg/00`00Kg]_N`35Kg/4
000<Kg/000a_N`<00<Q_N`03001_Nfmk0<I_N`8000e_N`0036mk1000afmk00<006mkKg/0aFmk1000
36mk000<Kg/40037Kg/00`00Kg]_N`34Kg/5000<Kg/000a_N`@00<M_N`<00<A_N`@000e_N`0036mk
1@00aVmk00<006mkKg/0a6mk10003Fmk000=Kg/40036Kg/00`00Kg]_N`34Kg/4000=Kg/000e_N`@0
0<I_N`03001_Nfmk0<A_N`@000e_N`003Fmk1000aVmk00<006mkKg/0`fmk1@003Fmk000=Kg/40036
Kg/00`00Kg]_N`33Kg/4000>Kg/000i_N`@00<E_N`03001_Nfmk0<=_N`@000i_N`003Vmk1000aFmk
00<006mkKg/0`fmk10003Vmk000>Kg/40035Kg/00`00Kg]_N`33Kg/4000>Kg/000m_N`@00<A_N`03
001_Nfmk0<9_N`@000m_N`003fmk1000a6mk00<006mkKg/0`Vmk10003fmk000?Kg/40034Kg/00`00
Kg]_N`32Kg/4000?Kg/000m_N`@00<A_N`03001_Nfmk0<5_N`D000m_N`003fmk1@00`fmk00<006mk
Kg/0`Fmk100046mk000@Kg/40033Kg/00`00Kg]_N`31Kg/4000@Kg/0011_N`@00<=_N`03001_Nfmk
0<5_N`@0011_N`0046mk1000`fmk00<006mkKg/0`Fmk100046mk000@Kg/50032Kg/00`00Kg]_N`30
Kg/4000AKg/0011_N`D00<9_N`03001_Nfmk0<1_N`@0015_N`004Fmk1000`Vmk00<006mkKg/0`6mk
10004Fmk000AKg/50031Kg/00`00Kg]_N`2oKg/4000BKg/0015_N`D00<5_N`<00;m_N`@0019_N`00
4Vmk1000`Fmk00<006mkKg/0_Vmk1@004Vmk000BKg/50030Kg/00`00Kg]_N`2nKg/4000CKg/0019_
N`D00<1_N`03001_Nfmk0;i_N`@001=_N`004fmk1000`6mk00<006mkKg/0_Vmk0`0056mk000DKg/4
002oKg/00`00Kg]_N`2mKg/4000DKg/001A_N`@00;m_N`03001_Nfmk0;e_N`@001A_N`0056mk1000
_fmk00<006mkKg/0_6mk1@0056mk000DKg/5002nKg/00`00Kg]_N`2lKg/4000EKg/001E_N`@00;i_
N`03001_Nfmk0;a_N`@001E_N`005Fmk1000_Vmk00<006mkKg/0^fmk1@005Fmk000EKg/5002mKg/0
0`00Kg]_N`2kKg/4000FKg/001I_N`@00;e_N`03001_Nfmk0;Y_N`D001I_N`005Vmk1000_Fmk00<0
06mkKg/0^Vmk1@005Vmk000FKg/5002lKg/00`00Kg]_N`2jKg/4000GKg/001M_N`@00;a_N`03001_
Nfmk0;U_N`D001M_N`005fmk1@00^fmk00<006mkKg/0^Fmk100066mk000HKg/4002MKg/40006Kg/2
0005Kg/60007Kg/00`00Kg]_N`2hKg/5000HKg/001Q_N`D009]_N`03001_Nfmk009_N`03001_Nfmk
00=_N`8000E_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0;Q_N`D001Q_N`0066mk1@00
Vfmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mkKg/0^6mk10006Fmk000I
Kg/4002KKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`08Kg/4002gKg/4000IKg/001Y_
N`@009Y_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk00M_N`03001_Nfmk0;M_N`@001Y_
N`006Vmk1000VVmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/0]Vmk
1@006Vmk000JKg/5002IKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`2fKg/4000KKg/001]_N`@009U_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0;E_N`D001]_N`006fmk1000VVmk10003Vmk1000
26mk00<006mkKg/0]Fmk100076mk000KKg/5002gKg/00`00Kg]_N`2dKg/5000LKg/001a_N`@00;M_
N`03001_Nfmk0;A_N`D001a_N`0076mk1@00]Vmk00<006mkKg/0]6mk10007Fmk000MKg/5002eKg/0
0`00Kg]_N`2cKg/5000MKg/001i_N`@00;E_N`03001_Nfmk0;=_N`@001i_N`007Vmk1000]Fmk00<0
06mkKg/0/Vmk1@007Vmk000NKg/5002dKg/00`00Kg]_N`2bKg/4000OKg/001m_N`@00;A_N`03001_
Nfmk0;5_N`D001m_N`007fmk1@00/fmk00<006mkKg/0/6mk1@0086mk000PKg/4002cKg/00`00Kg]_
N`2`Kg/5000PKg/0021_N`D00;9_N`03001_Nfmk0;1_N`@0025_N`008Fmk1@00/Fmk00<006mkKg/0
[fmk1@008Fmk000RKg/5002`Kg/00`00Kg]_N`2^Kg/5000RKg/0029_N`D00;1_N`03001_Nfmk0:i_
N`@002=_N`008fmk1000/6mk00<006mkKg/0[Vmk10008fmk000TKg/2002aKg/3002_Kg/2000TKg/0
02I_N`800:m_N`03001_Nfmk0:a_N`8002M_N`009Fmk1000[Vmk00<006mkKg/0Zfmk10009Vmk000U
Kg/5002]Kg/00`00Kg]_N`2[Kg/4000VKg/002I_N`D00:a_N`03001_Nfmk0:Y_N`D002I_N`009Vmk
1@00[6mk00<006mkKg/0ZVmk10009fmk000WKg/5002[Kg/00`00Kg]_N`2YKg/5000WKg/002Q_N`@0
0:]_N`03001_Nfmk0:Q_N`D002Q_N`00:6mk1@00ZVmk00<006mkKg/0Z6mk1000:Fmk000YKg/5002Y
Kg/00`00Kg]_N`2WKg/5000YKg/002Y_N`D00:Q_N`03001_Nfmk0:I_N`D002Y_N`00:Vmk1@00Z6mk
00<006mkKg/0YVmk1000:fmk000[Kg/5002WKg/00`00Kg]_N`2UKg/4000/Kg/002a_N`@00:M_N`03
001_Nfmk0:E_N`@002a_N`00;6mk1@00YVmk00<006mkKg/0Y6mk1@00;6mk000]Kg/5002UKg/00`00
Kg]_N`2SKg/5000]Kg/002i_N`@00:E_N`03001_Nfmk0:9_N`D002i_N`00;Vmk1@00Y6mk00<006mk
Kg/0XFmk1@00;fmk000_Kg/5002SKg/00`00Kg]_N`2QKg/4000`Kg/0031_N`D00:9_N`03001_Nfmk
0:1_N`D0031_N`00<Fmk1@00XFmk0`00Wfmk1@00<Fmk000bKg/4002QKg/00`00Kg]_N`2OKg/4000b
Kg/0039_N`D00:1_N`03001_Nfmk09i_N`D0039_N`00<fmk1@00Wfmk00<006mkKg/0WFmk1@00<fmk
000dKg/5002NKg/00`00Kg]_N`2LKg/5000dKg/003E_N`@009i_N`03001_Nfmk09]_N`D003E_N`00
=Fmk1@00WFmk00<006mkKg/0VVmk1P00=Fmk000fKg/5002LKg/00`00Kg]_N`2JKg/5000fKg/003M_
N`@009a_N`03001_Nfmk09Y_N`@003M_N`00>6mk1@00VVmk00<006mkKg/0V6mk1@00>6mk000hKg/6
002IKg/00`00Kg]_N`2GKg/6000hKg/003U_N`D009U_N`03001_Nfmk09M_N`D003U_N`00>Vmk1000
VFmk00<006mkKg/0Ufmk1000>Vmk000kKg/200000fmk0000002GKg/00`00Kg]_N`2DKg/20002Kg/2
000kKg/003e_N`@009I_N`03001_Nfmk09=_N`@003i_N`00?Fmk1@00UFmk00<006mkKg/0Tfmk1000
?Vmk000nKg/4002EKg/00`00Kg]_N`2BKg/5000nKg/003m_N`@009A_N`03001_Nfmk095_N`D003m_
N`00?fmk1P00TVmk00<006mkKg/0T6mk1@00@6mk0010Kg/6002AKg/00`00Kg]_N`2?Kg/50011Kg/0
045_N`H0091_N`03001_Nfmk08i_N`D0049_N`00@fmk1@00Sfmk0`00SFmk1@00@fmk0014Kg/5002>
Kg/00`00Kg]_N`2<Kg/50014Kg/004E_N`@008i_N`03001_Nfmk08a_N`@004E_N`00AVmk1@00S6mk
00<006mkKg/0RVmk0P0000=_N`000000AVmk0017Kg/5002;Kg/00`00Kg]_N`29Kg/40018Kg/004M_
N`H008Y_N`03001_Nfmk08Q_N`D004Q_N`00B6mk1P00RFmk00<006mkKg/0Qfmk1@00BFmk001:Kg/5
0028Kg/00`00Kg]_N`26Kg/5001:Kg/004]_N`D008M_N`03001_Nfmk08A_N`H004]_N`00C6mk1@00
QVmk00<006mkKg/0Pfmk1P00C6mk001=Kg/60024Kg/00`00Kg]_N`22Kg/6001=Kg/004i_N`H008=_
N`03001_Nfmk085_N`H004i_N`00D6mk1@00PVmk00<006mkKg/0P6mk1@00D6mk001@Kg/60021Kg/0
0`00Kg]_N`1nKg/6001AKg/0055_N`H0081_N`03001_Nfmk07e_N`H0059_N`00Dfmk1P00OVmk00<0
06mkKg/0O6mk1P00Dfmk001DKg/6001mKg/00`00Kg]_N`1kKg/5001EKg/005I_N`D005i_N`@000I_
N`8000M_N`@000M_N`03001_Nfmk07Y_N`D005I_N`00Efmk1P00Ffmk00<006mkKg/00Vmk00<006mk
Kg/00fmk0P002Fmk00<006mkKg/01Vmk00<006mkKg/0N6mk1P00Efmk001GKg/7001JKg/00`00Kg]_
N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`1gKg/6001HKg/005Q_N`H005Y_N`03
001_Nfmk009_N`03001_Nfmk00Y_N`H000M_N`@007E_N`H005U_N`00Ffmk1000FFmk00<006mkKg/0
0Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03001_Nfmk07E_N`D005]_N`00Ffmk1P00Efmk00<0
06mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03001_Nfmk07A_N`D005a_N`00G6mk1`00
EFmk00<006mkKg/00Vmk00<006mkKg/036mk00<006mk000026mk00<006mkKg/0LVmk1P00GFmk001N
Kg/7001CKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg/00008Kg/00`00Kg]_N`1`Kg/7001N
Kg/005m_N`L005=_N`@0011_N`8000Q_N`03001_Nfmk06m_N`L005m_N`00HFmk1`00Kfmk00<006mk
Kg/0KFmk1`00HFmk001SKg/6001^Kg/00`00Kg]_N`1/Kg/6001SKg/006A_N`D006i_N`03001_Nfmk
06a_N`D006A_N`00IFmk0`00Kfmk00<006mkKg/0KFmk0`00IFmk003GKg/00`00Kg]_N`3EKg/00=M_
N`03001_Nfmk0=E_N`00efmk00<006mkKg/0eFmk003GKg/00`00Kg]_N`3EKg/007=_N`80069_N`03
001_Nfmk05m_N`<007=_N`00LVmk1@00H6mk00<006mkKg/0GFmk1P00LVmk001bKg/6001OKg/00`00
Kg]_N`1LKg/7001bKg/007=_N`L005e_N`03001_Nfmk05]_N`L007=_N`00M6mk2000Ffmk00<006mk
Kg/0F6mk2@00M6mk001fKg/7001JKg/00`00Kg]_N`1GKg/7001gKg/007Q_N`D0009_N`8005I_N`03
001_Nfmk05A_N`800003Kg/0000000@007Q_N`00NVmk0P000Vmk1000EFmk0`00Dfmk100000=_N`00
0000Nfmk001nKg/7001BKg/00`00Kg]_N`1?Kg/8001nKg/007m_N`T004m_N`03001_Nfmk04e_N`T0
07m_N`00PFmk2000CVmk00<006mkKg/0C6mk2000PFmk0022Kg/;001:Kg/00`00Kg]_N`18Kg/;0022
Kg/008I_N`P004U_N`03001_Nfmk04I_N`T008I_N`00R6mk1`00B6mk00<006mkKg/0AFmk2000R6mk
0029Kg/60002Kg/30013Kg/00`00Kg]_N`11Kg/20002Kg/70029Kg/008a_N`80009_N`D00003Kg/0
000003m_N`03001_Nfmk03e_N`800003Kg/000000080009_N`8008e_N`00T6mk2P00?Fmk00<006mk
Kg/0>Vmk2P00TFmk002AKg/300000fmk00000005000kKg/00`00Kg]_N`0hKg/800000fmk0000002B
Kg/009I_N`L003Y_N`03001_Nfmk03M_N`P009I_N`00V6mk1@000fmk0P0000=_N`000000<Vmk00<0
06mkKg/0<6mk10000fmk1@00VFmk002JKg/20003Kg/7000aKg/00`00Kg]_N`0^Kg/70003Kg/2002K
Kg/009m_N`P00003Kg/00000008002]_N`03001_Nfmk02U_N``00:1_N`00X6mk0P0000=_N`000000
2000:Vmk00<006mkKg/0:6mk3000XFmk002TKg/200000fmk000000040004Kg/5000QKg/00`00Kg]_
N`0NKg/50005Kg/8002UKg/00:Q_N`@000A_N`L00004Kg/00000Kg/2000JKg/00`00Kg]_N`0HKg/2
00000fmk000000070005Kg/4002XKg/00;1_N`h0009_N`<000=_N`80009_N`8000]_N`03001_Nfmk
00U_N`800003Kg/0000000A_N`<0009_N`d00;5_N`00/Fmk1@0000=_N`0000001@0000=_N`000000
0`0000=_N`0000001`0026mk0P002Fmk20000Vmk1@0000=_N`0000002P00/Vmk002hKg/200000fmk
00000002Kg/500000fmk000000080006Kg/50006Kg/90002Kg/50002Kg/200000fmk0000002hKg/0
0<1_N`<000=_N`80009_N`D000I_N`@000M_N`D00003Kg/0000000A_N`<00<1_N`00c6mk0P0026mk
0P002Fmk0P00c6mk003GKg/00`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00efmk00<006mkKg/0
eFmk003GKg/00`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00efmk00<006mkKg/0eFmk003GKg/0
0`00Kg]_N`3EKg/00=M_N`03001_Nfmk0=E_N`00\
\>"],
  ImageRangeCache->{{{0, 430.875}, {430.875, 0}} -> {-0.525004, -0.525005, \
0.00365538, 0.00365538}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[16]="]
}, Open  ]],

Cell["\<\
Well, it is a bit of abuse, since normally the function is only used to move \
points out of the region back to its boundary.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Distributing as the Size Function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]]
}], "Section"],

Cell[TextData[{
  "The other important function in the algorithm is ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ". It is actually the goal of the algorithm to make the size of mesh \
triangles distributed,  in 2-D case, as ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ". The simplest case would be ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y) = 1\)]],
  ", such that all the mesh triangles are of the same size. A more \
interesting example, the following definition ask for triangle sizes related \
by ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x\^2 + y\^2\)\)]],
  ", which means the closer they are to the center point ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\((0, 0)\)\)]]]], TraditionalForm]]],
  ", the smaller  the triangle meshes are. It therefore asks for more \
meshpoints as they are closer to the center point ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\((0, 0)\)\)]]]], TraditionalForm]]],
  ". So the size function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " determines the locations of meshpoints indirectly."
}], "Text"],

Cell[BoxData[
    \(h[{x_, y_}] := 0.1 + 0.1 \@\( x\^2 + y\^2\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[TextData[{
  "To distribute meshpoints initially, for example, in a 2-D disk, we assign \
a value to each would-be meshpoint ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_i, \ y\_i)\)\)]],
  " by applying function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " to it. Since ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " is a relative measure, there is a scaling process, i.e. to normalize all \
the values between 0 and 1. Such scaling process is essential and will appear \
again later (",
  StyleBox["step 6",
    FontSlant->"Italic"],
  " in the paper). (The definition of function ",
  StyleBox["scale",
    FontFamily->"Courier"],
  " is a bit like MATLAB's style. It makes use of the \"Listable\" property \
of the function ",
  StyleBox["Divide",
    FontFamily->"Courier"],
  ".)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(scale[x_List] := x\/Max[x]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(scale\\)\\\" is similar to existing symbol \
\\\"\\!\\(Scale\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[18]:="]
}, Open  ]],

Cell["To attach a normalized value for each meshpoint", "Text"],

Cell[BoxData[
    \(\(\(\(pts = 
        selectMeshpoints[
          dcircle[#, {0, 0, 5}] &, \ {\(-10\), \(-10\), 10, 10}, 
          0.1]\) \)\(;\)\(\(values = 
        scale[\((\(1\/h[#]\^2 &\) /@ pts)\)]\) \)\(;\)\( (*\ 
      a\ more\ compact\ expression\ can\ be\[IndentingNewLine]values\  = \ 
        Divide @@ \((\({#, Max[#]} &\)[\(1/h[#]\^2 &\) /@ 
                pts])\)\ *) \)\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[TextData[{
  "In the algorithm, a lottery is drawn to select which meshpoints to \
survive. The attached values isn't actually ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " but ",
  Cell[BoxData[
      \(TraditionalForm\`1/h \((x, y)\)\^2\)]],
  " instead, as being the probability of \"survival\" (part of ",
  StyleBox["step 2",
    FontSlant->"Italic"],
  " in the paper). The meshpoint at locations ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_i, y\_i)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x\_i, y\_i)\)]],
  " is smaller, has larger ",
  Cell[BoxData[
      \(TraditionalForm\`1/h \((x\_i, y\_i)\)\^2\)]],
  " value so that has higher probability to survive, therefore more \
meshpoints are located at where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " demands smaller mesh triangles."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((p = Extract[pts, \ Position[values, \ _?\((# > Random[] &)\)]])\) // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]\ ] &\)], "Input",
  CellLabel->"In[21]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99724 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0962001 0.494206 0.0962001 [
[.1152 .48171 -6 -9 ]
[.1152 .48171 6 0 ]
[.3076 .48171 -6 -9 ]
[.3076 .48171 6 0 ]
[.6924 .48171 -3 -9 ]
[.6924 .48171 3 0 ]
[.8848 .48171 -3 -9 ]
[.8848 .48171 3 0 ]
[.4875 .10941 -12 -4.5 ]
[.4875 .10941 0 4.5 ]
[.4875 .30181 -12 -4.5 ]
[.4875 .30181 0 4.5 ]
[.4875 .68661 -6 -4.5 ]
[.4875 .68661 0 4.5 ]
[.4875 .87901 -6 -4.5 ]
[.4875 .87901 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99724 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1152 .49421 m
.1152 .50046 L
s
[(-4)] .1152 .48171 0 1 Mshowa
.3076 .49421 m
.3076 .50046 L
s
[(-2)] .3076 .48171 0 1 Mshowa
.6924 .49421 m
.6924 .50046 L
s
[(2)] .6924 .48171 0 1 Mshowa
.8848 .49421 m
.8848 .50046 L
s
[(4)] .8848 .48171 0 1 Mshowa
.125 Mabswid
.1633 .49421 m
.1633 .49796 L
s
.2114 .49421 m
.2114 .49796 L
s
.2595 .49421 m
.2595 .49796 L
s
.3557 .49421 m
.3557 .49796 L
s
.4038 .49421 m
.4038 .49796 L
s
.4519 .49421 m
.4519 .49796 L
s
.5481 .49421 m
.5481 .49796 L
s
.5962 .49421 m
.5962 .49796 L
s
.6443 .49421 m
.6443 .49796 L
s
.7405 .49421 m
.7405 .49796 L
s
.7886 .49421 m
.7886 .49796 L
s
.8367 .49421 m
.8367 .49796 L
s
.0671 .49421 m
.0671 .49796 L
s
.019 .49421 m
.019 .49796 L
s
.9329 .49421 m
.9329 .49796 L
s
.981 .49421 m
.981 .49796 L
s
.25 Mabswid
0 .49421 m
1 .49421 L
s
.5 .10941 m
.50625 .10941 L
s
[(-4)] .4875 .10941 1 0 Mshowa
.5 .30181 m
.50625 .30181 L
s
[(-2)] .4875 .30181 1 0 Mshowa
.5 .68661 m
.50625 .68661 L
s
[(2)] .4875 .68661 1 0 Mshowa
.5 .87901 m
.50625 .87901 L
s
[(4)] .4875 .87901 1 0 Mshowa
.125 Mabswid
.5 .15751 m
.50375 .15751 L
s
.5 .20561 m
.50375 .20561 L
s
.5 .25371 m
.50375 .25371 L
s
.5 .34991 m
.50375 .34991 L
s
.5 .39801 m
.50375 .39801 L
s
.5 .44611 m
.50375 .44611 L
s
.5 .54231 m
.50375 .54231 L
s
.5 .59041 m
.50375 .59041 L
s
.5 .63851 m
.50375 .63851 L
s
.5 .73471 m
.50375 .73471 L
s
.5 .78281 m
.50375 .78281 L
s
.5 .83091 m
.50375 .83091 L
s
.5 .06131 m
.50375 .06131 L
s
.5 .01321 m
.50375 .01321 L
s
.5 .92711 m
.50375 .92711 L
s
.5 .97521 m
.50375 .97521 L
s
.25 Mabswid
.5 0 m
.5 .99724 L
s
0 0 m
1 0 L
1 .99724 L
0 .99724 L
closepath
clip
newpath
.01 w
.47114 .02374 Mdot
.46152 .04041 Mdot
.52886 .04041 Mdot
.56253 .04874 Mdot
.4519 .05707 Mdot
.52405 .0654 Mdot
.47114 .07373 Mdot
.28355 .08206 Mdot
.31241 .08206 Mdot
.37013 .08206 Mdot
.63949 .08206 Mdot
.72607 .08206 Mdot
.5 .09039 Mdot
.42785 .09872 Mdot
.58177 .09872 Mdot
.3557 .10706 Mdot
.5 .10706 Mdot
.5962 .10706 Mdot
.66354 .10706 Mdot
.27393 .11539 Mdot
.31241 .11539 Mdot
.55291 .11539 Mdot
.62025 .11539 Mdot
.77417 .11539 Mdot
.79822 .12372 Mdot
.48557 .14871 Mdot
.49519 .14871 Mdot
.50481 .14871 Mdot
.58177 .14871 Mdot
.24988 .15704 Mdot
.50962 .15704 Mdot
.60582 .15704 Mdot
.44709 .16537 Mdot
.45671 .16537 Mdot
.80784 .1737 Mdot
.36051 .18204 Mdot
.39899 .18204 Mdot
.42785 .18204 Mdot
.44709 .18204 Mdot
.45671 .18204 Mdot
.48557 .18204 Mdot
.49519 .18204 Mdot
.64911 .18204 Mdot
.23064 .19037 Mdot
.27874 .19037 Mdot
.3076 .19037 Mdot
.61544 .19037 Mdot
.42785 .1987 Mdot
.44709 .1987 Mdot
.46633 .1987 Mdot
.51443 .1987 Mdot
.24988 .20703 Mdot
.3076 .20703 Mdot
.70202 .20703 Mdot
.29317 .21536 Mdot
.57215 .21536 Mdot
.61063 .21536 Mdot
.70683 .21536 Mdot
.81265 .21536 Mdot
.39418 .22369 Mdot
.4038 .22369 Mdot
.49038 .22369 Mdot
.67316 .22369 Mdot
.7405 .22369 Mdot
.79822 .22369 Mdot
.50481 .23202 Mdot
.63949 .23202 Mdot
.65873 .23202 Mdot
.73569 .23202 Mdot
.18254 .24035 Mdot
.36532 .24035 Mdot
.39418 .24035 Mdot
.44228 .24035 Mdot
.5481 .24035 Mdot
.12001 .24869 Mdot
.17773 .24869 Mdot
.69721 .24869 Mdot
.72607 .24869 Mdot
.82227 .24869 Mdot
.3076 .25702 Mdot
.3557 .25702 Mdot
.56734 .25702 Mdot
.6924 .25702 Mdot
.91366 .25702 Mdot
.09115 .26535 Mdot
.43747 .26535 Mdot
.56253 .26535 Mdot
.58177 .26535 Mdot
.79341 .26535 Mdot
.29798 .27368 Mdot
.38456 .27368 Mdot
.48076 .27368 Mdot
.42785 .28201 Mdot
.64911 .28201 Mdot
.36532 .29034 Mdot
.39418 .29034 Mdot
.52886 .29034 Mdot
.53848 .29034 Mdot
.5481 .29034 Mdot
.73088 .29034 Mdot
.21621 .29867 Mdot
.23545 .29867 Mdot
.28355 .29867 Mdot
.35089 .29867 Mdot
.60101 .29867 Mdot
.05748 .307 Mdot
.1633 .307 Mdot
.37494 .307 Mdot
.56734 .307 Mdot
.7405 .307 Mdot
.40861 .31533 Mdot
.55291 .31533 Mdot
.2114 .32367 Mdot
.31722 .32367 Mdot
.34608 .32367 Mdot
.38456 .32367 Mdot
.39418 .32367 Mdot
.43266 .32367 Mdot
.51924 .32367 Mdot
.5481 .32367 Mdot
.82708 .32367 Mdot
.84632 .32367 Mdot
.07191 .332 Mdot
.12963 .332 Mdot
.20659 .332 Mdot
.36051 .332 Mdot
.41823 .332 Mdot
.42785 .332 Mdot
.45671 .332 Mdot
.47595 .332 Mdot
.50481 .332 Mdot
.77417 .332 Mdot
.88961 .332 Mdot
.15368 .34033 Mdot
.22102 .34033 Mdot
.24988 .34033 Mdot
.26912 .34033 Mdot
.29798 .34033 Mdot
.37494 .34033 Mdot
.53848 .34033 Mdot
.55772 .34033 Mdot
.6924 .34033 Mdot
.48557 .34866 Mdot
.56253 .34866 Mdot
.62025 .34866 Mdot
.74531 .34866 Mdot
.81265 .34866 Mdot
.89923 .34866 Mdot
.20178 .35699 Mdot
.42304 .35699 Mdot
.50962 .35699 Mdot
.5481 .35699 Mdot
.61544 .35699 Mdot
.62506 .35699 Mdot
.82708 .35699 Mdot
.18735 .36532 Mdot
.39899 .36532 Mdot
.42785 .36532 Mdot
.45671 .36532 Mdot
.51443 .36532 Mdot
.54329 .36532 Mdot
.56253 .36532 Mdot
.85113 .36532 Mdot
.22102 .37365 Mdot
.32684 .37365 Mdot
.46152 .37365 Mdot
.48076 .37365 Mdot
.50962 .37365 Mdot
.51924 .37365 Mdot
.55772 .37365 Mdot
.61544 .37365 Mdot
.68278 .37365 Mdot
.70202 .37365 Mdot
.7405 .37365 Mdot
.84632 .37365 Mdot
.87518 .37365 Mdot
.91366 .37365 Mdot
.38937 .38198 Mdot
.43747 .38198 Mdot
.45671 .38198 Mdot
.52405 .38198 Mdot
.53367 .38198 Mdot
.61063 .38198 Mdot
.80303 .38198 Mdot
.95695 .38198 Mdot
.17292 .39032 Mdot
.2595 .39032 Mdot
.3557 .39032 Mdot
.36532 .39032 Mdot
.38456 .39032 Mdot
.39418 .39032 Mdot
.4038 .39032 Mdot
.43266 .39032 Mdot
.52886 .39032 Mdot
.53848 .39032 Mdot
.68278 .39032 Mdot
.70202 .39032 Mdot
.73088 .39032 Mdot
.86556 .39032 Mdot
.14887 .39865 Mdot
.25469 .39865 Mdot
.38937 .39865 Mdot
.40861 .39865 Mdot
.42785 .39865 Mdot
.46633 .39865 Mdot
.51443 .39865 Mdot
.54329 .39865 Mdot
.55291 .39865 Mdot
.57215 .39865 Mdot
.64911 .39865 Mdot
.74531 .39865 Mdot
.87999 .39865 Mdot
.88961 .39865 Mdot
.29798 .40698 Mdot
.31722 .40698 Mdot
.38456 .40698 Mdot
.4519 .40698 Mdot
.46152 .40698 Mdot
.5 .40698 Mdot
.57696 .40698 Mdot
.61544 .40698 Mdot
.79822 .40698 Mdot
.06229 .41531 Mdot
.15849 .41531 Mdot
.45671 .41531 Mdot
.46633 .41531 Mdot
.48557 .41531 Mdot
.49519 .41531 Mdot
.53367 .41531 Mdot
.54329 .41531 Mdot
.55291 .41531 Mdot
.60101 .41531 Mdot
.31722 .42364 Mdot
.32684 .42364 Mdot
.38456 .42364 Mdot
.41342 .42364 Mdot
.44228 .42364 Mdot
.50962 .42364 Mdot
.51924 .42364 Mdot
.52886 .42364 Mdot
.53848 .42364 Mdot
.55772 .42364 Mdot
.72126 .42364 Mdot
.73088 .42364 Mdot
.7886 .42364 Mdot
.84632 .42364 Mdot
.90404 .42364 Mdot
.37975 .43197 Mdot
.41823 .43197 Mdot
.43747 .43197 Mdot
.45671 .43197 Mdot
.48557 .43197 Mdot
.54329 .43197 Mdot
.58177 .43197 Mdot
.81265 .43197 Mdot
.24026 .4403 Mdot
.27874 .4403 Mdot
.31722 .4403 Mdot
.33646 .4403 Mdot
.34608 .4403 Mdot
.44228 .4403 Mdot
.5 .4403 Mdot
.51924 .4403 Mdot
.52886 .4403 Mdot
.56734 .4403 Mdot
.5962 .4403 Mdot
.60582 .4403 Mdot
.73088 .4403 Mdot
.87518 .4403 Mdot
.16811 .44863 Mdot
.31241 .44863 Mdot
.41823 .44863 Mdot
.47595 .44863 Mdot
.48557 .44863 Mdot
.55291 .44863 Mdot
.56253 .44863 Mdot
.58177 .44863 Mdot
.65873 .44863 Mdot
.77417 .44863 Mdot
.1633 .45696 Mdot
.33646 .45696 Mdot
.36532 .45696 Mdot
.43266 .45696 Mdot
.44228 .45696 Mdot
.46152 .45696 Mdot
.47114 .45696 Mdot
.48076 .45696 Mdot
.49038 .45696 Mdot
.50962 .45696 Mdot
.51924 .45696 Mdot
.52886 .45696 Mdot
.53848 .45696 Mdot
.56734 .45696 Mdot
.62506 .45696 Mdot
.66354 .45696 Mdot
.75012 .45696 Mdot
.23545 .4653 Mdot
.35089 .4653 Mdot
.38937 .4653 Mdot
.42785 .4653 Mdot
.45671 .4653 Mdot
.46633 .4653 Mdot
.47595 .4653 Mdot
.48557 .4653 Mdot
.50481 .4653 Mdot
.52405 .4653 Mdot
.53367 .4653 Mdot
.54329 .4653 Mdot
.56253 .4653 Mdot
.59139 .4653 Mdot
.65873 .4653 Mdot
.69721 .4653 Mdot
.84151 .4653 Mdot
.97619 .4653 Mdot
.32684 .47363 Mdot
.33646 .47363 Mdot
.34608 .47363 Mdot
.3557 .47363 Mdot
.41342 .47363 Mdot
.42304 .47363 Mdot
.44228 .47363 Mdot
.4519 .47363 Mdot
.47114 .47363 Mdot
.48076 .47363 Mdot
.49038 .47363 Mdot
.5 .47363 Mdot
.50962 .47363 Mdot
.53848 .47363 Mdot
.5481 .47363 Mdot
.20659 .48196 Mdot
.32203 .48196 Mdot
.35089 .48196 Mdot
.38937 .48196 Mdot
.44709 .48196 Mdot
.45671 .48196 Mdot
.48557 .48196 Mdot
.49519 .48196 Mdot
.51443 .48196 Mdot
.55291 .48196 Mdot
.59139 .48196 Mdot
.60101 .48196 Mdot
.63949 .48196 Mdot
.67797 .48196 Mdot
.75493 .48196 Mdot
.82227 .48196 Mdot
.93771 .48196 Mdot
.08634 .49029 Mdot
.1633 .49029 Mdot
.17292 .49029 Mdot
.2114 .49029 Mdot
.33646 .49029 Mdot
.41342 .49029 Mdot
.42304 .49029 Mdot
.44228 .49029 Mdot
.46152 .49029 Mdot
.47114 .49029 Mdot
.48076 .49029 Mdot
.49038 .49029 Mdot
.5 .49029 Mdot
.53848 .49029 Mdot
.55772 .49029 Mdot
.63468 .49029 Mdot
.72126 .49029 Mdot
.81746 .49029 Mdot
.89442 .49029 Mdot
.02381 .49862 Mdot
.17773 .49862 Mdot
.23545 .49862 Mdot
.32203 .49862 Mdot
.37975 .49862 Mdot
.39899 .49862 Mdot
.41823 .49862 Mdot
.43747 .49862 Mdot
.44709 .49862 Mdot
.47595 .49862 Mdot
.49519 .49862 Mdot
.50481 .49862 Mdot
.51443 .49862 Mdot
.53367 .49862 Mdot
.54329 .49862 Mdot
.55291 .49862 Mdot
.56253 .49862 Mdot
.58177 .49862 Mdot
.64911 .49862 Mdot
.72607 .49862 Mdot
.04786 .50695 Mdot
.20178 .50695 Mdot
.2114 .50695 Mdot
.24988 .50695 Mdot
.28836 .50695 Mdot
.38456 .50695 Mdot
.4038 .50695 Mdot
.41342 .50695 Mdot
.42304 .50695 Mdot
.44228 .50695 Mdot
.4519 .50695 Mdot
.46152 .50695 Mdot
.47114 .50695 Mdot
.48076 .50695 Mdot
.49038 .50695 Mdot
.5 .50695 Mdot
.50962 .50695 Mdot
.51924 .50695 Mdot
.53848 .50695 Mdot
.56734 .50695 Mdot
.60582 .50695 Mdot
.6443 .50695 Mdot
.76936 .50695 Mdot
.82708 .50695 Mdot
.12963 .51528 Mdot
.32203 .51528 Mdot
.40861 .51528 Mdot
.41823 .51528 Mdot
.42785 .51528 Mdot
.47595 .51528 Mdot
.49519 .51528 Mdot
.53367 .51528 Mdot
.56253 .51528 Mdot
.57215 .51528 Mdot
.62987 .51528 Mdot
.64911 .51528 Mdot
.67797 .51528 Mdot
.72607 .51528 Mdot
.04786 .52361 Mdot
.09596 .52361 Mdot
.10558 .52361 Mdot
.24026 .52361 Mdot
.27874 .52361 Mdot
.3076 .52361 Mdot
.32684 .52361 Mdot
.4038 .52361 Mdot
.41342 .52361 Mdot
.43266 .52361 Mdot
.4519 .52361 Mdot
.46152 .52361 Mdot
.47114 .52361 Mdot
.50962 .52361 Mdot
.52886 .52361 Mdot
.56734 .52361 Mdot
.58658 .52361 Mdot
.61544 .52361 Mdot
.75012 .52361 Mdot
.80784 .52361 Mdot
.19697 .53195 Mdot
.25469 .53195 Mdot
.34127 .53195 Mdot
.45671 .53195 Mdot
.46633 .53195 Mdot
.47595 .53195 Mdot
.52405 .53195 Mdot
.53367 .53195 Mdot
.55291 .53195 Mdot
.56253 .53195 Mdot
.57215 .53195 Mdot
.58177 .53195 Mdot
.64911 .53195 Mdot
.65873 .53195 Mdot
.74531 .53195 Mdot
.34608 .54028 Mdot
.38456 .54028 Mdot
.39418 .54028 Mdot
.4038 .54028 Mdot
.4519 .54028 Mdot
.46152 .54028 Mdot
.48076 .54028 Mdot
.49038 .54028 Mdot
.50962 .54028 Mdot
.52886 .54028 Mdot
.55772 .54028 Mdot
.58658 .54028 Mdot
.66354 .54028 Mdot
.73088 .54028 Mdot
.7405 .54028 Mdot
.90404 .54028 Mdot
.29317 .54861 Mdot
.33165 .54861 Mdot
.37975 .54861 Mdot
.45671 .54861 Mdot
.46633 .54861 Mdot
.49519 .54861 Mdot
.50481 .54861 Mdot
.51443 .54861 Mdot
.54329 .54861 Mdot
.59139 .54861 Mdot
.66835 .54861 Mdot
.70683 .54861 Mdot
.0671 .55694 Mdot
.2114 .55694 Mdot
.34608 .55694 Mdot
.4519 .55694 Mdot
.46152 .55694 Mdot
.47114 .55694 Mdot
.51924 .55694 Mdot
.52886 .55694 Mdot
.53848 .55694 Mdot
.57696 .55694 Mdot
.58658 .55694 Mdot
.60582 .55694 Mdot
.10077 .56527 Mdot
.36051 .56527 Mdot
.40861 .56527 Mdot
.41823 .56527 Mdot
.46633 .56527 Mdot
.47595 .56527 Mdot
.48557 .56527 Mdot
.50481 .56527 Mdot
.53367 .56527 Mdot
.56253 .56527 Mdot
.57215 .56527 Mdot
.60101 .56527 Mdot
.63949 .56527 Mdot
.70683 .56527 Mdot
.87999 .56527 Mdot
.88961 .56527 Mdot
.89923 .56527 Mdot
.07672 .5736 Mdot
.27874 .5736 Mdot
.28836 .5736 Mdot
.32684 .5736 Mdot
.39418 .5736 Mdot
.44228 .5736 Mdot
.47114 .5736 Mdot
.58658 .5736 Mdot
.62506 .5736 Mdot
.6443 .5736 Mdot
.07191 .58193 Mdot
.08153 .58193 Mdot
.37975 .58193 Mdot
.50481 .58193 Mdot
.56253 .58193 Mdot
.57215 .58193 Mdot
.59139 .58193 Mdot
.63949 .58193 Mdot
.65873 .58193 Mdot
.68759 .58193 Mdot
.14406 .59026 Mdot
.38456 .59026 Mdot
.47114 .59026 Mdot
.5481 .59026 Mdot
.63468 .59026 Mdot
.71164 .59026 Mdot
.07191 .59859 Mdot
.44709 .59859 Mdot
.49519 .59859 Mdot
.52405 .59859 Mdot
.53367 .59859 Mdot
.60101 .59859 Mdot
.71645 .59859 Mdot
.23064 .60693 Mdot
.24026 .60693 Mdot
.3557 .60693 Mdot
.38456 .60693 Mdot
.48076 .60693 Mdot
.5 .60693 Mdot
.50962 .60693 Mdot
.53848 .60693 Mdot
.15849 .61526 Mdot
.25469 .61526 Mdot
.29317 .61526 Mdot
.45671 .61526 Mdot
.50481 .61526 Mdot
.53367 .61526 Mdot
.56253 .61526 Mdot
.57215 .61526 Mdot
.68759 .61526 Mdot
.69721 .61526 Mdot
.27874 .62359 Mdot
.34608 .62359 Mdot
.3557 .62359 Mdot
.38456 .62359 Mdot
.4519 .62359 Mdot
.48076 .62359 Mdot
.70202 .62359 Mdot
.35089 .63192 Mdot
.41823 .63192 Mdot
.45671 .63192 Mdot
.61063 .63192 Mdot
.64911 .63192 Mdot
.67797 .63192 Mdot
.05748 .64025 Mdot
.1633 .64025 Mdot
.26912 .64025 Mdot
.66354 .64025 Mdot
.18735 .64858 Mdot
.33165 .64858 Mdot
.40861 .64858 Mdot
.42785 .64858 Mdot
.56253 .64858 Mdot
.69721 .64858 Mdot
.42304 .65691 Mdot
.44228 .65691 Mdot
.56734 .65691 Mdot
.61544 .65691 Mdot
.62506 .65691 Mdot
.77898 .65691 Mdot
.32203 .66524 Mdot
.34127 .66524 Mdot
.39899 .66524 Mdot
.40861 .66524 Mdot
.41823 .66524 Mdot
.47595 .66524 Mdot
.48557 .66524 Mdot
.50481 .66524 Mdot
.57215 .66524 Mdot
.94733 .66524 Mdot
.23064 .67358 Mdot
.33646 .67358 Mdot
.5 .67358 Mdot
.51924 .67358 Mdot
.6443 .67358 Mdot
.81746 .67358 Mdot
.87518 .67358 Mdot
.30279 .68191 Mdot
.33165 .68191 Mdot
.46633 .68191 Mdot
.60101 .68191 Mdot
.26912 .69024 Mdot
.34608 .69024 Mdot
.51924 .69024 Mdot
.6443 .69024 Mdot
.71164 .69024 Mdot
.72126 .69024 Mdot
.13925 .69857 Mdot
.45671 .69857 Mdot
.47595 .69857 Mdot
.50481 .69857 Mdot
.53367 .69857 Mdot
.58177 .69857 Mdot
.61063 .69857 Mdot
.07672 .7069 Mdot
.24026 .7069 Mdot
.32684 .7069 Mdot
.4038 .7069 Mdot
.43266 .7069 Mdot
.47114 .7069 Mdot
.5481 .7069 Mdot
.55772 .7069 Mdot
.57696 .7069 Mdot
.70202 .7069 Mdot
.75974 .7069 Mdot
.12001 .71523 Mdot
.29317 .71523 Mdot
.45671 .71523 Mdot
.48557 .71523 Mdot
.52405 .71523 Mdot
.62987 .71523 Mdot
.74531 .71523 Mdot
.13444 .72356 Mdot
.37494 .72356 Mdot
.4038 .72356 Mdot
.48076 .72356 Mdot
.84632 .72356 Mdot
.18735 .73189 Mdot
.22583 .73189 Mdot
.38937 .73189 Mdot
.40861 .73189 Mdot
.58177 .73189 Mdot
.82227 .73189 Mdot
.88961 .73189 Mdot
.15368 .74022 Mdot
.32684 .74022 Mdot
.37494 .74022 Mdot
.85594 .74022 Mdot
.23545 .74856 Mdot
.27393 .74856 Mdot
.70683 .74856 Mdot
.24988 .75689 Mdot
.3076 .75689 Mdot
.33646 .75689 Mdot
.43266 .75689 Mdot
.48076 .75689 Mdot
.5962 .75689 Mdot
.67316 .75689 Mdot
.19697 .76522 Mdot
.21621 .76522 Mdot
.43747 .76522 Mdot
.48557 .76522 Mdot
.51443 .76522 Mdot
.58177 .76522 Mdot
.73569 .76522 Mdot
.22102 .77355 Mdot
.23064 .77355 Mdot
.33646 .77355 Mdot
.38456 .77355 Mdot
.7405 .77355 Mdot
.46633 .78188 Mdot
.83189 .78188 Mdot
.39418 .79021 Mdot
.41342 .79021 Mdot
.4519 .79021 Mdot
.5 .79021 Mdot
.20659 .79854 Mdot
.40861 .79854 Mdot
.31722 .80687 Mdot
.46152 .80687 Mdot
.47114 .80687 Mdot
.7405 .80687 Mdot
.28355 .81521 Mdot
.20178 .82354 Mdot
.75974 .82354 Mdot
.22583 .83187 Mdot
.37975 .83187 Mdot
.38937 .83187 Mdot
.48557 .83187 Mdot
.60101 .83187 Mdot
.66835 .83187 Mdot
.77417 .83187 Mdot
.53848 .8402 Mdot
.18735 .84853 Mdot
.22583 .84853 Mdot
.39899 .84853 Mdot
.43747 .84853 Mdot
.28836 .85686 Mdot
.52886 .85686 Mdot
.55772 .85686 Mdot
.71164 .85686 Mdot
.31241 .86519 Mdot
.46633 .86519 Mdot
.61063 .86519 Mdot
.78379 .86519 Mdot
.30279 .88185 Mdot
.65873 .88185 Mdot
.4519 .89019 Mdot
.24507 .89852 Mdot
.55772 .90685 Mdot
.55772 .92351 Mdot
.66354 .92351 Mdot
.56734 .94017 Mdot
.37013 .9485 Mdot
.52405 .9485 Mdot
.52886 .95684 Mdot
.52405 .96517 Mdot
.57215 .96517 Mdot
.48076 .9735 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[21]:=",
  ImageSize->{288, 287.188},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001[Q000`40O003h00Oefmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk0039Kg/4000:Kg/00`00Kg]_N`3FKg/0
0<U_N`@000Y_N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk0036Kg/2000?Kg/00`00Kg]_N`09Kg/2
003;Kg/00<E_N`@000i_N`03001_Nfmk00Q_N`@00<Y_N`00aFmk10003Vmk00<006mkKg/026mk1000
bVmk0036Kg/2000?Kg/00`00Kg]_N`09Kg/2000<Kg/2002mKg/00=M_N`03001_Nfmk01I_N`@00;a_
N`00efmk00<006mkKg/05Vmk1000_6mk003GKg/00`00Kg]_N`0GKg/2002mKg/00<9_N`8001=_N`03
001_Nfmk0=I_N`00`Fmk10004Vmk00<006mkKg/0eVmk0031Kg/4000BKg/00`00Kg]_N`3FKg/00<9_
N`8001=_N`<00=I_N`00efmk00<006mkKg/01fmk0P00cFmk003GKg/00`00Kg]_N`06Kg/4003<Kg/0
0=M_N`03001_Nfmk00I_N`@00<a_N`00bVmk0P002fmk00<006mkKg/01fmk0P00cFmk0039Kg/4000:
Kg/00`00Kg]_N`3FKg/00<U_N`@000Y_N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk
001iKg/2000;Kg/2000FKg/2000gKg/00`00Kg]_N`0hKg/2000TKg/2001fKg/007Q_N`@000U_N`@0
01A_N`@003I_N`03001_Nfmk03M_N`@0029_N`@007E_N`00N6mk10002Fmk100056mk1000=Vmk00<0
06mkKg/0=fmk10008Vmk1000MFmk001iKg/2000;Kg/2000FKg/2000fKg/2000jKg/2000TKg/2001f
Kg/00=E_N`@00=M_N`00eFmk1000efmk003FKg/2003HKg/00;M_N`8001i_N`03001_Nfmk021_N`80
0;A_N`00]Vmk10007Fmk00<006mkKg/07fmk1000/fmk002fKg/4000BKg/40007Kg/00`00Kg]_N`0O
Kg/4002cKg/00;M_N`8001E_N`03001_Nfmk00I_N`03001_Nfmk021_N`800;A_N`00V6mk0P00=6mk
00<006mkKg/01Fmk0P00:6mk0P006fmk0P00TFmk002GKg/4000_Kg/60005Kg/4000VKg/4000IKg/4
002@Kg/009M_N`@002I_N`H000A_N`04001_Nfmk0006Kg/6000TKg/4000IKg/4002@Kg/007E_N`80
00m_N`80011_N`80035_N`04001_Nfmk0007Kg/2000EKg/2000AKg/20008Kg/2000AKg/2000^Kg/2
001QKg/007A_N`@000e_N`@004=_N`03001_N`0000Q_N`03001_Nfmk019_N`@001U_N`@003m_N`@0
061_N`00M6mk10003Fmk1000@fmk00<006mk000026mk00<006mkKg/04Vmk10006Fmk1000?fmk1000
H6mk001eKg/2000?Kg/20015Kg/20008Kg/00`00Kg]_N`0CKg/2000KKg/20011Kg/2001QKg/00=M_
N`03001_Nfmk07e_N`8005M_N`00efmk00<006mkKg/0O6mk1000EVmk003GKg/00`00Kg]_N`1lKg/4
001FKg/00=M_N`03001_Nfmk07e_N`8005M_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00d6mk0P000Vmk0P0000A_N`000000021_N`800;A_N`00cfmk30007Vmk1000/fmk
003?Kg/<000NKg/4002cKg/00=1_N`80009_N`800004Kg/00000000PKg/2002dKg/006]_N`8006Y_
N`04001_NfmkKg/2000WKg/2002ZKg/006Y_N`@006U_N`03001_Nfmk00@002E_N`@00:U_N`00JVmk
1000JFmk1`009Fmk1000ZFmk001[Kg/2001ZKg/01000Kg]_Nfmk0P009fmk0P00ZVmk0030Kg/20002
Kg/2000AKg/00`00Kg]_N`3FKg/00;m_N`P0011_N`03001_Nfmk0=I_N`00_fmk200046mk00<006mk
Kg/0eVmk0030Kg/20002Kg/2000AKg/00`00Kg]_N`21Kg/2001CKg/00=M_N`03001_Nfmk081_N`@0
059_N`00efmk00<006mkKg/0P6mk1000DVmk003GKg/00`00Kg]_N`21Kg/2001CKg/009Y_N`8000m_
N`8000Y_N`8000M_N`80009_N`8000Y_N`80009_N`800003Kg/006mk03i_N`8009M_N`00VFmk1000
3Fmk100026mk10001Fmk200026mk2@00?Vmk1000UVmk002IKg/4000=Kg/40008Kg/40005Kg/80008
Kg/9000nKg/4002FKg/0069_N`8001=_N`8000Y_N`8001E_N`8000m_N`8000Y_N`8000M_N`80009_
N`8000Y_N`80009_N`800003Kg/006mk02m_N`8000e_N`8009M_N`00HFmk10004Fmk100026mk1000
DFmk00<006mkKg/0;Fmk1000YFmk001QKg/4000AKg/40008Kg/4001AKg/00`00Kg]_N`0]Kg/4002U
Kg/0069_N`8001=_N`8000Y_N`80059_N`03001_Nfmk02i_N`800:I_N`00]fmk0P001fmk0P001Vmk
0P003Fmk00<006mkKg/00fmk0P00dFmk002fKg/40005Kg/40004Kg/4000<Kg/00`00Kg]_N`02Kg/4
003@Kg/00;I_N`@000E_N`@000A_N`@000a_N`03001_Nfmk009_N`@00=1_N`00]fmk0P001fmk0P00
1Vmk0P003Fmk00<006mkKg/00fmk0P00dFmk001[Kg/2000FKg/2001BKg/3001CKg/20021Kg/006Y_
N`@001A_N`@0055_N`03001_Nfmk059_N`@0081_N`00JVmk100056mk1000DFmk00<006mkKg/0DVmk
1000P6mk001[Kg/2000@Kg/20004Kg/2001BKg/00`00Kg]_N`0KKg/2000?Kg/2000UKg/200000fmk
0000000[Kg/2001AKg/007a_N`@005M_N`03001_Nfmk01Y_N`@000e_N`@002I_N`@002U_N`@0051_
N`00O6mk1000Efmk00<006mkKg/06Vmk10003Fmk10009Vmk1000:Fmk1000D6mk001mKg/2001HKg/0
0`00Kg]_N`0KKg/2000?Kg/2000XKg/2000[Kg/2001AKg/00:U_N`80009_N`8002=_N`8000=_N`03
001_Nfmk04M_N`8001]_N`8001M_N`8005M_N`00Z6mk20008Fmk10000Vmk00<006mkKg/0AVmk1000
6Fmk10005Fmk1000EVmk002XKg/8000QKg/40002Kg/00`00Kg]_N`16Kg/4000IKg/4000EKg/4001F
Kg/00:U_N`80009_N`8002=_N`8000=_N`<003Q_N`8000M_N`8000A_N`8001U_N`@001M_N`8005M_
N`00efmk1000=Vmk10001Fmk10007Fmk1000LFmk003GKg/4000fKg/40005Kg/4000MKg/4001aKg/0
0=M_N`<003Q_N`8000M_N`8001m_N`80079_N`00CVmk0P00C6mk0P002fmk0P004fmk0P005fmk00<0
06mkKg/04Fmk0P00`fmk001=Kg/4001:Kg/40009Kg/4000AKg/4000FKg/00`00Kg]_N`0@Kg/40032
Kg/004e_N`@004Y_N`@000U_N`@0015_N`@001I_N`03001_Nfmk011_N`@00<9_N`00CVmk0P00C6mk
0P002fmk0P004fmk0P005fmk00<006mkKg/04Fmk0P00`fmk000cKg/2000FKg/2002:Kg/00`00Kg]_
N`1AKg/2000;Kg/2000WKg/2001=Kg/0039_N`@001A_N`@008U_N`03001_Nfmk051_N`@000U_N`@0
02E_N`@004a_N`00<Vmk100056mk1000RFmk00<006mkKg/0D6mk10002Fmk10009Fmk1000C6mk000c
Kg/2000FKg/2000fKg/2000CKg/2000mKg/3000IKg/2000dKg/4000;Kg/2000WKg/2000VKg/2000U
Kg/0089_N`@0015_N`@003a_N`03001_Nfmk01Q_N`@0039_N`@005a_N`@002A_N`00PVmk10004Fmk
1000?6mk00<006mkKg/066mk1000<Vmk1000G6mk100096mk0023Kg/2000CKg/2000mKg/00`00Kg]_
N`0IKg/2000dKg/2001NKg/2000UKg/002I_N`8009=_N`8001Y_N`03001_Nfmk01M_N`8000M_N`80
05U_N`8005U_N`009Fmk1000TFmk10006Fmk00<006mkKg/05Vmk10001Fmk1000Efmk1000F6mk000U
Kg/4002AKg/4000IKg/00`00Kg]_N`0FKg/40005Kg/4001GKg/4001HKg/002I_N`8005M_N`8002A_
N`8001A_N`80015_N`8000M_N`03001_Nfmk01M_N`8000M_N`8005U_N`8005U_N`00OVmk10008Vmk
10009Fmk10001Vmk00<006mkKg/0eVmk001nKg/4000RKg/4000UKg/40006Kg/00`00Kg]_N`3FKg/0
07m_N`8002A_N`8002M_N`8000M_N`03001_Nfmk0=I_N`00]fmk0P007Vmk00<006mkKg/0?Fmk0P00
Ufmk002fKg/4000MKg/00`00Kg]_N`0lKg/4002FKg/00;I_N`@001e_N`03001_Nfmk03a_N`@009I_
N`00W6mk0P002fmk0P0036mk0P007Vmk00<006mkKg/02Fmk0P000Vmk0P000Vmk0P00:Vmk0P008Fmk
0P00M6mk002KKg/40009Kg/4000[Kg/00`00Kg]_N`08Kg/<001;Kg/4001cKg/009]_N`@000U_N`@0
02]_N`03001_Nfmk00Q_N``004]_N`@007=_N`00W6mk0P002fmk0P007fmk1P001fmk00<006mkKg/0
2Fmk0P000Vmk0P000Vmk0P00CFmk0P00M6mk001LKg/20006Kg/2000CKg/2000KKg/2000bKg/00`00
Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0XKg/2002/Kg/005]_N`@000A_N`@0015_N`@001U_
N`@0039_N`03001_Nfmk00U_N`03001_Nfmk02M_N`@00:]_N`00Ffmk100016mk10004Fmk10006Fmk
1000<fmk00<006mkKg/026mk00<006mkKg/09fmk1000Zfmk001LKg/20006Kg/2000CKg/2000KKg/2
000YKg/60006Kg/00`00Kg]_N`07Kg/4000WKg/2002/Kg/001Q_N`8002]_N`8005U_N`8002a_N`03
001_Nfmk00I_N`03001_Nfmk01U_N`8004U_N`80071_N`005fmk1000:Fmk1000Efmk10009fmk00<0
06mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/066mk1000Afmk1000Kfmk000GKg/4000YKg/4001G
Kg/4000WKg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0HKg/40017Kg/4001_Kg/001Q_
N`8002]_N`8005U_N`8000e_N`8001Y_N`@000Q_N`03001_Nfmk01=_N`8000A_N`8004U_N`80071_
N`00[Vmk10009Fmk00<006mkKg/04Vmk1000`6mk002^Kg/4000UKg/00`00Kg]_N`0BKg/40030Kg/0
0:m_N`8002I_N`03001_Nfmk01=_N`800<5_N`00FVmk0P00;6mk0P002Vmk0P003fmk0P000Vmk0P00
3Vmk0P0076mk00<006mkKg/01Fmk0P002Vmk0P00MVmk0P001fmk0P00@Vmk001IKg/4000ZKg/40008
Kg/4000=Kg/8000<Kg/4000KKg/00`00Kg]_N`04Kg/40008Kg/4001dKg/40005Kg/40011Kg/005U_
N`@002Y_N`@000Q_N`@000e_N`P000a_N`@001]_N`03001_Nfmk00A_N`@000Q_N`@007A_N`@000E_
N`@0045_N`007Vmk0P005fmk0P007fmk1000;6mk0P002Vmk0P0016mk0P002Fmk0P000Vmk0P0026mk
0P000Vmk10002Fmk0P001Vmk0P002Fmk0`001Fmk0P002Vmk0P00H6mk0P0056mk0P001fmk0P0046mk
0P00<6mk000MKg/4000EKg/4000MKg/4000nKg/4000EKg/80009Kg/40004Kg/40008Kg/4001aKg/4
000]Kg/4000_Kg/001e_N`@001E_N`@001e_N`@003i_N`@001E_N`P000U_N`@000A_N`@000Q_N`@0
075_N`@002e_N`@002m_N`007Vmk0P005fmk0P007fmk0P00@6mk0P005fmk0P000Vmk0P002fmk0P00
1Vmk0P002Fmk0`00Lfmk0P00;fmk0P00<6mk0011Kg/2000KKg/2000;Kg/20006Kg/2000:Kg/2000O
Kg/2000eKg/00`00Kg]_N`0=Kg/20006Kg/2000hKg/20025Kg/0041_N`@001U_N`@000U_N`@000A_
N`@000Q_N`@001e_N`@003A_N`03001_Nfmk00a_N`@000A_N`@003I_N`@008A_N`00@6mk10006Fmk
10002Fmk100016mk100026mk10007Fmk1000=6mk00<006mkKg/036mk100016mk1000=Vmk1000Q6mk
0011Kg/2000KKg/2000;Kg/20006Kg/2000:Kg/2000OKg/2000eKg/00`00Kg]_N`0=Kg/20006Kg/2
000hKg/20025Kg/00=1_N`8000E_N`03001_Nfmk01M_N`8001M_N`8003A_N`8001]_N`8002=_N`80
02a_N`00cfmk100016mk00<006mkKg/05Vmk10005Fmk1000<Vmk10006Fmk10008Fmk1000:fmk003?
Kg/40004Kg/3000FKg/4000EKg/4000bKg/4000IKg/4000QKg/4000[Kg/005I_N`8005e_N`8001U_
N`8000E_N`04001_NfmkKg/2000>Kg/20004Kg/2000EKg/6000bKg/2000KKg/20004Kg/2000MKg/2
000/Kg/005E_N`@005]_N`@001m_N`03001_Nfmk00@000a_N`@001U_N`P005=_N`@004Y_N`00EFmk
1000Ffmk10007fmk00<006mkKg/0100036mk10006Fmk2000Dfmk1000BVmk001FKg/2001MKg/2000P
Kg/01000Kg]_Nfmk0P003Vmk0P006fmk0P000Vmk0P00EFmk0P00Bfmk001@Kg/2001IKg/2000:Kg/2
000;Kg/2000AKg/00`00Kg]_N`03Kg/2000:Kg/20006Kg/2001kKg/20010Kg/004m_N`@005M_N`@0
00Q_N`@000U_N`@0011_N`03001_Nfmk009_N`@000Q_N`@000A_N`@007U_N`@003m_N`00Cfmk1000
Efmk100026mk10002Fmk100046mk00<006mkKg/00Vmk100026mk100016mk1000NFmk1000?fmk001@
Kg/2000<Kg/2000/Kg/2000MKg/2000:Kg/2000;Kg/40006Kg/20007Kg/01000Kg]_Nfmk1P0026mk
0P0016mk10005Fmk0P006fmk0P001Vmk0P003fmk0P00;6mk100026mk0P003fmk0P009Fmk001MKg/4
000ZKg/4000fKg/40004Kg/40006Kg/00`00Kg]_N`08000<Kg/4000EKg/4000IKg/40004Kg/4000=
Kg/4000ZKg/40008Kg/4000=Kg/4000TKg/005e_N`@002Y_N`@003I_N`@000A_N`@000I_N`03001_
Nfmk00P000a_N`@001E_N`@001U_N`@000A_N`@000e_N`@002Y_N`@000Q_N`@000e_N`@002A_N`00
GVmk0P00;6mk0P00>6mk0P001Vmk0P001fmk00@006mkKg]_N`80009_N`8000i_N`8001M_N`8001]_
N`8000I_N`8000m_N`8002a_N`8000Y_N`8000m_N`8002E_N`00Yfmk0P004Vmk0P001fmk0P004Fmk
00<006mkKg/01fmk0P000Vmk0P007fmk0P00DFmk0P00@6mk0P004fmk002VKg/4000@Kg/40005Kg/4
000@Kg/00`00Kg]_N`06Kg/8000MKg/4001?Kg/4000nKg/4000BKg/00:I_N`@0011_N`@000E_N`@0
011_N`03001_Nfmk00I_N`P001e_N`@004m_N`@003i_N`@0019_N`00Yfmk0P004Vmk0P001fmk0P00
4Fmk00<006mkKg/01fmk0P000Vmk0P007fmk0P00DFmk0P00@6mk0P004fmk0019Kg/2000TKg/2000W
Kg/20002Kg/20007Kg/20002Kg/20002Kg/2000:Kg/2000LKg/00`00Kg]_N`09Kg/20002Kg/2000l
Kg/20006Kg/2000;Kg/2000hKg/2000jKg/004Q_N`@0029_N`@002E_N`P000E_N``000Q_N`@001]_
N`03001_Nfmk00Q_N`P003Y_N`@000A_N`@000U_N`@003I_N`@003U_N`00B6mk10008Vmk10009Fmk
20001Fmk300026mk10006fmk00<006mkKg/026mk2000>Vmk100016mk10002Fmk1000=Vmk1000>Fmk
000oKg/20008Kg/2000RKg/4000WKg/20002Kg/20007Kg/60002Kg/40006Kg/4000=Kg/2000=Kg/0
0`00Kg]_N`03Kg/20004Kg/20002Kg/40002Kg/20006Kg/2000PKg/2000<Kg/20006Kg/2000;Kg/2
0004Kg/2000bKg/20004Kg/20002Kg/2000`Kg/003i_N`@002Y_N`@003I_N`@000A_N`@000A_N`@0
00e_N`@000a_N`<0009_N`@000Q_N`P000A_N`@001i_N`@002E_N`@003I_N`P002m_N`00?Vmk1000
:Vmk1000=Vmk100016mk100016mk10003Fmk100036mk00<006mkKg/00Vmk100026mk200016mk1000
7Vmk10009Fmk1000=Vmk2000;fmk000oKg/2000/Kg/2000hKg/20006Kg/20006Kg/2000?Kg/2000=
Kg/00`00Kg]_N`03Kg/2000:Kg/20002Kg/20006Kg/2000PKg/2000WKg/2000hKg/20002Kg/2000`
Kg/007m_N`8000M_N`8001]_N`8001]_N`80009_N`8000i_N`80021_N`8000i_N`8004e_N`8005M_
N`00OVmk10001Fmk10006Fmk10006Fmk200036mk10007Vmk100036mk1000Bfmk1000EVmk001nKg/4
0005Kg/4000IKg/4000IKg/8000<Kg/4000NKg/4000<Kg/4001;Kg/4001FKg/001Y_N`8002M_N`80
03Y_N`8000M_N`8001]_N`8001]_N`P000I_N`80009_N`@000e_N`80009_N`80009_N`8000U_N`80
00Q_N`8000A_N`8004e_N`8005M_N`006Fmk10009Fmk1000OFmk200016mk2@0036mk30004Fmk1000
Zfmk000IKg/4000UKg/4001mKg/80004Kg/9000<Kg/<000AKg/4002[Kg/001Y_N`8002M_N`8007m_
N`80009_N`8000I_N`80009_N`800003Kg/006mk00a_N`80009_N`80009_N`8001=_N`800:a_N`00
R6mk0P000Vmk0P005fmk0P002Vmk0P002fmk0P005fmk00@006mkKg]_N`80009_N`80009_N`80009_
N`8000I_N`8004E_N`80009_N`8001M_N`8001M_N`8001I_N`8002Y_N`00Qfmk20005Fmk100026mk
10002Fmk10005Vmk00<006mkKg/0400016mk1000@fmk20005Fmk10005Fmk100056mk1000:Fmk0027
Kg/8000EKg/40008Kg/40009Kg/4000FKg/00`00Kg]_N`0@0004Kg/40013Kg/8000EKg/4000EKg/4
000DKg/4000YKg/008Q_N`80009_N`8001M_N`8000Y_N`8000]_N`8001M_N`04001_NfmkKg/20002
Kg/20002Kg/20002Kg/20006Kg/20015Kg/20002Kg/2000GKg/2000GKg/2000FKg/2000ZKg/00:=_
N`8000i_N`8000I_N`8000M_N`8000Y_N`8000E_N`03001_Nfmk00m_N`8000m_N`80065_N`80055_
N`00XVmk100036mk100016mk10001Fmk100026mk100016mk00<006mkKg/03Vmk10003Fmk1000Gfmk
1000D6mk002RKg/4000<Kg/40004Kg/40005Kg/40008Kg/40004Kg/00`00Kg]_N`0>Kg/4000=Kg/4
001OKg/4001@Kg/006I_N`8000m_N`8000m_N`8000I_N`80009_N`8000e_N`8000i_N`8000I_N`80
0003Kg/0000000A_N`8000Y_N`8000A_N`8000M_N`80009_N`8000A_N`8000Q_N`8000E_N`8000A_
N`80009_N`8003A_N`80025_N`8001U_N`8003I_N`00IFmk10003Fmk10003Fmk100016mk20009Vmk
100056mk10001Fmk200036mk10002Fmk2000<Vmk1000>Vmk1000=Fmk001UKg/4000=Kg/4000=Kg/4
0004Kg/8000VKg/4000DKg/40005Kg/8000<Kg/40009Kg/8000bKg/4000jKg/4000eKg/006I_N`80
00m_N`8000m_N`8000I_N`80009_N`8002Q_N`8001I_N`8000M_N`80009_N`8000i_N`8000]_N`80
009_N`8003A_N`8003a_N`8003I_N`00Afmk0P00?Fmk0P00:fmk0P005fmk0P000Vmk0P001Fmk0`00
4fmk0P000Vmk0P001fmk0P007fmk0P00<6mk0P00HFmk0016Kg/4000kKg/4000YKg/4000EKg/80004
Kg/00`00Kg]_N`0BKg/80005Kg/4000MKg/4000^Kg/4001PKg/004I_N`@003]_N`@002U_N`@001E_
N`P000A_N`03001_Nfmk019_N`P000E_N`@001e_N`@002i_N`@0061_N`00=6mk10003Fmk1000?6mk
1P001Fmk0P002Vmk0P005Fmk0P0016mk0P000fmk0P001Vmk0P000Vmk2P000fmk00@006mkKg]_N`80
009_N`80009_N`80009_N`8000A_N`80009_N`@000E_N`80011_N`8000e_N`@000M_N`H001I_N`80
00U_N`8002a_N`@0035_N`00=Vmk00<006mkKg/02fmk1000?Fmk00<006mkKg/00Vmk00<006mkKg/0
0Vmk100026mk10006Fmk100000=_N`0000000P0016mk40000Vmk00<006mkKg/0400026mk10005Fmk
10003Fmk10001Vmk00<006mkKg/00Vmk00<006mkKg/04fmk1000>6mk00<006mkKg/0<6mk000fKg/0
0`00Kg]_N`0;Kg/4000nKg/00`00Kg]_N`06Kg/40008Kg/4000IKg/400000fmk000000020004Kg/@
0002Kg/00`00Kg]_N`0@0008Kg/4000EKg/4000=Kg/40007Kg/00`00Kg]_N`0GKg/4000hKg/00`00
Kg]_N`0`Kg/0039_N`H000e_N`80041_N`03001_Nfmk00I_N`8000Y_N`8001]_N`8000=_N`8000I_
N`80009_N`80009_N`80009_N`8000=_N`04001_NfmkKg/20002Kg/20002Kg/20002Kg/2000:Kg/2
000GKg/2000?Kg/20009Kg/00`00Kg]_N`0GKg/2000eKg/6000aKg/002U_N`H000A_N`04001_Nfmk
000]Kg/2000FKg/60006Kg/00`00Kg]_N`0;Kg/2000?Kg/2000>Kg/2000;Kg/20002Kg/20002Kg/2
0002Kg/20005Kg/30007Kg/20002Kg/20002Kg/20006Kg/2000;Kg/2000KKg/2000<Kg/01000Kg/0
0000?Fmk0P003Vmk00@006mkKg/002I_N`8000Y_N`00<fmk00@006mkKg/002a_N`@0029_N`03001_
Nfmk00U_N`@000e_N`@000a_N`@000U_Na0000A_N`@000E_N``000A_N`@000U_N`@001U_N`@000a_
N`@003]_N`@000e_N`04001_Nfmk000UKg/40009Kg/003A_N`03001_N`0002a_N`@001i_N`03001_
Nfmk009_N`03001_Nfmk00Q_N`@000e_N`@000a_N`@000U_Na0000A_N`@000E_N``000A_N`@000U_
N`@001U_N`@000Q_N`04001_NfmkKg/4000kKg/4000>Kg/00`00Kg/0000UKg/40009Kg/003A_N`03
001_N`0002e_N`8001m_N`03001_Nfmk009_N`04001_N`000002Kg/20002Kg/6000=Kg/20008Kg/2
0002Kg/40005Kg/20002Kg/40002Kg/<0002Kg/400000fmk00000004Kg/20002Kg/80004Kg/2000;
Kg/2000KKg/20009Kg/00`00Kg]_N`02Kg/2000mKg/2000?Kg/00`00Kg/0000VKg/2000:Kg/003E_
N`8004m_N`@00003Kg/0000000h001E_N`P000E_N`P000A_Na000003Kg/00000008000Q_N`P003U_
N`@0055_N`80039_N`00Rfmk40005Fmk20001Fmk200016mk400000=_N`0000000P0026mk2000`Vmk
002<Kg/20002Kg/20002Kg/20002Kg/2000GKg/20002Kg/20007Kg/20002Kg/20006Kg/20002Kg/2
0002Kg/20002Kg/20003Kg/2000:Kg/20002Kg/20033Kg/005Q_N`80031_N`8000Y_N`8000m_N`80
01M_N`80009_N`8000Y_N`80009_N`800003Kg/006mk00A_N`8000i_N`8000m_N`80009_N`8000i_
N`8000m_N`8001m_N`8001]_N`80031_N`8001]_N`00Efmk1000;Vmk100026mk10003Fmk10005Fmk
200026mk2@0016mk100036mk10003Fmk200036mk10003Fmk10007Fmk10006Fmk1000;Vmk10006Vmk
001GKg/4000^Kg/40008Kg/4000=Kg/4000EKg/80008Kg/90004Kg/4000<Kg/4000=Kg/8000<Kg/4
000=Kg/4000MKg/4000IKg/4000^Kg/4000JKg/005Q_N`80031_N`8000Y_N`8000m_N`8001M_N`80
009_N`8000Y_N`80009_N`800003Kg/006mk00A_N`8000i_N`8000m_N`80009_N`8000i_N`8000m_
N`8001m_N`8001]_N`80031_N`8001]_N`0096mk0P007fmk0P000Vmk0P003fmk0P00=6mk0P007fmk
0P000Vmk0P001fmk0P001Vmk0P000Vmk0P000Vmk0P000Vmk0P000Vmk0P003fmk0P001Vmk0P007fmk
0P0096mk0P009fmk0P007fmk0P00;Vmk000SKg/4000MKg/8000=Kg/4000bKg/4000MKg/80005Kg/4
0004Kg/D000=Kg/40004Kg/4000MKg/4000RKg/4000UKg/4000MKg/4000]Kg/002=_N`@001e_N`P0
00e_N`@0039_N`@001e_N`P000E_N`@000A_Na@000e_N`@000A_N`@001e_N`@0029_N`@002E_N`@0
01e_N`@002e_N`00o`00/0000Fmk0008Kg/4000@Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/01000
Kg]_Nfmk10003Fmk00<006mkKg/01Fmk100026mk00<006mkKg/04Vmk00<006mkKg/00Vmk100036mk
00<006mkKg/01Vmk100016mk1@000fmk100016mk100000=_N`0000000P0026mk100016mk200000=_
N`0000000P0016mk40001Fmk10000fmk00<006mkKg/04Vmk1@0046mk00<006mkKg/02Vmk100016mk
00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk
00<006mkKg/01fmk0008Kg/4000UKg/00`00Kg]_N`0FKg/4000EKg/4000MKg/00`00Kg]_N`02Kg/4
000EKg/40004Kg/40004Kg/40004Kg/400000fmk000000020008Kg/40004Kg/800000fmk00000002
0004Kg/@0005Kg/4000IKg/4000@Kg/00`00Kg]_N`0:Kg/40012Kg/00`00Kg]_N`0`Kg/000U_N`80
041_N`8001M_N`8002A_N`8001M_N`8000I_N`8000I_N`8000I_N`8000=_N`8000Y_N`8000I_N`80
0004Kg/000000003Kg/20006Kg/20002Kg/20002Kg/20002Kg/20007Kg/2000KKg/2000OKg/2001f
Kg/001A_N`80041_N`80009_N`8000m_N`8000i_N`8002Q_N`8000I_N`80009_N`80009_N`8000M_
N`80009_N`80009_N`80009_N`80009_N`80009_N`80009_N`8000=_N`80009_N`8000I_N`8000Y_
N`8000m_N`8000m_N`8003=_N`8001M_N`8004]_N`004fmk1000?Vmk20003Fmk100036mk10009Vmk
100016mk30001Fmk700000=_N`0000001P0016mk100026mk10003Fmk10003Fmk1000<Fmk10005Fmk
1000BVmk000CKg/4000nKg/8000=Kg/4000<Kg/4000VKg/40004Kg/<0005Kg/L00000fmk00000006
0004Kg/40008Kg/4000=Kg/4000=Kg/4000aKg/4000EKg/4001:Kg/001A_N`80025_N`8001e_N`80
009_N`8000m_N`8000i_N`8000e_N`8001U_N`8000I_N``000E_N`80009_N`80009_N`80009_N`H0
009_N`H000=_N`80009_N`8000A_N`@000Q_N`H000e_N`8000Q_N`8000E_N`@000Y_N`8001=_N`80
011_N`8001M_N`8004]_N`00=Vmk1000Cfmk10008Fmk30004Fmk100016mk1@0036mk100026mk2000
5Fmk10001Fmk100026mk10004Fmk1000MFmk000fKg/4001?Kg/4000QKg/<000AKg/40004Kg/5000<
Kg/40008Kg/8000EKg/40005Kg/40008Kg/4000AKg/4001eKg/003M_N`80055_N`8002=_N`80009_
N`80009_N`8001=_N`8000I_N`800003Kg/006mk00a_N`8000Y_N`80009_N`8001M_N`8000M_N`80
00Y_N`8001=_N`8007I_N`0056mk0P004Vmk0P000Vmk0P00>6mk0P003fmk0P002Vmk0P001fmk0P00
7fmk0P000Vmk0P001Vmk0P001fmk0P000Vmk0P000Vmk0P002fmk00@006mkKg]_N`8000I_N`8000i_
N`8000M_N`8000Y_N`8003Q_N`8001M_N`8005=_N`004fmk100046mk2000=Vmk10003Fmk100026mk
10001Fmk10007Fmk200016mk10001Fmk30002Vmk00<006mkKg/0100016mk100036mk10001Fmk1000
26mk1000=Vmk10005Fmk1000DVmk000CKg/4000@Kg/8000fKg/4000=Kg/40008Kg/40005Kg/4000M
Kg/80004Kg/40005Kg/<000:Kg/00`00Kg]_N`040004Kg/4000<Kg/40005Kg/40008Kg/4000fKg/4
000EKg/4001BKg/001A_N`80019_N`80009_N`8003Q_N`8000m_N`8000Y_N`8000M_N`8001m_N`80
009_N`8000I_N`8000M_N`80009_N`80009_N`8000]_N`04001_NfmkKg/20006Kg/2000>Kg/20007
Kg/2000:Kg/2000hKg/2000GKg/2001CKg/005A_N`8001M_N`8002=_N`80031_N`80009_N`80009_
N`8000U_N`03001_Nfmk00M_N`80009_N`8000I_N`80009_N`80009_N`8000=_N`8001]_N`80009_
N`8002=_N`8006i_N`00Dfmk10005Fmk10008Fmk1000;Vmk300026mk00<006mkKg/01Vmk200016mk
300000=_N`0000000P006Fmk20008Fmk1000KFmk001CKg/4000EKg/4000QKg/4000^Kg/<0008Kg/0
0`00Kg]_N`06Kg/80004Kg/<00000fmk00000002000IKg/8000QKg/4001]Kg/005A_N`8001M_N`80
02=_N`@000m_N`80009_N`80009_N`8001=_N`P0009_N`@0009_N`8000=_N`04001_NfmkKg/20004
Kg/60006Kg/60002Kg/20003Kg/4000IKg/20002Kg/4000KKg/20002Kg/40012Kg/2000ZKg/009=_
N`@000e_N``0015_N`P000A_N`P0009_N`03001_Nfmk00@000A_N`@000Q_N`@000U_N`@001e_N`@0
01U_N`P0049_N`@002U_N`00Tfmk10003Fmk30004Fmk200016mk20000Vmk1`0016mk100026mk1000
2Fmk10007Fmk10006Fmk2000@Vmk1000:Fmk002DKg/2000?Kg/20002Kg/20002Kg/2000CKg/20002
Kg/20006Kg/20002Kg/20003Kg/01000Kg]_Nfmk0P001Vmk0P002Vmk0P002fmk0P007fmk0P006fmk
0P000Vmk0P00A6mk0P00:Vmk001mKg/2000?Kg/2000CKg/2000OKg/20002Kg/2000:Kg/2000016mk
000000000fmk0P002Vmk0P004fmk0P007fmk0P003fmk0P00OVmk001lKg/4000=Kg/4000AKg/4000M
Kg/80008Kg/800000fmk000000020008Kg/4000AKg/4000MKg/4000=Kg/4001mKg/007a_N`@000e_
N`@0015_N`@001e_N`P000Q_N`P00003Kg/00000008000Q_N`@0015_N`@001e_N`@000e_N`@007e_
N`0076mk0P00?6mk0P008Fmk0P003fmk0P0016mk0P003Fmk0P007Fmk2P0026mk0P0000A_N`000000
00=_N`@0009_N`80009_N`@000e_N`80009_N`@000A_N`8001U_N`8000m_N`8007i_N`006fmk1000
>Vmk1000=Vmk1000:Vmk30002Vmk00<006mkKg/016mk30003Fmk200016mk1000ZFmk000KKg/4000j
Kg/4000fKg/4000ZKg/<000:Kg/00`00Kg]_N`04Kg/<000=Kg/80004Kg/4002YKg/001a_N`8003a_
N`8003Q_N`8002a_N`80009_N`80009_N`8000]_N`03001_Nfmk00E_N`80009_N`80009_N`8000m_
N`80009_N`8000I_N`800:Y_N`00:Vmk0P00KVmk0P004fmk0P000Vmk0P004fmk0P000Vmk0P000Vmk
0P001Fmk0`002fmk0P002Vmk0P000Vmk0P002fmk0P003Vmk0P0076mk0P00B6mk0P000Vmk0P000Vmk
0P00;6mk000YKg/4001/Kg/4000AKg/8000AKg/<0004Kg/40009Kg/40008Kg/80009Kg/4000<Kg/4
000JKg/40016Kg/<000[Kg/002U_N`@006a_N`@0015_N`P0015_N``000A_N`@000U_N`@000Q_N`P0
00U_N`@000a_N`@001Y_N`@004I_N``002]_N`00:Vmk0P00KVmk0P004fmk0P000Vmk0P004fmk0P00
0Vmk0P000Vmk0P001Fmk0`002fmk0P002Vmk0P000Vmk0P002fmk0P003Vmk0P0076mk0P00B6mk0P00
0Vmk0P000Vmk0P00;6mk000PKg/2001EKg/20002Kg/2000?Kg/2000KKg/2000CKg/2000:Kg/2000;
Kg/00`00Kg]_N`0RKg/2000>Kg/20007Kg/2002IKg/001m_N`@005=_N`P000e_N`@001U_N`@0015_
N`@000Q_N`@000Y_N`03001_Nfmk025_N`@000a_N`@000E_N`@009Q_N`007fmk1000Dfmk20003Fmk
10006Fmk10004Fmk100026mk10002Vmk00<006mkKg/08Fmk100036mk10001Fmk1000V6mk000NKg/6
001CKg/20002Kg/2000?Kg/2000EKg/20004Kg/2000CKg/2000:Kg/2000;Kg/3000GKg/20002Kg/2
0005Kg/4000<Kg/20004Kg/200000fmk00000004Kg/2000:Kg/20027Kg/001e_N`P007e_N`@0035_
N`@001E_N`P000E_N`@0011_N`@000E_N`@000Q_N`@008I_N`007Fmk2000OFmk1000<Fmk10005Fmk
20001Fmk100046mk10001Fmk100026mk1000QVmk000NKg/20002Kg/2001oKg/2000bKg/3000GKg/2
0002Kg/20007Kg/2000BKg/20007Kg/2000:Kg/20027Kg/003e_N`8006I_N`8002=_N`8000]_N`03
001_Nfmk015_N`8002=_N`80021_N`8007a_N`00?6mk1000I6mk10008Fmk10002Vmk0`0046mk1000
8Fmk10007Vmk1000Nfmk000lKg/4001TKg/4000QKg/4000:Kg/00`00Kg]_N`0@Kg/4000QKg/4000N
Kg/4001kKg/001i_N`8001e_N`8006I_N`8001U_N`8000Q_N`8000Q_N`800003Kg/006mk00Q_N`80
009_N`8000A_N`8001E_N`8000a_N`80021_N`@007Y_N`007Fmk1000WVmk100046mk1@0026mk2000
6Fmk1000;Vmk1000NFmk000MKg/4002NKg/4000@Kg/50008Kg/8000IKg/4000^Kg/4001iKg/001i_
N`800:1_N`80019_N`800003Kg/006mk00Q_N`80009_N`8001]_N`80031_N`8007Y_N`00HVmk0P00
0Vmk0P00<6mk0P002fmk0P009fmk0P001Vmk0P000fmk0P002Vmk0P00afmk001QKg/8000^Kg/40009
Kg/4000UKg/40004Kg/400000fmk000000020008Kg/40036Kg/0065_N`P002i_N`@000U_N`@002E_
N`@000A_N`@00003Kg/00000008000Q_N`@00<I_N`00HVmk0P000Vmk0P00<6mk0P002fmk0P009fmk
0P001Vmk0P000fmk0P002Vmk0P00afmk0013Kg/2000XKg/2000>Kg/20015Kg/2000AKg/3000;Kg/2
000:Kg/20002Kg/2000`Kg/20002Kg/20023Kg/0049_N`@002I_N`@000a_N`@004=_N`@0011_N`@0
00U_N`@000Q_N`P002i_N`P0089_N`00@Vmk10009Vmk100036mk1000@fmk100046mk10002Fmk1000
26mk2000;Vmk2000PVmk0013Kg/2000XKg/20008Kg/20004Kg/2000EKg/20002Kg/2000;Kg/2000K
Kg/40008Kg/20007Kg/3000;Kg/2000:Kg/20002Kg/2000`Kg/20002Kg/40021Kg/007I_N`@001U_
N`P000U_N`@001U_N`@000Q_N`@000I_N`03001_Nfmk059_N`@0081_N`00MVmk10006Fmk20002Fmk
10006Fmk100026mk10001Vmk00<006mkKg/0DVmk1000P6mk001gKg/2000KKg/20002Kg/2000;Kg/2
000KKg/2000:Kg/20007Kg/00`00Kg]_N`1CKg/20021Kg/009I_N`8001]_N`8000m_N`80015_N`03
001_Nfmk02a_N`8000m_N`8000Y_N`8008]_N`00UFmk10006Fmk10003Fmk100046mk00<006mkKg/0
:fmk10003Fmk100026mk1000RVmk002EKg/4000IKg/4000=Kg/4000@Kg/00`00Kg]_N`0[Kg/4000=
Kg/40008Kg/4002:Kg/001Q_N`8002]_N`8002a_N`80025_N`8001]_N`8000m_N`80015_N`03001_
Nfmk02a_N`8000m_N`8000A_N`8000A_N`8008]_N`005fmk1000:Fmk1000:Vmk1000HFmk0`00@Vmk
1000T6mk000GKg/4000YKg/4000ZKg/4001QKg/00`00Kg]_N`12Kg/4002@Kg/001Q_N`8002]_N`80
02a_N`80069_N`03001_Nfmk04=_N`80095_N`00D6mk0P00?6mk0P007fmk0P001Vmk0P007Vmk00<0
06mkKg/05fmk0P00>6mk0P00Pfmk001?Kg/4000jKg/4000MKg/40004Kg/4000MKg/00`00Kg]_N`0F
Kg/4000fKg/40022Kg/004m_N`@003Y_N`@001e_N`@000A_N`@001e_N`03001_Nfmk01I_N`@003I_
N`@0089_N`00D6mk0P00?6mk0P007fmk0P0016mk10001Fmk0P005fmk00<006mkKg/05fmk10004fmk
0P000Vmk0P007Fmk0P008Vmk0P00Gfmk002dKg/40005Kg/4000FKg/00`00Kg]_N`0HKg/4000AKg/8
000oKg/4001NKg/00;A_N`@000E_N`@001I_N`03001_Nfmk01Q_N`@0015_N`P003m_N`@005i_N`00
]Fmk0P001fmk0P005fmk00<006mkKg/06Fmk0P004fmk0P000Vmk0P00@Fmk0P00Gfmk002:Kg/20006
Kg/2000GKg/20002Kg/20002Kg/2000GKg/20002Kg/20005Kg/3000KKg/2002PKg/2000GKg/008U_
N`@000A_N`@001E_N``001E_N`P000A_N`@001U_N`@009i_N`@001I_N`00RFmk100016mk10005Fmk
30005Fmk200016mk10006Fmk1000WVmk10005Vmk002:Kg/20006Kg/2000GKg/20002Kg/20002Kg/2
000GKg/20002Kg/20005Kg/3000KKg/2002PKg/2000GKg/0069_N`8002a_N`8004A_N`8000M_N`80
03A_N`8004Q_N`8001M_N`8003I_N`00HFmk1000:Vmk1000@Vmk10001Fmk1000<Vmk1000AVmk1000
5Fmk1000=Fmk001QKg/4000ZKg/40012Kg/40005Kg/4000bKg/40016Kg/4000EKg/4000eKg/0069_
N`8001e_N`8000]_N`@003I_N`P000I_N`8000M_N`80025_N`80015_N`8004Q_N`8001M_N`8003I_
N`00P6mk10002Fmk1000=Vmk100016mk00<006mkKg/01Fmk00<006mkKg/09fmk1000Zfmk0020Kg/4
0009Kg/4000fKg/5000;Kg/00`00Kg]_N`0WKg/4002[Kg/0085_N`8000]_N`8003Q_N`80009_N`03
001_Nfmk00Q_N`03001_Nfmk02Q_N`800:a_N`00Lfmk0P007fmk0P00=fmk00<006mkKg/01fmk1000
16mk0P00=6mk0P006fmk0P000Vmk0P00N6mk001bKg/4000MKg/4000gKg/00`00Kg]_N`06Kg/00`00
Kg]_N`04Kg/4000bKg/4000IKg/8001gKg/0079_N`@001e_N`@003=_N`03001_Nfmk009_N`03001_
Nfmk00E_N`03001_Nfmk00A_N`@0039_N`@001U_N`P007M_N`00>fmk0P00=Vmk0P007fmk0P00;Vmk
0P0016mk00H006mk000006mk0007Kg/30005Kg/20004Kg/2000CKg/2000:Kg/2000=Kg/2000KKg/2
0002Kg/2001hKg/003Y_N`@008E_N`@000A_N`@000Q_N`@000U_N`@0015_N`@000Q_N`@00:M_N`00
>Vmk1000QFmk100016mk100026mk10002Fmk10004Fmk100026mk1000Yfmk000kKg/20027Kg/20006
Kg/20009Kg/3000;Kg/2000CKg/2000:Kg/2002XKg/0021_N`8004A_N`8002A_N`8001m_N`8000Y_
N`8000m_N`8000]_N`03001_Nfmk015_N`80009_N`8000M_N`8003=_N`8001M_N`8006Q_N`007fmk
1000@Vmk10008Vmk10007Fmk100026mk10003Fmk10002Vmk00<006mkKg/046mk20001Fmk1000<Fmk
10005Fmk1000Ifmk000OKg/40012Kg/4000RKg/4000MKg/40008Kg/4000=Kg/4000:Kg/00`00Kg]_
N`0@Kg/80005Kg/4000aKg/4000EKg/4001WKg/0021_N`8004A_N`8002A_N`8001m_N`8000Y_N`80
00m_N`8000]_N`03001_Nfmk015_N`80009_N`8000M_N`8003=_N`8001M_N`8006Q_N`00<fmk0P00
B6mk0P00AFmk0P002Vmk0P001Fmk00<006mkKg/01fmk0P00:fmk0P00<6mk0P00KVmk000bKg/40016
Kg/40013Kg/40008Kg/40004Kg/00`00Kg]_N`06Kg/4000YKg/4000^Kg/4001]Kg/0039_N`@004I_
N`@004=_N`@000Q_N`@000A_N`03001_Nfmk00I_N`@002U_N`@002i_N`@006e_N`00<fmk0P0016mk
0P00@Vmk0P008Fmk0P002fmk0P005Fmk0P0026mk10001Fmk00<006mkKg/01fmk0P00:fmk0P00<6mk
0P00:Vmk0P00@Vmk000hKg/4001SKg/40009Kg/4000MKg/40006Kg/00`00Kg]_N`2AKg/40011Kg/0
03Q_N`@006=_N`@000U_N`@001e_N`@000I_N`03001_Nfmk095_N`@0045_N`00>Fmk0P00IFmk0P00
2fmk0P007fmk0P001fmk00<006mkKg/0TVmk0P00@Vmk001@Kg/2000>Kg/20015Kg/20006Kg/2000V
Kg/00`00Kg]_N`0PKg/2001UKg/2000KKg/2000`Kg/004m_N`@000a_N`@004=_N`@000A_N`@002E_
N`03001_Nfmk01m_N`@006=_N`@001U_N`@002m_N`00Cfmk100036mk1000@fmk100016mk10009Fmk
0`007fmk1000Hfmk10006Fmk1000;fmk0011Kg/2000=Kg/2000>Kg/2000ZKg/2000BKg/20005Kg/2
0006Kg/2000VKg/00`00Kg]_N`0PKg/2001UKg/2000=Kg/2000<Kg/2000`Kg/0041_N`@004M_N`@0
011_N`@003A_N`03001_Nfmk09E_N`@003e_N`00@6mk1000Afmk100046mk1000=6mk00<006mkKg/0
UFmk1000?Fmk0011Kg/20019Kg/2000BKg/2000eKg/00`00Kg]_N`2FKg/2000nKg/006A_N`8000m_
N`80061_N`03001_Nfmk05I_N`8007i_N`00Hfmk10003Fmk1000Gfmk00<006mkKg/0EFmk1000OFmk
001SKg/4000=Kg/4001OKg/00`00Kg]_N`1EKg/4001mKg/006A_N`8000m_N`80061_N`03001_Nfmk
05I_N`8007i_N`00Jfmk0P005Vmk0P002fmk0P009fmk0P004fmk0P001fmk00<006mkKg/09Vmk0P00
7fmk0P00SFmk001ZKg/4000DKg/40009Kg/4000UKg/4000AKg/40006Kg/00`00Kg]_N`0UKg/4000M
Kg/4002<Kg/006Y_N`@001A_N`@000U_N`@002E_N`@0015_N`@000I_N`03001_Nfmk02E_N`@001e_
N`@008a_N`00E6mk0P001Vmk0P003Fmk0P005Vmk0P002fmk0P009fmk10004Fmk10001Fmk00<006mk
Kg/00fmk0P006fmk0P0016mk0P007fmk0P006Fmk0P00LVmk001CKg/40004Kg/4001KKg/4000AKg/4
0004Kg/00`00Kg]_N`02Kg/4000IKg/4000nKg/4001aKg/005=_N`@000A_N`@005]_N`@0015_N`@0
00A_N`03001_Nfmk009_N`@001U_N`@003i_N`@0075_N`00E6mk0P001Vmk0P00GFmk0P004fmk0P00
1Fmk00<006mkKg/00fmk0P006fmk0P00@6mk0P00LVmk001NKg/20002Kg/2000/Kg/2000CKg/2000`
Kg/00`00Kg]_N`1TKg/2001`Kg/005e_N`P002Y_N`@0015_N`@002m_N`03001_Nfmk06=_N`@006m_
N`00GFmk2000:Vmk10004Fmk1000;fmk00<006mkKg/0Hfmk1000Kfmk001NKg/20002Kg/2000/Kg/2
000CKg/2000QKg/2000=Kg/00`00Kg]_N`1TKg/2000UKg/20019Kg/00<M_N`@000a_N`03001_Nfmk
08Y_N`@004Q_N`00afmk100036mk0`00RVmk1000B6mk0038Kg/2000=Kg/00`00Kg]_N`2;Kg/20019
Kg/00:U_N`8000I_N`8000m_N`80019_N`800=Q_N`00Z6mk100016mk10003Fmk100046mk1000efmk
002XKg/40004Kg/4000=Kg/4000@Kg/4003GKg/005Q_N`8004m_N`8000A_N`@000m_N`80019_N`80
0=Q_N`00Efmk1000Dfmk10009Fmk00<006mkKg/0eVmk001GKg/4001CKg/4000UKg/00`00Kg]_N`3F
Kg/005Q_N`8005E_N`8002I_N`03001_Nfmk0=I_N`00R6mk0P00?6mk0P000Vmk0P002fmk00<006mk
Kg/0I6mk0P00L6mk0027Kg/4000jKg/8000:Kg/00`00Kg]_N`1SKg/4001_Kg/008M_N`@003Y_N`P0
00Y_N`03001_Nfmk06=_N`@006m_N`00R6mk0P00?6mk0P000Vmk0P002fmk00<006mkKg/0I6mk0P00
L6mk001iKg/2001LKg/00`00Kg]_N`3FKg/007Q_N`@005]_N`03001_Nfmk0=I_N`00N6mk1000Ffmk
00<006mkKg/0eVmk001FKg/2000QKg/2001LKg/00`00Kg]_N`1/Kg/2001XKg/005E_N`@007i_N`03
001_Nfmk06]_N`@006M_N`00EFmk1000OVmk00<006mkKg/0Jfmk1000Ifmk001FKg/2001oKg/00`00
Kg]_N`1/Kg/2001XKg/0061_N`80045_N`80009_N`8002M_N`8000E_N`03001_Nfmk02Q_N`8001]_
N`8002a_N`80065_N`00Gfmk1000?fmk20009Fmk100016mk0`009fmk10006Fmk1000:Vmk1000H6mk
001OKg/4000oKg/8000UKg/40004Kg/00`00Kg]_N`0WKg/4000IKg/4000ZKg/4001PKg/0061_N`80
045_N`80009_N`8002M_N`8000E_N`03001_Nfmk00e_N`8001U_N`8001]_N`8002a_N`80065_N`00
efmk00<006mkKg/036mk1000aVmk003GKg/00`00Kg]_N`0<Kg/40036Kg/00=M_N`03001_Nfmk00e_
N`800<M_N`00D6mk0P003Vmk0P00BFmk0P003Vmk0P006Vmk00<006mkKg/0eVmk001?Kg/4000<Kg/4
0017Kg/4000<Kg/4000IKg/00`00Kg]_N`3FKg/004m_N`@000a_N`@004M_N`@000a_N`@001U_N`03
001_Nfmk0=I_N`00D6mk0P003Vmk0P00BFmk0P003Vmk0P006Vmk00<006mkKg/0eVmk001kKg/2001J
Kg/00`00Kg]_N`09Kg/2000:Kg/20011Kg/2001lKg/007Y_N`@005U_N`03001_Nfmk00Q_N`@000Q_
N`@003m_N`@007]_N`00NVmk1000FFmk00<006mkKg/026mk100026mk1000?fmk1000Nfmk001kKg/2
0009Kg/20010Kg/2000=Kg/00`00Kg]_N`09Kg/2000:Kg/2000EKg/2000ZKg/2000MKg/2001MKg/0
08E_N`@003i_N`@000a_N`03001_Nfmk02]_N`@004M_N`@005a_N`00QFmk1000?Vmk100036mk00<0
06mkKg/0:fmk1000Afmk1000G6mk0026Kg/20010Kg/2000=Kg/00`00Kg]_N`0/Kg/20019Kg/2001M
Kg/00<a_N`@000M_N`03001_Nfmk0=I_N`00cVmk00<006mkKg/01Vmk00<006mkKg/0eVmk003>Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`3FKg/0085_N`8004M_N`H000M_N`03001_Nfmk045_N`8009=_N`00
P6mk1000Afmk00@006mkKg/000Q_N`@003m_N`@0099_N`00P6mk1000Afmk00@006mkKg/000Q_N`03
001_Nfmk041_N`@0099_N`00PFmk0P00BFmk00<006mk000026mk00<006mkKg/0@Fmk0P00Tfmk0032
Kg/20008Kg/00`00Kg/00008Kg/00`00Kg]_N`3FKg/00<5_N`@000Q_N`8000Q_N`03001_Nfmk0=I_
N`00`Fmk10004Vmk00<006mkKg/0eVmk0032Kg/2000CKg/00`00Kg]_N`3FKg/006U_N`8006a_N`03
001_Nfmk0=I_N`00J6mk1000Jfmk00<006mkKg/0eVmk001XKg/4001[Kg/00`00Kg]_N`3FKg/006U_
N`8006a_N`03001_Nfmk01E_N`800;m_N`00efmk00<006mkKg/056mk1000_Vmk003GKg/00`00Kg]_
N`0DKg/4002nKg/00=M_N`03001_Nfmk01E_N`800;m_N`00efmk00<006mkKg/0eVmk003GKg/00`00
Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/05Fmk0P00;6mk0P00TFmk003GKg/0
0`00Kg]_N`0DKg/4000ZKg/4002@Kg/00=M_N`03001_Nfmk01A_N`@002Y_N`@0091_N`00efmk0`00
5Fmk0P00;6mk0P00TFmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk01U_N`800;]_N`00efmk00<006mkKg/0
66mk1000^Vmk003GKg/00`00Kg]_N`0HKg/4002jKg/009i_N`8003M_N`03001_Nfmk00M_N`80011_
N`800;]_N`00WFmk1000=Vmk00<006mkKg/01Vmk1000c6mk002MKg/4000fKg/00`00Kg]_N`06Kg/4
003<Kg/009i_N`8003M_N`03001_Nfmk00M_N`800<e_N`00efmk00<006mkKg/02Fmk0P00bfmk003G
Kg/00`00Kg]_N`08Kg/4003:Kg/00=M_N`03001_Nfmk00Q_N`@00<Y_N`00efmk00<006mkKg/01fmk
100046mk0P00^Fmk003GKg/00`00Kg]_N`06Kg/4000@Kg/4002hKg/00=M_N`03001_Nfmk00I_N`@0
011_N`@00;Q_N`00efmk00<006mkKg/01fmk0P004Vmk0P00^Fmk003>Kg/20007Kg/00`00Kg]_N`3F
Kg/00<e_N`@000I_N`03001_Nfmk0=I_N`00cFmk10001Vmk0`00eVmk003>Kg/20007Kg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk0000\
\>"],
  ImageRangeCache->{{{0, 431}, {429.75, 0}} -> {-5.19828, -5.13732, \
0.0361829, 0.0361829}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["The above graphic", "NumberedFigure"],
  " certainly shows more points toward the center, doesn't it. From now on, \
the number of meshpoints in the list ",
  StyleBox["p",
    FontFamily->"Courier"],
  " is determined. No points will be drop out, but relocated while minimizing \
the \"force\". "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Delaunay Triangulation", "Section"],

Cell[TextData[{
  "Now we have a fixed number of meshpoints selected. Delaunay triangulation \
can begin (part of ",
  StyleBox["step 3",
    FontSlant->"Italic"],
  " in the paper)"
}], "Text"],

Cell[BoxData[
    \(\(t = DelaunayTriangulation[p];\)\)], "Input",
  CellLabel->"In[22]:="],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function returns mesh triangles in a different format from MATLAB \
function's. It even has a function to plot the meshes directly. We can define \
such a function ourselves (",
  StyleBox["step 5",
    FontSlant->"Italic"],
  " in the paper)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      the\ Mathematica\ built - 
        in\ function\ *) \)\(\[IndentingNewLine]\)\(PlanarGraphPlot[p, 
      LabelPoints \[Rule] False]\)\)\)], "Input",
  CellLabel->"In[23]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0959596 0.495596 0.0959596 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.012 w
.47121 .02631 Mdot
.46162 .04293 Mdot
.52879 .04293 Mdot
.56237 .05124 Mdot
.45202 .05955 Mdot
.52399 .06786 Mdot
.47121 .07617 Mdot
.28409 .08448 Mdot
.31288 .08448 Mdot
.37045 .08448 Mdot
.63914 .08448 Mdot
.72551 .08448 Mdot
.5 .09279 Mdot
.42803 .1011 Mdot
.58157 .1011 Mdot
.35606 .10941 Mdot
.5 .10941 Mdot
.59596 .10941 Mdot
.66313 .10941 Mdot
.27449 .11772 Mdot
.31288 .11772 Mdot
.55278 .11772 Mdot
.61995 .11772 Mdot
.77348 .11772 Mdot
.79747 .12603 Mdot
.48561 .15097 Mdot
.4952 .15097 Mdot
.5048 .15097 Mdot
.58157 .15097 Mdot
.25051 .15928 Mdot
.5096 .15928 Mdot
.60556 .15928 Mdot
.44722 .16759 Mdot
.45682 .16759 Mdot
.80707 .1759 Mdot
.36086 .18421 Mdot
.39924 .18421 Mdot
.42803 .18421 Mdot
.44722 .18421 Mdot
.45682 .18421 Mdot
.48561 .18421 Mdot
.4952 .18421 Mdot
.64874 .18421 Mdot
.23131 .19252 Mdot
.27929 .19252 Mdot
.30808 .19252 Mdot
.61515 .19252 Mdot
.42803 .20083 Mdot
.44722 .20083 Mdot
.46641 .20083 Mdot
.51439 .20083 Mdot
.25051 .20914 Mdot
.30808 .20914 Mdot
.70152 .20914 Mdot
.29369 .21745 Mdot
.57197 .21745 Mdot
.61035 .21745 Mdot
.70631 .21745 Mdot
.81187 .21745 Mdot
.39444 .22576 Mdot
.40404 .22576 Mdot
.4904 .22576 Mdot
.67273 .22576 Mdot
.7399 .22576 Mdot
.79747 .22576 Mdot
.5048 .23407 Mdot
.63914 .23407 Mdot
.65833 .23407 Mdot
.7351 .23407 Mdot
.18333 .24238 Mdot
.36566 .24238 Mdot
.39444 .24238 Mdot
.44242 .24238 Mdot
.54798 .24238 Mdot
.12096 .25069 Mdot
.17854 .25069 Mdot
.69672 .25069 Mdot
.72551 .25069 Mdot
.82146 .25069 Mdot
.30808 .259 Mdot
.35606 .259 Mdot
.56717 .259 Mdot
.69192 .259 Mdot
.91263 .259 Mdot
.09217 .26731 Mdot
.43763 .26731 Mdot
.56237 .26731 Mdot
.58157 .26731 Mdot
.79268 .26731 Mdot
.29848 .27562 Mdot
.38485 .27562 Mdot
.48081 .27562 Mdot
.42803 .28393 Mdot
.64874 .28393 Mdot
.36566 .29224 Mdot
.39444 .29224 Mdot
.52879 .29224 Mdot
.53838 .29224 Mdot
.54798 .29224 Mdot
.7303 .29224 Mdot
.21692 .30055 Mdot
.23611 .30055 Mdot
.28409 .30055 Mdot
.35126 .30055 Mdot
.60076 .30055 Mdot
.05859 .30886 Mdot
.16414 .30886 Mdot
.37525 .30886 Mdot
.56717 .30886 Mdot
.7399 .30886 Mdot
.40884 .31717 Mdot
.55278 .31717 Mdot
.21212 .32548 Mdot
.31768 .32548 Mdot
.34646 .32548 Mdot
.38485 .32548 Mdot
.39444 .32548 Mdot
.43283 .32548 Mdot
.51919 .32548 Mdot
.54798 .32548 Mdot
.82626 .32548 Mdot
.84545 .32548 Mdot
.07298 .33379 Mdot
.13056 .33379 Mdot
.20732 .33379 Mdot
.36086 .33379 Mdot
.41843 .33379 Mdot
.42803 .33379 Mdot
.45682 .33379 Mdot
.47601 .33379 Mdot
.5048 .33379 Mdot
.77348 .33379 Mdot
.88864 .33379 Mdot
.15455 .3421 Mdot
.22172 .3421 Mdot
.25051 .3421 Mdot
.2697 .3421 Mdot
.29848 .3421 Mdot
.37525 .3421 Mdot
.53838 .3421 Mdot
.55758 .3421 Mdot
.69192 .3421 Mdot
.48561 .35041 Mdot
.56237 .35041 Mdot
.61995 .35041 Mdot
.7447 .35041 Mdot
.81187 .35041 Mdot
.89823 .35041 Mdot
.20253 .35872 Mdot
.42323 .35872 Mdot
.5096 .35872 Mdot
.54798 .35872 Mdot
.61515 .35872 Mdot
.62475 .35872 Mdot
.82626 .35872 Mdot
.18813 .36703 Mdot
.39924 .36703 Mdot
.42803 .36703 Mdot
.45682 .36703 Mdot
.51439 .36703 Mdot
.54318 .36703 Mdot
.56237 .36703 Mdot
.85025 .36703 Mdot
.22172 .37534 Mdot
.32727 .37534 Mdot
.46162 .37534 Mdot
.48081 .37534 Mdot
.5096 .37534 Mdot
.51919 .37534 Mdot
.55758 .37534 Mdot
.61515 .37534 Mdot
.68232 .37534 Mdot
.70152 .37534 Mdot
.7399 .37534 Mdot
.84545 .37534 Mdot
.87424 .37534 Mdot
.91263 .37534 Mdot
.38965 .38366 Mdot
.43763 .38366 Mdot
.45682 .38366 Mdot
.52399 .38366 Mdot
.53359 .38366 Mdot
.61035 .38366 Mdot
.80227 .38366 Mdot
.95581 .38366 Mdot
.17374 .39197 Mdot
.2601 .39197 Mdot
.35606 .39197 Mdot
.36566 .39197 Mdot
.38485 .39197 Mdot
.39444 .39197 Mdot
.40404 .39197 Mdot
.43283 .39197 Mdot
.52879 .39197 Mdot
.53838 .39197 Mdot
.68232 .39197 Mdot
.70152 .39197 Mdot
.7303 .39197 Mdot
.86465 .39197 Mdot
.14975 .40028 Mdot
.2553 .40028 Mdot
.38965 .40028 Mdot
.40884 .40028 Mdot
.42803 .40028 Mdot
.46641 .40028 Mdot
.51439 .40028 Mdot
.54318 .40028 Mdot
.55278 .40028 Mdot
.57197 .40028 Mdot
.64874 .40028 Mdot
.7447 .40028 Mdot
.87904 .40028 Mdot
.88864 .40028 Mdot
.29848 .40859 Mdot
.31768 .40859 Mdot
.38485 .40859 Mdot
.45202 .40859 Mdot
.46162 .40859 Mdot
.5 .40859 Mdot
.57677 .40859 Mdot
.61515 .40859 Mdot
.79747 .40859 Mdot
.06338 .4169 Mdot
.15934 .4169 Mdot
.45682 .4169 Mdot
.46641 .4169 Mdot
.48561 .4169 Mdot
.4952 .4169 Mdot
.53359 .4169 Mdot
.54318 .4169 Mdot
.55278 .4169 Mdot
.60076 .4169 Mdot
.31768 .42521 Mdot
.32727 .42521 Mdot
.38485 .42521 Mdot
.41364 .42521 Mdot
.44242 .42521 Mdot
.5096 .42521 Mdot
.51919 .42521 Mdot
.52879 .42521 Mdot
.53838 .42521 Mdot
.55758 .42521 Mdot
.72071 .42521 Mdot
.7303 .42521 Mdot
.78788 .42521 Mdot
.84545 .42521 Mdot
.90303 .42521 Mdot
.38005 .43352 Mdot
.41843 .43352 Mdot
.43763 .43352 Mdot
.45682 .43352 Mdot
.48561 .43352 Mdot
.54318 .43352 Mdot
.58157 .43352 Mdot
.81187 .43352 Mdot
.24091 .44183 Mdot
.27929 .44183 Mdot
.31768 .44183 Mdot
.33687 .44183 Mdot
.34646 .44183 Mdot
.44242 .44183 Mdot
.5 .44183 Mdot
.51919 .44183 Mdot
.52879 .44183 Mdot
.56717 .44183 Mdot
.59596 .44183 Mdot
.60556 .44183 Mdot
.7303 .44183 Mdot
.87424 .44183 Mdot
.16894 .45014 Mdot
.31288 .45014 Mdot
.41843 .45014 Mdot
.47601 .45014 Mdot
.48561 .45014 Mdot
.55278 .45014 Mdot
.56237 .45014 Mdot
.58157 .45014 Mdot
.65833 .45014 Mdot
.77348 .45014 Mdot
.16414 .45845 Mdot
.33687 .45845 Mdot
.36566 .45845 Mdot
.43283 .45845 Mdot
.44242 .45845 Mdot
.46162 .45845 Mdot
.47121 .45845 Mdot
.48081 .45845 Mdot
.4904 .45845 Mdot
.5096 .45845 Mdot
.51919 .45845 Mdot
.52879 .45845 Mdot
.53838 .45845 Mdot
.56717 .45845 Mdot
.62475 .45845 Mdot
.66313 .45845 Mdot
.74949 .45845 Mdot
.23611 .46676 Mdot
.35126 .46676 Mdot
.38965 .46676 Mdot
.42803 .46676 Mdot
.45682 .46676 Mdot
.46641 .46676 Mdot
.47601 .46676 Mdot
.48561 .46676 Mdot
.5048 .46676 Mdot
.52399 .46676 Mdot
.53359 .46676 Mdot
.54318 .46676 Mdot
.56237 .46676 Mdot
.59116 .46676 Mdot
.65833 .46676 Mdot
.69672 .46676 Mdot
.84066 .46676 Mdot
.975 .46676 Mdot
.32727 .47507 Mdot
.33687 .47507 Mdot
.34646 .47507 Mdot
.35606 .47507 Mdot
.41364 .47507 Mdot
.42323 .47507 Mdot
.44242 .47507 Mdot
.45202 .47507 Mdot
.47121 .47507 Mdot
.48081 .47507 Mdot
.4904 .47507 Mdot
.5 .47507 Mdot
.5096 .47507 Mdot
.53838 .47507 Mdot
.54798 .47507 Mdot
.20732 .48338 Mdot
.32247 .48338 Mdot
.35126 .48338 Mdot
.38965 .48338 Mdot
.44722 .48338 Mdot
.45682 .48338 Mdot
.48561 .48338 Mdot
.4952 .48338 Mdot
.51439 .48338 Mdot
.55278 .48338 Mdot
.59116 .48338 Mdot
.60076 .48338 Mdot
.63914 .48338 Mdot
.67753 .48338 Mdot
.75429 .48338 Mdot
.82146 .48338 Mdot
.93662 .48338 Mdot
.08737 .49169 Mdot
.16414 .49169 Mdot
.17374 .49169 Mdot
.21212 .49169 Mdot
.33687 .49169 Mdot
.41364 .49169 Mdot
.42323 .49169 Mdot
.44242 .49169 Mdot
.46162 .49169 Mdot
.47121 .49169 Mdot
.48081 .49169 Mdot
.4904 .49169 Mdot
.5 .49169 Mdot
.53838 .49169 Mdot
.55758 .49169 Mdot
.63434 .49169 Mdot
.72071 .49169 Mdot
.81667 .49169 Mdot
.89343 .49169 Mdot
.025 .5 Mdot
.17854 .5 Mdot
.23611 .5 Mdot
.32247 .5 Mdot
.38005 .5 Mdot
.39924 .5 Mdot
.41843 .5 Mdot
.43763 .5 Mdot
.44722 .5 Mdot
.47601 .5 Mdot
.4952 .5 Mdot
.5048 .5 Mdot
.51439 .5 Mdot
.53359 .5 Mdot
.54318 .5 Mdot
.55278 .5 Mdot
.56237 .5 Mdot
.58157 .5 Mdot
.64874 .5 Mdot
.72551 .5 Mdot
.04899 .50831 Mdot
.20253 .50831 Mdot
.21212 .50831 Mdot
.25051 .50831 Mdot
.28889 .50831 Mdot
.38485 .50831 Mdot
.40404 .50831 Mdot
.41364 .50831 Mdot
.42323 .50831 Mdot
.44242 .50831 Mdot
.45202 .50831 Mdot
.46162 .50831 Mdot
.47121 .50831 Mdot
.48081 .50831 Mdot
.4904 .50831 Mdot
.5 .50831 Mdot
.5096 .50831 Mdot
.51919 .50831 Mdot
.53838 .50831 Mdot
.56717 .50831 Mdot
.60556 .50831 Mdot
.64394 .50831 Mdot
.76869 .50831 Mdot
.82626 .50831 Mdot
.13056 .51662 Mdot
.32247 .51662 Mdot
.40884 .51662 Mdot
.41843 .51662 Mdot
.42803 .51662 Mdot
.47601 .51662 Mdot
.4952 .51662 Mdot
.53359 .51662 Mdot
.56237 .51662 Mdot
.57197 .51662 Mdot
.62955 .51662 Mdot
.64874 .51662 Mdot
.67753 .51662 Mdot
.72551 .51662 Mdot
.04899 .52493 Mdot
.09697 .52493 Mdot
.10657 .52493 Mdot
.24091 .52493 Mdot
.27929 .52493 Mdot
.30808 .52493 Mdot
.32727 .52493 Mdot
.40404 .52493 Mdot
.41364 .52493 Mdot
.43283 .52493 Mdot
.45202 .52493 Mdot
.46162 .52493 Mdot
.47121 .52493 Mdot
.5096 .52493 Mdot
.52879 .52493 Mdot
.56717 .52493 Mdot
.58636 .52493 Mdot
.61515 .52493 Mdot
.74949 .52493 Mdot
.80707 .52493 Mdot
.19773 .53324 Mdot
.2553 .53324 Mdot
.34167 .53324 Mdot
.45682 .53324 Mdot
.46641 .53324 Mdot
.47601 .53324 Mdot
.52399 .53324 Mdot
.53359 .53324 Mdot
.55278 .53324 Mdot
.56237 .53324 Mdot
.57197 .53324 Mdot
.58157 .53324 Mdot
.64874 .53324 Mdot
.65833 .53324 Mdot
.7447 .53324 Mdot
.34646 .54155 Mdot
.38485 .54155 Mdot
.39444 .54155 Mdot
.40404 .54155 Mdot
.45202 .54155 Mdot
.46162 .54155 Mdot
.48081 .54155 Mdot
.4904 .54155 Mdot
.5096 .54155 Mdot
.52879 .54155 Mdot
.55758 .54155 Mdot
.58636 .54155 Mdot
.66313 .54155 Mdot
.7303 .54155 Mdot
.7399 .54155 Mdot
.90303 .54155 Mdot
.29369 .54986 Mdot
.33207 .54986 Mdot
.38005 .54986 Mdot
.45682 .54986 Mdot
.46641 .54986 Mdot
.4952 .54986 Mdot
.5048 .54986 Mdot
.51439 .54986 Mdot
.54318 .54986 Mdot
.59116 .54986 Mdot
.66793 .54986 Mdot
.70631 .54986 Mdot
.06818 .55817 Mdot
.21212 .55817 Mdot
.34646 .55817 Mdot
.45202 .55817 Mdot
.46162 .55817 Mdot
.47121 .55817 Mdot
.51919 .55817 Mdot
.52879 .55817 Mdot
.53838 .55817 Mdot
.57677 .55817 Mdot
.58636 .55817 Mdot
.60556 .55817 Mdot
.10177 .56648 Mdot
.36086 .56648 Mdot
.40884 .56648 Mdot
.41843 .56648 Mdot
.46641 .56648 Mdot
.47601 .56648 Mdot
.48561 .56648 Mdot
.5048 .56648 Mdot
.53359 .56648 Mdot
.56237 .56648 Mdot
.57197 .56648 Mdot
.60076 .56648 Mdot
.63914 .56648 Mdot
.70631 .56648 Mdot
.87904 .56648 Mdot
.88864 .56648 Mdot
.89823 .56648 Mdot
.07778 .57479 Mdot
.27929 .57479 Mdot
.28889 .57479 Mdot
.32727 .57479 Mdot
.39444 .57479 Mdot
.44242 .57479 Mdot
.47121 .57479 Mdot
.58636 .57479 Mdot
.62475 .57479 Mdot
.64394 .57479 Mdot
.07298 .5831 Mdot
.08258 .5831 Mdot
.38005 .5831 Mdot
.5048 .5831 Mdot
.56237 .5831 Mdot
.57197 .5831 Mdot
.59116 .5831 Mdot
.63914 .5831 Mdot
.65833 .5831 Mdot
.68712 .5831 Mdot
.14495 .59141 Mdot
.38485 .59141 Mdot
.47121 .59141 Mdot
.54798 .59141 Mdot
.63434 .59141 Mdot
.71111 .59141 Mdot
.07298 .59972 Mdot
.44722 .59972 Mdot
.4952 .59972 Mdot
.52399 .59972 Mdot
.53359 .59972 Mdot
.60076 .59972 Mdot
.71591 .59972 Mdot
.23131 .60803 Mdot
.24091 .60803 Mdot
.35606 .60803 Mdot
.38485 .60803 Mdot
.48081 .60803 Mdot
.5 .60803 Mdot
.5096 .60803 Mdot
.53838 .60803 Mdot
.15934 .61634 Mdot
.2553 .61634 Mdot
.29369 .61634 Mdot
.45682 .61634 Mdot
.5048 .61634 Mdot
.53359 .61634 Mdot
.56237 .61634 Mdot
.57197 .61634 Mdot
.68712 .61634 Mdot
.69672 .61634 Mdot
.27929 .62466 Mdot
.34646 .62466 Mdot
.35606 .62466 Mdot
.38485 .62466 Mdot
.45202 .62466 Mdot
.48081 .62466 Mdot
.70152 .62466 Mdot
.35126 .63297 Mdot
.41843 .63297 Mdot
.45682 .63297 Mdot
.61035 .63297 Mdot
.64874 .63297 Mdot
.67753 .63297 Mdot
.05859 .64128 Mdot
.16414 .64128 Mdot
.2697 .64128 Mdot
.66313 .64128 Mdot
.18813 .64959 Mdot
.33207 .64959 Mdot
.40884 .64959 Mdot
.42803 .64959 Mdot
.56237 .64959 Mdot
.69672 .64959 Mdot
.42323 .6579 Mdot
.44242 .6579 Mdot
.56717 .6579 Mdot
.61515 .6579 Mdot
.62475 .6579 Mdot
.77828 .6579 Mdot
.32247 .66621 Mdot
.34167 .66621 Mdot
.39924 .66621 Mdot
.40884 .66621 Mdot
.41843 .66621 Mdot
.47601 .66621 Mdot
.48561 .66621 Mdot
.5048 .66621 Mdot
.57197 .66621 Mdot
.94621 .66621 Mdot
.23131 .67452 Mdot
.33687 .67452 Mdot
.5 .67452 Mdot
.51919 .67452 Mdot
.64394 .67452 Mdot
.81667 .67452 Mdot
.87424 .67452 Mdot
.30328 .68283 Mdot
.33207 .68283 Mdot
.46641 .68283 Mdot
.60076 .68283 Mdot
.2697 .69114 Mdot
.34646 .69114 Mdot
.51919 .69114 Mdot
.64394 .69114 Mdot
.71111 .69114 Mdot
.72071 .69114 Mdot
.14015 .69945 Mdot
.45682 .69945 Mdot
.47601 .69945 Mdot
.5048 .69945 Mdot
.53359 .69945 Mdot
.58157 .69945 Mdot
.61035 .69945 Mdot
.07778 .70776 Mdot
.24091 .70776 Mdot
.32727 .70776 Mdot
.40404 .70776 Mdot
.43283 .70776 Mdot
.47121 .70776 Mdot
.54798 .70776 Mdot
.55758 .70776 Mdot
.57677 .70776 Mdot
.70152 .70776 Mdot
.75909 .70776 Mdot
.12096 .71607 Mdot
.29369 .71607 Mdot
.45682 .71607 Mdot
.48561 .71607 Mdot
.52399 .71607 Mdot
.62955 .71607 Mdot
.7447 .71607 Mdot
.13535 .72438 Mdot
.37525 .72438 Mdot
.40404 .72438 Mdot
.48081 .72438 Mdot
.84545 .72438 Mdot
.18813 .73269 Mdot
.22652 .73269 Mdot
.38965 .73269 Mdot
.40884 .73269 Mdot
.58157 .73269 Mdot
.82146 .73269 Mdot
.88864 .73269 Mdot
.15455 .741 Mdot
.32727 .741 Mdot
.37525 .741 Mdot
.85505 .741 Mdot
.23611 .74931 Mdot
.27449 .74931 Mdot
.70631 .74931 Mdot
.25051 .75762 Mdot
.30808 .75762 Mdot
.33687 .75762 Mdot
.43283 .75762 Mdot
.48081 .75762 Mdot
.59596 .75762 Mdot
.67273 .75762 Mdot
.19773 .76593 Mdot
.21692 .76593 Mdot
.43763 .76593 Mdot
.48561 .76593 Mdot
.51439 .76593 Mdot
.58157 .76593 Mdot
.7351 .76593 Mdot
.22172 .77424 Mdot
.23131 .77424 Mdot
.33687 .77424 Mdot
.38485 .77424 Mdot
.7399 .77424 Mdot
.46641 .78255 Mdot
.83106 .78255 Mdot
.39444 .79086 Mdot
.41364 .79086 Mdot
.45202 .79086 Mdot
.5 .79086 Mdot
.20732 .79917 Mdot
.40884 .79917 Mdot
.31768 .80748 Mdot
.46162 .80748 Mdot
.47121 .80748 Mdot
.7399 .80748 Mdot
.28409 .81579 Mdot
.20253 .8241 Mdot
.75909 .8241 Mdot
.22652 .83241 Mdot
.38005 .83241 Mdot
.38965 .83241 Mdot
.48561 .83241 Mdot
.60076 .83241 Mdot
.66793 .83241 Mdot
.77348 .83241 Mdot
.53838 .84072 Mdot
.18813 .84903 Mdot
.22652 .84903 Mdot
.39924 .84903 Mdot
.43763 .84903 Mdot
.28889 .85734 Mdot
.52879 .85734 Mdot
.55758 .85734 Mdot
.71111 .85734 Mdot
.31288 .86566 Mdot
.46641 .86566 Mdot
.61035 .86566 Mdot
.78308 .86566 Mdot
.30328 .88228 Mdot
.65833 .88228 Mdot
.45202 .89059 Mdot
.24571 .8989 Mdot
.55758 .90721 Mdot
.55758 .92383 Mdot
.66313 .92383 Mdot
.56717 .94045 Mdot
.37045 .94876 Mdot
.52399 .94876 Mdot
.52879 .95707 Mdot
.52399 .96538 Mdot
.57197 .96538 Mdot
.48081 .97369 Mdot
.003 w
[ ] 0 setdash
.47121 .02631 m
.46162 .04293 L
s
.47121 .02631 m
.52879 .04293 L
s
.47121 .02631 m
.56237 .05124 L
s
.47121 .02631 m
.52399 .06786 L
s
.47121 .02631 m
.28409 .08448 L
s
.47121 .02631 m
.31288 .08448 L
s
.47121 .02631 m
.37045 .08448 L
s
.47121 .02631 m
.72551 .08448 L
s
.46162 .04293 m
.45202 .05955 L
s
.46162 .04293 m
.52399 .06786 L
s
.46162 .04293 m
.47121 .07617 L
s
.46162 .04293 m
.37045 .08448 L
s
.52879 .04293 m
.56237 .05124 L
s
.52879 .04293 m
.52399 .06786 L
s
.56237 .05124 m
.52399 .06786 L
s
.56237 .05124 m
.63914 .08448 L
s
.56237 .05124 m
.72551 .08448 L
s
.56237 .05124 m
.58157 .1011 L
s
.45202 .05955 m
.47121 .07617 L
s
.45202 .05955 m
.37045 .08448 L
s
.45202 .05955 m
.42803 .1011 L
s
.52399 .06786 m
.47121 .07617 L
s
.52399 .06786 m
.5 .09279 L
s
.52399 .06786 m
.58157 .1011 L
s
.52399 .06786 m
.55278 .11772 L
s
.47121 .07617 m
.5 .09279 L
s
.47121 .07617 m
.42803 .1011 L
s
.47121 .07617 m
.5 .10941 L
s
.28409 .08448 m
.31288 .08448 L
s
.28409 .08448 m
.27449 .11772 L
s
.28409 .08448 m
.31288 .11772 L
s
.28409 .08448 m
.25051 .15928 L
s
.28409 .08448 m
.12096 .25069 L
s
.28409 .08448 m
.09217 .26731 L
s
.31288 .08448 m
.37045 .08448 L
s
.31288 .08448 m
.35606 .10941 L
s
.31288 .08448 m
.31288 .11772 L
s
.37045 .08448 m
.42803 .1011 L
s
.37045 .08448 m
.35606 .10941 L
s
.63914 .08448 m
.72551 .08448 L
s
.63914 .08448 m
.58157 .1011 L
s
.63914 .08448 m
.59596 .10941 L
s
.63914 .08448 m
.66313 .10941 L
s
.63914 .08448 m
.61995 .11772 L
s
.72551 .08448 m
.66313 .10941 L
s
.72551 .08448 m
.77348 .11772 L
s
.72551 .08448 m
.79747 .12603 L
s
.72551 .08448 m
.70152 .20914 L
s
.5 .09279 m
.5 .10941 L
s
.5 .09279 m
.55278 .11772 L
s
.42803 .1011 m
.35606 .10941 L
s
.42803 .1011 m
.5 .10941 L
s
.42803 .1011 m
.48561 .15097 L
s
.42803 .1011 m
.44722 .16759 L
s
.42803 .1011 m
.45682 .16759 L
s
.42803 .1011 m
.39924 .18421 L
s
.58157 .1011 m
.59596 .10941 L
s
.58157 .1011 m
.55278 .11772 L
s
.35606 .10941 m
.31288 .11772 L
s
.35606 .10941 m
.36086 .18421 L
s
.35606 .10941 m
.39924 .18421 L
s
.5 .10941 m
.55278 .11772 L
s
.5 .10941 m
.48561 .15097 L
s
.5 .10941 m
.4952 .15097 L
s
.5 .10941 m
.5048 .15097 L
s
.59596 .10941 m
.55278 .11772 L
s
.59596 .10941 m
.61995 .11772 L
s
.59596 .10941 m
.58157 .15097 L
s
.59596 .10941 m
.60556 .15928 L
s
.66313 .10941 m
.61995 .11772 L
s
.66313 .10941 m
.64874 .18421 L
s
.66313 .10941 m
.70152 .20914 L
s
.27449 .11772 m
.31288 .11772 L
s
.27449 .11772 m
.25051 .15928 L
s
.27449 .11772 m
.27929 .19252 L
s
.27449 .11772 m
.30808 .19252 L
s
.31288 .11772 m
.36086 .18421 L
s
.31288 .11772 m
.30808 .19252 L
s
.55278 .11772 m
.5048 .15097 L
s
.55278 .11772 m
.58157 .15097 L
s
.55278 .11772 m
.5096 .15928 L
s
.61995 .11772 m
.60556 .15928 L
s
.61995 .11772 m
.64874 .18421 L
s
.77348 .11772 m
.79747 .12603 L
s
.77348 .11772 m
.80707 .1759 L
s
.77348 .11772 m
.70152 .20914 L
s
.77348 .11772 m
.7399 .22576 L
s
.79747 .12603 m
.80707 .1759 L
s
.79747 .12603 m
.91263 .259 L
s
.48561 .15097 m
.4952 .15097 L
s
.48561 .15097 m
.45682 .16759 L
s
.48561 .15097 m
.48561 .18421 L
s
.48561 .15097 m
.4952 .18421 L
s
.4952 .15097 m
.5048 .15097 L
s
.4952 .15097 m
.5096 .15928 L
s
.4952 .15097 m
.4952 .18421 L
s
.5048 .15097 m
.5096 .15928 L
s
.58157 .15097 m
.5096 .15928 L
s
.58157 .15097 m
.60556 .15928 L
s
.58157 .15097 m
.61515 .19252 L
s
.58157 .15097 m
.51439 .20083 L
s
.58157 .15097 m
.57197 .21745 L
s
.25051 .15928 m
.23131 .19252 L
s
.25051 .15928 m
.27929 .19252 L
s
.25051 .15928 m
.25051 .20914 L
s
.25051 .15928 m
.12096 .25069 L
s
.5096 .15928 m
.4952 .18421 L
s
.5096 .15928 m
.51439 .20083 L
s
.60556 .15928 m
.64874 .18421 L
s
.60556 .15928 m
.61515 .19252 L
s
.44722 .16759 m
.45682 .16759 L
s
.44722 .16759 m
.39924 .18421 L
s
.44722 .16759 m
.42803 .18421 L
s
.44722 .16759 m
.44722 .18421 L
s
.44722 .16759 m
.45682 .18421 L
s
.45682 .16759 m
.45682 .18421 L
s
.45682 .16759 m
.48561 .18421 L
s
.80707 .1759 m
.81187 .21745 L
s
.80707 .1759 m
.7399 .22576 L
s
.80707 .1759 m
.79747 .22576 L
s
.80707 .1759 m
.91263 .259 L
s
.36086 .18421 m
.39924 .18421 L
s
.36086 .18421 m
.30808 .19252 L
s
.36086 .18421 m
.30808 .20914 L
s
.36086 .18421 m
.39444 .22576 L
s
.36086 .18421 m
.36566 .24238 L
s
.39924 .18421 m
.42803 .18421 L
s
.39924 .18421 m
.42803 .20083 L
s
.39924 .18421 m
.39444 .22576 L
s
.39924 .18421 m
.40404 .22576 L
s
.42803 .18421 m
.44722 .18421 L
s
.42803 .18421 m
.42803 .20083 L
s
.42803 .18421 m
.44722 .20083 L
s
.44722 .18421 m
.45682 .18421 L
s
.44722 .18421 m
.44722 .20083 L
s
.45682 .18421 m
.48561 .18421 L
s
.45682 .18421 m
.44722 .20083 L
s
.45682 .18421 m
.46641 .20083 L
s
.48561 .18421 m
.4952 .18421 L
s
.48561 .18421 m
.46641 .20083 L
s
.48561 .18421 m
.4904 .22576 L
s
.4952 .18421 m
.51439 .20083 L
s
.4952 .18421 m
.4904 .22576 L
s
.64874 .18421 m
.61515 .19252 L
s
.64874 .18421 m
.70152 .20914 L
s
.64874 .18421 m
.67273 .22576 L
s
.64874 .18421 m
.63914 .23407 L
s
.64874 .18421 m
.65833 .23407 L
s
.23131 .19252 m
.25051 .20914 L
s
.23131 .19252 m
.18333 .24238 L
s
.23131 .19252 m
.12096 .25069 L
s
.27929 .19252 m
.30808 .19252 L
s
.27929 .19252 m
.25051 .20914 L
s
.27929 .19252 m
.30808 .20914 L
s
.27929 .19252 m
.29369 .21745 L
s
.30808 .19252 m
.30808 .20914 L
s
.61515 .19252 m
.57197 .21745 L
s
.61515 .19252 m
.61035 .21745 L
s
.61515 .19252 m
.63914 .23407 L
s
.42803 .20083 m
.44722 .20083 L
s
.42803 .20083 m
.40404 .22576 L
s
.42803 .20083 m
.44242 .24238 L
s
.44722 .20083 m
.46641 .20083 L
s
.44722 .20083 m
.44242 .24238 L
s
.46641 .20083 m
.4904 .22576 L
s
.46641 .20083 m
.44242 .24238 L
s
.51439 .20083 m
.57197 .21745 L
s
.51439 .20083 m
.4904 .22576 L
s
.51439 .20083 m
.5048 .23407 L
s
.51439 .20083 m
.54798 .24238 L
s
.25051 .20914 m
.29369 .21745 L
s
.25051 .20914 m
.18333 .24238 L
s
.25051 .20914 m
.29848 .27562 L
s
.25051 .20914 m
.23611 .30055 L
s
.30808 .20914 m
.29369 .21745 L
s
.30808 .20914 m
.36566 .24238 L
s
.30808 .20914 m
.30808 .259 L
s
.30808 .20914 m
.35606 .259 L
s
.70152 .20914 m
.70631 .21745 L
s
.70152 .20914 m
.67273 .22576 L
s
.70152 .20914 m
.7399 .22576 L
s
.29369 .21745 m
.30808 .259 L
s
.29369 .21745 m
.29848 .27562 L
s
.57197 .21745 m
.61035 .21745 L
s
.57197 .21745 m
.54798 .24238 L
s
.57197 .21745 m
.56717 .259 L
s
.57197 .21745 m
.58157 .26731 L
s
.61035 .21745 m
.63914 .23407 L
s
.61035 .21745 m
.58157 .26731 L
s
.70631 .21745 m
.67273 .22576 L
s
.70631 .21745 m
.7399 .22576 L
s
.70631 .21745 m
.7351 .23407 L
s
.70631 .21745 m
.69672 .25069 L
s
.70631 .21745 m
.72551 .25069 L
s
.81187 .21745 m
.79747 .22576 L
s
.81187 .21745 m
.82146 .25069 L
s
.81187 .21745 m
.91263 .259 L
s
.39444 .22576 m
.40404 .22576 L
s
.39444 .22576 m
.36566 .24238 L
s
.39444 .22576 m
.39444 .24238 L
s
.40404 .22576 m
.39444 .24238 L
s
.40404 .22576 m
.44242 .24238 L
s
.4904 .22576 m
.5048 .23407 L
s
.4904 .22576 m
.44242 .24238 L
s
.4904 .22576 m
.48081 .27562 L
s
.67273 .22576 m
.65833 .23407 L
s
.67273 .22576 m
.69672 .25069 L
s
.67273 .22576 m
.69192 .259 L
s
.7399 .22576 m
.79747 .22576 L
s
.7399 .22576 m
.7351 .23407 L
s
.7399 .22576 m
.79268 .26731 L
s
.79747 .22576 m
.82146 .25069 L
s
.79747 .22576 m
.79268 .26731 L
s
.5048 .23407 m
.54798 .24238 L
s
.5048 .23407 m
.48081 .27562 L
s
.5048 .23407 m
.52879 .29224 L
s
.63914 .23407 m
.65833 .23407 L
s
.63914 .23407 m
.58157 .26731 L
s
.63914 .23407 m
.64874 .28393 L
s
.65833 .23407 m
.69192 .259 L
s
.65833 .23407 m
.64874 .28393 L
s
.7351 .23407 m
.72551 .25069 L
s
.7351 .23407 m
.79268 .26731 L
s
.18333 .24238 m
.12096 .25069 L
s
.18333 .24238 m
.17854 .25069 L
s
.18333 .24238 m
.21692 .30055 L
s
.18333 .24238 m
.23611 .30055 L
s
.36566 .24238 m
.39444 .24238 L
s
.36566 .24238 m
.35606 .259 L
s
.36566 .24238 m
.38485 .27562 L
s
.39444 .24238 m
.44242 .24238 L
s
.39444 .24238 m
.43763 .26731 L
s
.39444 .24238 m
.38485 .27562 L
s
.39444 .24238 m
.42803 .28393 L
s
.44242 .24238 m
.43763 .26731 L
s
.44242 .24238 m
.48081 .27562 L
s
.54798 .24238 m
.56717 .259 L
s
.54798 .24238 m
.56237 .26731 L
s
.54798 .24238 m
.52879 .29224 L
s
.54798 .24238 m
.53838 .29224 L
s
.12096 .25069 m
.17854 .25069 L
s
.12096 .25069 m
.09217 .26731 L
s
.12096 .25069 m
.16414 .30886 L
s
.12096 .25069 m
.13056 .33379 L
s
.17854 .25069 m
.21692 .30055 L
s
.17854 .25069 m
.16414 .30886 L
s
.69672 .25069 m
.72551 .25069 L
s
.69672 .25069 m
.69192 .259 L
s
.72551 .25069 m
.69192 .259 L
s
.72551 .25069 m
.79268 .26731 L
s
.72551 .25069 m
.7303 .29224 L
s
.82146 .25069 m
.91263 .259 L
s
.82146 .25069 m
.79268 .26731 L
s
.82146 .25069 m
.82626 .32548 L
s
.82146 .25069 m
.84545 .32548 L
s
.30808 .259 m
.35606 .259 L
s
.30808 .259 m
.29848 .27562 L
s
.30808 .259 m
.35126 .30055 L
s
.35606 .259 m
.38485 .27562 L
s
.35606 .259 m
.36566 .29224 L
s
.35606 .259 m
.35126 .30055 L
s
.56717 .259 m
.56237 .26731 L
s
.56717 .259 m
.58157 .26731 L
s
.69192 .259 m
.64874 .28393 L
s
.69192 .259 m
.7303 .29224 L
s
.69192 .259 m
.69192 .3421 L
s
.91263 .259 m
.84545 .32548 L
s
.91263 .259 m
.88864 .33379 L
s
.91263 .259 m
.89823 .35041 L
s
.91263 .259 m
.95581 .38366 L
s
.09217 .26731 m
.05859 .30886 L
s
.09217 .26731 m
.07298 .33379 L
s
.09217 .26731 m
.13056 .33379 L
s
.43763 .26731 m
.48081 .27562 L
s
.43763 .26731 m
.42803 .28393 L
s
.56237 .26731 m
.58157 .26731 L
s
.56237 .26731 m
.53838 .29224 L
s
.56237 .26731 m
.54798 .29224 L
s
.56237 .26731 m
.56717 .30886 L
s
.58157 .26731 m
.64874 .28393 L
s
.58157 .26731 m
.60076 .30055 L
s
.58157 .26731 m
.56717 .30886 L
s
.79268 .26731 m
.7303 .29224 L
s
.79268 .26731 m
.7399 .30886 L
s
.79268 .26731 m
.82626 .32548 L
s
.79268 .26731 m
.77348 .33379 L
s
.29848 .27562 m
.23611 .30055 L
s
.29848 .27562 m
.28409 .30055 L
s
.29848 .27562 m
.35126 .30055 L
s
.29848 .27562 m
.31768 .32548 L
s
.38485 .27562 m
.42803 .28393 L
s
.38485 .27562 m
.36566 .29224 L
s
.38485 .27562 m
.39444 .29224 L
s
.48081 .27562 m
.42803 .28393 L
s
.48081 .27562 m
.52879 .29224 L
s
.48081 .27562 m
.51919 .32548 L
s
.48081 .27562 m
.45682 .33379 L
s
.48081 .27562 m
.47601 .33379 L
s
.48081 .27562 m
.5048 .33379 L
s
.42803 .28393 m
.39444 .29224 L
s
.42803 .28393 m
.40884 .31717 L
s
.42803 .28393 m
.43283 .32548 L
s
.42803 .28393 m
.45682 .33379 L
s
.64874 .28393 m
.60076 .30055 L
s
.64874 .28393 m
.69192 .3421 L
s
.64874 .28393 m
.61995 .35041 L
s
.36566 .29224 m
.39444 .29224 L
s
.36566 .29224 m
.35126 .30055 L
s
.36566 .29224 m
.37525 .30886 L
s
.39444 .29224 m
.37525 .30886 L
s
.39444 .29224 m
.40884 .31717 L
s
.39444 .29224 m
.39444 .32548 L
s
.52879 .29224 m
.53838 .29224 L
s
.52879 .29224 m
.51919 .32548 L
s
.52879 .29224 m
.54798 .32548 L
s
.53838 .29224 m
.54798 .29224 L
s
.53838 .29224 m
.55278 .31717 L
s
.53838 .29224 m
.54798 .32548 L
s
.54798 .29224 m
.56717 .30886 L
s
.54798 .29224 m
.55278 .31717 L
s
.7303 .29224 m
.7399 .30886 L
s
.7303 .29224 m
.69192 .3421 L
s
.21692 .30055 m
.23611 .30055 L
s
.21692 .30055 m
.16414 .30886 L
s
.21692 .30055 m
.21212 .32548 L
s
.23611 .30055 m
.28409 .30055 L
s
.23611 .30055 m
.21212 .32548 L
s
.23611 .30055 m
.22172 .3421 L
s
.23611 .30055 m
.25051 .3421 L
s
.28409 .30055 m
.31768 .32548 L
s
.28409 .30055 m
.25051 .3421 L
s
.28409 .30055 m
.2697 .3421 L
s
.28409 .30055 m
.29848 .3421 L
s
.35126 .30055 m
.37525 .30886 L
s
.35126 .30055 m
.31768 .32548 L
s
.35126 .30055 m
.34646 .32548 L
s
.60076 .30055 m
.56717 .30886 L
s
.60076 .30055 m
.56237 .35041 L
s
.60076 .30055 m
.61995 .35041 L
s
.05859 .30886 m
.07298 .33379 L
s
.05859 .30886 m
.06338 .4169 L
s
.05859 .30886 m
.025 .5 L
s
.16414 .30886 m
.21212 .32548 L
s
.16414 .30886 m
.13056 .33379 L
s
.16414 .30886 m
.20732 .33379 L
s
.16414 .30886 m
.15455 .3421 L
s
.37525 .30886 m
.34646 .32548 L
s
.37525 .30886 m
.38485 .32548 L
s
.37525 .30886 m
.39444 .32548 L
s
.37525 .30886 m
.36086 .33379 L
s
.56717 .30886 m
.55278 .31717 L
s
.56717 .30886 m
.55758 .3421 L
s
.56717 .30886 m
.56237 .35041 L
s
.7399 .30886 m
.77348 .33379 L
s
.7399 .30886 m
.69192 .3421 L
s
.7399 .30886 m
.7447 .35041 L
s
.40884 .31717 m
.39444 .32548 L
s
.40884 .31717 m
.43283 .32548 L
s
.40884 .31717 m
.41843 .33379 L
s
.55278 .31717 m
.54798 .32548 L
s
.55278 .31717 m
.55758 .3421 L
s
.21212 .32548 m
.20732 .33379 L
s
.21212 .32548 m
.22172 .3421 L
s
.31768 .32548 m
.34646 .32548 L
s
.31768 .32548 m
.29848 .3421 L
s
.31768 .32548 m
.32727 .37534 L
s
.34646 .32548 m
.36086 .33379 L
s
.34646 .32548 m
.32727 .37534 L
s
.38485 .32548 m
.39444 .32548 L
s
.38485 .32548 m
.36086 .33379 L
s
.38485 .32548 m
.37525 .3421 L
s
.39444 .32548 m
.41843 .33379 L
s
.39444 .32548 m
.37525 .3421 L
s
.39444 .32548 m
.39924 .36703 L
s
.43283 .32548 m
.41843 .33379 L
s
.43283 .32548 m
.42803 .33379 L
s
.43283 .32548 m
.45682 .33379 L
s
.51919 .32548 m
.54798 .32548 L
s
.51919 .32548 m
.5048 .33379 L
s
.51919 .32548 m
.53838 .3421 L
s
.51919 .32548 m
.5096 .35872 L
s
.54798 .32548 m
.53838 .3421 L
s
.54798 .32548 m
.55758 .3421 L
s
.82626 .32548 m
.84545 .32548 L
s
.82626 .32548 m
.77348 .33379 L
s
.82626 .32548 m
.81187 .35041 L
s
.82626 .32548 m
.82626 .35872 L
s
.84545 .32548 m
.88864 .33379 L
s
.84545 .32548 m
.82626 .35872 L
s
.84545 .32548 m
.85025 .36703 L
s
.07298 .33379 m
.13056 .33379 L
s
.07298 .33379 m
.14975 .40028 L
s
.07298 .33379 m
.06338 .4169 L
s
.13056 .33379 m
.15455 .3421 L
s
.13056 .33379 m
.14975 .40028 L
s
.20732 .33379 m
.15455 .3421 L
s
.20732 .33379 m
.22172 .3421 L
s
.20732 .33379 m
.20253 .35872 L
s
.20732 .33379 m
.18813 .36703 L
s
.36086 .33379 m
.37525 .3421 L
s
.36086 .33379 m
.32727 .37534 L
s
.36086 .33379 m
.35606 .39197 L
s
.41843 .33379 m
.42803 .33379 L
s
.41843 .33379 m
.42323 .35872 L
s
.41843 .33379 m
.39924 .36703 L
s
.42803 .33379 m
.45682 .33379 L
s
.42803 .33379 m
.42323 .35872 L
s
.45682 .33379 m
.47601 .33379 L
s
.45682 .33379 m
.48561 .35041 L
s
.45682 .33379 m
.42323 .35872 L
s
.45682 .33379 m
.45682 .36703 L
s
.47601 .33379 m
.5048 .33379 L
s
.47601 .33379 m
.48561 .35041 L
s
.5048 .33379 m
.48561 .35041 L
s
.5048 .33379 m
.5096 .35872 L
s
.77348 .33379 m
.7447 .35041 L
s
.77348 .33379 m
.81187 .35041 L
s
.77348 .33379 m
.80227 .38366 L
s
.88864 .33379 m
.89823 .35041 L
s
.88864 .33379 m
.85025 .36703 L
s
.88864 .33379 m
.87424 .37534 L
s
.15455 .3421 m
.18813 .36703 L
s
.15455 .3421 m
.17374 .39197 L
s
.15455 .3421 m
.14975 .40028 L
s
.22172 .3421 m
.25051 .3421 L
s
.22172 .3421 m
.20253 .35872 L
s
.22172 .3421 m
.22172 .37534 L
s
.25051 .3421 m
.2697 .3421 L
s
.25051 .3421 m
.22172 .37534 L
s
.25051 .3421 m
.2601 .39197 L
s
.2697 .3421 m
.29848 .3421 L
s
.2697 .3421 m
.2601 .39197 L
s
.29848 .3421 m
.32727 .37534 L
s
.29848 .3421 m
.2601 .39197 L
s
.29848 .3421 m
.29848 .40859 L
s
.37525 .3421 m
.39924 .36703 L
s
.37525 .3421 m
.38965 .38366 L
s
.37525 .3421 m
.35606 .39197 L
s
.37525 .3421 m
.36566 .39197 L
s
.53838 .3421 m
.55758 .3421 L
s
.53838 .3421 m
.5096 .35872 L
s
.53838 .3421 m
.54798 .35872 L
s
.53838 .3421 m
.51439 .36703 L
s
.53838 .3421 m
.54318 .36703 L
s
.55758 .3421 m
.56237 .35041 L
s
.55758 .3421 m
.54798 .35872 L
s
.69192 .3421 m
.61995 .35041 L
s
.69192 .3421 m
.7447 .35041 L
s
.69192 .3421 m
.62475 .35872 L
s
.69192 .3421 m
.68232 .37534 L
s
.69192 .3421 m
.70152 .37534 L
s
.48561 .35041 m
.5096 .35872 L
s
.48561 .35041 m
.45682 .36703 L
s
.48561 .35041 m
.48081 .37534 L
s
.56237 .35041 m
.61995 .35041 L
s
.56237 .35041 m
.54798 .35872 L
s
.56237 .35041 m
.61515 .35872 L
s
.56237 .35041 m
.56237 .36703 L
s
.61995 .35041 m
.61515 .35872 L
s
.61995 .35041 m
.62475 .35872 L
s
.7447 .35041 m
.70152 .37534 L
s
.7447 .35041 m
.7399 .37534 L
s
.7447 .35041 m
.80227 .38366 L
s
.81187 .35041 m
.82626 .35872 L
s
.81187 .35041 m
.80227 .38366 L
s
.89823 .35041 m
.87424 .37534 L
s
.89823 .35041 m
.91263 .37534 L
s
.89823 .35041 m
.95581 .38366 L
s
.20253 .35872 m
.18813 .36703 L
s
.20253 .35872 m
.22172 .37534 L
s
.42323 .35872 m
.39924 .36703 L
s
.42323 .35872 m
.42803 .36703 L
s
.42323 .35872 m
.45682 .36703 L
s
.5096 .35872 m
.51439 .36703 L
s
.5096 .35872 m
.48081 .37534 L
s
.5096 .35872 m
.5096 .37534 L
s
.54798 .35872 m
.54318 .36703 L
s
.54798 .35872 m
.56237 .36703 L
s
.61515 .35872 m
.62475 .35872 L
s
.61515 .35872 m
.56237 .36703 L
s
.61515 .35872 m
.61515 .37534 L
s
.61515 .35872 m
.61035 .38366 L
s
.62475 .35872 m
.61515 .37534 L
s
.62475 .35872 m
.68232 .37534 L
s
.62475 .35872 m
.64874 .40028 L
s
.82626 .35872 m
.85025 .36703 L
s
.82626 .35872 m
.84545 .37534 L
s
.82626 .35872 m
.80227 .38366 L
s
.18813 .36703 m
.22172 .37534 L
s
.18813 .36703 m
.17374 .39197 L
s
.39924 .36703 m
.42803 .36703 L
s
.39924 .36703 m
.38965 .38366 L
s
.39924 .36703 m
.40404 .39197 L
s
.42803 .36703 m
.45682 .36703 L
s
.42803 .36703 m
.43763 .38366 L
s
.42803 .36703 m
.40404 .39197 L
s
.42803 .36703 m
.43283 .39197 L
s
.45682 .36703 m
.46162 .37534 L
s
.45682 .36703 m
.48081 .37534 L
s
.45682 .36703 m
.43763 .38366 L
s
.45682 .36703 m
.45682 .38366 L
s
.51439 .36703 m
.54318 .36703 L
s
.51439 .36703 m
.5096 .37534 L
s
.51439 .36703 m
.51919 .37534 L
s
.54318 .36703 m
.56237 .36703 L
s
.54318 .36703 m
.51919 .37534 L
s
.54318 .36703 m
.55758 .37534 L
s
.54318 .36703 m
.53359 .38366 L
s
.56237 .36703 m
.55758 .37534 L
s
.56237 .36703 m
.61035 .38366 L
s
.56237 .36703 m
.57197 .40028 L
s
.85025 .36703 m
.84545 .37534 L
s
.85025 .36703 m
.87424 .37534 L
s
.22172 .37534 m
.17374 .39197 L
s
.22172 .37534 m
.2601 .39197 L
s
.22172 .37534 m
.2553 .40028 L
s
.22172 .37534 m
.24091 .44183 L
s
.32727 .37534 m
.35606 .39197 L
s
.32727 .37534 m
.29848 .40859 L
s
.32727 .37534 m
.31768 .40859 L
s
.46162 .37534 m
.48081 .37534 L
s
.46162 .37534 m
.45682 .38366 L
s
.46162 .37534 m
.46641 .40028 L
s
.48081 .37534 m
.5096 .37534 L
s
.48081 .37534 m
.46641 .40028 L
s
.48081 .37534 m
.5 .40859 L
s
.5096 .37534 m
.51919 .37534 L
s
.5096 .37534 m
.52399 .38366 L
s
.5096 .37534 m
.51439 .40028 L
s
.5096 .37534 m
.5 .40859 L
s
.51919 .37534 m
.52399 .38366 L
s
.51919 .37534 m
.53359 .38366 L
s
.55758 .37534 m
.53359 .38366 L
s
.55758 .37534 m
.53838 .39197 L
s
.55758 .37534 m
.55278 .40028 L
s
.55758 .37534 m
.57197 .40028 L
s
.61515 .37534 m
.61035 .38366 L
s
.61515 .37534 m
.64874 .40028 L
s
.68232 .37534 m
.70152 .37534 L
s
.68232 .37534 m
.68232 .39197 L
s
.68232 .37534 m
.70152 .39197 L
s
.68232 .37534 m
.64874 .40028 L
s
.70152 .37534 m
.7399 .37534 L
s
.70152 .37534 m
.70152 .39197 L
s
.70152 .37534 m
.7303 .39197 L
s
.7399 .37534 m
.80227 .38366 L
s
.7399 .37534 m
.7303 .39197 L
s
.7399 .37534 m
.7447 .40028 L
s
.84545 .37534 m
.87424 .37534 L
s
.84545 .37534 m
.80227 .38366 L
s
.84545 .37534 m
.86465 .39197 L
s
.84545 .37534 m
.84545 .42521 L
s
.87424 .37534 m
.91263 .37534 L
s
.87424 .37534 m
.86465 .39197 L
s
.87424 .37534 m
.87904 .40028 L
s
.87424 .37534 m
.88864 .40028 L
s
.91263 .37534 m
.95581 .38366 L
s
.91263 .37534 m
.88864 .40028 L
s
.91263 .37534 m
.90303 .42521 L
s
.38965 .38366 m
.36566 .39197 L
s
.38965 .38366 m
.38485 .39197 L
s
.38965 .38366 m
.39444 .39197 L
s
.38965 .38366 m
.40404 .39197 L
s
.43763 .38366 m
.45682 .38366 L
s
.43763 .38366 m
.43283 .39197 L
s
.43763 .38366 m
.45202 .40859 L
s
.45682 .38366 m
.46641 .40028 L
s
.45682 .38366 m
.45202 .40859 L
s
.52399 .38366 m
.53359 .38366 L
s
.52399 .38366 m
.52879 .39197 L
s
.52399 .38366 m
.51439 .40028 L
s
.53359 .38366 m
.52879 .39197 L
s
.53359 .38366 m
.53838 .39197 L
s
.61035 .38366 m
.57197 .40028 L
s
.61035 .38366 m
.64874 .40028 L
s
.61035 .38366 m
.57677 .40859 L
s
.61035 .38366 m
.61515 .40859 L
s
.61035 .38366 m
.60076 .4169 L
s
.80227 .38366 m
.7447 .40028 L
s
.80227 .38366 m
.79747 .40859 L
s
.80227 .38366 m
.84545 .42521 L
s
.95581 .38366 m
.90303 .42521 L
s
.95581 .38366 m
.975 .46676 L
s
.17374 .39197 m
.14975 .40028 L
s
.17374 .39197 m
.15934 .4169 L
s
.17374 .39197 m
.24091 .44183 L
s
.17374 .39197 m
.16894 .45014 L
s
.2601 .39197 m
.2553 .40028 L
s
.2601 .39197 m
.29848 .40859 L
s
.35606 .39197 m
.36566 .39197 L
s
.35606 .39197 m
.31768 .40859 L
s
.35606 .39197 m
.38485 .40859 L
s
.35606 .39197 m
.32727 .42521 L
s
.35606 .39197 m
.38005 .43352 L
s
.35606 .39197 m
.34646 .44183 L
s
.36566 .39197 m
.38485 .39197 L
s
.36566 .39197 m
.38485 .40859 L
s
.38485 .39197 m
.39444 .39197 L
s
.38485 .39197 m
.38965 .40028 L
s
.38485 .39197 m
.38485 .40859 L
s
.39444 .39197 m
.40404 .39197 L
s
.39444 .39197 m
.38965 .40028 L
s
.40404 .39197 m
.43283 .39197 L
s
.40404 .39197 m
.38965 .40028 L
s
.40404 .39197 m
.40884 .40028 L
s
.43283 .39197 m
.40884 .40028 L
s
.43283 .39197 m
.42803 .40028 L
s
.43283 .39197 m
.45202 .40859 L
s
.52879 .39197 m
.53838 .39197 L
s
.52879 .39197 m
.51439 .40028 L
s
.52879 .39197 m
.54318 .40028 L
s
.52879 .39197 m
.53359 .4169 L
s
.53838 .39197 m
.54318 .40028 L
s
.53838 .39197 m
.55278 .40028 L
s
.68232 .39197 m
.70152 .39197 L
s
.68232 .39197 m
.64874 .40028 L
s
.68232 .39197 m
.72071 .42521 L
s
.68232 .39197 m
.65833 .45014 L
s
.70152 .39197 m
.7303 .39197 L
s
.70152 .39197 m
.72071 .42521 L
s
.7303 .39197 m
.7447 .40028 L
s
.7303 .39197 m
.72071 .42521 L
s
.7303 .39197 m
.7303 .42521 L
s
.86465 .39197 m
.87904 .40028 L
s
.86465 .39197 m
.84545 .42521 L
s
.14975 .40028 m
.06338 .4169 L
s
.14975 .40028 m
.15934 .4169 L
s
.2553 .40028 m
.29848 .40859 L
s
.2553 .40028 m
.24091 .44183 L
s
.2553 .40028 m
.27929 .44183 L
s
.38965 .40028 m
.40884 .40028 L
s
.38965 .40028 m
.38485 .40859 L
s
.40884 .40028 m
.42803 .40028 L
s
.40884 .40028 m
.38485 .40859 L
s
.40884 .40028 m
.41364 .42521 L
s
.42803 .40028 m
.45202 .40859 L
s
.42803 .40028 m
.41364 .42521 L
s
.42803 .40028 m
.44242 .42521 L
s
.46641 .40028 m
.45202 .40859 L
s
.46641 .40028 m
.46162 .40859 L
s
.46641 .40028 m
.5 .40859 L
s
.46641 .40028 m
.46641 .4169 L
s
.46641 .40028 m
.48561 .4169 L
s
.51439 .40028 m
.5 .40859 L
s
.51439 .40028 m
.53359 .4169 L
s
.51439 .40028 m
.5096 .42521 L
s
.51439 .40028 m
.51919 .42521 L
s
.54318 .40028 m
.55278 .40028 L
s
.54318 .40028 m
.53359 .4169 L
s
.54318 .40028 m
.54318 .4169 L
s
.55278 .40028 m
.57197 .40028 L
s
.55278 .40028 m
.54318 .4169 L
s
.55278 .40028 m
.55278 .4169 L
s
.57197 .40028 m
.57677 .40859 L
s
.57197 .40028 m
.55278 .4169 L
s
.64874 .40028 m
.61515 .40859 L
s
.64874 .40028 m
.65833 .45014 L
s
.7447 .40028 m
.79747 .40859 L
s
.7447 .40028 m
.7303 .42521 L
s
.7447 .40028 m
.78788 .42521 L
s
.7447 .40028 m
.77348 .45014 L
s
.87904 .40028 m
.88864 .40028 L
s
.87904 .40028 m
.84545 .42521 L
s
.87904 .40028 m
.90303 .42521 L
s
.87904 .40028 m
.87424 .44183 L
s
.88864 .40028 m
.90303 .42521 L
s
.29848 .40859 m
.31768 .40859 L
s
.29848 .40859 m
.31768 .42521 L
s
.29848 .40859 m
.27929 .44183 L
s
.31768 .40859 m
.31768 .42521 L
s
.31768 .40859 m
.32727 .42521 L
s
.38485 .40859 m
.38485 .42521 L
s
.38485 .40859 m
.41364 .42521 L
s
.38485 .40859 m
.38005 .43352 L
s
.45202 .40859 m
.46162 .40859 L
s
.45202 .40859 m
.45682 .4169 L
s
.45202 .40859 m
.44242 .42521 L
s
.46162 .40859 m
.45682 .4169 L
s
.46162 .40859 m
.46641 .4169 L
s
.5 .40859 m
.48561 .4169 L
s
.5 .40859 m
.4952 .4169 L
s
.5 .40859 m
.5096 .42521 L
s
.57677 .40859 m
.55278 .4169 L
s
.57677 .40859 m
.60076 .4169 L
s
.57677 .40859 m
.55758 .42521 L
s
.57677 .40859 m
.58157 .43352 L
s
.61515 .40859 m
.60076 .4169 L
s
.61515 .40859 m
.60556 .44183 L
s
.61515 .40859 m
.65833 .45014 L
s
.61515 .40859 m
.62475 .45845 L
s
.79747 .40859 m
.78788 .42521 L
s
.79747 .40859 m
.84545 .42521 L
s
.79747 .40859 m
.81187 .43352 L
s
.06338 .4169 m
.15934 .4169 L
s
.06338 .4169 m
.08737 .49169 L
s
.06338 .4169 m
.025 .5 L
s
.06338 .4169 m
.04899 .50831 L
s
.15934 .4169 m
.16894 .45014 L
s
.15934 .4169 m
.16414 .45845 L
s
.15934 .4169 m
.08737 .49169 L
s
.45682 .4169 m
.46641 .4169 L
s
.45682 .4169 m
.44242 .42521 L
s
.45682 .4169 m
.45682 .43352 L
s
.46641 .4169 m
.48561 .4169 L
s
.46641 .4169 m
.45682 .43352 L
s
.46641 .4169 m
.48561 .43352 L
s
.48561 .4169 m
.4952 .4169 L
s
.48561 .4169 m
.48561 .43352 L
s
.4952 .4169 m
.5096 .42521 L
s
.4952 .4169 m
.48561 .43352 L
s
.53359 .4169 m
.54318 .4169 L
s
.53359 .4169 m
.51919 .42521 L
s
.53359 .4169 m
.52879 .42521 L
s
.53359 .4169 m
.53838 .42521 L
s
.54318 .4169 m
.55278 .4169 L
s
.54318 .4169 m
.53838 .42521 L
s
.54318 .4169 m
.55758 .42521 L
s
.54318 .4169 m
.54318 .43352 L
s
.55278 .4169 m
.55758 .42521 L
s
.60076 .4169 m
.58157 .43352 L
s
.60076 .4169 m
.59596 .44183 L
s
.60076 .4169 m
.60556 .44183 L
s
.31768 .42521 m
.32727 .42521 L
s
.31768 .42521 m
.27929 .44183 L
s
.31768 .42521 m
.31768 .44183 L
s
.32727 .42521 m
.31768 .44183 L
s
.32727 .42521 m
.33687 .44183 L
s
.32727 .42521 m
.34646 .44183 L
s
.38485 .42521 m
.41364 .42521 L
s
.38485 .42521 m
.38005 .43352 L
s
.41364 .42521 m
.44242 .42521 L
s
.41364 .42521 m
.38005 .43352 L
s
.41364 .42521 m
.41843 .43352 L
s
.44242 .42521 m
.41843 .43352 L
s
.44242 .42521 m
.43763 .43352 L
s
.44242 .42521 m
.45682 .43352 L
s
.44242 .42521 m
.44242 .44183 L
s
.5096 .42521 m
.51919 .42521 L
s
.5096 .42521 m
.48561 .43352 L
s
.5096 .42521 m
.5 .44183 L
s
.5096 .42521 m
.51919 .44183 L
s
.51919 .42521 m
.52879 .42521 L
s
.51919 .42521 m
.51919 .44183 L
s
.52879 .42521 m
.53838 .42521 L
s
.52879 .42521 m
.51919 .44183 L
s
.52879 .42521 m
.52879 .44183 L
s
.53838 .42521 m
.54318 .43352 L
s
.53838 .42521 m
.52879 .44183 L
s
.55758 .42521 m
.54318 .43352 L
s
.55758 .42521 m
.58157 .43352 L
s
.55758 .42521 m
.56717 .44183 L
s
.55758 .42521 m
.55278 .45014 L
s
.72071 .42521 m
.7303 .42521 L
s
.72071 .42521 m
.7303 .44183 L
s
.72071 .42521 m
.65833 .45014 L
s
.72071 .42521 m
.69672 .46676 L
s
.7303 .42521 m
.7303 .44183 L
s
.7303 .42521 m
.77348 .45014 L
s
.78788 .42521 m
.81187 .43352 L
s
.78788 .42521 m
.77348 .45014 L
s
.84545 .42521 m
.81187 .43352 L
s
.84545 .42521 m
.87424 .44183 L
s
.84545 .42521 m
.84066 .46676 L
s
.90303 .42521 m
.87424 .44183 L
s
.90303 .42521 m
.975 .46676 L
s
.90303 .42521 m
.93662 .48338 L
s
.90303 .42521 m
.89343 .49169 L
s
.38005 .43352 m
.41843 .43352 L
s
.38005 .43352 m
.34646 .44183 L
s
.38005 .43352 m
.41843 .45014 L
s
.38005 .43352 m
.36566 .45845 L
s
.38005 .43352 m
.38965 .46676 L
s
.41843 .43352 m
.43763 .43352 L
s
.41843 .43352 m
.41843 .45014 L
s
.43763 .43352 m
.44242 .44183 L
s
.43763 .43352 m
.41843 .45014 L
s
.45682 .43352 m
.48561 .43352 L
s
.45682 .43352 m
.44242 .44183 L
s
.45682 .43352 m
.47601 .45014 L
s
.45682 .43352 m
.46162 .45845 L
s
.48561 .43352 m
.5 .44183 L
s
.48561 .43352 m
.47601 .45014 L
s
.48561 .43352 m
.48561 .45014 L
s
.54318 .43352 m
.52879 .44183 L
s
.54318 .43352 m
.55278 .45014 L
s
.54318 .43352 m
.53838 .45845 L
s
.58157 .43352 m
.56717 .44183 L
s
.58157 .43352 m
.59596 .44183 L
s
.58157 .43352 m
.58157 .45014 L
s
.81187 .43352 m
.77348 .45014 L
s
.81187 .43352 m
.84066 .46676 L
s
.81187 .43352 m
.82146 .48338 L
s
.24091 .44183 m
.27929 .44183 L
s
.24091 .44183 m
.16894 .45014 L
s
.24091 .44183 m
.23611 .46676 L
s
.24091 .44183 m
.20732 .48338 L
s
.27929 .44183 m
.31768 .44183 L
s
.27929 .44183 m
.31288 .45014 L
s
.27929 .44183 m
.23611 .46676 L
s
.27929 .44183 m
.28889 .50831 L
s
.31768 .44183 m
.33687 .44183 L
s
.31768 .44183 m
.31288 .45014 L
s
.31768 .44183 m
.33687 .45845 L
s
.33687 .44183 m
.34646 .44183 L
s
.33687 .44183 m
.33687 .45845 L
s
.34646 .44183 m
.33687 .45845 L
s
.34646 .44183 m
.36566 .45845 L
s
.34646 .44183 m
.35126 .46676 L
s
.44242 .44183 m
.41843 .45014 L
s
.44242 .44183 m
.43283 .45845 L
s
.44242 .44183 m
.44242 .45845 L
s
.44242 .44183 m
.46162 .45845 L
s
.5 .44183 m
.51919 .44183 L
s
.5 .44183 m
.48561 .45014 L
s
.5 .44183 m
.4904 .45845 L
s
.5 .44183 m
.5096 .45845 L
s
.51919 .44183 m
.52879 .44183 L
s
.51919 .44183 m
.5096 .45845 L
s
.51919 .44183 m
.51919 .45845 L
s
.52879 .44183 m
.51919 .45845 L
s
.52879 .44183 m
.52879 .45845 L
s
.52879 .44183 m
.53838 .45845 L
s
.56717 .44183 m
.55278 .45014 L
s
.56717 .44183 m
.56237 .45014 L
s
.56717 .44183 m
.58157 .45014 L
s
.59596 .44183 m
.60556 .44183 L
s
.59596 .44183 m
.58157 .45014 L
s
.59596 .44183 m
.59116 .46676 L
s
.60556 .44183 m
.62475 .45845 L
s
.60556 .44183 m
.59116 .46676 L
s
.7303 .44183 m
.77348 .45014 L
s
.7303 .44183 m
.74949 .45845 L
s
.7303 .44183 m
.69672 .46676 L
s
.7303 .44183 m
.72071 .49169 L
s
.87424 .44183 m
.84066 .46676 L
s
.87424 .44183 m
.89343 .49169 L
s
.16894 .45014 m
.16414 .45845 L
s
.16894 .45014 m
.20732 .48338 L
s
.31288 .45014 m
.33687 .45845 L
s
.31288 .45014 m
.32727 .47507 L
s
.31288 .45014 m
.32247 .48338 L
s
.31288 .45014 m
.28889 .50831 L
s
.41843 .45014 m
.43283 .45845 L
s
.41843 .45014 m
.38965 .46676 L
s
.41843 .45014 m
.42803 .46676 L
s
.41843 .45014 m
.41364 .47507 L
s
.47601 .45014 m
.48561 .45014 L
s
.47601 .45014 m
.46162 .45845 L
s
.47601 .45014 m
.47121 .45845 L
s
.47601 .45014 m
.48081 .45845 L
s
.48561 .45014 m
.48081 .45845 L
s
.48561 .45014 m
.4904 .45845 L
s
.55278 .45014 m
.56237 .45014 L
s
.55278 .45014 m
.53838 .45845 L
s
.55278 .45014 m
.54318 .46676 L
s
.55278 .45014 m
.56237 .46676 L
s
.56237 .45014 m
.58157 .45014 L
s
.56237 .45014 m
.56717 .45845 L
s
.56237 .45014 m
.56237 .46676 L
s
.58157 .45014 m
.56717 .45845 L
s
.58157 .45014 m
.59116 .46676 L
s
.65833 .45014 m
.62475 .45845 L
s
.65833 .45014 m
.66313 .45845 L
s
.65833 .45014 m
.65833 .46676 L
s
.65833 .45014 m
.69672 .46676 L
s
.77348 .45014 m
.74949 .45845 L
s
.77348 .45014 m
.75429 .48338 L
s
.77348 .45014 m
.82146 .48338 L
s
.77348 .45014 m
.81667 .49169 L
s
.16414 .45845 m
.20732 .48338 L
s
.16414 .45845 m
.08737 .49169 L
s
.16414 .45845 m
.16414 .49169 L
s
.16414 .45845 m
.17374 .49169 L
s
.33687 .45845 m
.35126 .46676 L
s
.33687 .45845 m
.32727 .47507 L
s
.33687 .45845 m
.33687 .47507 L
s
.36566 .45845 m
.35126 .46676 L
s
.36566 .45845 m
.38965 .46676 L
s
.36566 .45845 m
.35606 .47507 L
s
.43283 .45845 m
.44242 .45845 L
s
.43283 .45845 m
.42803 .46676 L
s
.44242 .45845 m
.46162 .45845 L
s
.44242 .45845 m
.42803 .46676 L
s
.44242 .45845 m
.45682 .46676 L
s
.44242 .45845 m
.44242 .47507 L
s
.44242 .45845 m
.45202 .47507 L
s
.46162 .45845 m
.47121 .45845 L
s
.46162 .45845 m
.45682 .46676 L
s
.46162 .45845 m
.46641 .46676 L
s
.47121 .45845 m
.48081 .45845 L
s
.47121 .45845 m
.46641 .46676 L
s
.47121 .45845 m
.47601 .46676 L
s
.48081 .45845 m
.4904 .45845 L
s
.48081 .45845 m
.47601 .46676 L
s
.48081 .45845 m
.48561 .46676 L
s
.4904 .45845 m
.5096 .45845 L
s
.4904 .45845 m
.48561 .46676 L
s
.4904 .45845 m
.5048 .46676 L
s
.5096 .45845 m
.51919 .45845 L
s
.5096 .45845 m
.5048 .46676 L
s
.5096 .45845 m
.52399 .46676 L
s
.5096 .45845 m
.5096 .47507 L
s
.51919 .45845 m
.52879 .45845 L
s
.51919 .45845 m
.52399 .46676 L
s
.52879 .45845 m
.53838 .45845 L
s
.52879 .45845 m
.52399 .46676 L
s
.52879 .45845 m
.53359 .46676 L
s
.53838 .45845 m
.53359 .46676 L
s
.53838 .45845 m
.54318 .46676 L
s
.56717 .45845 m
.56237 .46676 L
s
.56717 .45845 m
.59116 .46676 L
s
.62475 .45845 m
.59116 .46676 L
s
.62475 .45845 m
.65833 .46676 L
s
.62475 .45845 m
.60076 .48338 L
s
.62475 .45845 m
.63914 .48338 L
s
.62475 .45845 m
.63434 .49169 L
s
.66313 .45845 m
.65833 .46676 L
s
.66313 .45845 m
.69672 .46676 L
s
.66313 .45845 m
.67753 .48338 L
s
.74949 .45845 m
.75429 .48338 L
s
.74949 .45845 m
.72071 .49169 L
s
.23611 .46676 m
.20732 .48338 L
s
.23611 .46676 m
.21212 .49169 L
s
.23611 .46676 m
.23611 .5 L
s
.23611 .46676 m
.25051 .50831 L
s
.23611 .46676 m
.28889 .50831 L
s
.35126 .46676 m
.33687 .47507 L
s
.35126 .46676 m
.34646 .47507 L
s
.35126 .46676 m
.35606 .47507 L
s
.38965 .46676 m
.35606 .47507 L
s
.38965 .46676 m
.41364 .47507 L
s
.38965 .46676 m
.38965 .48338 L
s
.42803 .46676 m
.41364 .47507 L
s
.42803 .46676 m
.42323 .47507 L
s
.42803 .46676 m
.44242 .47507 L
s
.45682 .46676 m
.46641 .46676 L
s
.45682 .46676 m
.45202 .47507 L
s
.45682 .46676 m
.45682 .48338 L
s
.46641 .46676 m
.47601 .46676 L
s
.46641 .46676 m
.47121 .47507 L
s
.46641 .46676 m
.45682 .48338 L
s
.47601 .46676 m
.48561 .46676 L
s
.47601 .46676 m
.47121 .47507 L
s
.47601 .46676 m
.48081 .47507 L
s
.48561 .46676 m
.5048 .46676 L
s
.48561 .46676 m
.48081 .47507 L
s
.48561 .46676 m
.4904 .47507 L
s
.5048 .46676 m
.4904 .47507 L
s
.5048 .46676 m
.5 .47507 L
s
.5048 .46676 m
.5096 .47507 L
s
.52399 .46676 m
.53359 .46676 L
s
.52399 .46676 m
.5096 .47507 L
s
.52399 .46676 m
.53838 .47507 L
s
.52399 .46676 m
.51439 .48338 L
s
.53359 .46676 m
.54318 .46676 L
s
.53359 .46676 m
.53838 .47507 L
s
.54318 .46676 m
.56237 .46676 L
s
.54318 .46676 m
.53838 .47507 L
s
.54318 .46676 m
.54798 .47507 L
s
.56237 .46676 m
.59116 .46676 L
s
.56237 .46676 m
.54798 .47507 L
s
.56237 .46676 m
.55278 .48338 L
s
.56237 .46676 m
.59116 .48338 L
s
.56237 .46676 m
.55758 .49169 L
s
.59116 .46676 m
.59116 .48338 L
s
.59116 .46676 m
.60076 .48338 L
s
.65833 .46676 m
.63914 .48338 L
s
.65833 .46676 m
.67753 .48338 L
s
.65833 .46676 m
.64874 .5 L
s
.69672 .46676 m
.67753 .48338 L
s
.69672 .46676 m
.72071 .49169 L
s
.84066 .46676 m
.82146 .48338 L
s
.84066 .46676 m
.89343 .49169 L
s
.84066 .46676 m
.82626 .50831 L
s
.975 .46676 m
.93662 .48338 L
s
.975 .46676 m
.90303 .54155 L
s
.975 .46676 m
.94621 .66621 L
s
.32727 .47507 m
.33687 .47507 L
s
.32727 .47507 m
.32247 .48338 L
s
.32727 .47507 m
.33687 .49169 L
s
.33687 .47507 m
.34646 .47507 L
s
.33687 .47507 m
.35126 .48338 L
s
.33687 .47507 m
.33687 .49169 L
s
.34646 .47507 m
.35606 .47507 L
s
.34646 .47507 m
.35126 .48338 L
s
.35606 .47507 m
.35126 .48338 L
s
.35606 .47507 m
.38965 .48338 L
s
.35606 .47507 m
.38005 .5 L
s
.41364 .47507 m
.42323 .47507 L
s
.41364 .47507 m
.38965 .48338 L
s
.41364 .47507 m
.41364 .49169 L
s
.41364 .47507 m
.42323 .49169 L
s
.42323 .47507 m
.44242 .47507 L
s
.42323 .47507 m
.42323 .49169 L
s
.42323 .47507 m
.44242 .49169 L
s
.44242 .47507 m
.45202 .47507 L
s
.44242 .47507 m
.44722 .48338 L
s
.44242 .47507 m
.44242 .49169 L
s
.45202 .47507 m
.44722 .48338 L
s
.45202 .47507 m
.45682 .48338 L
s
.47121 .47507 m
.48081 .47507 L
s
.47121 .47507 m
.45682 .48338 L
s
.47121 .47507 m
.48561 .48338 L
s
.47121 .47507 m
.46162 .49169 L
s
.47121 .47507 m
.47121 .49169 L
s
.48081 .47507 m
.4904 .47507 L
s
.48081 .47507 m
.48561 .48338 L
s
.4904 .47507 m
.5 .47507 L
s
.4904 .47507 m
.48561 .48338 L
s
.4904 .47507 m
.4952 .48338 L
s
.5 .47507 m
.5096 .47507 L
s
.5 .47507 m
.4952 .48338 L
s
.5 .47507 m
.5 .49169 L
s
.5096 .47507 m
.51439 .48338 L
s
.5096 .47507 m
.5 .49169 L
s
.53838 .47507 m
.54798 .47507 L
s
.53838 .47507 m
.51439 .48338 L
s
.53838 .47507 m
.55278 .48338 L
s
.53838 .47507 m
.53838 .49169 L
s
.54798 .47507 m
.55278 .48338 L
s
.20732 .48338 m
.17374 .49169 L
s
.20732 .48338 m
.21212 .49169 L
s
.20732 .48338 m
.17854 .5 L
s
.20732 .48338 m
.20253 .50831 L
s
.32247 .48338 m
.33687 .49169 L
s
.32247 .48338 m
.32247 .5 L
s
.32247 .48338 m
.28889 .50831 L
s
.35126 .48338 m
.33687 .49169 L
s
.35126 .48338 m
.38005 .5 L
s
.38965 .48338 m
.41364 .49169 L
s
.38965 .48338 m
.38005 .5 L
s
.38965 .48338 m
.39924 .5 L
s
.44722 .48338 m
.45682 .48338 L
s
.44722 .48338 m
.44242 .49169 L
s
.44722 .48338 m
.44722 .5 L
s
.45682 .48338 m
.46162 .49169 L
s
.45682 .48338 m
.44722 .5 L
s
.48561 .48338 m
.4952 .48338 L
s
.48561 .48338 m
.47121 .49169 L
s
.48561 .48338 m
.48081 .49169 L
s
.48561 .48338 m
.4904 .49169 L
s
.4952 .48338 m
.4904 .49169 L
s
.4952 .48338 m
.5 .49169 L
s
.51439 .48338 m
.5 .49169 L
s
.51439 .48338 m
.53838 .49169 L
s
.51439 .48338 m
.5048 .5 L
s
.51439 .48338 m
.51439 .5 L
s
.51439 .48338 m
.53359 .5 L
s
.55278 .48338 m
.53838 .49169 L
s
.55278 .48338 m
.55758 .49169 L
s
.55278 .48338 m
.54318 .5 L
s
.59116 .48338 m
.60076 .48338 L
s
.59116 .48338 m
.55758 .49169 L
s
.59116 .48338 m
.58157 .5 L
s
.59116 .48338 m
.60556 .50831 L
s
.60076 .48338 m
.63434 .49169 L
s
.60076 .48338 m
.60556 .50831 L
s
.63914 .48338 m
.63434 .49169 L
s
.63914 .48338 m
.64874 .5 L
s
.67753 .48338 m
.72071 .49169 L
s
.67753 .48338 m
.64874 .5 L
s
.67753 .48338 m
.67753 .51662 L
s
.75429 .48338 m
.72071 .49169 L
s
.75429 .48338 m
.81667 .49169 L
s
.75429 .48338 m
.72551 .5 L
s
.75429 .48338 m
.76869 .50831 L
s
.75429 .48338 m
.74949 .52493 L
s
.82146 .48338 m
.81667 .49169 L
s
.82146 .48338 m
.82626 .50831 L
s
.93662 .48338 m
.89343 .49169 L
s
.93662 .48338 m
.90303 .54155 L
s
.08737 .49169 m
.16414 .49169 L
s
.08737 .49169 m
.04899 .50831 L
s
.08737 .49169 m
.13056 .51662 L
s
.08737 .49169 m
.09697 .52493 L
s
.08737 .49169 m
.10657 .52493 L
s
.16414 .49169 m
.17374 .49169 L
s
.16414 .49169 m
.17854 .5 L
s
.16414 .49169 m
.13056 .51662 L
s
.17374 .49169 m
.17854 .5 L
s
.21212 .49169 m
.23611 .5 L
s
.21212 .49169 m
.20253 .50831 L
s
.21212 .49169 m
.21212 .50831 L
s
.33687 .49169 m
.32247 .5 L
s
.33687 .49169 m
.38005 .5 L
s
.33687 .49169 m
.32247 .51662 L
s
.33687 .49169 m
.32727 .52493 L
s
.33687 .49169 m
.34167 .53324 L
s
.41364 .49169 m
.42323 .49169 L
s
.41364 .49169 m
.39924 .5 L
s
.41364 .49169 m
.41843 .5 L
s
.41364 .49169 m
.41364 .50831 L
s
.42323 .49169 m
.44242 .49169 L
s
.42323 .49169 m
.41843 .5 L
s
.42323 .49169 m
.43763 .5 L
s
.44242 .49169 m
.43763 .5 L
s
.44242 .49169 m
.44722 .5 L
s
.46162 .49169 m
.47121 .49169 L
s
.46162 .49169 m
.44722 .5 L
s
.46162 .49169 m
.47601 .5 L
s
.46162 .49169 m
.45202 .50831 L
s
.46162 .49169 m
.46162 .50831 L
s
.46162 .49169 m
.47121 .50831 L
s
.47121 .49169 m
.48081 .49169 L
s
.47121 .49169 m
.47601 .5 L
s
.48081 .49169 m
.4904 .49169 L
s
.48081 .49169 m
.47601 .5 L
s
.4904 .49169 m
.5 .49169 L
s
.4904 .49169 m
.47601 .5 L
s
.4904 .49169 m
.4952 .5 L
s
.4904 .49169 m
.48081 .50831 L
s
.5 .49169 m
.4952 .5 L
s
.5 .49169 m
.5048 .5 L
s
.53838 .49169 m
.53359 .5 L
s
.53838 .49169 m
.54318 .5 L
s
.55758 .49169 m
.54318 .5 L
s
.55758 .49169 m
.55278 .5 L
s
.55758 .49169 m
.56237 .5 L
s
.55758 .49169 m
.58157 .5 L
s
.63434 .49169 m
.64874 .5 L
s
.63434 .49169 m
.60556 .50831 L
s
.63434 .49169 m
.64394 .50831 L
s
.63434 .49169 m
.62955 .51662 L
s
.72071 .49169 m
.72551 .5 L
s
.72071 .49169 m
.67753 .51662 L
s
.72071 .49169 m
.72551 .51662 L
s
.81667 .49169 m
.76869 .50831 L
s
.81667 .49169 m
.82626 .50831 L
s
.81667 .49169 m
.80707 .52493 L
s
.89343 .49169 m
.82626 .50831 L
s
.89343 .49169 m
.90303 .54155 L
s
.025 .5 m
.04899 .50831 L
s
.025 .5 m
.04899 .52493 L
s
.025 .5 m
.05859 .64128 L
s
.17854 .5 m
.20253 .50831 L
s
.17854 .5 m
.13056 .51662 L
s
.17854 .5 m
.19773 .53324 L
s
.23611 .5 m
.21212 .50831 L
s
.23611 .5 m
.25051 .50831 L
s
.23611 .5 m
.24091 .52493 L
s
.32247 .5 m
.28889 .50831 L
s
.32247 .5 m
.32247 .51662 L
s
.32247 .5 m
.30808 .52493 L
s
.38005 .5 m
.39924 .5 L
s
.38005 .5 m
.38485 .50831 L
s
.38005 .5 m
.34167 .53324 L
s
.39924 .5 m
.38485 .50831 L
s
.39924 .5 m
.40404 .50831 L
s
.39924 .5 m
.41364 .50831 L
s
.41843 .5 m
.43763 .5 L
s
.41843 .5 m
.41364 .50831 L
s
.41843 .5 m
.42323 .50831 L
s
.43763 .5 m
.44722 .5 L
s
.43763 .5 m
.42323 .50831 L
s
.43763 .5 m
.44242 .50831 L
s
.44722 .5 m
.44242 .50831 L
s
.44722 .5 m
.45202 .50831 L
s
.47601 .5 m
.47121 .50831 L
s
.47601 .5 m
.48081 .50831 L
s
.4952 .5 m
.5048 .5 L
s
.4952 .5 m
.48081 .50831 L
s
.4952 .5 m
.4904 .50831 L
s
.4952 .5 m
.5 .50831 L
s
.5048 .5 m
.51439 .5 L
s
.5048 .5 m
.5 .50831 L
s
.5048 .5 m
.5096 .50831 L
s
.51439 .5 m
.53359 .5 L
s
.51439 .5 m
.5096 .50831 L
s
.51439 .5 m
.51919 .50831 L
s
.53359 .5 m
.54318 .5 L
s
.53359 .5 m
.51919 .50831 L
s
.53359 .5 m
.53838 .50831 L
s
.54318 .5 m
.55278 .5 L
s
.54318 .5 m
.53838 .50831 L
s
.55278 .5 m
.56237 .5 L
s
.55278 .5 m
.53838 .50831 L
s
.55278 .5 m
.56717 .50831 L
s
.55278 .5 m
.56237 .51662 L
s
.56237 .5 m
.58157 .5 L
s
.56237 .5 m
.56717 .50831 L
s
.58157 .5 m
.56717 .50831 L
s
.58157 .5 m
.60556 .50831 L
s
.58157 .5 m
.57197 .51662 L
s
.58157 .5 m
.58636 .52493 L
s
.64874 .5 m
.64394 .50831 L
s
.64874 .5 m
.64874 .51662 L
s
.64874 .5 m
.67753 .51662 L
s
.72551 .5 m
.72551 .51662 L
s
.72551 .5 m
.74949 .52493 L
s
.04899 .50831 m
.04899 .52493 L
s
.04899 .50831 m
.09697 .52493 L
s
.20253 .50831 m
.21212 .50831 L
s
.20253 .50831 m
.19773 .53324 L
s
.21212 .50831 m
.24091 .52493 L
s
.21212 .50831 m
.19773 .53324 L
s
.25051 .50831 m
.28889 .50831 L
s
.25051 .50831 m
.24091 .52493 L
s
.25051 .50831 m
.27929 .52493 L
s
.25051 .50831 m
.2553 .53324 L
s
.28889 .50831 m
.27929 .52493 L
s
.28889 .50831 m
.30808 .52493 L
s
.38485 .50831 m
.40404 .50831 L
s
.38485 .50831 m
.40404 .52493 L
s
.38485 .50831 m
.34167 .53324 L
s
.38485 .50831 m
.38485 .54155 L
s
.40404 .50831 m
.41364 .50831 L
s
.40404 .50831 m
.40884 .51662 L
s
.40404 .50831 m
.40404 .52493 L
s
.41364 .50831 m
.42323 .50831 L
s
.41364 .50831 m
.40884 .51662 L
s
.41364 .50831 m
.41843 .51662 L
s
.42323 .50831 m
.44242 .50831 L
s
.42323 .50831 m
.41843 .51662 L
s
.42323 .50831 m
.42803 .51662 L
s
.44242 .50831 m
.45202 .50831 L
s
.44242 .50831 m
.42803 .51662 L
s
.44242 .50831 m
.43283 .52493 L
s
.44242 .50831 m
.45202 .52493 L
s
.45202 .50831 m
.46162 .50831 L
s
.45202 .50831 m
.45202 .52493 L
s
.45202 .50831 m
.46162 .52493 L
s
.46162 .50831 m
.47121 .50831 L
s
.46162 .50831 m
.46162 .52493 L
s
.47121 .50831 m
.48081 .50831 L
s
.47121 .50831 m
.47601 .51662 L
s
.47121 .50831 m
.46162 .52493 L
s
.48081 .50831 m
.4904 .50831 L
s
.48081 .50831 m
.47601 .51662 L
s
.48081 .50831 m
.4952 .51662 L
s
.4904 .50831 m
.5 .50831 L
s
.4904 .50831 m
.4952 .51662 L
s
.5 .50831 m
.5096 .50831 L
s
.5 .50831 m
.4952 .51662 L
s
.5096 .50831 m
.51919 .50831 L
s
.5096 .50831 m
.4952 .51662 L
s
.5096 .50831 m
.5096 .52493 L
s
.51919 .50831 m
.53838 .50831 L
s
.51919 .50831 m
.53359 .51662 L
s
.51919 .50831 m
.5096 .52493 L
s
.51919 .50831 m
.52879 .52493 L
s
.53838 .50831 m
.53359 .51662 L
s
.53838 .50831 m
.56237 .51662 L
s
.56717 .50831 m
.56237 .51662 L
s
.56717 .50831 m
.57197 .51662 L
s
.60556 .50831 m
.62955 .51662 L
s
.60556 .50831 m
.58636 .52493 L
s
.60556 .50831 m
.61515 .52493 L
s
.64394 .50831 m
.62955 .51662 L
s
.64394 .50831 m
.64874 .51662 L
s
.76869 .50831 m
.74949 .52493 L
s
.76869 .50831 m
.80707 .52493 L
s
.82626 .50831 m
.80707 .52493 L
s
.82626 .50831 m
.90303 .54155 L
s
.82626 .50831 m
.87904 .56648 L
s
.13056 .51662 m
.10657 .52493 L
s
.13056 .51662 m
.19773 .53324 L
s
.13056 .51662 m
.10177 .56648 L
s
.13056 .51662 m
.14495 .59141 L
s
.32247 .51662 m
.30808 .52493 L
s
.32247 .51662 m
.32727 .52493 L
s
.40884 .51662 m
.41843 .51662 L
s
.40884 .51662 m
.40404 .52493 L
s
.40884 .51662 m
.41364 .52493 L
s
.41843 .51662 m
.42803 .51662 L
s
.41843 .51662 m
.41364 .52493 L
s
.41843 .51662 m
.43283 .52493 L
s
.42803 .51662 m
.43283 .52493 L
s
.47601 .51662 m
.4952 .51662 L
s
.47601 .51662 m
.46162 .52493 L
s
.47601 .51662 m
.47121 .52493 L
s
.47601 .51662 m
.47601 .53324 L
s
.4952 .51662 m
.5096 .52493 L
s
.4952 .51662 m
.47601 .53324 L
s
.4952 .51662 m
.4904 .54155 L
s
.53359 .51662 m
.56237 .51662 L
s
.53359 .51662 m
.52879 .52493 L
s
.53359 .51662 m
.53359 .53324 L
s
.53359 .51662 m
.55278 .53324 L
s
.56237 .51662 m
.57197 .51662 L
s
.56237 .51662 m
.56717 .52493 L
s
.56237 .51662 m
.55278 .53324 L
s
.57197 .51662 m
.56717 .52493 L
s
.57197 .51662 m
.58636 .52493 L
s
.57197 .51662 m
.57197 .53324 L
s
.62955 .51662 m
.64874 .51662 L
s
.62955 .51662 m
.61515 .52493 L
s
.62955 .51662 m
.64874 .53324 L
s
.64874 .51662 m
.67753 .51662 L
s
.64874 .51662 m
.64874 .53324 L
s
.64874 .51662 m
.65833 .53324 L
s
.67753 .51662 m
.72551 .51662 L
s
.67753 .51662 m
.65833 .53324 L
s
.67753 .51662 m
.66313 .54155 L
s
.67753 .51662 m
.66793 .54986 L
s
.67753 .51662 m
.70631 .54986 L
s
.72551 .51662 m
.74949 .52493 L
s
.72551 .51662 m
.7447 .53324 L
s
.72551 .51662 m
.7303 .54155 L
s
.72551 .51662 m
.70631 .54986 L
s
.04899 .52493 m
.09697 .52493 L
s
.04899 .52493 m
.06818 .55817 L
s
.04899 .52493 m
.07298 .5831 L
s
.04899 .52493 m
.05859 .64128 L
s
.09697 .52493 m
.10657 .52493 L
s
.09697 .52493 m
.06818 .55817 L
s
.09697 .52493 m
.10177 .56648 L
s
.10657 .52493 m
.10177 .56648 L
s
.24091 .52493 m
.19773 .53324 L
s
.24091 .52493 m
.2553 .53324 L
s
.24091 .52493 m
.21212 .55817 L
s
.27929 .52493 m
.30808 .52493 L
s
.27929 .52493 m
.2553 .53324 L
s
.27929 .52493 m
.29369 .54986 L
s
.30808 .52493 m
.32727 .52493 L
s
.30808 .52493 m
.29369 .54986 L
s
.30808 .52493 m
.33207 .54986 L
s
.32727 .52493 m
.34167 .53324 L
s
.32727 .52493 m
.33207 .54986 L
s
.40404 .52493 m
.41364 .52493 L
s
.40404 .52493 m
.38485 .54155 L
s
.40404 .52493 m
.39444 .54155 L
s
.40404 .52493 m
.40404 .54155 L
s
.41364 .52493 m
.43283 .52493 L
s
.41364 .52493 m
.40404 .54155 L
s
.43283 .52493 m
.45202 .52493 L
s
.43283 .52493 m
.40404 .54155 L
s
.43283 .52493 m
.45202 .54155 L
s
.43283 .52493 m
.41843 .56648 L
s
.45202 .52493 m
.46162 .52493 L
s
.45202 .52493 m
.45682 .53324 L
s
.45202 .52493 m
.45202 .54155 L
s
.46162 .52493 m
.47121 .52493 L
s
.46162 .52493 m
.45682 .53324 L
s
.46162 .52493 m
.46641 .53324 L
s
.47121 .52493 m
.46641 .53324 L
s
.47121 .52493 m
.47601 .53324 L
s
.5096 .52493 m
.52879 .52493 L
s
.5096 .52493 m
.52399 .53324 L
s
.5096 .52493 m
.4904 .54155 L
s
.5096 .52493 m
.5096 .54155 L
s
.52879 .52493 m
.52399 .53324 L
s
.52879 .52493 m
.53359 .53324 L
s
.56717 .52493 m
.55278 .53324 L
s
.56717 .52493 m
.56237 .53324 L
s
.56717 .52493 m
.57197 .53324 L
s
.58636 .52493 m
.61515 .52493 L
s
.58636 .52493 m
.57197 .53324 L
s
.58636 .52493 m
.58157 .53324 L
s
.58636 .52493 m
.58636 .54155 L
s
.61515 .52493 m
.64874 .53324 L
s
.61515 .52493 m
.58636 .54155 L
s
.61515 .52493 m
.59116 .54986 L
s
.61515 .52493 m
.60556 .55817 L
s
.61515 .52493 m
.63914 .56648 L
s
.74949 .52493 m
.80707 .52493 L
s
.74949 .52493 m
.7447 .53324 L
s
.80707 .52493 m
.7447 .53324 L
s
.80707 .52493 m
.7399 .54155 L
s
.80707 .52493 m
.87904 .56648 L
s
.80707 .52493 m
.77828 .6579 L
s
.19773 .53324 m
.21212 .55817 L
s
.19773 .53324 m
.14495 .59141 L
s
.2553 .53324 m
.29369 .54986 L
s
.2553 .53324 m
.21212 .55817 L
s
.2553 .53324 m
.27929 .57479 L
s
.34167 .53324 m
.34646 .54155 L
s
.34167 .53324 m
.38485 .54155 L
s
.34167 .53324 m
.33207 .54986 L
s
.45682 .53324 m
.46641 .53324 L
s
.45682 .53324 m
.45202 .54155 L
s
.45682 .53324 m
.46162 .54155 L
s
.46641 .53324 m
.47601 .53324 L
s
.46641 .53324 m
.46162 .54155 L
s
.46641 .53324 m
.48081 .54155 L
s
.46641 .53324 m
.46641 .54986 L
s
.47601 .53324 m
.48081 .54155 L
s
.47601 .53324 m
.4904 .54155 L
s
.52399 .53324 m
.53359 .53324 L
s
.52399 .53324 m
.5096 .54155 L
s
.52399 .53324 m
.52879 .54155 L
s
.53359 .53324 m
.55278 .53324 L
s
.53359 .53324 m
.52879 .54155 L
s
.53359 .53324 m
.54318 .54986 L
s
.55278 .53324 m
.56237 .53324 L
s
.55278 .53324 m
.55758 .54155 L
s
.55278 .53324 m
.54318 .54986 L
s
.56237 .53324 m
.57197 .53324 L
s
.56237 .53324 m
.55758 .54155 L
s
.57197 .53324 m
.58157 .53324 L
s
.57197 .53324 m
.55758 .54155 L
s
.57197 .53324 m
.58636 .54155 L
s
.57197 .53324 m
.57677 .55817 L
s
.58157 .53324 m
.58636 .54155 L
s
.64874 .53324 m
.65833 .53324 L
s
.64874 .53324 m
.66313 .54155 L
s
.64874 .53324 m
.63914 .56648 L
s
.65833 .53324 m
.66313 .54155 L
s
.7447 .53324 m
.7303 .54155 L
s
.7447 .53324 m
.7399 .54155 L
s
.34646 .54155 m
.38485 .54155 L
s
.34646 .54155 m
.33207 .54986 L
s
.34646 .54155 m
.38005 .54986 L
s
.34646 .54155 m
.34646 .55817 L
s
.34646 .54155 m
.36086 .56648 L
s
.38485 .54155 m
.39444 .54155 L
s
.38485 .54155 m
.38005 .54986 L
s
.39444 .54155 m
.40404 .54155 L
s
.39444 .54155 m
.38005 .54986 L
s
.39444 .54155 m
.40884 .56648 L
s
.40404 .54155 m
.40884 .56648 L
s
.40404 .54155 m
.41843 .56648 L
s
.45202 .54155 m
.46162 .54155 L
s
.45202 .54155 m
.45682 .54986 L
s
.45202 .54155 m
.45202 .55817 L
s
.45202 .54155 m
.41843 .56648 L
s
.46162 .54155 m
.45682 .54986 L
s
.46162 .54155 m
.46641 .54986 L
s
.48081 .54155 m
.4904 .54155 L
s
.48081 .54155 m
.46641 .54986 L
s
.48081 .54155 m
.4952 .54986 L
s
.48081 .54155 m
.47121 .55817 L
s
.48081 .54155 m
.48561 .56648 L
s
.4904 .54155 m
.5096 .54155 L
s
.4904 .54155 m
.4952 .54986 L
s
.4904 .54155 m
.5048 .54986 L
s
.5096 .54155 m
.52879 .54155 L
s
.5096 .54155 m
.5048 .54986 L
s
.5096 .54155 m
.51439 .54986 L
s
.52879 .54155 m
.51439 .54986 L
s
.52879 .54155 m
.54318 .54986 L
s
.52879 .54155 m
.51919 .55817 L
s
.52879 .54155 m
.52879 .55817 L
s
.55758 .54155 m
.54318 .54986 L
s
.55758 .54155 m
.57677 .55817 L
s
.55758 .54155 m
.56237 .56648 L
s
.58636 .54155 m
.59116 .54986 L
s
.58636 .54155 m
.57677 .55817 L
s
.66313 .54155 m
.66793 .54986 L
s
.66313 .54155 m
.63914 .56648 L
s
.7303 .54155 m
.7399 .54155 L
s
.7303 .54155 m
.70631 .54986 L
s
.7303 .54155 m
.70631 .56648 L
s
.7399 .54155 m
.70631 .56648 L
s
.7399 .54155 m
.71111 .59141 L
s
.7399 .54155 m
.71591 .59972 L
s
.7399 .54155 m
.77828 .6579 L
s
.90303 .54155 m
.87904 .56648 L
s
.90303 .54155 m
.88864 .56648 L
s
.90303 .54155 m
.89823 .56648 L
s
.90303 .54155 m
.94621 .66621 L
s
.29369 .54986 m
.33207 .54986 L
s
.29369 .54986 m
.27929 .57479 L
s
.29369 .54986 m
.28889 .57479 L
s
.29369 .54986 m
.32727 .57479 L
s
.33207 .54986 m
.34646 .55817 L
s
.33207 .54986 m
.32727 .57479 L
s
.38005 .54986 m
.36086 .56648 L
s
.38005 .54986 m
.40884 .56648 L
s
.38005 .54986 m
.39444 .57479 L
s
.38005 .54986 m
.38005 .5831 L
s
.45682 .54986 m
.46641 .54986 L
s
.45682 .54986 m
.45202 .55817 L
s
.45682 .54986 m
.46162 .55817 L
s
.46641 .54986 m
.46162 .55817 L
s
.46641 .54986 m
.47121 .55817 L
s
.4952 .54986 m
.5048 .54986 L
s
.4952 .54986 m
.48561 .56648 L
s
.4952 .54986 m
.5048 .56648 L
s
.5048 .54986 m
.51439 .54986 L
s
.5048 .54986 m
.51919 .55817 L
s
.5048 .54986 m
.5048 .56648 L
s
.51439 .54986 m
.51919 .55817 L
s
.54318 .54986 m
.52879 .55817 L
s
.54318 .54986 m
.53838 .55817 L
s
.54318 .54986 m
.56237 .56648 L
s
.59116 .54986 m
.57677 .55817 L
s
.59116 .54986 m
.58636 .55817 L
s
.59116 .54986 m
.60556 .55817 L
s
.66793 .54986 m
.70631 .54986 L
s
.66793 .54986 m
.63914 .56648 L
s
.66793 .54986 m
.70631 .56648 L
s
.66793 .54986 m
.64394 .57479 L
s
.66793 .54986 m
.65833 .5831 L
s
.66793 .54986 m
.68712 .5831 L
s
.70631 .54986 m
.70631 .56648 L
s
.06818 .55817 m
.10177 .56648 L
s
.06818 .55817 m
.07778 .57479 L
s
.06818 .55817 m
.07298 .5831 L
s
.21212 .55817 m
.27929 .57479 L
s
.21212 .55817 m
.14495 .59141 L
s
.21212 .55817 m
.23131 .60803 L
s
.21212 .55817 m
.24091 .60803 L
s
.21212 .55817 m
.15934 .61634 L
s
.34646 .55817 m
.36086 .56648 L
s
.34646 .55817 m
.32727 .57479 L
s
.45202 .55817 m
.46162 .55817 L
s
.45202 .55817 m
.41843 .56648 L
s
.45202 .55817 m
.46641 .56648 L
s
.45202 .55817 m
.44242 .57479 L
s
.46162 .55817 m
.47121 .55817 L
s
.46162 .55817 m
.46641 .56648 L
s
.47121 .55817 m
.46641 .56648 L
s
.47121 .55817 m
.47601 .56648 L
s
.47121 .55817 m
.48561 .56648 L
s
.51919 .55817 m
.52879 .55817 L
s
.51919 .55817 m
.5048 .56648 L
s
.51919 .55817 m
.53359 .56648 L
s
.52879 .55817 m
.53838 .55817 L
s
.52879 .55817 m
.53359 .56648 L
s
.53838 .55817 m
.53359 .56648 L
s
.53838 .55817 m
.56237 .56648 L
s
.57677 .55817 m
.58636 .55817 L
s
.57677 .55817 m
.56237 .56648 L
s
.57677 .55817 m
.57197 .56648 L
s
.57677 .55817 m
.58636 .57479 L
s
.58636 .55817 m
.60556 .55817 L
s
.58636 .55817 m
.60076 .56648 L
s
.58636 .55817 m
.58636 .57479 L
s
.60556 .55817 m
.60076 .56648 L
s
.60556 .55817 m
.63914 .56648 L
s
.60556 .55817 m
.62475 .57479 L
s
.10177 .56648 m
.07778 .57479 L
s
.10177 .56648 m
.08258 .5831 L
s
.10177 .56648 m
.14495 .59141 L
s
.36086 .56648 m
.32727 .57479 L
s
.36086 .56648 m
.38005 .5831 L
s
.36086 .56648 m
.35606 .60803 L
s
.40884 .56648 m
.41843 .56648 L
s
.40884 .56648 m
.39444 .57479 L
s
.41843 .56648 m
.39444 .57479 L
s
.41843 .56648 m
.44242 .57479 L
s
.41843 .56648 m
.44722 .59972 L
s
.46641 .56648 m
.47601 .56648 L
s
.46641 .56648 m
.44242 .57479 L
s
.46641 .56648 m
.47121 .57479 L
s
.47601 .56648 m
.48561 .56648 L
s
.47601 .56648 m
.47121 .57479 L
s
.48561 .56648 m
.5048 .56648 L
s
.48561 .56648 m
.47121 .57479 L
s
.48561 .56648 m
.5048 .5831 L
s
.48561 .56648 m
.47121 .59141 L
s
.48561 .56648 m
.4952 .59972 L
s
.5048 .56648 m
.53359 .56648 L
s
.5048 .56648 m
.5048 .5831 L
s
.53359 .56648 m
.56237 .56648 L
s
.53359 .56648 m
.5048 .5831 L
s
.53359 .56648 m
.54798 .59141 L
s
.53359 .56648 m
.52399 .59972 L
s
.53359 .56648 m
.53359 .59972 L
s
.56237 .56648 m
.57197 .56648 L
s
.56237 .56648 m
.56237 .5831 L
s
.56237 .56648 m
.54798 .59141 L
s
.57197 .56648 m
.58636 .57479 L
s
.57197 .56648 m
.56237 .5831 L
s
.57197 .56648 m
.57197 .5831 L
s
.60076 .56648 m
.58636 .57479 L
s
.60076 .56648 m
.62475 .57479 L
s
.60076 .56648 m
.59116 .5831 L
s
.63914 .56648 m
.62475 .57479 L
s
.63914 .56648 m
.64394 .57479 L
s
.63914 .56648 m
.63914 .5831 L
s
.70631 .56648 m
.68712 .5831 L
s
.70631 .56648 m
.71111 .59141 L
s
.87904 .56648 m
.88864 .56648 L
s
.87904 .56648 m
.77828 .6579 L
s
.87904 .56648 m
.81667 .67452 L
s
.87904 .56648 m
.87424 .67452 L
s
.88864 .56648 m
.89823 .56648 L
s
.88864 .56648 m
.87424 .67452 L
s
.89823 .56648 m
.94621 .66621 L
s
.89823 .56648 m
.87424 .67452 L
s
.07778 .57479 m
.07298 .5831 L
s
.07778 .57479 m
.08258 .5831 L
s
.27929 .57479 m
.28889 .57479 L
s
.27929 .57479 m
.24091 .60803 L
s
.27929 .57479 m
.2553 .61634 L
s
.27929 .57479 m
.29369 .61634 L
s
.28889 .57479 m
.32727 .57479 L
s
.28889 .57479 m
.29369 .61634 L
s
.32727 .57479 m
.35606 .60803 L
s
.32727 .57479 m
.29369 .61634 L
s
.32727 .57479 m
.34646 .62466 L
s
.39444 .57479 m
.38005 .5831 L
s
.39444 .57479 m
.38485 .59141 L
s
.39444 .57479 m
.44722 .59972 L
s
.44242 .57479 m
.47121 .57479 L
s
.44242 .57479 m
.47121 .59141 L
s
.44242 .57479 m
.44722 .59972 L
s
.47121 .57479 m
.47121 .59141 L
s
.58636 .57479 m
.57197 .5831 L
s
.58636 .57479 m
.59116 .5831 L
s
.62475 .57479 m
.59116 .5831 L
s
.62475 .57479 m
.63914 .5831 L
s
.62475 .57479 m
.63434 .59141 L
s
.62475 .57479 m
.60076 .59972 L
s
.64394 .57479 m
.63914 .5831 L
s
.64394 .57479 m
.65833 .5831 L
s
.07298 .5831 m
.08258 .5831 L
s
.07298 .5831 m
.07298 .59972 L
s
.07298 .5831 m
.05859 .64128 L
s
.08258 .5831 m
.14495 .59141 L
s
.08258 .5831 m
.07298 .59972 L
s
.38005 .5831 m
.38485 .59141 L
s
.38005 .5831 m
.35606 .60803 L
s
.5048 .5831 m
.4952 .59972 L
s
.5048 .5831 m
.52399 .59972 L
s
.5048 .5831 m
.5096 .60803 L
s
.56237 .5831 m
.57197 .5831 L
s
.56237 .5831 m
.54798 .59141 L
s
.56237 .5831 m
.56237 .61634 L
s
.56237 .5831 m
.57197 .61634 L
s
.57197 .5831 m
.59116 .5831 L
s
.57197 .5831 m
.60076 .59972 L
s
.57197 .5831 m
.57197 .61634 L
s
.59116 .5831 m
.60076 .59972 L
s
.63914 .5831 m
.65833 .5831 L
s
.63914 .5831 m
.63434 .59141 L
s
.65833 .5831 m
.68712 .5831 L
s
.65833 .5831 m
.63434 .59141 L
s
.65833 .5831 m
.68712 .61634 L
s
.65833 .5831 m
.64874 .63297 L
s
.68712 .5831 m
.71111 .59141 L
s
.68712 .5831 m
.68712 .61634 L
s
.68712 .5831 m
.69672 .61634 L
s
.14495 .59141 m
.07298 .59972 L
s
.14495 .59141 m
.15934 .61634 L
s
.38485 .59141 m
.44722 .59972 L
s
.38485 .59141 m
.35606 .60803 L
s
.38485 .59141 m
.38485 .60803 L
s
.47121 .59141 m
.44722 .59972 L
s
.47121 .59141 m
.4952 .59972 L
s
.47121 .59141 m
.48081 .60803 L
s
.47121 .59141 m
.45682 .61634 L
s
.54798 .59141 m
.53359 .59972 L
s
.54798 .59141 m
.53838 .60803 L
s
.54798 .59141 m
.56237 .61634 L
s
.63434 .59141 m
.60076 .59972 L
s
.63434 .59141 m
.61035 .63297 L
s
.63434 .59141 m
.64874 .63297 L
s
.71111 .59141 m
.71591 .59972 L
s
.71111 .59141 m
.69672 .61634 L
s
.07298 .59972 m
.15934 .61634 L
s
.07298 .59972 m
.05859 .64128 L
s
.44722 .59972 m
.38485 .60803 L
s
.44722 .59972 m
.45682 .61634 L
s
.44722 .59972 m
.45202 .62466 L
s
.44722 .59972 m
.41843 .63297 L
s
.4952 .59972 m
.48081 .60803 L
s
.4952 .59972 m
.5 .60803 L
s
.4952 .59972 m
.5096 .60803 L
s
.52399 .59972 m
.53359 .59972 L
s
.52399 .59972 m
.5096 .60803 L
s
.52399 .59972 m
.53359 .61634 L
s
.53359 .59972 m
.53838 .60803 L
s
.53359 .59972 m
.53359 .61634 L
s
.60076 .59972 m
.57197 .61634 L
s
.60076 .59972 m
.61035 .63297 L
s
.71591 .59972 m
.69672 .61634 L
s
.71591 .59972 m
.70152 .62466 L
s
.71591 .59972 m
.77828 .6579 L
s
.23131 .60803 m
.24091 .60803 L
s
.23131 .60803 m
.15934 .61634 L
s
.23131 .60803 m
.2553 .61634 L
s
.23131 .60803 m
.18813 .64959 L
s
.23131 .60803 m
.23131 .67452 L
s
.24091 .60803 m
.2553 .61634 L
s
.35606 .60803 m
.38485 .60803 L
s
.35606 .60803 m
.34646 .62466 L
s
.35606 .60803 m
.35606 .62466 L
s
.38485 .60803 m
.35606 .62466 L
s
.38485 .60803 m
.38485 .62466 L
s
.38485 .60803 m
.41843 .63297 L
s
.48081 .60803 m
.5 .60803 L
s
.48081 .60803 m
.45682 .61634 L
s
.48081 .60803 m
.48081 .62466 L
s
.5 .60803 m
.5096 .60803 L
s
.5 .60803 m
.5048 .61634 L
s
.5 .60803 m
.48081 .62466 L
s
.5096 .60803 m
.5048 .61634 L
s
.5096 .60803 m
.53359 .61634 L
s
.53838 .60803 m
.53359 .61634 L
s
.53838 .60803 m
.56237 .61634 L
s
.15934 .61634 m
.05859 .64128 L
s
.15934 .61634 m
.16414 .64128 L
s
.15934 .61634 m
.18813 .64959 L
s
.2553 .61634 m
.29369 .61634 L
s
.2553 .61634 m
.27929 .62466 L
s
.2553 .61634 m
.2697 .64128 L
s
.2553 .61634 m
.23131 .67452 L
s
.29369 .61634 m
.27929 .62466 L
s
.29369 .61634 m
.34646 .62466 L
s
.29369 .61634 m
.33207 .64959 L
s
.29369 .61634 m
.32247 .66621 L
s
.45682 .61634 m
.45202 .62466 L
s
.45682 .61634 m
.48081 .62466 L
s
.45682 .61634 m
.45682 .63297 L
s
.5048 .61634 m
.53359 .61634 L
s
.5048 .61634 m
.48081 .62466 L
s
.5048 .61634 m
.5048 .66621 L
s
.53359 .61634 m
.56237 .61634 L
s
.53359 .61634 m
.56237 .64959 L
s
.53359 .61634 m
.5048 .66621 L
s
.53359 .61634 m
.51919 .67452 L
s
.56237 .61634 m
.57197 .61634 L
s
.56237 .61634 m
.56237 .64959 L
s
.57197 .61634 m
.61035 .63297 L
s
.57197 .61634 m
.56237 .64959 L
s
.68712 .61634 m
.69672 .61634 L
s
.68712 .61634 m
.70152 .62466 L
s
.68712 .61634 m
.64874 .63297 L
s
.68712 .61634 m
.67753 .63297 L
s
.69672 .61634 m
.70152 .62466 L
s
.27929 .62466 m
.2697 .64128 L
s
.27929 .62466 m
.32247 .66621 L
s
.34646 .62466 m
.35606 .62466 L
s
.34646 .62466 m
.35126 .63297 L
s
.34646 .62466 m
.33207 .64959 L
s
.35606 .62466 m
.38485 .62466 L
s
.35606 .62466 m
.35126 .63297 L
s
.38485 .62466 m
.35126 .63297 L
s
.38485 .62466 m
.41843 .63297 L
s
.38485 .62466 m
.40884 .64959 L
s
.38485 .62466 m
.39924 .66621 L
s
.45202 .62466 m
.41843 .63297 L
s
.45202 .62466 m
.45682 .63297 L
s
.45202 .62466 m
.42803 .64959 L
s
.48081 .62466 m
.45682 .63297 L
s
.48081 .62466 m
.47601 .66621 L
s
.48081 .62466 m
.48561 .66621 L
s
.48081 .62466 m
.5048 .66621 L
s
.70152 .62466 m
.67753 .63297 L
s
.70152 .62466 m
.69672 .64959 L
s
.70152 .62466 m
.77828 .6579 L
s
.35126 .63297 m
.33207 .64959 L
s
.35126 .63297 m
.34167 .66621 L
s
.35126 .63297 m
.39924 .66621 L
s
.41843 .63297 m
.40884 .64959 L
s
.41843 .63297 m
.42803 .64959 L
s
.45682 .63297 m
.42803 .64959 L
s
.45682 .63297 m
.44242 .6579 L
s
.45682 .63297 m
.47601 .66621 L
s
.61035 .63297 m
.64874 .63297 L
s
.61035 .63297 m
.56237 .64959 L
s
.61035 .63297 m
.56717 .6579 L
s
.61035 .63297 m
.61515 .6579 L
s
.61035 .63297 m
.62475 .6579 L
s
.61035 .63297 m
.57197 .66621 L
s
.64874 .63297 m
.67753 .63297 L
s
.64874 .63297 m
.66313 .64128 L
s
.64874 .63297 m
.62475 .6579 L
s
.64874 .63297 m
.64394 .67452 L
s
.67753 .63297 m
.66313 .64128 L
s
.67753 .63297 m
.69672 .64959 L
s
.05859 .64128 m
.16414 .64128 L
s
.05859 .64128 m
.14015 .69945 L
s
.05859 .64128 m
.07778 .70776 L
s
.16414 .64128 m
.18813 .64959 L
s
.16414 .64128 m
.14015 .69945 L
s
.2697 .64128 m
.32247 .66621 L
s
.2697 .64128 m
.23131 .67452 L
s
.2697 .64128 m
.30328 .68283 L
s
.2697 .64128 m
.2697 .69114 L
s
.66313 .64128 m
.69672 .64959 L
s
.66313 .64128 m
.64394 .67452 L
s
.18813 .64959 m
.23131 .67452 L
s
.18813 .64959 m
.14015 .69945 L
s
.18813 .64959 m
.18813 .73269 L
s
.33207 .64959 m
.32247 .66621 L
s
.33207 .64959 m
.34167 .66621 L
s
.40884 .64959 m
.42803 .64959 L
s
.40884 .64959 m
.42323 .6579 L
s
.40884 .64959 m
.39924 .66621 L
s
.40884 .64959 m
.40884 .66621 L
s
.40884 .64959 m
.41843 .66621 L
s
.42803 .64959 m
.42323 .6579 L
s
.42803 .64959 m
.44242 .6579 L
s
.56237 .64959 m
.56717 .6579 L
s
.56237 .64959 m
.51919 .67452 L
s
.69672 .64959 m
.77828 .6579 L
s
.69672 .64959 m
.64394 .67452 L
s
.69672 .64959 m
.71111 .69114 L
s
.69672 .64959 m
.72071 .69114 L
s
.42323 .6579 m
.44242 .6579 L
s
.42323 .6579 m
.41843 .66621 L
s
.44242 .6579 m
.41843 .66621 L
s
.44242 .6579 m
.47601 .66621 L
s
.44242 .6579 m
.46641 .68283 L
s
.44242 .6579 m
.45682 .69945 L
s
.44242 .6579 m
.43283 .70776 L
s
.56717 .6579 m
.57197 .66621 L
s
.56717 .6579 m
.51919 .67452 L
s
.61515 .6579 m
.62475 .6579 L
s
.61515 .6579 m
.57197 .66621 L
s
.61515 .6579 m
.60076 .68283 L
s
.62475 .6579 m
.64394 .67452 L
s
.62475 .6579 m
.60076 .68283 L
s
.77828 .6579 m
.81667 .67452 L
s
.77828 .6579 m
.72071 .69114 L
s
.77828 .6579 m
.75909 .70776 L
s
.32247 .66621 m
.34167 .66621 L
s
.32247 .66621 m
.33687 .67452 L
s
.32247 .66621 m
.30328 .68283 L
s
.32247 .66621 m
.33207 .68283 L
s
.34167 .66621 m
.39924 .66621 L
s
.34167 .66621 m
.33687 .67452 L
s
.34167 .66621 m
.34646 .69114 L
s
.39924 .66621 m
.40884 .66621 L
s
.39924 .66621 m
.34646 .69114 L
s
.39924 .66621 m
.40404 .70776 L
s
.40884 .66621 m
.41843 .66621 L
s
.40884 .66621 m
.40404 .70776 L
s
.41843 .66621 m
.40404 .70776 L
s
.41843 .66621 m
.43283 .70776 L
s
.47601 .66621 m
.48561 .66621 L
s
.47601 .66621 m
.46641 .68283 L
s
.48561 .66621 m
.5048 .66621 L
s
.48561 .66621 m
.5 .67452 L
s
.48561 .66621 m
.46641 .68283 L
s
.48561 .66621 m
.47601 .69945 L
s
.5048 .66621 m
.5 .67452 L
s
.5048 .66621 m
.51919 .67452 L
s
.57197 .66621 m
.51919 .67452 L
s
.57197 .66621 m
.60076 .68283 L
s
.57197 .66621 m
.53359 .69945 L
s
.57197 .66621 m
.58157 .69945 L
s
.57197 .66621 m
.55758 .70776 L
s
.94621 .66621 m
.87424 .67452 L
s
.94621 .66621 m
.88864 .73269 L
s
.94621 .66621 m
.78308 .86566 L
s
.23131 .67452 m
.2697 .69114 L
s
.23131 .67452 m
.24091 .70776 L
s
.23131 .67452 m
.18813 .73269 L
s
.33687 .67452 m
.33207 .68283 L
s
.33687 .67452 m
.34646 .69114 L
s
.5 .67452 m
.51919 .67452 L
s
.5 .67452 m
.51919 .69114 L
s
.5 .67452 m
.47601 .69945 L
s
.5 .67452 m
.5048 .69945 L
s
.51919 .67452 m
.51919 .69114 L
s
.51919 .67452 m
.53359 .69945 L
s
.64394 .67452 m
.60076 .68283 L
s
.64394 .67452 m
.64394 .69114 L
s
.64394 .67452 m
.71111 .69114 L
s
.64394 .67452 m
.61035 .69945 L
s
.81667 .67452 m
.87424 .67452 L
s
.81667 .67452 m
.75909 .70776 L
s
.81667 .67452 m
.84545 .72438 L
s
.81667 .67452 m
.82146 .73269 L
s
.87424 .67452 m
.84545 .72438 L
s
.87424 .67452 m
.88864 .73269 L
s
.30328 .68283 m
.33207 .68283 L
s
.30328 .68283 m
.2697 .69114 L
s
.30328 .68283 m
.32727 .70776 L
s
.30328 .68283 m
.29369 .71607 L
s
.33207 .68283 m
.34646 .69114 L
s
.33207 .68283 m
.32727 .70776 L
s
.46641 .68283 m
.45682 .69945 L
s
.46641 .68283 m
.47601 .69945 L
s
.60076 .68283 m
.58157 .69945 L
s
.60076 .68283 m
.61035 .69945 L
s
.2697 .69114 m
.24091 .70776 L
s
.2697 .69114 m
.29369 .71607 L
s
.34646 .69114 m
.32727 .70776 L
s
.34646 .69114 m
.40404 .70776 L
s
.34646 .69114 m
.37525 .72438 L
s
.51919 .69114 m
.5048 .69945 L
s
.51919 .69114 m
.53359 .69945 L
s
.51919 .69114 m
.52399 .71607 L
s
.64394 .69114 m
.71111 .69114 L
s
.64394 .69114 m
.61035 .69945 L
s
.64394 .69114 m
.70152 .70776 L
s
.64394 .69114 m
.62955 .71607 L
s
.71111 .69114 m
.72071 .69114 L
s
.71111 .69114 m
.70152 .70776 L
s
.72071 .69114 m
.70152 .70776 L
s
.72071 .69114 m
.75909 .70776 L
s
.72071 .69114 m
.7447 .71607 L
s
.14015 .69945 m
.07778 .70776 L
s
.14015 .69945 m
.12096 .71607 L
s
.14015 .69945 m
.13535 .72438 L
s
.14015 .69945 m
.18813 .73269 L
s
.14015 .69945 m
.15455 .741 L
s
.45682 .69945 m
.47601 .69945 L
s
.45682 .69945 m
.43283 .70776 L
s
.45682 .69945 m
.47121 .70776 L
s
.45682 .69945 m
.45682 .71607 L
s
.47601 .69945 m
.5048 .69945 L
s
.47601 .69945 m
.47121 .70776 L
s
.47601 .69945 m
.48561 .71607 L
s
.5048 .69945 m
.48561 .71607 L
s
.5048 .69945 m
.52399 .71607 L
s
.53359 .69945 m
.54798 .70776 L
s
.53359 .69945 m
.55758 .70776 L
s
.53359 .69945 m
.52399 .71607 L
s
.58157 .69945 m
.61035 .69945 L
s
.58157 .69945 m
.55758 .70776 L
s
.58157 .69945 m
.57677 .70776 L
s
.61035 .69945 m
.57677 .70776 L
s
.61035 .69945 m
.62955 .71607 L
s
.61035 .69945 m
.58157 .73269 L
s
.07778 .70776 m
.12096 .71607 L
s
.07778 .70776 m
.13535 .72438 L
s
.07778 .70776 m
.15455 .741 L
s
.07778 .70776 m
.18813 .84903 L
s
.24091 .70776 m
.29369 .71607 L
s
.24091 .70776 m
.18813 .73269 L
s
.24091 .70776 m
.22652 .73269 L
s
.24091 .70776 m
.23611 .74931 L
s
.24091 .70776 m
.27449 .74931 L
s
.32727 .70776 m
.29369 .71607 L
s
.32727 .70776 m
.37525 .72438 L
s
.32727 .70776 m
.32727 .741 L
s
.40404 .70776 m
.43283 .70776 L
s
.40404 .70776 m
.37525 .72438 L
s
.40404 .70776 m
.40404 .72438 L
s
.40404 .70776 m
.38965 .73269 L
s
.43283 .70776 m
.45682 .71607 L
s
.43283 .70776 m
.40404 .72438 L
s
.43283 .70776 m
.40884 .73269 L
s
.43283 .70776 m
.43283 .75762 L
s
.47121 .70776 m
.45682 .71607 L
s
.47121 .70776 m
.48561 .71607 L
s
.47121 .70776 m
.48081 .72438 L
s
.54798 .70776 m
.55758 .70776 L
s
.54798 .70776 m
.52399 .71607 L
s
.54798 .70776 m
.58157 .73269 L
s
.55758 .70776 m
.57677 .70776 L
s
.55758 .70776 m
.58157 .73269 L
s
.57677 .70776 m
.58157 .73269 L
s
.70152 .70776 m
.62955 .71607 L
s
.70152 .70776 m
.7447 .71607 L
s
.70152 .70776 m
.70631 .74931 L
s
.70152 .70776 m
.67273 .75762 L
s
.75909 .70776 m
.7447 .71607 L
s
.75909 .70776 m
.82146 .73269 L
s
.75909 .70776 m
.7351 .76593 L
s
.75909 .70776 m
.7399 .77424 L
s
.12096 .71607 m
.13535 .72438 L
s
.29369 .71607 m
.32727 .741 L
s
.29369 .71607 m
.27449 .74931 L
s
.29369 .71607 m
.30808 .75762 L
s
.45682 .71607 m
.48081 .72438 L
s
.45682 .71607 m
.43283 .75762 L
s
.45682 .71607 m
.48081 .75762 L
s
.48561 .71607 m
.52399 .71607 L
s
.48561 .71607 m
.48081 .72438 L
s
.52399 .71607 m
.48081 .72438 L
s
.52399 .71607 m
.58157 .73269 L
s
.52399 .71607 m
.51439 .76593 L
s
.62955 .71607 m
.58157 .73269 L
s
.62955 .71607 m
.59596 .75762 L
s
.62955 .71607 m
.67273 .75762 L
s
.7447 .71607 m
.70631 .74931 L
s
.7447 .71607 m
.7351 .76593 L
s
.13535 .72438 m
.15455 .741 L
s
.37525 .72438 m
.38965 .73269 L
s
.37525 .72438 m
.32727 .741 L
s
.37525 .72438 m
.37525 .741 L
s
.40404 .72438 m
.38965 .73269 L
s
.40404 .72438 m
.40884 .73269 L
s
.48081 .72438 m
.48081 .75762 L
s
.48081 .72438 m
.51439 .76593 L
s
.84545 .72438 m
.82146 .73269 L
s
.84545 .72438 m
.88864 .73269 L
s
.84545 .72438 m
.85505 .741 L
s
.18813 .73269 m
.22652 .73269 L
s
.18813 .73269 m
.15455 .741 L
s
.18813 .73269 m
.19773 .76593 L
s
.22652 .73269 m
.23611 .74931 L
s
.22652 .73269 m
.19773 .76593 L
s
.22652 .73269 m
.21692 .76593 L
s
.38965 .73269 m
.40884 .73269 L
s
.38965 .73269 m
.37525 .741 L
s
.38965 .73269 m
.38485 .77424 L
s
.40884 .73269 m
.43283 .75762 L
s
.40884 .73269 m
.38485 .77424 L
s
.58157 .73269 m
.59596 .75762 L
s
.58157 .73269 m
.51439 .76593 L
s
.58157 .73269 m
.58157 .76593 L
s
.82146 .73269 m
.85505 .741 L
s
.82146 .73269 m
.7399 .77424 L
s
.82146 .73269 m
.83106 .78255 L
s
.88864 .73269 m
.85505 .741 L
s
.88864 .73269 m
.83106 .78255 L
s
.88864 .73269 m
.78308 .86566 L
s
.15455 .741 m
.19773 .76593 L
s
.15455 .741 m
.20732 .79917 L
s
.15455 .741 m
.20253 .8241 L
s
.15455 .741 m
.18813 .84903 L
s
.32727 .741 m
.37525 .741 L
s
.32727 .741 m
.30808 .75762 L
s
.32727 .741 m
.33687 .75762 L
s
.37525 .741 m
.33687 .75762 L
s
.37525 .741 m
.38485 .77424 L
s
.85505 .741 m
.83106 .78255 L
s
.23611 .74931 m
.27449 .74931 L
s
.23611 .74931 m
.25051 .75762 L
s
.23611 .74931 m
.21692 .76593 L
s
.23611 .74931 m
.23131 .77424 L
s
.27449 .74931 m
.25051 .75762 L
s
.27449 .74931 m
.30808 .75762 L
s
.27449 .74931 m
.28409 .81579 L
s
.70631 .74931 m
.67273 .75762 L
s
.70631 .74931 m
.7351 .76593 L
s
.70631 .74931 m
.7399 .80748 L
s
.25051 .75762 m
.23131 .77424 L
s
.25051 .75762 m
.28409 .81579 L
s
.30808 .75762 m
.33687 .75762 L
s
.30808 .75762 m
.33687 .77424 L
s
.30808 .75762 m
.31768 .80748 L
s
.30808 .75762 m
.28409 .81579 L
s
.33687 .75762 m
.33687 .77424 L
s
.33687 .75762 m
.38485 .77424 L
s
.43283 .75762 m
.48081 .75762 L
s
.43283 .75762 m
.43763 .76593 L
s
.43283 .75762 m
.38485 .77424 L
s
.43283 .75762 m
.41364 .79086 L
s
.48081 .75762 m
.43763 .76593 L
s
.48081 .75762 m
.48561 .76593 L
s
.48081 .75762 m
.51439 .76593 L
s
.48081 .75762 m
.46641 .78255 L
s
.59596 .75762 m
.67273 .75762 L
s
.59596 .75762 m
.58157 .76593 L
s
.59596 .75762 m
.60076 .83241 L
s
.59596 .75762 m
.66793 .83241 L
s
.67273 .75762 m
.7399 .80748 L
s
.67273 .75762 m
.66793 .83241 L
s
.19773 .76593 m
.21692 .76593 L
s
.19773 .76593 m
.22172 .77424 L
s
.19773 .76593 m
.20732 .79917 L
s
.21692 .76593 m
.22172 .77424 L
s
.21692 .76593 m
.23131 .77424 L
s
.43763 .76593 m
.46641 .78255 L
s
.43763 .76593 m
.41364 .79086 L
s
.43763 .76593 m
.45202 .79086 L
s
.48561 .76593 m
.51439 .76593 L
s
.48561 .76593 m
.46641 .78255 L
s
.48561 .76593 m
.5 .79086 L
s
.51439 .76593 m
.58157 .76593 L
s
.51439 .76593 m
.5 .79086 L
s
.51439 .76593 m
.53838 .84072 L
s
.58157 .76593 m
.60076 .83241 L
s
.58157 .76593 m
.53838 .84072 L
s
.7351 .76593 m
.7399 .77424 L
s
.7351 .76593 m
.7399 .80748 L
s
.22172 .77424 m
.23131 .77424 L
s
.22172 .77424 m
.20732 .79917 L
s
.23131 .77424 m
.20732 .79917 L
s
.23131 .77424 m
.28409 .81579 L
s
.23131 .77424 m
.22652 .83241 L
s
.33687 .77424 m
.38485 .77424 L
s
.33687 .77424 m
.39444 .79086 L
s
.33687 .77424 m
.31768 .80748 L
s
.33687 .77424 m
.38005 .83241 L
s
.38485 .77424 m
.39444 .79086 L
s
.38485 .77424 m
.41364 .79086 L
s
.7399 .77424 m
.83106 .78255 L
s
.7399 .77424 m
.7399 .80748 L
s
.7399 .77424 m
.75909 .8241 L
s
.46641 .78255 m
.45202 .79086 L
s
.46641 .78255 m
.5 .79086 L
s
.46641 .78255 m
.46162 .80748 L
s
.46641 .78255 m
.47121 .80748 L
s
.83106 .78255 m
.75909 .8241 L
s
.83106 .78255 m
.77348 .83241 L
s
.83106 .78255 m
.78308 .86566 L
s
.39444 .79086 m
.41364 .79086 L
s
.39444 .79086 m
.40884 .79917 L
s
.39444 .79086 m
.38005 .83241 L
s
.39444 .79086 m
.38965 .83241 L
s
.41364 .79086 m
.45202 .79086 L
s
.41364 .79086 m
.40884 .79917 L
s
.45202 .79086 m
.40884 .79917 L
s
.45202 .79086 m
.46162 .80748 L
s
.5 .79086 m
.47121 .80748 L
s
.5 .79086 m
.48561 .83241 L
s
.5 .79086 m
.53838 .84072 L
s
.20732 .79917 m
.20253 .8241 L
s
.20732 .79917 m
.22652 .83241 L
s
.40884 .79917 m
.46162 .80748 L
s
.40884 .79917 m
.38965 .83241 L
s
.40884 .79917 m
.39924 .84903 L
s
.40884 .79917 m
.43763 .84903 L
s
.31768 .80748 m
.28409 .81579 L
s
.31768 .80748 m
.38005 .83241 L
s
.31768 .80748 m
.28889 .85734 L
s
.31768 .80748 m
.31288 .86566 L
s
.46162 .80748 m
.47121 .80748 L
s
.46162 .80748 m
.48561 .83241 L
s
.46162 .80748 m
.43763 .84903 L
s
.47121 .80748 m
.48561 .83241 L
s
.7399 .80748 m
.75909 .8241 L
s
.7399 .80748 m
.66793 .83241 L
s
.7399 .80748 m
.71111 .85734 L
s
.28409 .81579 m
.22652 .83241 L
s
.28409 .81579 m
.28889 .85734 L
s
.20253 .8241 m
.22652 .83241 L
s
.20253 .8241 m
.18813 .84903 L
s
.20253 .8241 m
.22652 .84903 L
s
.75909 .8241 m
.77348 .83241 L
s
.75909 .8241 m
.71111 .85734 L
s
.75909 .8241 m
.78308 .86566 L
s
.22652 .83241 m
.22652 .84903 L
s
.22652 .83241 m
.28889 .85734 L
s
.38005 .83241 m
.38965 .83241 L
s
.38005 .83241 m
.39924 .84903 L
s
.38005 .83241 m
.31288 .86566 L
s
.38965 .83241 m
.39924 .84903 L
s
.48561 .83241 m
.53838 .84072 L
s
.48561 .83241 m
.43763 .84903 L
s
.48561 .83241 m
.52879 .85734 L
s
.48561 .83241 m
.46641 .86566 L
s
.60076 .83241 m
.66793 .83241 L
s
.60076 .83241 m
.53838 .84072 L
s
.60076 .83241 m
.55758 .85734 L
s
.60076 .83241 m
.61035 .86566 L
s
.66793 .83241 m
.71111 .85734 L
s
.66793 .83241 m
.61035 .86566 L
s
.66793 .83241 m
.65833 .88228 L
s
.77348 .83241 m
.78308 .86566 L
s
.53838 .84072 m
.52879 .85734 L
s
.53838 .84072 m
.55758 .85734 L
s
.18813 .84903 m
.22652 .84903 L
s
.18813 .84903 m
.24571 .8989 L
s
.22652 .84903 m
.28889 .85734 L
s
.22652 .84903 m
.24571 .8989 L
s
.39924 .84903 m
.43763 .84903 L
s
.39924 .84903 m
.31288 .86566 L
s
.39924 .84903 m
.45202 .89059 L
s
.39924 .84903 m
.37045 .94876 L
s
.43763 .84903 m
.46641 .86566 L
s
.43763 .84903 m
.45202 .89059 L
s
.28889 .85734 m
.31288 .86566 L
s
.28889 .85734 m
.30328 .88228 L
s
.28889 .85734 m
.24571 .8989 L
s
.52879 .85734 m
.55758 .85734 L
s
.52879 .85734 m
.46641 .86566 L
s
.52879 .85734 m
.55758 .90721 L
s
.52879 .85734 m
.52399 .94876 L
s
.55758 .85734 m
.61035 .86566 L
s
.55758 .85734 m
.55758 .90721 L
s
.71111 .85734 m
.78308 .86566 L
s
.71111 .85734 m
.65833 .88228 L
s
.71111 .85734 m
.66313 .92383 L
s
.31288 .86566 m
.30328 .88228 L
s
.31288 .86566 m
.37045 .94876 L
s
.46641 .86566 m
.45202 .89059 L
s
.46641 .86566 m
.52399 .94876 L
s
.61035 .86566 m
.65833 .88228 L
s
.61035 .86566 m
.55758 .90721 L
s
.61035 .86566 m
.66313 .92383 L
s
.61035 .86566 m
.56717 .94045 L
s
.78308 .86566 m
.66313 .92383 L
s
.30328 .88228 m
.24571 .8989 L
s
.30328 .88228 m
.37045 .94876 L
s
.65833 .88228 m
.66313 .92383 L
s
.45202 .89059 m
.37045 .94876 L
s
.45202 .89059 m
.52399 .94876 L
s
.45202 .89059 m
.48081 .97369 L
s
.24571 .8989 m
.37045 .94876 L
s
.55758 .90721 m
.55758 .92383 L
s
.55758 .90721 m
.56717 .94045 L
s
.55758 .90721 m
.52399 .94876 L
s
.55758 .92383 m
.56717 .94045 L
s
.55758 .92383 m
.52399 .94876 L
s
.66313 .92383 m
.56717 .94045 L
s
.66313 .92383 m
.57197 .96538 L
s
.56717 .94045 m
.52399 .94876 L
s
.56717 .94045 m
.52879 .95707 L
s
.56717 .94045 m
.57197 .96538 L
s
.37045 .94876 m
.48081 .97369 L
s
.52399 .94876 m
.52879 .95707 L
s
.52399 .94876 m
.52399 .96538 L
s
.52399 .94876 m
.48081 .97369 L
s
.52879 .95707 m
.52399 .96538 L
s
.52879 .95707 m
.57197 .96538 L
s
.52399 .96538 m
.57197 .96538 L
s
.52399 .96538 m
.48081 .97369 L
s
.57197 .96538 m
.48081 .97369 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/1000`40O003h00Oofmk/Fmk003oKg^a
Kg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00
ofmk/Fmk003:Kg/3003SKg/00<U_N`D00>9_N`00bFmk1@00hVmk0037Kg/;003NKg/00<=_N`H00003
Kg/0000000<0009_N`D00=Y_N`00`6mk1`000Vmk00<006mkKg/00fmk00<006mkKg/00Vmk1`00eFmk
002mKg/50002Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/016mk2000dFmk002jKg/50003Kg/20000
16mk000000002Fmk00<006mkKg/01fmk2P00bfmk002fKg/60004Kg/20002Kg/50009Kg/00`00Kg]_
N`09Kg/:0038Kg/00;=_N`<00004Kg/000000004Kg/20004Kg/5000:Kg/2000<Kg/50002Kg/40034
Kg/00;1_N`<00004Kg/000000006Kg/00`00Kg]_N`03Kg/7000;Kg/00`00Kg]_N`09Kg/90002Kg/5
002oKg/00:e_N`<00004Kg/000000007Kg/20004Kg/20002Kg/30002Kg/30009Kg/00`00Kg]_N`09
Kg/30004Kg/40004Kg/4002kKg/00:U_N`@0009_N`8000Q_N`8000A_N`8000=_N`04001_Nfmk0005
Kg/20008Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/<002gKg/00:I_N`<000=_N`<000Q_N`8000A_
N`8000E_N`04001_Nfmk0007Kg/30006Kg/20008Kg/00`00Kg]_N`0;Kg/50004Kg/5002bKg/00:=_
N`<000=_N`<000Y_N`03001_Nfmk009_N`8000A_N`<000A_N`03001_Nfmk00M_N`8000I_N`03001_
Nfmk00E_N`03001_Nfmk00Y_N`/000A_N`@00:i_N`00X6mk0`000fmk0`002fmk0P000Vmk0`001Fmk
1@000fmk00<006mkKg/02Fmk0P001Fmk00<006mkKg/016mk00<006mkKg/01fmk0`000Vmk0`000Vmk
0P000Vmk1@000fmk1000ZVmk002MKg/30003Kg/3000<Kg/20002Kg/20008Kg/50003Kg/00`00Kg]_
N`0;Kg/30003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/20007Kg/00`00Kg]_N`02Kg/30004Kg/5
0002Kg/5002UKg/009U_N`@000A_N`8000e_N`80009_N`8000Q_N`L000A_N`03001_Nfmk00e_N`80
009_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000Y_N`03001_Nfmk00A_N`8000M_N`D0009_N`@0
0:5_N`00UVmk0`001Fmk0`003Fmk0P000Vmk0P001fmk0`000fmk1@000fmk00<006mkKg/03fmk2000
0Vmk0`0036mk00<006mkKg/01Vmk0P002Vmk1@0000=_N`0000000P00WFmk002CKg/30005Kg/3000?
Kg/00`00Kg]_N`020005Kg/40005Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00004fmk1`003fmk00<0
06mkKg/026mk0`0036mk2P00V6mk002@Kg/30005Kg/3000@Kg/200000fmk00000004Kg/30009Kg/0
0`00Kg]_N`04Kg/01000Kg]_N`004fmk1P004Fmk00<006mkKg/02Vmk0P003fmk2@00U6mk002<Kg/4
0006Kg/2000AKg/50003Kg/3000;Kg/00`00Kg]_N`06Kg/5000:Kg/700000fmk00000003000AKg/0
0`00Kg]_N`0<Kg/3000AKg/9002?Kg/008U_N`<000M_N`<0015_N`@000=_N`<000i_N`03001_Nfmk
00M_N`D00003Kg/0000000H000Q_N`@00003Kg/0000000m_N`03001_Nfmk00m_N`8001A_N`P008]_
N`00QVmk0`001fmk0`004fmk0`000Vmk0`0046mk00<006mkKg/026mk1P003fmk00<006mkKg/00Vmk
00<006mkKg/00P003Vmk00<006mkKg/046mk0P005fmk1`00Qfmk0023Kg/30007Kg/3000DKg/7000C
Kg/00`00Kg]_N`08Kg/5000?Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/2000<Kg/00`00Kg]_N`0B
Kg/3000IKg/70022Kg/007U_N`<000=_N`@0009_N`<000=_N`80015_N`<00003Kg/0000000<001I_
N`03001_Nfmk00M_N`800003Kg/0000000@000a_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_
Nfmk00Y_N`03001_Nfmk01A_N`80009_N`<001M_N`H000E_N`<007I_N`00N6mk1`001Fmk1`004Vmk
1`0066mk00<006mkKg/01Vmk0P001Vmk00@006mkKg/000Y_N`03001_Nfmk00M_N`03001_Nfmk00=_
N`8000Y_N`03001_Nfmk01I_N`H001]_N`X007E_N`00N6mk:P006Vmk00<006mkKg/01Fmk00<006mk
Kg/01fmk00<006mkKg/00P001fmk00<006mkKg/026mk00<006mkKg/01Fmk0P0026mk00<006mkKg/0
5fmk:P00MFmk001hKg/50007Kg/5000DKg/8000FKg/00`00Kg]_N`04Kg/2000;Kg/01000Kg]_Nfmk
0P0016mk00<006mkKg/02Vmk00<006mkKg/01Vmk0P001fmk00<006mkKg/04fmk20007fmk1P00MFmk
001hKg/50008Kg/300000fmk0000000CKg/30004Kg/3000CKg/00`00Kg]_N`02Kg/2000>Kg/00`00
Kg]_N`02Kg/4000>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0@Kg/3000016mk0000
06mk100076mk0`000Vmk0`0000=_N`000000Lfmk001gKg/00`00Kg/00003Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`02Kg/2000@Kg/00`00Kg]_N`08Kg/4000>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/0
1000Kg]_Nfmk1@003Fmk00<006mkKg/026mk0P0016mk00<006mkKg/036mk10000Vmk0P000Vmk00<0
06mkKg/00Vmk00<006mkKg/05fmk0P001Fmk00<006mkKg/00Vmk0`00LFmk001fKg/01000Kg/00000
0fmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mkKg/03Fmk00<006mkKg/036mk10002Vmk00<0
06mkKg/00P004Vmk00@006mkKg]_N`H000e_N`03001_Nfmk00U_N`8000=_N`03001_Nfmk00M_N`@0
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk01=_N`<000M_N`03001_Nfmk00A_N`80
071_N`00MFmk00<006mkKg/00P0016mk00<006mkKg/01Fmk00<006mkKg/01Fmk0P0036mk00<006mk
Kg/04Fmk0`0016mk0`0000=_N`0000005Fmk00<006mkKg/01@0000=_N`0000002fmk00<006mkKg/0
2fmk0P0000A_N`00000000A_N`<000M_N`8000A_N`03001_Nfmk00E_N`03001_Nfmk011_N`8000Y_
N`03001_Nfmk00E_N`<006i_N`00M6mk00<006mkKg/00P001Vmk00<006mkKg/016mk00<006mkKg/0
1fmk0P002Vmk00<006mkKg/056mk200066mk00<006mkKg/00`0016mk0P002Vmk00<006mkKg/036mk
200026mk0P001Vmk00<006mkKg/01Fmk00<006mkKg/03Vmk0P0036mk00<006mkKg/01fmk0`00K6mk
001cKg/01000Kg]_Nfmk0P001fmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/01Vmk00<0
06mkKg/05fmk1`0066mk00@006mkKg/000M_N`8000U_N`03001_Nfmk00]_N`D000Y_N`03001_Nfmk
00E_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`<000i_N`03001_Nfmk00Q_N`<006]_N`00LVmk00L0
06mkKg]_N`00Kg/00008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/20006Kg/00`00Kg]_N`0?Kg/8
00000fmk0000000300000fmk00000006000AKg/00`00Kg/00009Kg/20007Kg/00`00Kg]_N`0;Kg/5
0008Kg/20007Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/2000AKg/00`00Kg]_N`0:Kg/3001YKg/0
075_N`03001_Nfmk009_N`8000Y_N`05001_NfmkKg/0000>Kg/2000016mk000000002Vmk20002Vmk
10002Fmk20002Fmk10002Vmk0P001Vmk00<006mkKg/026mk0P0000M_N`00000006mk001_N`030000
0fmk00000009Kg/00`00Kg]_N`0:Kg/40002Kg/3000BKg/00`00Kg]_N`0<Kg/4001WKg/006m_N`80
00A_N`03001_N`0000]_N`04001_Nfmk000@Kg/500000fmk00000006000BKg/01@00Kg/006mk0000
46mk200000=_N`0000000`002fmk0P001Fmk00<006mkKg/01Vmk00<006mkKg/01Vmk1@002Vmk00<0
06mkKg/02fmk1P005Fmk00<006mkKg/03Vmk00@006mk000006E_N`00KVmk0P001Fmk00<006mk0000
2fmk00@006mkKg/000m_N`L001Y_N`05001_N`00001_N`02000FKg/7000<Kg/20003Kg/00`00Kg]_
N`04Kg/20009Kg/5000:Kg/00`00Kg]_N`0;Kg/5000FKg/00`00Kg]_N`0?Kg/200000fmk001_N`1S
Kg/006e_N`8000E_N`@000a_N`@000Q_N`H00003Kg/0000000<001Y_N`03001_Nfmk008000=_N`03
001_Nfmk01A_N`D00003Kg/0000000H000I_N`80009_N`<00003Kg/0000000E_N`h000A_N`<000Q_
N`/001I_N`03001_Nfmk015_N`03001_N`000080065_N`00K6mk0P001Vmk1@002fmk1@0000=_N`00
0000100026mk0`006fmk00D006mkKg]_N`0000A_N`03001_Nfmk01A_N`<000Y_N`h00003Kg/00000
00@000M_N`<000A_N`P00003Kg/0000000@000M_N`<001M_N`03001_Nfmk019_N`D0061_N`00Jfmk
0P001Vmk5`003fmk00<006mk00006Vmk00@006mkKg]_N`8000A_N`03001_Nfmk01=_N`8001=_N`L0
00e_N`03001_N`0000M_N`H000e_N`03001_N`0001I_N`03001_Nfmk01=_N`H005m_N`00JVmk0P00
1fmk1P002fmk1@0046mk00<006mk00006Fmk00<006mkKg/00Vmk0P001Fmk00<006mkKg/04Vmk0P00
56mk1@003Vmk00<006mk00001fmk1@003Vmk00@006mkKg/001E_N`03001_Nfmk01=_N`P005e_N`00
JFmk0P001fmk00<006mkKg/00`003Fmk0`004Fmk00@006mkKg/001Q_N`03001_Nfmk009_N`03001_
N`0000E_N`03001_Nfmk011_N`800003Kg/006mk015_N`H000e_N`04001_Nfmk0008Kg/3000?Kg/0
1000Kg]_N`005Fmk00<006mkKg/04fmk10000Vmk100000A_N`00000005M_N`00J6mk0P0026mk00@0
06mk001_N`8000i_N`03001_N`00011_N`05001_NfmkKg/0000GKg/00`00Kg]_N`03Kg/20006Kg/0
0`00Kg]_N`0?Kg/200000fmk001_N`0@Kg/20004Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0026mk00<0
06mk00003fmk00@006mkKg/001E_N`03001_Nfmk01=_N`80009_N`03001_Nfmk009_N`H005I_N`00
Ifmk0P002Fmk00L006mk001_N`00Kg/0000=Kg/01000Kg]_N`003fmk00D006mkKg]_N`0001I_N`03
001_Nfmk00A_N`03001_N`0000I_N`8000m_N`800003Kg/006mk00i_N`<000I_N`03001_Nfmk00Y_
N`04001_Nfmk0007Kg/01@00Kg]_Nfmk00003Vmk00D006mkKg]_N`0001A_N`03001_Nfmk019_N`03
001_N`00009_N`03001_Nfmk00=_N`D005I_N`00IVmk00<006mk000026mk00<006mk00000Vmk00<0
06mk00003Fmk00D006mkKg]_N`0000i_N`03001_Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk00A_
N`03001_N`0000Q_N`03001_Nfmk00]_N`05001_N`00Kg/0000>Kg/00`00Kg/00008Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/00Vmk00<0
06mkKg/04Fmk00<006mkKg/04Vmk00<006mk000016mk00<006mkKg/00Vmk1@00EVmk001UKg/00`00
Kg/00009Kg/20003Kg/01000Kg]_N`0036mk00D006mkKg]_N`0000m_N`05001_NfmkKg/0000EKg/0
0`00Kg]_N`05Kg/20009Kg/00`00Kg]_N`0:Kg/01@00Kg/006mk000036mk0P0000=_N`00Kg/02Fmk
00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/016mk00D006mkKg]_N`0000e_N`03001_Nfmk
00=_N`03001_Nfmk011_N`03001_Nfmk015_N`04001_Nfmk0004Kg/00`00Kg]_N`03Kg/4001FKg/0
06A_N`03001_N`0000U_N`03001_N`0000=_N`04001_Nfmk000<Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/00`00Kg]_N`06Kg/00`00Kg/00009Kg/00`00Kg]_
N`09Kg/01@00Kg/006mk00002fmk00@006mkKg/000a_N`03001_Nfmk00I_N`03001_Nfmk009_N`03
001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk011_N`03
001_Nfmk015_N`04001_Nfmk0005Kg/00`00Kg]_N`04Kg/00`00Kg/0001EKg/006=_N`03001_N`00
00Y_N`8000A_N`04001_Nfmk000;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0@Kg/00`00Kg]_N`06Kg/00`00Kg/0000:Kg/00`00Kg]_N`07Kg/01P00Kg]_N`00Kg/0
00Y_N`04001_Nfmk000=Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0@Kg/01000Kg]_
N`001Vmk00<006mkKg/016mk00@006mkKg/005A_N`00HVmk00<006mk00002Vmk0P001Vmk00@006mk
Kg/000Y_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk011_N`03001_
Nfmk00I_N`04001_Nfmk000:Kg/00`00Kg]_N`06Kg/01P00Kg]_N`00Kg/000Q_N`800003Kg/00000
00m_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk
00U_N`03001_Nfmk00A_N`03001_Nfmk00m_N`03001_Nfmk00m_N`05001_NfmkKg/00007Kg/00`00
Kg]_N`03Kg/01000Kg]_N`00E6mk001QKg/00`00Kg/0000;Kg/20006Kg/01000Kg]_N`002Vmk00<0
06mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/03Vmk00<006mkKg/026mk00<0
06mk00002fmk00<006mkKg/01Fmk00H006mkKg/006mk0007Kg/01000Kg]_N`004Vmk00<006mkKg/0
0fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/0
16mk00<006mkKg/03fmk00<006mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/0
0Vmk00D006mkKg]_N`0005=_N`00H6mk00<006mk00002fmk0P001fmk00D006mkKg]_N`0000U_N`03
001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00A_N`03001_Nfmk00i_N`03001_Nfmk00Q_N`03
001_N`0000a_N`8000A_N`04001_Nfmk0003Kg/00`00Kg]_N`02Kg/20002Kg/00`00Kg]_N`0BKg/0
1@00Kg]_Nfmk00001fmk00D006mkKg]_N`0000Q_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_
Nfmk00e_N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk051_N`00Gfmk00<006mk000036mk0P001fmk00D006mkKg]_N`0000U_N`03
001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk00e_N`03001_Nfmk00Q_N`04
001_Nfmk000=Kg/01@00Kg]_Nfmk00000Vmk00D006mkKg]_N`0000=_N`05001_NfmkKg/0000FKg/0
1000Kg]_N`001fmk00@006mkKg/000U_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00e_
N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk009_
N`03001_Nfmk04m_N`00GVmk00<006mk000036mk0P0026mk00<006mkKg/00Vmk00<006mkKg/01Vmk
00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/036mk00<006mkKg/02Vmk
00<006mk00003Vmk100000E_N`00000006mk00<00003Kg/006mk009_N`03001_Nfmk01E_N`@000M_
N`04001_Nfmk0009Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0=
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`1>
Kg/005e_N`03001_N`0000e_N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_
Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00]_N`03001_Nfmk00Y_N`04001_
Nfmk000=Kg/=0003Kg/00`00Kg]_N`0FKg/50006Kg/01000Kg]_N`002Vmk00<006mkKg/01Vmk00<0
06mkKg/01fmk00<006mkKg/036mk00<006mkKg/036mk00<006mkKg/016mk00<006mkKg/02Fmk00D0
06mkKg]_N`0000I_N`03001_Nfmk04e_N`00G6mk00<006mk00003Fmk0P002Fmk00<006mkKg/00fmk
00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/02Vmk
00<006mkKg/02Vmk00@006mkKg/000e_N`d0009_N`03001_Nfmk01A_N`P000I_N`03001_N`0000]_
N`03001_Nfmk00I_N`03001_Nfmk00M_N`03001_Nfmk00a_N`03001_Nfmk00]_N`03001_Nfmk00A_
N`03001_Nfmk00Y_N`05001_NfmkKg/00007Kg/00`00Kg]_N`1<Kg/005Y_N`800003Kg/006mk00]_
N`<000Y_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_
Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk00]_N`05001_NfmkKg/0000<Kg/?000=Kg/:0003Kg/7
0004Kg/3000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0026mk00<006mkKg/0Bfmk001IKg/01000Kg]_
N`0036mk1@002Fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/01Fmk
00<006mkKg/026mk00<006mkKg/026mk00<006mkKg/036mk00@006mkKg/000Y_N`800005Kg/00000
001_N`0300000fmk000000040003Kg/:000<Kg/00`00Kg/000030002Kg/8000;Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<
Kg/00`00Kg/00008Kg/00`00Kg]_N`1;Kg/005Q_N`04001_Nfmk000=Kg/50009Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`0<Kg/01000Kg]_N`0026mk0P0016mk0P000Vmk00@006mkKg]_N`P001E_N`05001_
NfmkKg/00002Kg/00`00Kg]_N`02Kg/5000;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/01000Kg]_N`0026mk00<006mk
Kg/0BVmk001GKg/01000Kg]_N`003Vmk1@002Fmk00<006mkKg/016mk00<006mkKg/016mk00<006mk
Kg/036mk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/01Vmk00<006mkKg/03Fmk00D006mk
Kg]_N`0000E_N`8000I_N`80009_N`04001_NfmkKg/5000FKg/20003Kg/00`00Kg]_N`02Kg/01000
Kg]_Nfmk1@0036mk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/02Fmk00<006mkKg/02Fmk
00<006mkKg/01Vmk00<006mkKg/03Vmk00<006mk00002Fmk00<006mkKg/0BFmk001FKg/01000Kg]_
N`003Vmk00<006mk00000`002Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/036mk00<0
06mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/01Fmk00<006mkKg/03Fmk0`0000E_N`00000006mk
008000Q_N`80009_N`03001_Nfmk009_N`<001I_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk009_N`<00003Kg/0000000Y_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk00U_N`03
001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk00i_N`03001_N`0000Y_N`03001_Nfmk04Q_N`00
EFmk00@006mkKg/000i_N`05001_N`00Kg/00002Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0<Kg/9000:Kg/01@00Kg/006mk00000fmk00<006mk00005Vmk00<006mkKg/016mk00<006mk
Kg/00fmk00<006mkKg/00fmk00@006mkKg]_N`8000U_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0@Kg/2000;Kg/00`00Kg]_N`17Kg/005A_
N`04001_Nfmk000=Kg/20002Kg/00`00Kg/00003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0=Kg/9000:Kg/01@00Kg/006mk00000fmk00<006mk000056mk0P001fmk00<006mkKg/016mk
00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01Vmk00D006mkKg]_N`0000i_N`03001_Nfmk
00M_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk011_N`8000a_N`03001_Nfmk04I_N`00
Dfmk00@006mkKg/000e_N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/01@00Kg]_Nfmk000036mk00<006mkKg/00fmk
00<006mkKg/02fmk2`002Vmk00D006mk001_N`00009_N`05001_NfmkKg/0000BKg/00`00Kg]_N`07
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20007Kg/01000Kg]_N`003Vmk00<0
06mkKg/01fmk00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/04Fmk0`002fmk00<006mkKg/0
AFmk001BKg/01000Kg]_N`003Fmk00<006mkKg/00Vmk00@006mkKg/000E_N`03001_Nfmk00=_N`03
001_Nfmk00I_N`05001_NfmkKg/0000BKg/01@00Kg]_Nfmk00003Fmk00<006mkKg/00Vmk00<006mk
Kg/026mk0`000Vmk100000E_N`00000006mk008000Q_N`03001_Nfmk0080009_N`05001_NfmkKg/0
000@Kg/2000:Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00001fmk0P001Fmk00@006mkKg/000m_N`03
001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00Q_N`03001_Nfmk015_N`D000]_N`03001_Nfmk
04A_N`00DFmk00@006mkKg/000a_N`8000A_N`05001_NfmkKg/00005Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`06Kg/01000Kg]_N`004fmk00@006mkKg/000i_N`04001_Nfmk0009Kg/20004Kg/02000Kg]_
N`00Kg/006mk0004Kg/20006Kg/00`00Kg]_N`0200000fmk001_N`03Kg/00`00Kg]_N`0=Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`07Kg/01000Kg]_N`002Fmk00<006mkKg/00Vmk00@006mkKg/000m_N`03
001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00Q_N`03001_Nfmk015_N`D000]_N`03001_Nfmk
04A_N`00D6mk00@006mkKg/000a_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00A_N`03
001_Nfmk00=_N`03001_Nfmk00I_N`04001_Nfmk000DKg/00`00Kg/0000>Kg/01000Kg]_N`001Vmk
0`0016mk0P000fmk00D006mk001_N`0000I_N`8000A_N`03001_Nfmk00800003Kg/006mk00=_N`03
001_Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk00U_N`04001_Nfmk0009Kg/20003Kg/00`00Kg/0
000?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0AKg/5000<Kg/0
0`00Kg]_N`13Kg/004m_N`04001_Nfmk000;Kg/20006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg/0000EKg/3000>Kg/30003Kg/30003Kg/40004Kg/3
000016mk000000001fmk0P0000E_N`00000006mk00<000E_N`03001_Nfmk00Y_N`8000e_N`03001_
Nfmk00Y_N`03001_N`0000]_N`800004Kg/00000000@Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`0AKg/7000<Kg/00`00Kg]_N`12Kg/004i_N`04001_Nfmk000;Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00002Fmk00<006mk0000
56mk1@0036mk1`001Fmk1@000fmk2@0026mk2@0016mk00<006mkKg/02Fmk00<006mkKg/03Fmk00<0
06mkKg/02Vmk00@006mkKg/000a_N`D000m_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk
00Y_N`03001_Nfmk011_N`03001_Nfmk008000=_N`03001_Nfmk00Y_N`03001_Nfmk045_N`00CFmk
00@006mkKg/000]_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00M_N`04001_Nfmk000:
Kg/2000CKg]00004Kg/00`00Kg]_N`07Kg/2000@Kg/00`00Kg]_N`0;Kg/00`00Kg/0000<Kg/5000@
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/01000Kg]_Nfmk
0P0016mk00<006mkKg/02Vmk00<006mkKg/0@6mk001<Kg/01000Kg]_N`002Vmk0P0026mk00<006mk
Kg/016mk00<006mkKg/026mk00<006mk00002Vmk0P002fmk3P0036mk1@001fmk1@000fmk2@0026mk
2@0016mk00<006mkKg/01Vmk00<006mkKg/046mk00<006mkKg/036mk0P0026mk2P003fmk00<006mk
Kg/00fmk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/03Vmk0P0016mk00<006mk000016mk
0P002fmk00<006mkKg/0?fmk001;Kg/01000Kg]_N`002Vmk00<006mkKg/01Vmk0`001Vmk00<006mk
Kg/02Fmk0`002Fmk0`000Vmk20001Vmk0P000Vmk10003Fmk0`0000=_N`0000001Vmk100016mk0`00
00A_N`00000000U_N`@00003Kg/00000008000A_N`03001_Nfmk00E_N`03001_Nfmk015_N`03001_
Nfmk00e_N`<00003Kg/0000000<000E_N`<0009_N`8000e_N`03001_Nfmk00=_N`03001_Nfmk009_
N`03001_Nfmk00]_N`03001_Nfmk00e_N`03001_Nfmk00A_N`03001_N`0000I_N`03001_Nfmk00U_
N`03001_Nfmk03i_N`00BVmk00@006mkKg/000Y_N`03001_Nfmk00I_N`D000E_N`03001_Nfmk00Q_
Na8000a_N`8000E_N`03001_N`0000i_N`03001_Nfmk009_N`03001_Nfmk00A_N`04001_Nfmk0004
Kg/00`00Kg/00003Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk00@006mkKg/000A_N`03001_Nfmk
009_N`8001A_N`03001_Nfmk00a_N`D000Y_N`04001_N`000003Kg/2000<Kg/01@00Kg]_Nfmk0000
16mk00<006mkKg/036mk00<006mkKg/036mk00<006mkKg/01Fmk00<006mk00001fmk00<006mkKg/0
2Fmk00<006mkKg/0?Fmk0019Kg/01000Kg]_N`002Fmk0P002Fmk1@001Fmk00<006mkKg/026mk1@00
1fmk1@002fmk0P001fmk00@006mkKg/000e_N`03001_Nfmk00=_N`8000A_N`04001_NfmkKg/20002
Kg/00`00Kg/00004Kg/00`00Kg]_N`02Kg/20003Kg/01@00Kg]_Nfmk00000fmk0P000Vmk00D006mk
Kg]_N`0001E_N`03001_Nfmk00e_N`D000Y_N`04001_N`000005Kg/2000:Kg/01@00Kg]_Nfmk0000
0fmk00<006mkKg/036mk00<006mkKg/02fmk0P0026mk00<006mk000026mk00<006mkKg/026mk00<0
06mkKg/0?Fmk0018Kg/01000Kg]_N`002Fmk00<006mkKg/01fmk1`001Fmk00<006mkKg/01Vmk2000
1Vmk1@002Fmk0P002Fmk00D006mkKg]_N`0000]_N`03001_N`0000I_N`800004Kg/000000004Kg/4
0005Kg/300000fmk001_N`05Kg/00`00Kg/00006Kg/400000fmk001_N`0EKg/00`00Kg]_N`0;Kg/7
000:Kg/01@00Kg/006mk00001Vmk0P002Fmk00@006mkKg/000=_N`03001_Nfmk00a_N`03001_Nfmk
00Y_N`03001_Nfmk00M_N`04001_Nfmk0009Kg/20009Kg/00`00Kg]_N`0lKg/004I_N`80009_N`03
001_Nfmk00I_N`8000Q_N`800003Kg/006mk00<00003Kg/006mk00=_N`03001_Nfmk00E_N`04001_
NfmkKg/400000fmk00000005Kg/30008Kg/2000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00
Kg/00008Kg/50003Kg/50003Kg/50007Kg/00`00Kg/00006Kg/5000GKg/00`00Kg]_N`09Kg/20003
Kg/4000:Kg/01@00Kg/006mk000026mk0P001fmk00@006mkKg/0009_N`03001_Nfmk00e_N`03001_
Nfmk00U_N`03001_Nfmk00Q_N`04001_Nfmk000;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0kKg/004E_
N`05001_NfmkKg/00008Kg/00`00Kg]_N`06Kg/20002Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk0000
1Fmk0P001fmk00D006mkKg]_N`0000E_N`03001_Nfmk00E_N`8000i_N`03001_Nfmk009_N`03001_
Nfmk00M_N`03001_N`0000Q_NaD000M_N`03001_N`0000I_N`D001M_N`03001_Nfmk00Q_N`03001_
Nfmk00=_N`04001_Nfmk000:Kg/00`00Kg/00002Kg/00`00Kg]_N`07Kg/20005Kg/01P00Kg]_N`00
Kg/0011_N`03001_Nfmk00M_N`8000]_N`04001_Nfmk000<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0j
Kg/004A_N`05001_NfmkKg/00008Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00002Fmk00@006mkKg/0
00A_N`03001_Nfmk00Q_N`04001_NfmkKg/20003Kg/00`00Kg]_N`03Kg/2000@Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`06Kg/00`00Kg/00008Kg/50003Kg/50003Kg/50007Kg/00`00Kg/00006Kg/8000D
Kg/00`00Kg]_N`06Kg/20006Kg/01@00Kg]_Nfmk000026mk00L006mkKg]_N`00Kg/0000;Kg/20004
Kg/01000Kg/0000046mk00<006mkKg/01fmk00<006mkKg/02fmk00@006mkKg/000e_N`03001_Nfmk
00M_N`03001_Nfmk03U_N`00@fmk00D006mkKg]_N`0000M_N`8000M_N`8000A_N`03001_Nfmk00Q_
N`@00003Kg/0000000]_N`03001_Nfmk00=_N`03001_N`000080009_N`80019_N`03001_Nfmk00=_
N`03001_Nfmk00I_N`03001_N`0000Q_N`@000E_N`<000E_N`<00003Kg/006mk00E_N`03001_N`00
00I_N`D000=_N`<0015_N`03001_Nfmk00A_N`8000Q_N`05001_NfmkKg/00008Kg/01@00Kg]_Nfmk
00000Vmk00<006mkKg/02Vmk0P000Vmk100046mk00<006mkKg/01Vmk00<006mkKg/036mk00@006mk
Kg/000i_N`8000Q_N`03001_Nfmk03Q_N`00@Vmk00D006mkKg]_N`0000M_N`03001_Nfmk00E_N`80
00E_N`03001_Nfmk00U_N`D000i_N`03001_Nfmk00=_N`H001A_N`03001_Nfmk00A_N`03001_Nfmk
00E_N`03001_N`0000M_N`05001_NfmkKg/00006Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/00`00Kg/00005Kg/00`00Kg/00002Kg/00`00Kg]_N`04Kg/4000=Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00000fmk00<006mk
Kg/02fmk1P0046mk00<006mkKg/016mk0P003Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mk
Kg/01Vmk00<006mkKg/0=fmk0011Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/016mk0P001Vmk00<0
06mkKg/02Vmk1P003Fmk00<006mkKg/00fmk1@005Fmk00<006mkKg/01Fmk00<006mkKg/016mk00<0
06mk00001Vmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/00fmk00<0
06mkKg/00Vmk00<006mk000016mk00@006mkKg/000=_N`03001_Nfmk00M_N`@000Q_N`03001_Nfmk
009_N`8000]_N`03001_Nfmk009_N`03001_Nfmk00E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`0<
Kg/5000?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`0fKg/0041_N`03001_Nfmk009_N`03001_Nfmk00=_N`8000E_N`8000M_
N`03001_Nfmk00]_N`D00003Kg/0000000@000Q_N`<0009_N`D001E_N`03001_Nfmk00I_N`03001_
Nfmk00=_N`03001_N`0000E_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_
Nfmk00E_N`07001_NfmkKg/006mk00000fmk00D006mkKg]_N`0000A_N`03001_Nfmk00Y_N`<000A_
N`<00003Kg/0000000Y_N`<000I_N`03001_Nfmk00A_N`05001_NfmkKg/00004Kg/00`00Kg]_N`0;
Kg/6000>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0?Kg/01000Kg]_Nfmk0`0046mk0P001Vmk00<006mk
Kg/0=Vmk000oKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0:Kg/2000016mk0000000026mk1P0000=_N`000000100000=_N`00000010004fmk00<0
06mkKg/01fmk00<006mkKg/00Vmk00<006mk00001Fmk00<006mkKg/016mk00<006mkKg/00Vmk00<0
06mkKg/00fmk00<006mkKg/01Vmk00L006mkKg]_N`00Kg/00003Kg/01000Kg]_N`001Vmk00<006mk
Kg/036mk20002fmk1@001Vmk00<006mkKg/00fmk00D006mkKg]_N`0000A_N`03001_Nfmk00U_N`80
0003Kg/0000000D000a_N`04001_NfmkKg/2000BKg/00`00Kg]_N`05000AKg/00`00Kg]_N`04Kg/0
0`00Kg]_N`0eKg/003i_N`03001_Nfmk009_N`03001_Nfmk009_N`8000E_N`8000Q_N`03001_Nfmk
00U_N`8000A_N`03001_N`0000e_N`H000=_N`05001_Nfmk001_N`02000AKg/00`00Kg]_N`08Kg/0
1000Kg]_N`000fmk00D006mkKg]_N`0000M_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk
00M_N`05001_NfmkKg/00003Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/03Vmk5@001Vmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/01Vmk0P0016mk1@0000=_N`000000
2Fmk00D006mkKg]_N`0001A_N`03001_Nfmk00D0019_N`03001_Nfmk00A_N`03001_Nfmk03A_N`00
?Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/026mk0P00
1Fmk00D006mkKg]_N`0000e_N`D000=_N`05001_NfmkKg/00002Kg/2000?Kg/00`00Kg]_N`08Kg/0
1000Kg]_N`000fmk00@006mkKg/000U_N`05001_NfmkKg/00004Kg/00`00Kg]_N`09Kg/01000Kg]_
N`000Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/03Fmk1@002fmk1P001Vmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00A_N`8000=_N`h000I_N`04001_Nfmk000EKg/0
0`00Kg]_N`06000BKg/00`00Kg]_N`04Kg/00`00Kg]_N`0cKg/003a_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk009_N`8000Y_N`03001_Nfmk00M_N`8000M_N`03001_Nfmk009_N`03001_
Nfmk00]_N`<000A_N`03001_Nfmk009_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`09Kg/30002Kg/4
000:Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02fmk1@0016mk00<006mkKg/01fmk00<006mkKg/0
3Fmk10003Fmk0`000Vmk0P0016mk00D006mkKg]_N`0000E_N`03001_Nfmk00=_N`<00004Kg/00000
Kg/40004Kg/3000016mk000006mk1@000Vmk1@0056mk0`0000=_N`00Kg/00`000Vmk0`0046mk0P00
1Fmk00<006mkKg/0<Vmk000kKg/00`00Kg]_N`02Kg/01000Kg]_Nfmk0P000fmk0P002fmk00<006mk
Kg/01Vmk0P002Fmk00<006mkKg/00Vmk00<006mkKg/036mk0P0016mk00<006mkKg/00fmk00@006mk
Kg]_N`8000a_N`03001_Nfmk00Q_N`X000Y_N`05001_NfmkKg/00003Kg/00`00Kg]_N`0;Kg/50004
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`02000=Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`02Kg/01000Kg]_N`001Fmk00<006mkKg/00Vmk200026mk00@006mkKg/0009_N`04001_NfmkKg/8
000DKg/50004Kg/00`00Kg]_N`03Kg/2000@Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0aKg/003Y_N`03
001_Nfmk009_N`05001_NfmkKg/00003Kg/2000<Kg/00`00Kg]_N`05Kg/2000;Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`0;Kg/20004Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/2000:Kg/00`00Kg]_N`08
Kg/:000;Kg/01000Kg]_N`000Vmk00<006mkKg/036mk1@0016mk00<006mkKg/02Fmk00<006mkKg/0
2Fmk00@006mkKg]_N`8000e_N`03001_Nfmk00E_N`80009_N`04001_Nfmk0005Kg/00`00Kg]_N`02
Kg/5000;Kg/01000Kg]_N`000fmk0P0016mk7P0016mk00<006mkKg/01Fmk0P003fmk00<006mkKg/0
0fmk00<006mkKg/0<6mk000iKg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02fmk
00<006mkKg/016mk0P003Fmk00<006mkKg/016mk00<006mkKg/02Vmk00<006mk00000fmk00<006mk
Kg/01Fmk00<006mkKg/00fmk0P002Fmk00<006mkKg/01fmk2`002Vmk00@006mkKg/0009_N`03001_
Nfmk00Y_N`L0009_N`<000a_N`03001_Nfmk00M_N`07001_NfmkKg/006mk000036mk00<006mkKg/0
26mk0P0000A_N`00000000E_N`<0009_N`D000]_N`05001_NfmkKg/00004Kg/200000fmk00000004
000DKg/50005Kg/00`00Kg]_N`06Kg/3000=Kg/20004Kg/00`00Kg]_N`0_Kg/003Q_N`03001_Nfmk
009_N`03001_Nfmk0080009_N`8000i_N`03001_Nfmk009_N`8000m_N`03001_Nfmk00E_N`03001_
Nfmk00U_N`03001_N`0000=_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_
Nfmk00I_N`D0009_N`<0009_N`8000Q_N`06001_Nfmk001_N`002Vmk0`000fmk0`0000=_N`000000
100036mk00<006mkKg/01Vmk00L006mkKg]_N`00Kg/0000;Kg/00`00Kg]_N`0;Kg/50003Kg/60000
0fmk00000002000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/8000DKg/40005Kg/00`00Kg]_N`09
Kg/2000=Kg/01@00Kg]_Nfmk0000<Fmk000gKg/00`00Kg]_N`02Kg/01000Kg]_N`000Vmk0P003fmk
00@006mkKg]_N`80011_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`8000=_N`03001_Nfmk00M_N`03
001_Nfmk00A_N`8000I_N`03001_Nfmk00A_N`8000A_N`03001_N`0000M_N`8000M_N`800003Kg/0
06mk00M_N`<000I_N`03001_Nfmk009_N`D000e_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_
N`0000]_N`03001_Nfmk00]_N`d000E_N`8000U_N`03001_Nfmk00=_N`03001_Nfmk00=_N`D000=_
N`03001_Nfmk019_N`04001_Nfmk0004Kg/00`00Kg]_N`0;Kg/3000;Kg/01@00Kg]_Nfmk0000<6mk
000fKg/00`00Kg]_N`02Kg/01@00Kg/00000Kg/00P0046mk00<006mkKg/00P004Vmk00<006mkKg/0
1fmk00<006mkKg/02Fmk00<006mk00000Vmk00<006mkKg/026mk00<006mkKg/01Fmk0P0016mk00<0
06mkKg/00Vmk0P001Vmk00<006mk00002Fmk0`0016mk0P0000=_N`00Kg/016mk0`002Fmk00<006mk
Kg/00Vmk2P0026mk00<006mkKg/00fmk00<006mkKg/00fmk00<006mk00002Vmk00<006mkKg/036mk
1@000fmk1@001Vmk0P0026mk00<006mkKg/00fmk00<006mkKg/00fmk1@0016mk00<006mkKg/04Fmk
00D006mkKg]_N`0000A_N`03001_Nfmk00e_N`8000Y_N`05001_NfmkKg/0000_Kg/003E_N`03001_
Nfmk009_N`04001_N`00Kg/2000=Kg/300000fmk001_N`02000DKg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg/00002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/200001Fmk00000000Kg/00P00
1Vmk10003Fmk0P000Vmk0`000fmk0`0036mk00<006mkKg/00fmk0`001Vmk10001Fmk1@001Vmk00@0
06mkKg/000U_N`03001_Nfmk00Y_N`800004Kg/000000005Kg/300000fmk001_N`04Kg/00`00Kg/0
0007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/300000fmk00000003Kg/2000@Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00004Fmk0`0026mk0P000Vmk00<006mkKg/0;6mk000dKg/00`00Kg]_N`02Kg/0
1@00Kg/006mk00003Vmk1`005Vmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mk00000Vmk00<0
06mkKg/02Vmk00<006mkKg/01fmk1@001fmk1@003fmk20003fmk00<006mkKg/00Vmk00@006mkKg/0
00Y_N`X000I_N`04001_Nfmk0008Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg/00005Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`04Kg/01000Kg]_N`0056mk
0P0026mk00@006mkKg/002e_N`00<fmk00<006mkKg/00Vmk1@003fmk1@0066mk00<006mkKg/02Fmk
00<006mkKg/01fmk00H006mkKg/006mk000=Kg/00`00Kg]_N`06Kg/V000AKg/00`00Kg]_N`02Kg/0
1@00Kg]_Nfmk00003Vmk1@001Vmk00@006mkKg/000M_N`03001_Nfmk00U_N`8000I_N`03001_Nfmk
00=_N`03001_Nfmk00=_N`8000=_N`04001_Nfmk0004Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk0000
1fmk0P000fmk00<006mkKg/036mk00<006mkKg/01Fmk00@006mkKg/001E_N`<000I_N`04001_Nfmk
000/Kg/0035_N`8000A_N`@000Y_N``001Q_N`03001_Nfmk00Y_N`03001_Nfmk00I_N`06001_Nfmk
001_N`003Vmk00<006mkKg/01Fmk1@001fmk1P003fmk1@0046mk00<006mkKg/00Vmk00<006mkKg/0
0Vmk00<006mkKg/036mk1@001Vmk00@006mkKg/000M_N`03001_Nfmk00M_N`8000Q_N`03001_Nfmk
00=_N`03001_Nfmk00E_N`05001_NfmkKg/00002Kg/01@00Kg]_Nfmk000026mk00@006mkKg/000Y_
N`80009_N`03001_Nfmk00]_N`03001_Nfmk00I_N`03001_N`0001Q_N`8000E_N`04001_Nfmk000[
Kg/0031_N`03001_Nfmk00H000I_N`H000I_N`L001M_N`03001_Nfmk00]_N`03001_Nfmk00E_N`06
001_Nfmk001_N`003fmk00<006mkKg/01Fmk0`002Fmk0`0000A_N`00000000i_N`D000m_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00e_N`@000I_N`04001_Nfmk0006Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00000Vmk10002Fmk
0`0036mk00<006mkKg/00P002fmk00<006mkKg/01fmk0`006Fmk0P0016mk0P0000=_N`00Kg/0:Fmk
000_Kg/00`00Kg]_N`0500000fmk00000005000;Kg/50002Kg/2000EKg/00`00Kg]_N`0=Kg/00`00
Kg]_N`04Kg/01000Kg]_Nfmk0P0046mk00<006mkKg/00fmk00D006mkKg]_N`0000U_N`04001_Nfmk
0002Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk00001Vmk00<0
06mkKg/036mk00<006mkKg/00P0016mk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01Fmk
0P002fmk00<006mkKg/00fmk00<006mkKg/01fmk0P0000A_N`00Kg]_N`D000M_N`D000a_N`80009_
N`03001_Nfmk00Q_N`03001_Nfmk00I_N`D001Y_N`<000=_N`8002Y_N`00;Vmk00@006mkKg]_Nad0
009_N`03001_N`0001A_N`03001_Nfmk00e_N`03001_Nfmk00A_N`04001_NfmkKg/2000AKg/00`00
Kg]_N`02Kg/01@00Kg]_Nfmk00002Fmk00D006mkKg]_N`00009_N`8000]_N`03001_Nfmk00=_N`03
001_Nfmk00]_N`05001_NfmkKg/00006Kg/00`00Kg]_N`0;Kg/20002Kg/01000Kg/000000Vmk00<0
06mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/016mk0P003Fmk00<006mkKg/00fmk00<006mkKg/0
2Fmk00@006mk001_Na4000i_N`800003Kg/006mk00Q_N`03001_Nfmk00I_N`X001Q_N`80009_N`80
02U_N`00;Fmk00<006mkKg/00Vmk1@004fmk1@000fmk0P0056mk00<006mkKg/03Vmk00<006mkKg/0
0fmk00@006mkKg]_N`<0015_N`@000E_N`03001_Nfmk00E_N`03001_Nfmk00=_N`05001_NfmkKg/0
000:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/01000Kg]_N`0026mk00<006mkKg/02Vmk0P000fmk
00<006mkKg/010000fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/03Vmk00D006mkKg]_
N`0000e_N`03001_N`0000D000=_N`d000a_N`03001_N`0000Q_N`03001_Nfmk00I_N`D000E_N`d0
00e_N`P002E_N`00;6mk00@006mkKg]_N`800004Kg/00000000EKg/40003Kg/00`00Kg/0000CKg/0
0`00Kg]_N`0?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05000@Kg/50004Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`04Kg/01000Kg]_Nfmk0P0026mk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mk00002Fmk
00<006mkKg/02Fmk00<006mk00000fmk00<006mkKg/01@000Vmk00D006mkKg]_N`0000A_N`80015_
N`05001_NfmkKg/0000>Kg/:0005Kg/30005Kg/40009Kg/40006Kg/00`00Kg]_N`05Kg/6000BKg/=
0003Kg/6000TKg/002]_N`03001_Nfmk008000A_N`03001_N`0001A_N`04001_Nfmk0004Kg/00`00
Kg/0000BKg/00`00Kg]_N`0@Kg/01@00Kg]_Nfmk00000Vmk6P001Fmk00<006mkKg/00fmk00<006mk
Kg/01Fmk00<006mkKg/00fmk0P001Vmk00<006mkKg/01Vmk0P0026mk00@006mkKg/000U_N`03001_
Nfmk00U_N`03001_N`0000A_N`03001_N`0000@0009_N`04001_Nfmk0003Kg/2000CKg/01@00Kg]_
Nfmk00003Vmk1@002fmk00<006mkKg/026mk10001fmk0`0016mk00<006mkKg/016mk0P0016mk0P00
7fmk2@0096mk000ZKg/01000Kg/000001Vmk00@006mkKg/001=_N`05001_NfmkKg/00003Kg/01000
Kg]_N`004Fmk00<006mkKg/046mk00<006mkKg/00Vmk00<006mk0000100046mk1@001Vmk00<006mk
Kg/00Vmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/026mk00<006mk
Kg/01Fmk00<006mk00002fmk00<006mkKg/026mk0P001Fmk00<006mk000010000Vmk00@006mkKg/0
009_N`03001_Nfmk01=_N`05001_NfmkKg/0000>Kg/5000;Kg/00`00Kg]_N`0<Kg/40005Kg/20003
Kg/00`00Kg]_N`02Kg/20006Kg/2000SKg/5000TKg/002I_N`H000U_N`04001_Nfmk000BKg/00`00
Kg]_N`02Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/03Fmk00<006mkKg/04Vmk00D006mkKg]_N`00
009_N`@0015_N`<00003Kg/0000000A_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk00A_
N`800004Kg/00000000;Kg/00`00Kg]_N`04Kg/00`00Kg/0000;Kg/00`00Kg]_N`07Kg/00`00Kg/0
0006Kg/500000fmk001_N`0300000fmk0000000FKg/01@00Kg]_Nfmk000036mk0P0000=_N`000000
0P0036mk00<006mkKg/03fmk10000Vmk1P0000=_N`00000026mk00<006mk00008Vmk10009Fmk000U
Kg/5000;Kg/01000Kg]_N`004Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03001_Nfmk00a_
N`03001_Nfmk01=_N`06001_Nfmk001_N`0016mk00<006mkKg/03fmk0P000fmk00<006mkKg/00Vmk
00@006mkKg/000]_N`03001_Nfmk00E_N`D000]_N`03001_Nfmk00=_N`8000e_N`03001_Nfmk00I_
N`03001_N`0000E_N`D000=_N`D001U_N`03001_N`0000]_N`8000A_N`04001_Nfmk000;Kg/00`00
Kg]_N`0CKg/9000:Kg/00`00Kg/0000QKg/00`00Kg/00002000UKg/002E_N`D000]_N`05001_Nfmk
Kg/0000@Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk00<006mkKg/02fmk00<006mkKg/056mk00D0
06mk001_N`0000E_N`03001_Nfmk00i_N`8000A_N`80009_N`04001_Nfmk000<Kg/00`00Kg]_N`04
Kg/6000;Kg/00`00Kg]_N`02Kg/2000=Kg/00`00Kg]_N`05Kg/01000Kg]_N`001Fmk3@006Fmk00<0
06mk00002Vmk00<006mkKg/016mk00@006mkKg]_N`8000U_N`03001_Nfmk01M_N`D000Y_N`03001_
N`00021_N`06001_Nfmk001_N`009Fmk000UKg/5000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/0
0`00Kg]_N`05Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02Vmk00<006mkKg/056mk10001fmk00<0
06mkKg/036mk00<006mk00001Vmk0P0000A_N`00000000a_N`03001_Nfmk00A_N`D00003Kg/00000
00@000I_N`D000i_N`03001_Nfmk00E_N`04001_Nfmk0005Kg/50003Kg/9000EKg/00`00Kg/00008
Kg/20007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0EKg/7000:Kg/00`00Kg/0000O
Kg/00`00Kg]_N`020002Kg/00`00Kg]_N`0RKg/002E_N`@000a_N`03001_Nfmk009_N`03001_Nfmk
00e_N`03001_Nfmk00I_N`04001_Nfmk0003Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0DKg/50007Kg/0
0`00Kg]_N`0;Kg/01000Kg]_N`001fmk1@0036mk00<006mkKg/016mk0`0026mk1P0000=_N`000000
0`003Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`@000E_N`<000E_N`@0015_N`03001_N`00
00I_N`8000U_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk01=_N`800003Kg/0000000<0
00a_N`03001_N`0001e_N`04001_NfmkKg/20002Kg/00`00Kg]_N`0RKg/002E_N`80009_N`03001_
Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00a_N`03001_Nfmk00M_N`04001_Nfmk0003Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`0DKg/50008Kg/00`00Kg]_N`0:Kg/01000Kg]_N`001fmk1@003Fmk00<0
06mkKg/00Vmk00<006mkKg/03fmk1P003Vmk00<006mkKg/00fmk00@006mkKg/000E_N`800003Kg/0
06mk00E_N`04001_Nfmk0008Kg/4000=Kg/00`00Kg/00005Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0@Kg/30002Kg/01000Kg]_N`000Vmk00<006mkKg/02Fmk00<0
06mk000076mk00<006mkKg/00Vmk0P000Vmk00<006mkKg/08Vmk000TKg/00`00Kg/00002Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`09Kg/00`00Kg/00004Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`0CKg/70008Kg/00`00Kg]_N`09Kg/01000Kg]_N`001fmk2P002Fmk00D0
06mkKg]_N`0000a_N`d000e_N`03001_Nfmk009_N`04001_Nfmk0004Kg/01@00Kg/006mk00001Vmk
00@006mkKg/000a_N`@000U_N`03001_N`0000=_N`8000a_N`03001_Nfmk00I_N`03001_Nfmk00=_
N`03001_Nfmk00e_N`<000A_N`05001_NfmkKg/00002Kg/00`00Kg]_N`09Kg/00`00Kg/0000KKg/0
0`00Kg]_N`02Kg/00`00Kg/00003Kg/00`00Kg]_N`0QKg/002=_N`04001_Nfmk0003Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0:Kg/00`00Kg/00004Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`0AKg/30002Kg/30002Kg/20007Kg/20009Kg/01@00Kg]_Nfmk00001Vmk1000
1Vmk10001Fmk10001fmk1P001fmk0`000fmk0`002Vmk00D006mkKg]_N`0000=_N`07001_NfmkKg/0
06mk00000fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk10001Fmk0`0000=_N`00
00003Vmk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/02fmk0P001Fmk0P0016mk00D006mk
Kg]_N`0000Y_N`04001_Nfmk000IKg/00`00Kg]_N`03Kg/00`00Kg/00003Kg/00`00Kg]_N`0QKg/0
029_N`04001_Nfmk0005Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`0;Kg/00`00Kg/00004Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?Kg/20004Kg/01000Kg]_N`0016mk
0P001fmk00<006mkKg/01Vmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00M_Na00
00e_N`@000E_N`8000Q_N`05001_NfmkKg/00003Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk009_
N`03001_Nfmk009_N`03001_Nfmk015_N`T0011_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_
Nfmk00M_N`<000I_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00M_N`04001_Nfmk000H
Kg/00`00Kg]_N`04Kg/20004Kg/00`00Kg]_N`0QKg/0029_N`04001_Nfmk0005Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0;Kg/00`00Kg/00005Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0<Kg/30006Kg/01000Kg]_N`001Vmk0P001Vmk00<006mkKg/01Fmk00D006mkKg]_
N`0000=_N`8000I_N`03001_Nfmk00]_N`D0019_N`04001_N`00Kg/20006Kg/30006Kg/00`00Kg/0
0004Kg/00`00Kg/00002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`0DKg/5000@Kg/00`00Kg]_N`09Kg/20002Kg/00`00Kg]_N`04Kg/30008Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`07Kg/01000Kg]_N`005fmk00<006mkKg/01Fmk0P001Fmk00<006mk
Kg/086mk000QKg/01@00Kg]_Nfmk00001Vmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/0
1Vmk00<006mkKg/03Fmk00<006mk00001Fmk00<006mkKg/00fmk00<006mkKg/02Vmk0P0026mk00<0
06mkKg/00Vmk00<006mkKg/01Fmk0P001Fmk00<006mkKg/016mk00D006mkKg]_N`00009_N`03001_
Nfmk00M_N`03001_Nfmk00I_N`T0019_N`07001_N`00Kg/006mk000026mk0`000fmk00<006mk0000
0fmk00<006mk00000Vmk00<006mkKg/00fmk00D006mkKg]_N`0000M_N`03001_Nfmk015_N`L0011_
N`03001_Nfmk00]_N`03001_N`0000A_N`8000Y_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_
Nfmk00I_N`05001_NfmkKg/0000EKg/00`00Kg]_N`05Kg/00`00Kg/00005Kg/00`00Kg]_N`0PKg/0
021_N`05001_NfmkKg/00007Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0>Kg/20006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/2000:Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`07Kg/20004Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0`002Fmk0`000Vmk1@001Fmk0`004Vmk
00P006mkKg/006mk001_N`002fmk1P0000=_N`0000000P0000A_N`00000000E_N`05001_NfmkKg/0
0007Kg/00`00Kg]_N`0>Kg/30003Kg/4000@Kg/00`00Kg]_N`0<Kg/6000:Kg/20007Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk000056mk00<006mkKg/01Vmk00<006mk00001Fmk00<0
06mkKg/086mk000OKg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/3000;
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/20003Kg/01@00Kg]_Nfmk00000fmk4P002Fmk00D006mk
001_N`00015_N`03001_N`0000=_N`03001_N`0000a_N`h000A_N`05001_NfmkKg/00008Kg/00`00
Kg]_N`0:Kg/30006Kg/01000Kg]_N`0046mk00<006mkKg/02fmk1@002fmk00<006mkKg/01fmk00<0
06mkKg/01Vmk00<006mkKg/01Fmk00D006mkKg]_N`0001=_N`03001_Nfmk00M_N`03001_N`0000I_
N`03001_Nfmk01m_N`007Vmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01Fmk00<006mk
Kg/026mk00<006mkKg/016mk00<006mkKg/046mk00<006mkKg/016mk00@006mkKg/000I_N`8000i_
N`03001_Nfmk00A_N`03001_Nfmk00Y_N`80009_N`04001_Nfmk0003Kg/50007Kg/5000:Kg/01@00
Kg/006mk000046mk00@006mkKg/000=_N`04001_Nfmk000;Kg/>0004Kg/01000Kg]_N`002Fmk00<0
06mkKg/01fmk0`0026mk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/02fmk1@002Vmk00<0
06mkKg/026mk00<006mkKg/01fmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/03fmk00<0
06mkKg/01fmk00@006mkKg/000I_N`03001_Nfmk01m_N`007Vmk00<006mkKg/00fmk00<006mkKg/0
1fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/00Vmk00<006mkKg/04Fmk100016mk1000
0Vmk0`003Fmk0`001fmk00<006mkKg/036mk0P0000=_N`0000000P0000=_N`00000010001fmk1@00
2Fmk00L006mkKg]_N`00Kg/0000?Kg/01000Kg]_N`0016mk00@006mkKg/000Y_N`h000A_N`04001_
Nfmk000:Kg/30003Kg/3000;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0;Kg/50009
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>
Kg/00`00Kg]_N`08Kg/01000Kg]_N`001Vmk00<006mkKg/07fmk000MKg/00`00Kg]_N`03Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/50003
Kg/6000?Kg/50007Kg/00`00Kg]_N`0=Kg/60002Kg/30008Kg/400000fmk001_N`07Kg/01`00Kg]_
Nfmk001_N`0000m_N`04001_Nfmk0004Kg/01000Kg]_N`002fmk300000=_N`00Kg/00Vmk00@006mk
Kg/000U_N`L000i_N`03001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk00]_N`@000Q_N`8000]_
N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk00U_
N`03001_N`0000Q_N`03001_Nfmk01i_N`0076mk00<006mkKg/016mk00<006mkKg/02Fmk00<006mk
Kg/016mk00<006mkKg/02Vmk00D006mkKg]_N`0001=_Nb8000M_N`03001_Nfmk00i_N`D000E_N`03
001_Nfmk00=_N`8000=_N`03001_N`0000M_N`03001_Nfmk009_N`04001_Nfmk000=Kg/01@00Kg]_
Nfmk000016mk00D006mkKg]_N`0000Y_N`04001_Nfmk0003Kg/20002Kg/01000Kg]_N`000fmk0P00
2Vmk1@003fmk00<006mkKg/01Fmk00<006mkKg/02fmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<0
06mkKg/016mk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/00fmk00<0
06mkKg/02fmk00<006mkKg/02Fmk00@006mkKg/000Q_N`03001_Nfmk01i_N`006fmk00<006mkKg/0
1Fmk00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/02Vmk00@006mkKg/000e_N`/000=_N`D0
011_N`D000M_N`03001_Nfmk00i_N`H000A_N`03001_Nfmk009_N`03001_Nfmk00=_N`04001_Nfmk
0005Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000036mk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0009Kg/01@00Kg]_Nfmk00000Vmk00D006mk001_N`0000=_N`03001_Nfmk008000M_N`P000m_N`03
001_Nfmk00I_N`03001_Nfmk00Y_N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03
001_Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03
001_Nfmk00Y_N`04001_Nfmk0008Kg/00`00Kg]_N`0NKg/001Q_N`@000I_N`03001_Nfmk00a_N`03
001_Nfmk00=_N`03001_Nfmk00]_N`<000M_N`H000M_N`<000A_N`@0015_N`H000M_N`03001_Nfmk
00a_N`03001_N`000080009_N`<0009_N`@000I_N`04001_Nfmk0005Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00002fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000Q_N`03001_Nfmk
00=_N`03001_Nfmk00800003Kg/006mk00=_N`@000A_N`<000A_N`<000m_N`03001_Nfmk00Q_N`03
001_Nfmk00U_N`03001_Nfmk00U_N`03001_Nfmk00A_N`D000i_N`03001_Nfmk00a_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/01000Kg]_N`002Fmk00<006mkKg/07Fmk000G
Kg/50006Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/;000=Kg/00`00Kg]_N`03
Kg/01@00Kg/006mk000046mk00D006mk001_N`00009_N`03001_Nfmk00A_N`03001_Nfmk00]_N`04
001_Nfmk0007Kg/60006Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/016mk00<006mkKg/00Vmk00<0
06mkKg/026mk00<006mkKg/00Vmk00<006mkKg/016mk00D006mkKg]_N`0000M_N`03001_Nfmk00=_
N`05001_Nfmk001_N`020004Kg/80006Kg/01000Kg]_N`003fmk00<006mkKg/02Fmk00<006mkKg/0
26mk00<006mkKg/026mk00<006mkKg/016mk1@003fmk00<006mkKg/036mk00D006mkKg]_N`0000E_
N`03001_Nfmk00Q_N`03001_Nfmk00]_N`05001_NfmkKg/00009Kg/00`00Kg]_N`0MKg/001M_N`D0
00I_N`03001_Nfmk00e_N`03001_Nfmk009_N`03001_Nfmk00Y_N`D001=_N`03001_Nfmk009_N`06
001_Nfmk001_N`0046mk00D006mk001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk00U_N`8000=_
N`03001_Nfmk00I_N`D000I_N`05001_NfmkKg/00003Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`04Kg/01000Kg/006mk0P0016mk1@0026mk00<006mkKg/00Vmk00<006mkKg/02fmk00<0
06mkKg/02Vmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/01Fmk1@003fmk00<006mkKg/0
3Fmk00D006mkKg]_N`0000E_N`03001_Nfmk00I_N`03001_Nfmk00a_N`05001_NfmkKg/00009Kg/0
0`00Kg]_N`0MKg/001M_N`D000I_N`03001_Nfmk00i_N`05001_NfmkKg/0000<Kg/7000AKg/01@00
Kg]_Nfmk00000Vmk00D006mkKg]_N`0000i_N`03001_N`0000=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/50006Kg/00`00Kg]_N`02Kg/30007Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg/00002Kg/30002Kg/50007Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/5000?
Kg/00`00Kg]_N`0=Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Fmk00<006mkKg/03Fmk00D006mk
Kg]_N`0000Y_N`03001_Nfmk01a_N`0066mk0`001Vmk00<006mkKg/03fmk00D006mkKg]_N`0000]_
N`03001_N`0000800003Kg/0000000<000i_N`05001_NfmkKg/00002Kg/01@00Kg]_Nfmk00003Fmk
00@006mkKg/000=_N`03001_Nfmk009_N`8000=_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_
Nfmk00A_N`800003Kg/0000000<000E_N`04001_NfmkKg/50006Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`06Kg/00`00Kg/00006000016mk0000000026mk00<006mkKg/00fmk00<006mkKg/02fmk00<006mk
Kg/036mk00<006mkKg/01Vmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mk00000P0000=_N`00
Kg/036mk00<006mkKg/03fmk00@006mkKg/000E_N`03001_Nfmk00A_N`03001_Nfmk00e_N`05001_
NfmkKg/0000;Kg/00`00Kg]_N`0LKg/001Q_N`800003Kg/006mk00A_N`03001_Nfmk011_N`04001_
Nfmk000:Kg/01000Kg]_N`001Fmk0P0000A_N`00000000]_N`04001_Nfmk0003Kg/01@00Kg]_Nfmk
000036mk00D006mkKg]_N`0000=_N`03001_Nfmk00A_N`05001_NfmkKg/00005Kg/20007Kg/00`00
Kg]_N`03Kg/01000Kg]_N`000fmk00<006mk000016mk00@006mkKg]_N`D000M_N`03001_Nfmk00=_
N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk00=_N`05001_NfmkKg/0
0009Kg/70002Kg/20008Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0>Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00000fmk0P002fmk00<006mkKg/0
46mk00<006mk00001Vmk00<006mkKg/00Vmk00<006mkKg/03Vmk00D006mkKg]_N`0000]_N`03001_
Nfmk01a_N`0066mk0P0000=_N`00Kg/016mk00<006mkKg/046mk00@006mkKg/000Q_N`8000=_N`03
001_Nfmk00E_N`80009_N`<000Q_N`03001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`04Kg/01000Kg]_N`0016mk00<006mkKg/01fmk00@006mkKg]_
N`8000=_N`05001_NfmkKg/00002Kg/01@00Kg]_Nfmk00000fmk1P001Vmk00<006mkKg/016mk00<0
06mkKg/00fmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/00fmk00@006mkKg/000U_N`L0
009_N`8000M_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00i_N`03001_Nfmk00E_N`03
001_Nfmk00A_N`03001_Nfmk00A_N`8000A_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk
011_N`03001_N`0000I_N`05001_NfmkKg/0000AKg/01@00Kg]_Nfmk000036mk00<006mkKg/06fmk
000HKg/20002Kg/01@00Kg]_Nfmk000056mk00<006mk00001fmk00<006mkKg/00fmk00<006mkKg/0
1fmk0P000fmk0`000fmk100016mk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00<006mkKg/01Fmk1@0000=_N`00Kg/01fmk0`0000=_N`00000016mk00<006mkKg/0
0fmk1`000Vmk00<006mk00000P000Vmk0`000Vmk0`001Fmk00<006mkKg/00Vmk00<006mkKg/016mk
00<006mkKg/01fmk00<006mkKg/016mk0`002Vmk1@000fmk00<006mkKg/01Fmk00<006mkKg/026mk
00<006mkKg/01fmk00<006mkKg/046mk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/00fmk
00<006mkKg/01Fmk00<006mkKg/00fmk0P001fmk00<006mkKg/04Vmk0`001Fmk10004Vmk00D006mk
Kg]_N`0000a_N`03001_Nfmk01]_N`0066mk0P000fmk00@006mkKg/001E_N`03001_N`0000A_N`80
00E_N`03001_Nfmk00Y_N`8000A_N`L000A_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk
009_N`03001_Nfmk00=_N`03001_Nfmk00I_N`D000Q_N`D000E_N`03001_Nfmk00=_N`X000E_N`03
001_Nfmk009_N`H000E_N`05001_NfmkKg/00006Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/50008
Kg/60002Kg/20007Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0AKg/00`00Kg]_N`03
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/20008Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`0AKg/50003Kg/5000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0KKg/001Q_
N`8000=_N`04001_Nfmk000EKg/00`00Kg/00003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<Kg/20004
Kg/50003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`05Kg/B0005Kg/00`00Kg]_N`03Kg/90006Kg/00`00Kg]_N`03Kg/50005Kg/01000Kg]_N`00
1fmk00<006mkKg/026mk00<006mkKg/00Vmk4`000Vmk0P001Vmk00<006mkKg/02Fmk00<006mkKg/0
1fmk00<006mkKg/04Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/0
26mk00<006mkKg/01Vmk0P0016mk00<006mkKg/046mk3`0046mk00<006mkKg/00Vmk00<006mkKg/0
2fmk00<006mkKg/06Vmk000HKg/20004Kg/3000FKg/300000fmk001_N`07Kg/00`00Kg]_N`0>Kg/2
00000fmk000000040003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`05Kg/50008Kg/50002Kg/30004Kg/>0004Kg/300000fmk000000060004Kg/3
0006Kg/30009Kg/30002Kg/50008Kg/60002Kg/20005Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`0CKg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000fmk0P002fmk00<006mkKg/026mk00<0
06mk00000P002Vmk200000=_N`0000000`000fmk1@0000=_N`00000010001fmk10000fmk00<006mk
Kg/036mk00<006mkKg/06Vmk000GKg/00`00Kg/00003Kg/5000DKg/50008Kg/00`00Kg]_N`0AKg/6
0004Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`05Kg/4000:Kg/300000fmk000000070003Kg/70004Kg/=0003Kg/80004Kg/50007Kg/600000fmk
000000030008Kg/300001Vmk001_N`00Kg/000E_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_
Nfmk01A_N`05001_NfmkKg/00003Kg/01000Kg]_N`003Fmk00<006mkKg/02Fmk1@0000=_N`000000
1P002Vmk0`001Fmk0`0026mk2`000fmk00<006mkKg/036mk00<006mkKg/06Vmk000GKg/00`00Kg/0
0003Kg/N0008Kg/00`00Kg]_N`0AKg/500001Fmk001_Nfmk00002Fmk00D006mkKg]_N`0000I_N`03
001_Nfmk00M_N`03001_Nfmk00=_N`05001_NfmkKg/0000:Kg/00`00Kg]_N`02Kg/50005Kg/01000
Kg]_N`000fmk00<006mkKg/01Fmk:P000Vmk00<006mkKg/00Vmk00<006mkKg/016mk00@006mkKg]_
N`800004Kg/006mk0004Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0FKg/01000Kg]_
N`000Vmk00@006mkKg/000i_N`03001_Nfmk00U_N`H0015_N`03001_N`0000E_N`03001_N`0000m_
N`D000=_N`03001_Nfmk00e_N`03001_Nfmk01U_N`005fmk00<006mk00000fmk1@0056mk1P001fmk
00<006mkKg/02fmk2`0000E_N`00Kg]_N`0000U_N`04001_Nfmk0007Kg/00`00Kg]_N`07Kg/01000
Kg]_Nfmk0P0016mk00<006mkKg/01fmk00<006mkKg/00fmk1@001Fmk00<006mk000016mk00<006mk
Kg/01Fmk2@001fmk1@0016mk1@001fmk1@000Vmk00<006mkKg/00fmk00<006mkKg/00fmk00@006mk
Kg]_N`800004Kg/006mk0003Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0GKg/01P00
Kg/006mk001_N`8000m_N`03001_Nfmk00U_N`D0015_N`04001_Nfmk0005Kg/00`00Kg/0000?Kg/5
0003Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0IKg/001M_N`04001_Nfmk0003Kg/4000EKg/30002Kg/3
0002Kg/30007Kg/60007Kg/300000fmk001_N`030009Kg/40005Kg/30009Kg/40006Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`03Kg/400000fmk001_N`050006Kg/00`00Kg]_N`05Kg/3000016mk00000000
1fmk1@0000=_N`0000000fmk0`0026mk10000fmk00<006mkKg/016mk1@001Fmk0`0000E_N`00Kg]_
N`00019_N`05001_NfmkKg/0000JKg/400000fmk001_N`0@Kg/00`00Kg]_N`07Kg/200001Fmk0000
0000Kg/00P003fmk00@006mkKg/000A_N`05001_NfmkKg/0000?Kg/40003Kg/00`00Kg]_N`0=Kg/0
0`00Kg]_N`0IKg/001M_N`04001_Nfmk0004Kg/01000Kg]_N`005Vmk00<006mkKg/00fmk300036mk
0P0016mk1@001fmk1@0016mk1@001fmk1@001Vmk00<006mkKg/01fmk00<006mkKg/00fmk00<006mk
00000fmk1@001fmk00<006mkKg/016mk00H006mkKg/006mk0008Kg/01@00Kg]_Nfmk000016mk00<0
06mkKg/00Vmk00<006mkKg/01Fmk00D006mkKg]_N`00009_N`03001_Nfmk00E_N`D000A_N`H0009_
N`03001_Nfmk011_N`05001_NfmkKg/0000JKg/5000BKg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`02000<Kg/01@00Kg]_Nfmk000016mk00D006mkKg]_N`0000i_N`05001_N`00Kg/00003
Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0HKg/001I_N`05001_NfmkKg/00004Kg/01000Kg]_Nfmk0P00
56mk00<006mkKg/016mk1@004Vmk0P0016mk9P001fmk00<006mkKg/01Fmk00<006mkKg/00fmk00@0
06mkKg/000=_N`D000M_N`03001_Nfmk00A_N`06001_Nfmk001_N`001fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk0P000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00@006mkKg/000M_N`h0009_N`03
001_Nfmk015_N`05001_NfmkKg/0000IKg/6000CKg/00`00Kg]_N`03Kg/20007Kg/00`00Kg]_N`02
Kg/2000:Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/00Vmk00<006mkKg/02Vmk0P0000=_N`00Kg/0
0Vmk00@006mkKg/0011_N`03001_Nfmk01Q_N`005Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00A_
N`03001_Nfmk015_N`03001_Nfmk00A_N`D0015_N`03001_N`0000A_N`D000M_N`D000A_N`D000M_
N`D000M_N`03001_Nfmk00E_N`03001_Nfmk009_N`05001_NfmkKg/00003Kg/50007Kg/00`00Kg]_
N`03Kg/01`00Kg]_Nfmk001_N`0000I_N`03001_Nfmk00=_N`03001_Nfmk00E_N`04001_Nfmk0004
Kg/00`00Kg]_N`03Kg/01000Kg]_N`001fmk1@0016mk1@0000=_N`00Kg/056mk00<006mk00004Vmk
50003Fmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mkKg/00fmk0P001fmk00<006mkKg/00Vmk
00@006mkKg/000E_N`03001_Nfmk00U_N`05001_NfmkKg/00003Kg/00`00Kg/0000AKg/00`00Kg]_
N`0HKg/001I_N`05001_NfmkKg/00003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0AKg/00`00Kg]_N`04
Kg/300000fmk001_N`0?Kg/00`00Kg/00004Kg/40008Kg/40006Kg/30008Kg/50007Kg/00`00Kg]_
N`05Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00Vmk10001fmk00<006mkKg/00fmk00L006mkKg]_
N`00Kg/00004Kg/20006Kg/00`00Kg]_N`06Kg/200000fmk000000020006Kg/00`00Kg/00007Kg/6
0005Kg/5000FKg/3000:Kg/800000fmk000000020005Kg/30007Kg/50007Kg/300000fmk0000000;
Kg/00`00Kg]_N`05Kg/20002Kg/30005Kg/01000Kg]_N`001Fmk00<006mkKg/026mk00<006mkKg/0
0Vmk00<006mkKg/00Vmk0`004Fmk00<006mkKg/05fmk000FKg/01@00Kg]_Nfmk00000fmk00<006mk
Kg/01Vmk00<006mkKg/046mk00<006mkKg/01Fmk0P000Vmk00<006mkKg/036mk00@006mkKg/000=_
N`04001_Nfmk0008Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/026mk00<006mk00000Vmk00<006mk
Kg/016mk00<006mkKg/016mk00<006mkKg/00Vmk00D006mkKg]_N`0000E_N`05001_N`00Kg/00006
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg/00003Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08
Kg/50006Kg/00`00Kg/00005Kg/200000fmk001_N`02Kg/20003Kg/00`00Kg/00004000DKg/50000
0fmk000000060005Kg/40009Kg/00`00Kg/0000<Kg/;000>Kg/00`00Kg]_N`06Kg/60004Kg/00`00
Kg/00006Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/5000@Kg/00`00Kg]_N`0G
Kg/001I_N`05001_NfmkKg/00003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`05Kg/0
0`00Kg/00002Kg/2000<Kg/01@00Kg]_N`00Kg/00P000fmk00<006mkKg/01Vmk00D006mkKg]_N`00
00I_N`03001_Nfmk00M_N`04001_Nfmk0003Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk000016mk00<006mkKg/00Vmk0P0000E_N`00Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
009_N`03001_N`00009_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`D000I_N`03001_N`0000=_N`80
009_N`03001_Nfmk009_N`8000=_N`03001_N`0001h000U_N`@000e_N`03001_N`00019_N`D000i_
N`03001_Nfmk00M_N`D000A_N`03001_N`0000I_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_
Nfmk009_N`D0011_N`03001_Nfmk01M_N`005Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00Q_N`03
001_Nfmk00i_N`03001_Nfmk00E_N`03001_N`0000A_N`03001_Nfmk00Q_N`03001_N`0000<000E_
N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00I_N`05001_NfmkKg/0
0004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk0P00
0Vmk00@006mkKg/000A_N`05001_NfmkKg/00005Kg/5000:Kg/00`00Kg]_N`08Kg/70004Kg/30000
0fmk00000003Kg/00`00Kg]_N`03Kg/00`00Kg/000020002Kg/500000fmk00000006000:Kg/70005
Kg/4000AKg/00`00Kg/0000BKg/5000?Kg/00`00Kg]_N`06Kg/60002Kg/30007Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/5000AKg/00`00Kg]_N`0FKg/001E_N`03001_Nfmk009_
N`05001_NfmkKg/0000;Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`04Kg/00`00Kg/00005Kg/00`00Kg]_
N`07Kg/60005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01000Kg]_N`001Vmk
00<006mkKg/00Vmk0P000Vmk00D006mkKg]_N`0000=_N`05001_NfmkKg/00004Kg/5000;Kg/00`00
Kg]_N`06Kg/2000016mk000000000fmk200016mk00<006mkKg/016mk1`0000A_N`00000000Y_N`P0
0003Kg/0000000/001A_N`05001_NfmkKg/0000?Kg/200001Fmk00000000Kg/00P003Fmk00<006mk
Kg/01fmk0`000Vmk1P001Vmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/00fmk100000=_
N`0000003fmk00<006mkKg/05Vmk000EKg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk000036mk0P003Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`8000I_N`03001_N`0000@000E_N`03001_Nfmk00=_
N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`03001_Nfmk009_N`03001_Nfmk009_N`03001_N`0000M_N`07001_NfmkKg/006mk00000Vmk00<0
06mkKg/00Vmk00L006mkKg]_N`00Kg/00005Kg/5000;Kg/00`00Kg]_N`04Kg/20003Kg/00`00Kg]_
N`06Kg/50003Kg/00`00Kg]_N`05Kg/60003Kg/00`00Kg]_N`0AKg/:000HKg/01@00Kg]_Nfmk0000
3Fmk0P000fmk00<006mkKg/00fmk0P0036mk00<006mkKg/01Vmk00<006mkKg/00fmk1@001fmk00@0
06mkKg]_N`8000M_N`03001_Nfmk009_N`03001_Nfmk009_N`04001_Nfmk000>Kg/00`00Kg]_N`0F
Kg/001E_N`03001_Nfmk009_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001fmk00<006mkKg/00fmk00<006mk000010001Fmk00<006mkKg/00Vmk00<006mk
Kg/01Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/016mk00<006mk
Kg/00Vmk00@006mkKg/0009_N`03001_Nfmk00E_N`04001_NfmkKg/20004Kg/00`00Kg]_N`02Kg/0
1P00Kg]_N`00Kg/000A_N`T000Q_N`03001_Nfmk009_N`8000E_N`03001_Nfmk00I_N`D0009_N`03
001_Nfmk00I_N`H000=_N`03001_Nfmk00a_Na8001E_N`05001_NfmkKg/0000;Kg/20005Kg/00`00
Kg]_N`05Kg/2000;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/60006Kg/01000Kg]_N`0026mk00<0
06mkKg/00Vmk00<006mkKg/00fmk00@006mkKg]_N`8000e_N`03001_Nfmk01E_N`005Fmk00<006mk
Kg/00Vmk00D006mkKg]_N`0000m_N`03001_Nfmk00]_N`03001_Nfmk009_N`05001_NfmkKg/00008
Kg/00`00Kg/0000200000fmk001_N`040005Kg/01@00Kg]_Nfmk00002Fmk00<006mkKg/00Vmk00<0
06mkKg/016mk00<006mkKg/016mk00<006mkKg/01Fmk00D006mkKg]_N`00009_N`03001_N`0000Q_
N`04001_NfmkKg/20004Kg/00`00Kg]_N`03Kg/40002Kg/30002Kg/50002Kg/30004Kg/300000fmk
00000007Kg/00`00Kg]_N`04Kg/200000fmk000000040009Kg/500000fmk001_N`030007Kg/60007
Kg/3000016mk0000000016mk0`004Fmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01Fmk
00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/00fmk1@0000A_N`000000
009_N`@000U_N`03001_Nfmk008000M_N`03001_Nfmk009_N`8000]_N`03001_Nfmk01E_N`005Fmk
00<006mkKg/00Vmk00@006mkKg/0015_N`03001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk009_
N`03001_Nfmk00I_N`D000I_N`03001_Nfmk009_N`04001_Nfmk000:Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/01000Kg]_N`000Vmk0P002Fmk00H006mkKg/0
06mk0004Kg/00`00Kg]_N`03Kg/60006Kg/50004Kg/80009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/50008Kg/50003Kg/;000=Kg/200000fmk001_N`02Kg/00`00Kg]_N`04Kg/4000=Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`05Kg/20008Kg/00`00Kg]_N`08Kg/20009Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk1P002Fmk00<006mk00002Vmk00<006mkKg/00fmk0P00
2Fmk00<006mkKg/05Fmk000DKg/00`00Kg]_N`03Kg/01000Kg]_N`004Vmk00<006mkKg/02Fmk00<0
06mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk1@001fmk0P000Vmk00@006mkKg/000]_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/01000Kg/006mk0P002Vmk00H006mk
Kg/006mk0005Kg/00`00Kg]_N`02Kg/M0009Kg/01000Kg]_Nfmk0P001Fmk6P004fmk0P0000=_N`00
Kg/00Vmk00<006mkKg/026mk10002Fmk00<006mkKg/00fmk00<006mkKg/00fmk0P002Vmk00<006mk
Kg/02Vmk0P001fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/01Fmk0P000Vmk1@0026mk
00<006mk00002fmk00<006mkKg/01Fmk00<006mkKg/01fmk00<006mkKg/056mk000DKg/00`00Kg]_
N`03Kg/01000Kg]_N`004fmk00<006mkKg/026mk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk
Kg/01Fmk2@001Fmk1@0036mk00D006mkKg]_N`0000A_N`03001_Nfmk00I_N`03001_Nfmk00Q_N`D0
00Y_N`03001_N`00009_N`03001_Nfmk00=_N`03001_Nfmk009_N`D000M_N`D000M_N`P000A_N`<0
0003Kg/0000000I_N`L000A_N`P0009_N`P0015_N`<000E_N`03001_Nfmk00]_N`<000A_N`<000E_
N`<00003Kg/0000000Y_N`<000i_N`8000I_N`03001_Nfmk009_N`05001_NfmkKg/0000:Kg/90004
Kg/4000=Kg/30005Kg/20007Kg/00`00Kg]_N`0DKg/001A_N`03001_Nfmk00=_N`04001_Nfmk000D
Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Vmk0`001Fmk2P0036mk00D006mk
Kg]_N`0000=_N`03001_Nfmk00M_N`03001_Nfmk00M_N`D000]_N`03001_N`00009_N`03001_Nfmk
00=_N`03001_Nfmk00=_N`<000Q_N`@000Q_N`L00003Kg/0000000H000M_N``000A_N`<00003Kg/0
000000D000=_N`<000e_N`D000A_N`03001_Nfmk00i_N`P000=_N`D000]_N`D000m_N`03001_Nfmk
00=_N`05001_NfmkKg/00003Kg/00`00Kg]_N`09Kg/60003Kg/8000<Kg/50006Kg/20005Kg/00`00
Kg]_N`0DKg/001A_N`03001_Nfmk00=_N`04001_Nfmk000EKg/20008Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/01Fmk00<006mkKg/02fmk1@0036mk00@006mkKg/000=_N`03001_Nfmk00Q_N`03001_
Nfmk00M_N`D000]_N`05001_N`00Kg/00007Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01Fmk00@0
06mkKg]_N`8000I_N`03001_Nfmk01h000I_N`03001_Nfmk00=_N`H000I_N`<000Y_N`D000E_N`03
001_Nfmk011_Nah000m_N`8000A_N`04001_Nfmk0002Kg/00`00Kg]_N`0:Kg/R0008Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`0CKg/001A_N`03001_Nfmk00=_N`04001_Nfmk000GKg/00`00Kg]_N`05Kg/0
1@00Kg]_Nfmk00001Vmk00<006mkKg/00fmk00<006mkKg/02Vmk200036mk00<006mk00000fmk00<0
06mkKg/026mk00<006mkKg/01fmk1P002Fmk00<006mk00000Vmk00<006mkKg/01Fmk00@006mkKg/0
00=_N`03001_Nfmk00A_N`03001_Nfmk009_N`8000A_N`8000=_N`D000A_N`D000M_N`T000E_N`03
001_Nfmk009_N`P000U_N`<000M_N`D000E_N`03001_Nfmk011_N`D000=_N`D000]_N`D00003Kg/0
000000D000Y_N`80009_N`06001_Nfmk001_N`0026mk2P001fmk1@0036mk2@001Fmk0P000fmk00<0
06mkKg/04fmk000DKg/00`00Kg]_N`03Kg/01000Kg]_N`0066mk00<006mkKg/01Fmk00@006mkKg/0
00I_N`03001_Nfmk009_N`03001_Nfmk00Q_N`<000=_N`<00003Kg/00000008000U_N`03001_N`00
009_N`03001_Nfmk00U_N`03001_Nfmk00Q_N`<0009_N`8000M_N`03001_N`00009_N`03001_Nfmk
00E_N`<000A_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_N`0000<000A_N`D000I_N`<000U_
N`<00003Kg/0000000<00004Kg/000000003Kg/20002Kg/400000fmk001_N`0;Kg/30002Kg/80005
Kg/00`00Kg]_N`0>Kg/00`00Kg/000030004Kg/300000fmk0000000:Kg/30009Kg/60006Kg/20000
0fmk000000020005Kg/40006Kg/40008Kg/3000=Kg/40005Kg/50002Kg/2000016mk000000004fmk
000CKg/00`00Kg]_N`04Kg/01000Kg]_N`006Fmk00<006mkKg/016mk00@006mkKg/000I_N`03001_
Nfmk009_N`03001_Nfmk00E_N`<000Q_N`04001_Nfmk0002Kg/20007Kg/01@00Kg/006mk000036mk
00<006mkKg/01fmk00<006mk00001Fmk00<006mkKg/016mk00<006mk00000Vmk00<006mkKg/016mk
1@000fmk00<006mkKg/00Vmk00<006mkKg/016mk1P000fmk1P001Fmk00D006mkKg]_N`0000Q_N`03
001_N`00009_N`/000=_N`03001_N`00009_N`03001_N`0000i_N`H000A_N`03001_Nfmk00=_N`03
001_Nfmk00a_N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06
Kg/01000Kg]_N`003fmk1`0000=_N`00000020002fmk00@006mkKg/000I_N`03001_Nfmk008000]_
N`03001_N`0000a_N`T0019_N`004fmk00<006mkKg/016mk00@006mkKg/001Y_N`03001_Nfmk00=_
N`04001_Nfmk0007Kg/01000Kg]_N`001Fmk0`002fmk00@006mkKg]_N`80009_N`8000E_N`04001_
N`00000=Kg/00`00Kg]_N`07Kg/00`00Kg/00006Kg/20004Kg/20003Kg/00`00Kg]_N`04Kg/50003
Kg/01@00Kg]_Nfmk00001fmk3`001Fmk00D006mkKg]_N`0000Q_N`03001_N`00009_N`T000=_N`80
009_N`06001_Nfmk001_N`003fmk1@001Fmk00<006mkKg/00Vmk00<006mkKg/02Vmk0P0016mk00@0
06mkKg]_N`80009_N`03001_Nfmk00=_N`8000I_N`04001_Nfmk000FKg/6000@Kg/01000Kg]_Nfmk
0P0016mk00H006mkKg/006mk0009Kg/01000Kg]_N`0046mk1@004Vmk000CKg/00`00Kg]_N`04Kg/0
0`00Kg/0000LKg/00`00Kg]_N`02Kg/00`00Kg/00008Kg/00`00Kg/00003Kg/3000>Kg/00`00Kg]_
N`03Kg/01000Kg]_Nfmk0`000fmk00<006mk00003Fmk00<006mkKg/01Vmk00<006mk00002Fmk0P00
0Vmk0P000Vmk00<006mkKg/00fmk20000fmk00<006mk00002Fmk1@000fmk1P0016mk00<006mkKg/0
0fmk00<006mkKg/01Fmk00<006mk00000Vmk2@000Vmk00<006mkKg/00Vmk00@006mkKg]_N`8000m_
N`L000A_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_
N`0000M_N`8000=_N`05001_NfmkKg/0000DKg/8000@Kg/00`00Kg]_N`03Kg/01000Kg]_N`000fmk
00<006mk000026mk00D006mkKg]_N`00011_N`D0019_N`004fmk00<006mkKg/016mk00<006mk0000
7Fmk00<006mkKg/00Vmk0P0026mk1P004Vmk00<006mkKg/00fmk00<006mkKg/00fmk1@003Vmk00<0
06mkKg/01Fmk00@006mkKg/000]_N`@00003Kg/0000000D00003Kg/0000000X000U_N`D000E_N`<0
009_N`05001_NfmkKg/00005Kg/00`00Kg]_N`04Kg/01000Kg]_N`000fmk2P001Fmk00L006mkKg]_
N`00Kg/0000;Kg/70003Kg/20003Kg/20002Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/30005Kg/3
0008Kg/40003Kg/00`00Kg]_N`0?Kg/30004Kg/4000@Kg/00`00Kg]_N`04Kg/30003Kg/01000Kg]_
N`001fmk00D006mkKg]_N`0000m_N`D001=_N`004fmk00<006mkKg/01Fmk0P007Vmk0P000Vmk0P00
1fmk1@0056mk00<006mkKg/016mk0P0016mk1@003Fmk00<006mkKg/016mk00D006mkKg]_N`0000]_
NbH00003Kg/006mk00=_N`06001_Nfmk001_N`000Vmk00<006mkKg/01Fmk00<006mkKg/00fmk00@0
06mkKg/0009_N`03001_N`0000P000E_N`03001_Nfmk009_N`8000U_N`80009_N`06001_Nfmk001_
N`0016mk0P000fmk00@006mkKg/000I_N`8000I_NaT0009_N`03001_Nfmk00]_N`@000M_N`05001_
NfmkKg/0000?Kg/00`00Kg]_N`03Kg/50002Kg/01000Kg]_N`001Vmk00<006mkKg/00Vmk00<006mk
Kg/036mk00<006mkKg/00Vmk00<006mkKg/04Fmk000BKg/00`00Kg]_N`06Kg/2000PKg/01000Kg/0
00001Vmk1P0056mk00<006mkKg/01Vmk00@006mkKg]_N`D000e_N`03001_Nfmk00=_N`05001_Nfmk
Kg/0000;Kg/:0003Kg/>0006Kg/600000fmk001_N`03Kg/01000Kg]_Nfmk0P000Vmk00<006mkKg/0
1Fmk00<006mkKg/00fmk00@006mkKg/0009_N`03001_N`0000T000A_N`03001_Nfmk009_N`8000M_
N`80009_N`8000=_N`03001_N`0000I_N`<00004Kg/006mk0005Kg/00`00Kg]_N`03Kg/80003Kg/5
0007Kg/50002Kg/00`00Kg]_N`07Kg/4000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_
N`03Kg/50002Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00fmk00<006mkKg/02fmk00<006mkKg/0
0fmk00<006mkKg/04Fmk000BKg/00`00Kg]_N`06Kg/2000QKg/40002Kg/300000fmk00000004000C
Kg/00`00Kg]_N`07Kg/:000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/20000
0fmk000000070003Kg/?0002Kg/90002Kg/01@00Kg]_Nfmk00000fmk10002Fmk00<006mkKg/00Vmk
00<006mkKg/00`0000=_N`0000002P0000A_N`00000000E_N`<0009_N`<000=_N`03001_Nfmk009_
N`04001_Nfmk0009Kg/7000016mk001_Nfmk10000fmk1@000fmk1@001fmk1P0000A_N`00000000A_
N`<000m_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00=_N`H00005Kg/00000001_N`03
00000fmk001_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/0019_N`03001_
Nfmk00I_N`80025_N`H000A_N`@0009_N`03001_Nfmk015_N`03001_Nfmk00I_N`L000=_N`8000U_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`05Kg/20003Kg/800000fmk001_N`02Kg/70002Kg/70002
Kg/6000016mk001_N`000fmk00<006mkKg/01@002Fmk00D006mkKg]_N`00009_N`D0009_N`<00003
Kg/0000000T000=_N`H000E_N`03001_Nfmk00=_N`04001_Nfmk000;Kg/90008Kg/300000fmk001_
N`02Kg/40008Kg/30002Kg/8000BKg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/4
0002Kg/90006Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0AKg/0019_N`03001_Nfmk
00I_N`80025_N`D000E_N`03001_N`0000A_N`03001_Nfmk011_N`03001_Nfmk00I_N`H000I_N`80
00M_N`04001_Nfmk0005Kg/00`00Kg]_N`04Kg/20004Kg/00`00Kg/00002Kg/01`00Kg]_Nfmk001_
N`0000=_NaH000=_N`03001_N`00009_N`03001_Nfmk00D000Y_N`04001_Nfmk0002Kg/50004Kg/0
1000Kg]_Nfmk4@0016mk0P001Fmk00D006mkKg]_N`0000a_N`D000Y_N`03001_Nfmk00=_N`03001_
Nfmk00=_N`03001_Nfmk00I_N`8000=_N`D001E_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_
Nfmk00=_N`03001_Nfmk00=_N`T000I_N`03001_Nfmk00Q_N`8000U_N`03001_Nfmk011_N`004Vmk
00<006mkKg/01Vmk0P0076mk2P0016mk00@006mkKg/000E_N`80011_N`03001_Nfmk00I_N`D00003
Kg/00000008000A_N`8000E_N`04001_Nfmk0005Kg/00`00Kg]_N`02Kg/20005Kg/01000Kg]_N`00
0fmk00@006mkKg]_N`<0009_N`D0009_N`L000=_N`H000=_N`80009_N`03001_Nfmk00T000I_N`04
001_Nfmk0002Kg/50004Kg/01000Kg]_Nfmk2@000fmk1@000fmk00<006mkKg/01Fmk00D006mkKg]_
N`0000U_N`P000Y_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00E_N`8000=_N`/000m_
N`03001_Nfmk00I_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00A_N`T000I_N`03001_
Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk011_N`004Fmk00<006mkKg/01fmk0P005Vmk1P001Vmk
0`001Fmk00@006mkKg/000M_N`03001_Nfmk00i_N`03001_Nfmk00I_N`@000E_N`D00003Kg/00000
009_N`@000A_N`<0009_N`8000I_N`05001_NfmkKg/00003Kg/00`00Kg]_N`03Kg/700000fmk0000
0003Kg/30005Kg/30002Kg/300000fmk0000000200000fmk0000000300000fmk001_N`02Kg/30004
Kg/300000fmk001_N`040004Kg/00`00Kg]_N`02Kg/3000016mk0000000016mk1P0000=_N`00Kg/0
1fmk00@006mkKg]_N`<000A_N`<000A_N`<000Y_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_
Nfmk00A_N`03001_N`0000A_N`<00003Kg/0000000A_N`H000M_N`<000U_N`8000Q_N`03001_Nfmk
009_N`03001_Nfmk00=_N`X000I_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`03001_Nfmk011_N`00
4Fmk00<006mkKg/01fmk00<006mkKg/046mk1@003fmk00D006mkKg]_N`00009_N`03001_Nfmk00M_
N`03001_Nfmk00e_N`03001_Nfmk00M_N`04001_Nfmk0009Kg/90003Kg/60007Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/70007Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk000016mk
2`000Vmk00<006mkKg/00fmk20000Vmk00D006mk001_N`0000=_N`0;001_NfmkKg/006mk001_N`00
Kg/00004Kg/00`00Kg]_N`050008Kg/01000Kg]_Nfmk20002Fmk00<006mkKg/026mk00<006mkKg/0
1fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk00000fmk00D006mkKg]_N`00009_N`8000Q_
N`/000Y_N`03001_Nfmk00E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00D006mkKg]_
N`0000A_N`03001_Nfmk00I_N`03001_Nfmk00]_N`03001_Nfmk011_N`004Fmk00<006mkKg/01fmk
00<006mkKg/02fmk1@0056mk00D006mkKg]_N`00009_N`03001_Nfmk00Q_N`8000e_N`03001_Nfmk
00I_N`05001_NfmkKg/0000=Kg/=0008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/50009Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001Fmk2P000fmk0P001Vmk1@000Vmk00<006mk
00000Vmk0P0000E_N`00Kg]_N`00009_N`05001_N`00Kg/00002Kg/20003Kg/50008Kg/01000Kg]_
Nfmk1@0036mk00<006mkKg/026mk00<006mkKg/026mk0P000Vmk00<006mkKg/00fmk00<006mk0000
0fmk00D006mkKg]_N`0000A_N`03001_Nfmk00]_N`D000]_N`03001_Nfmk00A_N`05001_NfmkKg/0
0004Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00Vmk00<006mkKg/016mk0P00
3fmk00<006mkKg/03fmk000AKg/00`00Kg]_N`06Kg/30006Kg/6000JKg/30003Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/50003Kg/50007
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/50009Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk2P001Fmk100000=_N`00000010000Vmk00<006mk000016mk10000Vmk0`0000=_
N`0000000P000fmk2@0016mk0`000Vmk1P0036mk00<006mkKg/01fmk00<006mkKg/02fmk00@006mk
Kg/000A_N`03001_N`00009_N`03001_Nfmk00=_N`03001_Nfmk009_N`8000]_N`L000Y_N`03001_
Nfmk00=_N`04001_Nfmk0004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg]_N`000fmk00<0
06mkKg/00fmk00<006mkKg/03fmk00<006mkKg/03fmk000AKg/00`00Kg]_N`05Kg/:000OKg/50002
Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;
Kg/40004Kg/30007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/300000fmk0000
0007Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00fmk2P0016mk2P000fmk00<006mk000016mk4@00
0Vmk10000fmk2@000Vmk100036mk00<006mkKg/01fmk00<006mkKg/036mk00<006mk00000fmk00@0
06mkKg/0009_N`03001_Nfmk00A_N`03001_Nfmk00=_N`8000Y_N`<000=_N`<000Q_N`03001_Nfmk
009_N`04001_Nfmk0002Kg/20005Kg/00`00Kg]_N`04Kg/00`00Kg/00003Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0@Kg/00`00Kg]_N`0?Kg/0015_N`03001_Nfmk00E_Nbh0009_N`03001_Nfmk00a_N`80
00Y_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk
009_N`03001_N`0000E_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk009_N`8000A_N`80
00E_N`04001_Nfmk0007Kg/01P00Kg]_Nfmk001_NaH00007Kg/006mkKg/006mk000016mk3P0016mk
00D006mkKg]_N`0000I_N`D000=_N`05001_N`00Kg/0000;Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0>
Kg/00`00Kg/00002Kg/01P00Kg]_N`00Kg/000M_N`03001_Nfmk00E_N`03001_Nfmk00I_N`05001_
NfmkKg/00005Kg/30006Kg/01`00Kg]_Nfmk001_N`00009_N`03001_Nfmk00E_N`03001_Nfmk00E_
N`03001_N`00009_N`05001_NfmkKg/0000CKg/00`00Kg]_N`0?Kg/0011_N`03001_Nfmk00I_N`D0
02A_N`D0009_N`03001_Nfmk00i_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03
001_Nfmk00U_N`03001_Nfmk00=_N`80009_N`04001_Nfmk0003Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`06Kg/01000Kg]_Nfmk0P001Vmk0P000fmk00@006mkKg/000M_N`06001_NfmkKg/006mk2@0016mk
2@0000M_N`00Kg]_N`00Kg/00004Kg/>0002Kg/20004Kg/00`00Kg]_N`04Kg/50003Kg/00`00Kg/0
0002Kg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0?Kg/20002Kg/01P00Kg]_N`00Kg/0
00Q_N`03001_Nfmk00E_N`8000I_N`05001_NfmkKg/00008Kg/30004Kg/02000Kg]_N`00Kg/006mk
0008Kg/00`00Kg]_N`06Kg/20002Kg/01000Kg]_N`005Fmk00<006mkKg/03Vmk000@Kg/00`00Kg]_
N`07Kg/3000UKg/40003Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/400001Vmk00000000Kg/000M_N`03001_Nfmk00I_
N`04001_NfmkKg/30007Kg/2000016mk000000002Fmk0`0000=_N`00Kg/00`0000I_N`00000006mk
0004Kg/300001fmk00000000Kg/006mk00<00005Kg/00000001_N`0:00000fmk000000040006Kg/0
0`00Kg]_N`04Kg/40003Kg/01000Kg]_N`000fmk00<006mkKg/026mk00<006mkKg/016mk00<006mk
Kg/04Fmk100000A_N`00000000U_N`03001_Nfmk00M_N`800004Kg/000000005Kg/00`00Kg]_N`08
Kg/30002Kg/60009Kg/00`00Kg]_N`07Kg/6000FKg/00`00Kg]_N`0>Kg/0011_N`03001_Nfmk00M_
N`<002A_N`03001_Nfmk008000=_N`03001_Nfmk011_N`8000M_N`03001_Nfmk009_N`03001_Nfmk
00M_N`03001_Nfmk00I_N`03001_Nfmk00I_N`T000M_N`03001_Nfmk00Q_N`03001_N`0000@000Q_
N`D000M_N`D000=_N`04001_Nfmk0004Kg/00`00Kg]_N`02Kg/00`00Kg/00005Kg/B0003Kg/50006
Kg/00`00Kg]_N`03Kg/01@00Kg/006mk00000fmk00@006mkKg/000A_N`03001_Nfmk00M_N`03001_
Nfmk00A_N`03001_Nfmk015_N`T000U_N`03001_Nfmk00Q_N`D000E_N`03001_Nfmk00Y_N`L000Y_
N`03001_Nfmk00M_N`D001M_N`03001_Nfmk00i_N`0046mk00<006mkKg/01Vmk0P0000=_N`00Kg/0
8Vmk00@006mkKg]_N`8000=_N`03001_Nfmk019_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_
Nfmk00M_N`03001_Nfmk00E_N`03001_Nfmk00M_N`T000M_N`03001_Nfmk00Q_N`03001_N`0001d0
00=_N`03001_N`0000I_N`80009_N`03001_N`0000E_Na8000=_N`D000I_N`04001_NfmkKg/20002
Kg/00`00Kg/00002Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mk
Kg/04Fmk2@002Fmk00<006mkKg/026mk1@001Fmk00<006mkKg/036mk1@002Vmk00<006mkKg/01fmk
1@005fmk00<006mkKg/03Vmk000@Kg/00`00Kg]_N`06Kg/20002Kg/00`00Kg]_N`0OKg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00005Fmk00<006mkKg/00fmk00D006mkKg]_N`0000]_N`03001_Nfmk00=_
N`03001_Nfmk00M_N`X000M_N`03001_Nfmk00U_N`H000=_N`/000A_N`L0009_N`<000U_N`@000A_
NaD0009_N`L000A_N`@000A_N`03001_N`00009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_
Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk015_N`X000Y_N`03001_Nfmk00M_N`L000A_N`<000I_
N`X000Y_N`03001_Nfmk00M_N`D001Q_N`03001_Nfmk00e_N`003fmk00<006mkKg/01Vmk00<006mk
00000Vmk00<006mkKg/07Vmk00<006mkKg/016mk0P000Vmk00<006mkKg/056mk0P0016mk00@006mk
Kg/000]_N`03001_Nfmk00=_N`03001_Nfmk00E_N`80009_N`<00003Kg/0000000<000I_N`03001_
Nfmk00Q_N`X000I_N`l00003Kg/0000000@000Q_N`P000=_N`<00005Kg/00000001_N`0300000fmk
00000006000016mk000000000fmk200016mk00<006mk00000Vmk00<006mkKg/00Vmk00<006mkKg/0
16mk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/03Vmk0`000Vmk0`0000E_N`00000006mk
008000U_N`03001_Nfmk00M_N`<000=_N`d000I_N`<00003Kg/0000000Q_N`03001_Nfmk00E_N`80
0005Kg/00000001_N`02000FKg/00`00Kg]_N`0=Kg/000m_N`03001_Nfmk00I_N`03001_N`00009_
N`03001_Nfmk01e_N`03001_Nfmk00E_N`80009_N`03001_Nfmk01I_N`05001_NfmkKg/00002Kg/0
0`00Kg]_N`0:Kg/01@00Kg]_Nfmk00001Vmk0P001Fmk00@006mkKg/000=_N`8000E_N`03001_Nfmk
00Q_Nah000=_Na8000E_N`0;001_NfmkKg/006mk001_N`00Kg/00002Kg/00`00Kg/000040002Kg/0
1000Kg]_N`001Fmk1@0016mk00D006mk001_N`0000E_N`03001_Nfmk00E_N`03001_Nfmk00A_N`05
001_NfmkKg/0000?Kg/20004Kg/01`00Kg]_Nfmk001_N`0000A_N`8000M_N`03001_Nfmk00I_N`03
001_Nfmk00M_N`D000a_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00A_N`8000A_N`03
001_N`00009_N`8001A_N`03001_Nfmk00e_N`003fmk00<006mkKg/01Fmk00@006mkKg/0009_N`03
001_Nfmk01a_N`03001_Nfmk00I_N`80009_N`03001_Nfmk01M_N`06001_Nfmk001_N`003Fmk00D0
06mkKg]_N`0000=_N`<000M_N`03001_N`0000A_N`04001_N`000003Kg/00`00Kg]_N`05Kg/9000;
Kg/50003Kg/50003Kg/50008Kg/50005Kg/03@00Kg]_Nfmk001_N`00Kg/006mk001_N`00009_N`D0
009_N`04001_Nfmk0005Kg/50004Kg/01@00Kg/006mk00001Fmk00<006mkKg/01Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000a_N`<000I_N`07001_NfmkKg/006mk00001Vmk00<006mkKg/01Fmk00<0
06mkKg/01Fmk00<006mkKg/01fmk1@0036mk00<006mkKg/00fmk0P0016mk00<006mkKg/00Vmk0P00
1Fmk00@006mkKg/000A_N`03001_Nfmk015_N`03001_Nfmk00e_N`003fmk00<006mkKg/01Fmk00@0
06mkKg/000=_N`03001_Nfmk01Y_N`03001_Nfmk00M_N`800003Kg/006mk01Y_N`D000i_N`<0009_
N`8000U_N`<000I_N`L000A_N`<000A_N`<0009_N`8000Y_N`<000A_N`H00003Kg/006mk00@000U_
N`<00003Kg/006mk00<000E_N`<00005Kg/00000001_N`02000016mk000000000fmk00@006mkKg]_
N`<00003Kg/006mk00<00003Kg/006mk00<00004Kg/000000005Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`02Kg/01@00Kg]_Nfmk00002Vmk0P0026mk00<006mkKg/00fmk0`001Vmk0P001Fmk00<006mkKg/0
16mk00<006mkKg/01Vmk0P0000=_N`0000000P002fmk00<006mkKg/01Vmk0P0000E_N`00000006mk
008000M_N`05001_NfmkKg/00004Kg/2000BKg/00`00Kg]_N`0<Kg/000m_N`03001_Nfmk00A_N`04
001_Nfmk0004Kg/00`00Kg]_N`0IKg/00`00Kg]_N`08Kg/01000Kg/0000076mk1@0036mk1P002Vmk
1@0016mk30001Vmk00@006mkKg/000A_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00D000A_N`03
001_N`0000M_N`03001_N`0000=_N`D000=_N`T000=_N`03001_N`0000=_N`03001_Nfmk00D000=_
N`04001_NfmkKg/90004Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01fmk0P00
2Vmk00<006mkKg/00Vmk1@001fmk0P0016mk00<006mkKg/00fmk00<006mkKg/016mk0P001Fmk00<0
06mk00002Vmk00<006mkKg/026mk1@002Fmk00D006mkKg]_N`0000I_N`80011_N`03001_Nfmk00a_
N`003fmk00<006mkKg/016mk00@006mkKg/000A_N`03001_Nfmk01Q_N`03001_Nfmk00U_N`04001_
N`00000KKg/d0009Kg/01000Kg]_N`001Vmk0P001fmk00D006mkKg]_N`0000=_N`D000A_N`03001_
Nfmk008000E_N`03001_N`0000=_Na4000=_N`04001_Nfmk0002Kg/00`00Kg]_N`050003Kg/01000
Kg]_Nfmk2@001Fmk00<006mkKg/026mk00@006mkKg/0009_N`03001_Nfmk00A_N`<000]_N`03001_
Nfmk00=_N`D000U_N`03001_Nfmk009_N`05001_NfmkKg/00005Kg/20007Kg/00`00Kg/0000:Kg/0
0`00Kg]_N`08Kg/50009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_
N`0<Kg/000i_N`03001_Nfmk00A_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0FKg/00`00Kg]_N`0:
Kg/01000Kg/000004fmk200000=_N`0000000`0036mk200026mk1@0016mk2@0026mk00D006mkKg]_
N`0000Q_N`8000E_N`04001_Nfmk0003Kg/60004Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000Vmk
00@006mkKg]_N`D000=_N`T000=_N`04001_Nfmk0002Kg/00`00Kg]_N`050003Kg/01000Kg]_Nfmk
2@001Fmk00<006mkKg/02Fmk00D006mk001_N`0000E_N`8000i_N`03001_Nfmk00=_N`X000E_N`80
009_N`05001_NfmkKg/00003Kg/20009Kg/01000Kg]_N`002Fmk00<006mkKg/026mk1@002Fmk00<0
06mkKg/00Vmk00<006mkKg/01Vmk0P003Fmk00<006mkKg/036mk000>Kg/00`00Kg]_N`04Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/05Fmk00<006mkKg/02fmk00<006mk00000P002Vmk20002Fmk1000
2fmk0P0000A_N`00000000A_N`<000A_N`L000A_N`<00003Kg/00000008000Q_N`03001_Nfmk009_
N`03001_Nfmk00M_N`80009_N`@00004Kg/000000002Kg/40004Kg/00`00Kg]_N`03Kg/400001fmk
00000000Kg/006mk00<000E_N`<00004Kg/000000004Kg/01000Kg]_Nfmk0`0000=_N`0000000`00
00=_N`00Kg/00`0000=_N`00Kg/00`0000=_N`0000000`0016mk00<006mkKg/02Vmk10000Vmk0`00
3fmk00<006mkKg/00fmk1`0016mk10000fmk0P0000A_N`000000009_N`8000]_N`05001_NfmkKg/0
0008Kg/00`00Kg]_N`07Kg/5000:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/2000<Kg/00`00Kg]_
N`0;Kg/000i_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk01A_N`03
001_Nfmk00e_N`D00003Kg/0000000H0015_N`8000]_N`8000A_N`03001_Nfmk00I_N`P000=_N`03
001_Nfmk009_N`03001_N`00009_N`03001_N`0000I_N`03001_Nfmk00=_N`03001_Nfmk00U_N`L0
00A_N`03001_N`00009_N`05001_NfmkKg/00005Kg/900000fmk001_N`02Kg/03@00Kg]_Nfmk001_
N`00Kg/006mk001_N`0000=_N`03001_Nfmk00T000=_N`D0009_N`04001_Nfmk0005Kg/01@00Kg]_
Nfmk000036mk1P004Fmk00<006mkKg/00fmk00@006mkKg/000A_N`03001_Nfmk00E_N`/000i_N`05
001_NfmkKg/00007Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`08Kg/2000:Kg/00`00Kg]_N`0;Kg/000i_N`03001_Nfmk00=_N`03001_Nfmk009_
N`03001_Nfmk00A_N`03001_Nfmk019_N`03001_Nfmk00i_N`H001Q_N`03001_N`0000Y_N`03001_
Nfmk00E_N`03001_Nfmk00Q_N`D000A_N`07001_NfmkKg/006mk00000Vmk00<006mkKg/00P0016mk
00<006mkKg/00fmk00<006mkKg/02Vmk1@001Fmk00<006mk00000fmk0P0000=_N`00Kg/016mk2@00
00=_N`00Kg/00Vmk00/006mkKg]_N`00Kg/006mk001_N`00009_N`04001_Nfmk0002Kg/A0002Kg/0
1000Kg]_N`001Vmk00@006mkKg/000a_N`D0019_N`03001_Nfmk009_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`09Kg/5000?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`0;Kg/000i_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk015_N`03
001_Nfmk00i_N`H001Q_N`04001_Nfmk0008Kg/20008Kg/00`00Kg]_N`08Kg/80002Kg/50003Kg/0
0`00Kg]_N`02Kg/40006Kg/00`00Kg]_N`0:Kg/50002Kg/3000016mk0000000016mk10000Vmk2`00
1Fmk0`0000E_N`00000006mk00<00004Kg/000000003Kg/:0002Kg/50002Kg/00`00Kg/00008Kg/5
0006Kg/:000@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/40005Kg/7000?Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0:Kg/20007Kg/00`00Kg]_N`0;Kg/000e_N`03001_Nfmk00=_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk015_N`03001_Nfmk00e_N`P001I_N`05001_Nfmk
Kg/00006Kg/2000:Kg/00`00Kg]_N`09Kg/30004Kg/80002Kg/00`00Kg]_N`02Kg/50006Kg/00`00
Kg]_N`07Kg/200001Fmk00000000Kg/02P000fmk4P000fmk4`0000E_N`00000006mk00L00004Kg/0
00000003Kg/00`00Kg/00009Kg/:0005Kg/8000=Kg/00`00Kg]_N`020005Kg/00`00Kg]_N`04Kg/9
0003Kg/5000>Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/20009Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/20006Kg/00`00Kg]_N`0:Kg/000e_N`03001_Nfmk
009_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00m_N`03001_Nfmk00i_N`D000=_N`03
001_Nfmk01=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`09Kg/01000Kg/00000
1Vmk1@000Vmk00<006mkKg/00Vmk1@001Vmk00<006mkKg/01Fmk0P000fmk00D006mkKg/006mk0380
009_N`06001_NfmkKg/006mk1@001Fmk00<006mkKg/00P002Vmk1@002fmk1@000Vmk0P002Vmk00@0
06mkKg/000M_N`03001_Nfmk00A_N`D000I_N`03001_Nfmk009_N`<000a_N`03001_Nfmk00E_N`04
001_Nfmk0004Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0=Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/000e_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk
00I_N`03001_Nfmk00i_N`03001_Nfmk00i_N`H000A_N`03001_Nfmk015_N`03001_Nfmk009_N`04
001_NfmkKg/2000=Kg/00`00Kg]_N`08Kg/01P00Kg]_N`00Kg/000E_N`D0009_N`03001_Nfmk009_
N`H000E_N`03001_Nfmk00=_N`8000E_N`05001_Nfmk001_N`090003Kg/B0003Kg/A0002Kg/01P00
Kg]_Nfmk001_N`H000A_N`03001_Nfmk008000M_N`/000Q_N`P00003Kg/0000000Q_N`03001_N`00
00M_N`03001_Nfmk00E_N`D000I_N`03001_Nfmk00=_N`03001_N`0000a_N`03001_Nfmk00A_N`04
001_Nfmk0003Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/2
0003Kg/00`00Kg]_N`0:Kg/000e_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03
001_Nfmk00e_N`03001_Nfmk00e_N`80009_N`<00003Kg/0000000=_N`03001_Nfmk00m_N`04001_
NfmkKg/300000fmk0000000?Kg/00`00Kg]_N`08Kg/01P00Kg]_N`00Kg/000I_N`<00003Kg/006mk
00<00003Kg/006mk00<0009_N`<0009_N`<00003Kg/0000000M_N`04001_NfmkKg/500001fmk0000
0000Kg/006mk01800003Kg/006mk00D00003Kg/0000000`000E_N`D0009_N`<0009_N`<000A_N`@0
00=_N`@000A_N`<000A_N`D000A_N`H0009_N`D000Q_N`03001_Nfmk00I_N`<000I_N`03001_Nfmk
00E_N`04001_N`00000:Kg/00`00Kg]_N`05Kg/6000>Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`0?Kg/2000016mk000000002Vmk000=Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/01fmk
00<006mkKg/02fmk00<006mkKg/02fmk0`001Fmk0P000fmk0P000Vmk00<006mkKg/03Fmk00@006mk
Kg]_N`D0015_N`03001_Nfmk00Q_N`07001_NfmkKg/006mk000016mk00<006mk00000fmk1@0000=_
N`00Kg/01fmk1P002Fmk00<006mkKg/01@000fmk00@006mk001_Na8000=_N`D000=_N`h000=_N`D0
00I_N`T000I_N`04001_NfmkKg/20006Kg/800000fmk001_N`06Kg/80009Kg/00`00Kg]_N`05Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/01Vmk00@006mkKg/000U_N`03001_Nfmk00E_N`D000m_N`03
001_Nfmk00A_N`03001_Nfmk00U_N`03001_Nfmk011_N`D000U_N`003Fmk00D006mkKg]_N`0000I_
N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03001_Nfmk00Y_N`8000Q_N`8000E_N`03001_Nfmk0080
00a_N`03001_Nfmk009_N`D0019_N`03001_Nfmk00I_N`03001_Nfmk009_N`04001_Nfmk0003Kg/0
0`00Kg/00003Kg/500000fmk001_N`08Kg/50009Kg/00`00Kg]_N`050003Kg/01000Kg/006mk6P00
0fmk8P0026mk00<006mkKg/00Vmk0P002Fmk1@000Vmk00<006mkKg/01fmk1@002Fmk00<006mkKg/0
16mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mkKg/00P001fmk00<006mk
Kg/01Fmk1@0046mk00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/046mk1@002Fmk000<Kg/0
1@00Kg]_Nfmk00001fmk00<006mkKg/01fmk00<006mkKg/02Fmk00<006mkKg/02Fmk0P002Vmk0P00
1Vmk0P000Vmk00<006mkKg/02Fmk00<006mkKg/00Vmk1@004Vmk00<006mkKg/01Vmk00<006mkKg/0
0Vmk00<006mkKg/0100000E_N`00000006mk00L000I_N``000A_N`<00003Kg/0000000@0009_N`<0
0003Kg/0000001800003Kg/0000000D0009_N`l0009_N`D000M_N`D000M_N`03001_Nfmk00=_N`03
001_N`0000Q_N`D0009_N`03001_Nfmk00M_N`D000U_N`03001_Nfmk00=_N`03001_Nfmk00=_N`05
001_NfmkKg/0000<Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/016mk1P003fmk00<006mkKg/00Vmk
00<006mkKg/02fmk00<006mkKg/03Vmk1P002Fmk000<Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/0
26mk00<006mkKg/026mk00<006mkKg/01fmk0`0036mk00<006mk00001fmk0P0000=_N`00Kg/026mk
00@006mkKg]_N`P0015_N`03001_Nfmk00E_N`03001_Nfmk00A_NaP000E_N`<000A_N`d00003Kg/0
000000T00003Kg/0000001H00005Kg/00000001_N`0<00001Fmk00000000Kg/00P001Vmk0`001fmk
00<006mkKg/01Fmk0P0026mk1P000Vmk00<006mkKg/01Vmk1@002Fmk00<006mkKg/00Vmk00<006mk
Kg/016mk00D006mkKg]_N`0000e_N`80009_N`8000E_N`03001_Nfmk00A_N`@0009_N`8000i_N`05
001_NfmkKg/0000=Kg/00`00Kg]_N`0;Kg/300000fmk00000002000:Kg/000a_N`04001_Nfmk0007
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/2000?Kg/00`00Kg/00009Kg/00`00
Kg/00007Kg/01`00Kg]_Nfmk001_N`00009_N`80009_N`03001_Nfmk00i_N`03001_Nfmk00E_N`03
001_Nfmk00A_Na<000]_N`03001_Nfmk00I_NaD0009_N`03001_N`0001@00003Kg/006mk00A_N`X0
0003Kg/0000000E_N`03001_Nfmk00A_N`03001_N`0000E_N`03001_Nfmk00I_N`03001_N`0000I_
N`03001_N`0000A_N`03001_N`0000M_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk009_
N`03001_Nfmk00E_N`04001_Nfmk000@Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00fmk00<006mk
00001Vmk0`002fmk00D006mkKg]_N`0000i_N`03001_Nfmk00Q_N`8000=_N`04001_Nfmk000;Kg/0
00a_N`04001_Nfmk0007Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/3000AKg/0
0`00Kg/0000:Kg/30005Kg/00`00Kg]_N`0200000fmk001_N`02Kg/20003Kg/00`00Kg]_N`0=Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`04Kg/F0008Kg/00`00Kg]_N`04Kg/;0003Kg/9000016mk001_Nfmk
5@0000=_N`00Kg/00fmk2`0000=_N`0000001Vmk0P0016mk00<006mk000016mk00<006mkKg/01fmk
00<006mk000016mk0P000Vmk00<006mkKg/00fmk00<006mk000016mk0P001fmk00<006mkKg/016mk
00<006mkKg/00Vmk00<006mkKg/01Fmk00@006mkKg/0015_N`04001_NfmkKg/20002Kg/01000Kg]_
Nfmk0P000Vmk00<006mkKg/01fmk0P002Fmk00D006mkKg]_N`0000i_N`03001_Nfmk00I_N`8000A_
N`04001_Nfmk000<Kg/000a_N`03001_N`0000Q_N`03001_Nfmk00U_N`03001_Nfmk00A_N`03001_
Nfmk00=_N`8001A_N`04001_Nfmk000;Kg/90002Kg/00`00Kg]_N`02Kg/00`00Kg/00003Kg/2000=
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/600001Fmk00000000Kg/020000fmk0`0016mk0`000fmk
0P000fmk0`0000=_N`0000000P0016mk2@0000A_N`00001_N`<00003Kg/0000000T00003Kg/00000
00<000=_N`80009_N`<0009_N`D00003Kg/006mk00M_N`800005Kg/00000001_N`04000;Kg/00`00
Kg/000030004Kg/00`00Kg]_N`04Kg/400000fmk001_N`09Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
000026mk0`004fmk00<006mkKg/00Vmk100000=_N`00Kg/00Vmk00<006mkKg/02Vmk0P0026mk00@0
06mkKg/000m_N`<0009_N`<000E_N`05001_NfmkKg/0000<Kg/000]_N`04001_Nfmk0008Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/2000FKg/01000Kg]_N`003Fmk1@000fmk00<0
06mkKg/00fmk00<006mk00001Fmk00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/016mk1@00
0Vmk00<006mk00000fmk1@000Vmk00<006mkKg/00fmk2P001Vmk00D006mk001_N`00009_N`03001_
Nfmk009_N`T0009_N`03001_N`0000=_N`T00003Kg/006mk00L000I_N`04001_NfmkKg/6000:Kg/9
000;Kg/60003Kg/00`00Kg]_N`05Kg/5000<Kg/00`00Kg]_N`02Kg/01000Kg]_N`0026mk1@004fmk
00@006mkKg]_N`D000A_N`03001_Nfmk00a_N`8000I_N`04001_Nfmk000>Kg/60007Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`0:Kg/000]_N`03001_N`0000U_N`03001_Nfmk00Y_N`05001_NfmkKg/00002
Kg/3000HKg/01000Kg]_N`003Fmk1@000Vmk00<006mkKg/016mk00<006mk00001Vmk00<006mkKg/0
2Fmk00<006mkKg/00fmk00<006mkKg/01Fmk1@000Vmk00<006mk00000fmk1@000fmk00<006mkKg/0
1Fmk1@0026mk00D006mk001_N`0000=_N`80009_N`T00005Kg/006mkKg/00003Kg/900000fmk001_
N`050008Kg/01000Kg]_Nfmk1P002Vmk2@002fmk1P000fmk00<006mkKg/01Fmk1P0036mk00L006mk
Kg]_N`00Kg/00009Kg/7000BKg/00`00Kg]_N`050004Kg/00`00Kg]_N`0>Kg/30004Kg/2000?Kg/5
0007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/000]_N`03001_N`0000Q_N`03001_Nfmk00]_N`@0
0003Kg/0000001Y_N`<00004Kg/000000006Kg/<0007Kg/01000Kg]_N`001Vmk00<006mkKg/02Fmk
00<006mkKg/00Vmk00<006mkKg/01Fmk1P000Vmk0`000Vmk1@0016mk00<006mkKg/016mk200016mk
0`0000A_N`00000000A_N``0009_N`<00003Kg/0000000T0009_N`P000=_N`<000=_N`H000I_Na80
00I_N`H000=_N`03001_Nfmk00E_N`D00003Kg/0000000@000M_N`D000E_N`X0009_N`P000]_N`L0
00=_N`03001_Nfmk019_N`80009_N`<000Q_N`/000I_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`00
2fmk0P002Fmk00<006mkKg/02Vmk1P006fmk3P000fmk0P0000=_N`00000010001fmk00@006mkKg/0
00M_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00A_N`D0009_N`L00005Kg/00000001_N`020002
Kg/00`00Kg]_N`05Kg/30004Kg/<0003Kg/600000fmk0000000F00000fmk000000020003Kg/90000
0fmk000000090005Kg/3000016mk000000001Vmk2`000fmk00<006mkKg/01Fmk1@0026mk1P0000=_
N`00000020000fmk0P0000A_N`00000000]_N`T0009_N`H000A_N`03001_Nfmk01A_N`H00003Kg/0
000000@000M_N`<000I_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`002fmk0P002Fmk00<006mkKg/0
2Vmk:P001Vmk0P000fmk1P001fmk00@006mkKg/000U_N`03001_Nfmk00I_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk000016mk1@0026mk00@006mkKg/000E_N`05001_NfmkKg/00006Kg/A00000fmk
001_N`0F000016mk001_N`000Vmk00<006mkKg/00Vmk1@000Vmk00<006mk000010002Fmk00D006mk
Kg]_N`00009_N`03001_Nfmk00U_N`D00005Kg/006mkKg/00005Kg/20004Kg/00`00Kg]_N`0<Kg/6
0006Kg/20004Kg/00`00Kg/0000CKg/700000fmk001_N`02Kg/00`00Kg]_N`0EKg/6000<Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/000]_N`03001_Nfmk00Q_N`03001_Nfmk00Y_
N`D001a_N`T000A_N`8000E_N`L000I_N`05001_NfmkKg/00009Kg/00`00Kg]_N`05Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk2@001Fmk0P0000=_N`00Kg/00fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk2@000fmk1@0000=_N`00Kg/05P0000A_N`00Kg/000=_N`80009_N`D0
009_N`03001_N`0000D000Q_N`05001_NfmkKg/00002Kg/00`00Kg]_N`09Kg/500001Fmk001_Nfmk
00000fmk0P001Vmk00<006mkKg/03Fmk1@0016mk0P001Vmk00<006mk000056mk1P0000E_N`00Kg]_
N`0001E_N`P000e_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk00]_N`002Fmk0`002Vmk
00<006mkKg/026mk0P0000E_N`00000006mk008001U_N`D00003Kg/0000000<00003Kg/0000000M_
N`03001_N`000080009_N`<0009_N`<0009_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`04001_Nfmk
0005Kg/00`00Kg]_N`02Kg/3000016mk000006mk0`001Fmk1@000Vmk1P001Vmk0`0000=_N`00Kg/0
1`0000=_N`00Kg/01`0000=_N`00Kg/00`0000=_N`0000001P0000=_N`0000001`0000A_N`000000
00A_N`T00003Kg/0000000P0009_N`<000E_N`03001_N`0000U_N`800007Kg/00000001_N`00Kg/0
0`0000=_N`00000026mk00<006mkKg/02fmk0P0000=_N`0000000`0000=_N`0000001fmk00D006mk
Kg]_N`00011_N`<0009_N`<0009_N`04001_Nfmk000AKg/40004Kg/3000=Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/000Q_N`D000U_N`03001_Nfmk00I_N`8000E_N`80009_N`80
01I_N`03001_Nfmk00E_N`D000U_N`800003Kg/006mk00E_N`H00003Kg/006mk00Y_N`8000A_N`04
001_Nfmk0003Kg/20004Kg/50002Kg/3000;Kg/90004Kg/50003Kg/50003Kg/900001Vmk001_N`00
Kg/0009_N`D00003Kg/006mk00d000=_Na80009_N`H000A_N`03001_N`0000Q_N`07001_NfmkKg/0
06mk00000Vmk1@002Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk1@002Fmk00D006mkKg]_N`0000i_
N`8000E_N`06001_Nfmk001_N`000Vmk00<006mkKg/036mk0`002Vmk00<006mkKg/02fmk00<006mk
Kg/016mk00<006mkKg/026mk00<006mkKg/02fmk0008Kg/50009Kg/00`00Kg]_N`04Kg/20007Kg/2
0004Kg/00`00Kg]_N`0BKg/00`00Kg]_N`06Kg/50009Kg/200000fmk001_N`06Kg/50002Kg/00`00
Kg]_N`0:Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg/000I_N`D00003Kg/006mk008000m_N`h000=_
Na400006Kg/006mk001_N`000Vmk1@0000=_N`00Kg/0:P001Fmk0P001Vmk0P0016mk00D006mkKg/0
06mk00D000Y_N`03001_Nfmk00Q_N`8000E_N`D000U_N`03001_Nfmk009_N`03001_Nfmk00Q_N`<0
00M_N`08001_Nfmk001_N`00Kg/000]_N`@000e_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_
Nfmk00U_N`03001_Nfmk00]_N`0026mk1`001Vmk00<006mkKg/00fmk0P002Fmk00<006mk000016mk
0P004Fmk00<006mkKg/01Fmk2@001fmk00@006mkKg/000I_N`H0009_N`03001_Nfmk00]_N`04001_
NfmkKg/20002Kg/00`00Kg]_N`02Kg/800001Vmk001_N`00Kg/000i_N`D000A_N`D000=_N`D000=_
N`X0009_N`05001_Nfmk001_N`060002Kg/=0003Kg/B0003Kg/60004Kg/20005Kg/00`00Kg]_N`04
Kg/01@00Kg]_N`00Kg/01@002Vmk00<006mkKg/01fmk00<006mkKg/01Fmk1@002Fmk00<006mkKg/0
0Vmk00<006mkKg/01Vmk0P002Vmk00@006mkKg]_N`800003Kg/006mk00M_N`<0015_N`03001_Nfmk
00Y_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk00]_N`002Fmk10000Vmk0P000fmk0`00
0Vmk0P0036mk0P001Vmk0P003Fmk0P001Fmk0`000fmk0`000fmk0P000fmk0`0000A_N`000000009_
N`<0009_N`<00003Kg/006mk00<000a_N`L0009_N`<000A_N`<00004Kg/006mk0002Kg/00`00Kg]_
N`0<Kg/6000016mk000006mk1@0000=_N`0000001@0000=_N`00Kg/02@0000A_N`000000009_N`L0
0003Kg/0000000d00003Kg/006mk00P00005Kg/00000001_N`0500000fmk001_N`030002Kg/30002
Kg/300000fmk00000007Kg/01000Kg]_Nfmk1@0000=_N`00000026mk00<006mkKg/01Fmk0P002Fmk
10002Fmk00<006mkKg/00fmk0`000Vmk0`002fmk00<006mkKg/00fmk0`0016mk100056mk00<006mk
Kg/02Fmk00<006mkKg/00fmk00<006mkKg/02fmk00<006mkKg/02fmk000;Kg/00`00Kg/00003Kg/8
000>Kg/00`00Kg/00007Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/20009Kg/00`00Kg]_N`02Kg/<
0007Kg/00`00Kg]_N`05000<Kg/80006Kg/00`00Kg/00002Kg/00`00Kg/00002Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`050004Kg/=0003Kg/V0003Kg/60005Kg/00`00Kg/0000400001Fmk001_Nfmk0000
1Fmk1P002Fmk00<006mkKg/01@0016mk0P001Vmk00<006mkKg/00fmk0P002fmk0P000Vmk00<006mk
Kg/01Vmk00<006mkKg/00Vmk1P003Vmk00<006mkKg/00Vmk200066mk00<006mkKg/026mk00<006mk
Kg/016mk00<006mkKg/02Vmk00<006mkKg/036mk000;Kg/01000Kg]_N`0016mk1@003fmk00<006mk
000026mk0P0026mk00@006mkKg]_N`<000a_N`03001_Nfmk00=_N`T000Q_N`03001_Nfmk01H000U_
N`05001_N`00Kg/00002Kg/01000Kg]_N`002fmk0P000fmkA`001Vmk00<006mk0000100000E_N`00
Kg]_N`0000I_N`D000U_N`03001_Nfmk00D000I_N`8000A_N`03001_Nfmk009_N`03001_Nfmk00]_
N`8000=_N`03001_Nfmk00E_N`03001_Nfmk009_N`D000m_N`03001_Nfmk009_N`D001]_N`03001_
Nfmk00Q_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00a_N`002fmk00D006mkKg]_N`00
00=_N`L000e_N`04001_Nfmk0009Kg/200000fmk00000003000016mk000000003fmk00<006mkKg/0
0fmk2@0026mk00<006mkKg/01@0036mk1@0026mk00<006mk00000P000fmk00@006mkKg/000Y_N`03
001_Nfmk00=_N`D000A_N`h0009_NbH0009_N`T000A_N`L000=_N`03001_Nfmk00A_N`P000A_N`<0
009_N`H000M_N`D0009_N`8000i_N`<000=_N`03001_Nfmk00A_N`03001_Nfmk009_N`H000i_N`03
001_Nfmk009_N`H001]_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00a_N`03001_Nfmk
00a_N`002fmk00<006mkKg/00Vmk00@006mkKg]_N`<000=_N`<000]_N`03001_N`0000]_N`L001=_
N`03001_Nfmk00=_N`<00005Kg/00000001_N`020006Kg/01000Kg]_Nfmk0`0000=_N`0000002fmk
100026mk1P0000=_N`00Kg/00Vmk00<006mkKg/01fmk00<006mkKg/00Vmk0P0000=_N`0000000`00
16mk3`0000E_N`00000006mk00<00004Kg/000000002Kg/700000fmk0000000500001Fmk00000000
Kg/00`0000=_N`0000001@0016mk30000Vmk00<006mkKg/016mk100016mk2@0000=_N`0000001000
1fmk1P003fmk1@000fmk00<006mkKg/00fmk00<006mkKg/00Vmk10000Vmk0P002fmk00<006mkKg/0
0Vmk1P0000=_N`0000006Fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mk
Kg/036mk000<Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001fmk0P002Fmk00@006mkKg/000Y_N`D0
01E_N`03001_Nfmk00=_N`04001_Nfmk0006Kg/00`00Kg]_N`03Kg/01000Kg]_N`000Vmk00@006mk
Kg]_N`8000Q_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_N`0000@00003Kg/006mk009_N`03
001_Nfmk00I_N`04001_NfmkKg/20004Kg/01@00Kg]_Nfmk000016mk3@0000=_N`00Kg/00Vmk00L0
06mk001_N`00Kg/00002Kg/00`00Kg/0000<0003Kg/00`00Kg/00003Kg/00`00Kg/0000E0002Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/^0004Kg/01@00Kg]_Nfmk000016mk00<0
06mkKg/01Vmk0P002Fmk00D006mkKg]_N`0000I_N`03001_Nfmk00<001I_N`03001_Nfmk00E_N`03
001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00a_N`0036mk00<006mkKg/00fmk00@006mkKg/0
00U_N`<000I_N`04001_Nfmk0008Kg/;000BKg/00`00Kg]_N`02Kg/01000Kg]_N`001fmk0P000fmk
00@006mkKg/0009_N`03001_Nfmk00=_N`8000I_N`03001_Nfmk00=_N`8000A_N`03001_N`0000@0
0003Kg/006mk009_N`03001_Nfmk00E_N`03001_Nfmk008000I_N`03001_Nfmk009_N`04001_Nfmk
Kg/=00000fmk001_N`02Kg/02@00Kg/006mk001_N`00Kg/00002Kg/50003Kg/50003Kg/00`00Kg/0
0003Kg/00`00Kg/000040008Kg/90002Kg/01000Kg]_Nfmk0P001Vmk00<006mkKg/00fmk1@000fmk
1@001fmk1@0046mk1`000fmk00@006mkKg/0009_N`8000]_N`<000I_N`04001_Nfmk0008Kg/00`00
Kg]_N`02Kg/2000DKg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00004Fmk00<006mkKg/036mk000<Kg/0
0`00Kg]_N`04Kg/4000;Kg/30003Kg/3000016mk000000000fmk0P000fmk0`001Fmk10003fmk00L0
06mkKg]_N`00Kg/0000:Kg/2000016mk000000000fmk00<006mkKg/01Fmk0P0000A_N`00000000Q_
N`@00003Kg/006mk00H000=_N`03001_Nfmk00A_N`04001_Nfmk0008Kg/00`00Kg]_N`03Kg/;0000
0fmk000000030005Kg/300001Fmk00000000Kg/01P0016mk100000=_N`00Kg/00`001Fmk1`0026mk
1`0000=_N`00Kg/010002Fmk0`0000=_N`00Kg/0100016mk0`0026mk100000=_N`00Kg/03fmk1000
0Vmk0P000Vmk0`0000=_N`00Kg/03fmk0P000Vmk1@002Fmk00<006mkKg/016mk0P004Vmk00<006mk
Kg/016mk00D006mkKg]_N`00019_N`03001_Nfmk00a_N`0036mk00<006mkKg/016mk1@003Fmk3@00
16mk00@006mkKg/000U_N`@000]_N`04001_NfmkKg/2000=Kg/50003Kg/00`00Kg]_N`06Kg/50007
Kg/50003Kg/50004Kg/00`00Kg]_N`02Kg/01000Kg/000002Fmk00<006mkKg/016mk2@000fmk1@00
0fmk3P0016mk00<006mk000016mk1@000fmk1@000fmk00<006mkKg/016mk00<006mk000010000fmk
1@0026mk1@001Vmk00<006mkKg/00Vmk00<006mk00001Vmk00@006mk000000=_N`03001_Nfmk00a_
N`06001_Nfmk001_N`000fmk1P004fmk1P002fmk00<006mkKg/01Fmk0`0046mk00<006mkKg/00Vmk
00D006mkKg]_N`00019_N`03001_Nfmk00e_N`003Fmk00<006mkKg/00fmk7@001Vmk00@006mkKg/0
00e_N`@000Q_N`03001_Nfmk008000e_N`D000=_N`03001_Nfmk00I_NaT000A_N`03001_Nfmk00@0
00]_N`03001_Nfmk00A_Nb80009_N`80009_N`03001_Nfmk009_N`d000A_N`03001_Nfmk00=_N`03
001_N`0000@000=_Na8000M_N`80009_N`03001_N`0000E_N`05001_N`00Kg/00003Kg/00`00Kg]_
N`0<Kg/01000Kg]_N`000Vmk0P000Vmk7P0036mk00<006mkKg/01fmk0P003Vmk00<006mkKg/00Vmk
00@006mkKg/001=_N`03001_Nfmk00e_N`003Fmk00<006mkKg/00fmk1@003fmk2@001Fmk00D006mk
Kg]_N`00015_N`@000E_N`<000Q_N``00004Kg/000000005Kg/70007Kg/50003Kg/60002Kg/6000=
Kg/00`00Kg]_N`04Kg/90003Kg/50003Kg/@0004Kg/00`00Kg]_N`02Kg/50002Kg/70004Kg/50000
0fmk0000000500000fmk000000040008Kg/90005Kg/400000fmk000000030002Kg/20005Kg/00`00
Kg]_N`0:Kg/01@00Kg]_Nfmk000016mk1`002Fmk40003Fmk00<006mkKg/026mk0`002fmk00D006mk
Kg]_N`00009_N`03001_Nfmk019_N`03001_Nfmk00e_N`003Fmk00<006mkKg/016mk0`0046mk1000
00A_N`00000000E_N`03001_Nfmk009_N`03001_Nfmk01=_N`T00003Kg/0000000@000I_N`@0009_
N`T000=_N`<000U_N`@000A_N`<0009_N`H000m_N`03001_Nfmk00=_N`D00004Kg/000000002Kg/2
00000fmk000000020004Kg/?0004Kg/00`00Kg]_N`02Kg/400000fmk000000080004Kg/B0007Kg/6
0005Kg/>0002Kg/00`00Kg/00006Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk000016mk1P0000=_N`00
00001`000fmk10001Fmk0`0000=_N`00000036mk00<006mkKg/02Vmk0P002Fmk00L006mkKg]_N`00
Kg/0000EKg/00`00Kg]_N`0=Kg/000e_N`03001_Nfmk00E_N`<000i_N`04001_Nfmk0003Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0GKg/6000;Kg/00`00Kg]_N`04Kg/5000:Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05000?Kg/00`00Kg]_N`02Kg/0
1`00Kg/006mk001_N`0000A_N`05001_NfmkKg/00003Kg/00`00Kg]_N`02Kg/>0004Kg/01@00Kg]_
Nfmk00000Vmk00@006mkKg]_Nah000I_N`800004Kg/006mk0002Kg/00`00Kg]_N`07Kg/90002Kg/2
0008Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/70008Kg/40009Kg/00`00Kg]_
N`03Kg/2000;Kg/00`00Kg]_N`0;Kg/20007Kg/01P00Kg]_N`00Kg/001I_N`03001_Nfmk00e_N`00
3Vmk00<006mkKg/016mk00<006mk00003Vmk00@006mkKg/000=_N`03001_Nfmk00=_N`03001_Nfmk
00=_N`03001_Nfmk01M_N`D000a_N`03001_Nfmk00A_N`L000Q_N`03001_Nfmk00E_N`03001_Nfmk
00=_N`03001_Nfmk00=_N`03001_Nfmk00T000]_N`05001_NfmkKg/00002Kg/01@00Kg/006mk0000
0Vmk0P0016mk00<006mkKg/00Vmk0P000Vmk3P0016mk00@006mk000000=_N`04001_NfmkKg/90004
Kg/A0004Kg/20002Kg/01000Kg]_N`000Vmk00<006mkKg/01fmk2@0000A_N`00Kg/000U_N`03001_
Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk009_N`D000I_N`@000e_N`03001_Nfmk00E_N`03001_
Nfmk00U_N`03001_Nfmk00a_N`<000A_N`03001_Nfmk008001M_N`03001_Nfmk00e_N`003Vmk00<0
06mkKg/016mk00@006mk000000a_N`03001_Nfmk009_N`03001_N`0000I_N`03001_Nfmk00A_N`03
001_Nfmk01I_N`@000a_N`03001_Nfmk00A_N`H0009_N`8000M_N`03001_Nfmk00=_N`03001_Nfmk
00E_N`8000=_N`04001_NfmkKg/50003Kg/50005Kg/800001Fmk00000000Kg/00P001Fmk00<006mk
Kg/01Fmk2P000Vmk1@0000=_N`0000000P0016mk0`0000=_N`00Kg/01`001Vmk1`0000E_N`000000
06mk00D00003Kg/00000009_N`80009_N`03001_Nfmk009_N`03001_Nfmk00M_N`<00003Kg/00000
00<0009_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00=_N`<00003Kg/0000000<000=_
N`@0015_N`03001_Nfmk00I_N`8000Y_N`03001_Nfmk00i_N`80009_N`@001M_N`03001_Nfmk00i_
N`003Vmk00<006mkKg/016mk00@006mk000000]_N`03001_Nfmk00=_N`03001_N`0000E_N`03001_
Nfmk00E_N`03001_Nfmk01E_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`8000I_
N`04001_NfmkKg/20006Kg/01@00Kg]_Nfmk00002Vmk00@006mkKg/0009_N`03001_N`0000@000M_
Na8000M_N`03001_Nfmk00E_N`X000=_N`T000=_N`D000=_N`D00003Kg/006mk00=_N`03001_N`00
00@000A_N`03001_Nfmk00D000=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00M_N`03
001_Nfmk009_N`H000a_N`03001_Nfmk009_N`03001_Nfmk00=_N`d001E_N`03001_Nfmk00Q_N`80
00Q_N`03001_Nfmk011_N`H001M_N`03001_Nfmk00i_N`003Vmk00<006mkKg/01Fmk00@006mk0000
00U_N`03001_Nfmk00A_N`03001_N`0000A_N`03001_Nfmk00I_N`03001_Nfmk01A_N`03001_Nfmk
00=_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00=_N`<000=_N`05
001_NfmkKg/0000;Kg/00`00Kg/00002Kg/00`00Kg/0000M0007Kg/00`00Kg]_N`05Kg/:0003Kg/I
0002Kg/01P00Kg]_Nfmk001_N`D000A_N`03001_Nfmk00D0009_N`03001_Nfmk009_N`03001_Nfmk
00A_N`03001_Nfmk00I_N`03001_Nfmk009_N`H000a_N`03001_Nfmk009_N`03001_Nfmk00=_N`T0
01U_N`03001_Nfmk00Y_N`03001_Nfmk00I_N`03001_Nfmk011_N`D001M_N`03001_Nfmk00i_N`00
3fmk00<006mkKg/016mk00D006mk001_N`0000M_N`03001_Nfmk00E_N`03001_N`0000A_N`03001_
Nfmk00I_N`03001_Nfmk01=_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk009_N`8000Y_
N`03001_Nfmk00E_N`80009_N`03001_N`0000e_N`04001_N`000002Kg/90007Kg/>0006Kg/00`00
Kg]_N`06Kg/:0003Kg/90003Kg/50003Kg/60002Kg/00`00Kg/00002Kg/50004Kg/00`00Kg]_N`05
00000fmk001_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/6000=Kg/01000
Kg]_N`0016mk2`0066mk00<006mkKg/036mk0P001fmk00<006mkKg/03fmk1@005fmk00<006mkKg/0
3Vmk000?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`020006Kg/00`00Kg]_N`06Kg/00`00Kg/00003Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`0BKg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P00
36mk00<006mkKg/01fmk1@003Vmk1@0000A_N`00000000E_N`D00003Kg/0000000<00003Kg/00000
00800004Kg/000000007Kg/00`00Kg]_N`05Kg/;000016mk000006mk0`0000=_N`0000003@0000A_
N`000000009_N`L00003Kg/00000008000A_N`04001_NfmkKg/50006Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`03Kg/6000>Kg/70002Kg/8000IKg/00`00Kg]_N`0>Kg/20006Kg/00`00
Kg]_N`0>Kg/4000HKg/00`00Kg]_N`0>Kg/000m_N`03001_Nfmk00A_N`06001_Nfmk001_N`0016mk
00<006mkKg/01fmk00<006mk00000fmk00<006mkKg/026mk00<006mkKg/04Fmk00<006mkKg/01fmk
00<006mkKg/00Vmk00D006mkKg]_N`0000m_N`03001_Nfmk00M_NaH000=_N`03001_N`0000U_N`D0
00I_N`03001_Nfmk008000I_N`03001_Nfmk00A_N`04001_NfmkKg/90002Kg/01000Kg]_N`000Vmk
3@0000A_N`00Kg/000A_N`D000A_N`03001_N`0000=_N`05001_Nfmk001_N`050004Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0F0004Kg/01@00Kg]_N`00Kg/00P00
00=_N`00Kg/066mk00<006mkKg/046mk0P001Fmk00<006mkKg/036mk0`0000=_N`00Kg/05fmk00<0
06mkKg/03Vmk000?Kg/00`00Kg]_N`04Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk00M_N`03001_
N`00009_N`03001_Nfmk00U_N`03001_Nfmk011_N`03001_Nfmk00Q_N`03001_Nfmk009_N`04001_
N`00000@Kg/00`00Kg]_N`07Kg/5000<Kg/50003Kg/00`00Kg/00009Kg/50006Kg/00`00Kg]_N`02
0005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/90002Kg/01000Kg]_N`000Vmk3@0000A_N`00Kg/0
00A_N`D000A_N`03001_Nfmk00800006Kg/006mkKg/006mk1@0016mk00<006mkKg/01fmk00<006mk
Kg/00fmk00D006mkKg]_N`0000=_N`H000]_N`D000=_N`04001_Nfmk0002Kg/01000Kg]_N`006Fmk
00<006mkKg/04Vmk00<006mkKg/00fmk00<006mkKg/02Vmk00H006mk000006mk000HKg/00`00Kg]_
N`0>Kg/0011_N`03001_Nfmk00=_N`06001_NfmkKg/006mk10002Vmk00<006mk00000Vmk00<006mk
Kg/02Fmk00<006mkKg/03fmk00<006mkKg/02Vmk1P004fmk00<006mkKg/01Vmk1P002fmk1P0000I_
N`00000006mk0008Kg/70005Kg/01@00Kg/006mk000016mk00<006mkKg/00fmk00<006mkKg/00Vmk
30000fmk00<006mkKg/03P0000E_N`00000006mk00L000A_N`03001_Nfmk009_N`@00003Kg/00000
00D00004Kg/00000000:Kg/00`00Kg]_N`02Kg/01000Kg]_N`000fmk1P0000=_N`0000002Fmk1@00
0Vmk00@006mkKg/0009_N`8000=_N`03001_Nfmk01E_N`03001_Nfmk01A_N`8000A_N`03001_Nfmk
00Q_N`05001_N`00Kg/00002Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0?Kg/0011_N`03001_Nfmk00=_
N`04001_NfmkKg/6000:Kg/01@00Kg/006mk000036mk00<006mkKg/03Vmk00<006mkKg/02Vmk1@00
5Vmk00<006mkKg/01Fmk10000Vmk00<006mkKg/02Fmk0`000Vmk1P001fmk00<006mk00000`000Vmk
00<006mkKg/00Vmk00D006mk001_N`0000A_N`04001_NfmkKg/20004Kg/>0002Kg/00`00Kg]_N`04
00001Fmk00000000Kg/0400000=_N`00Kg/00Vmk00<006mkKg/00Vmk2P000Vmk1@002Fmk00D006mk
Kg]_N`0000=_N`03001_N`0000800003Kg/00000008000=_N`8000Q_N`<000=_N`<000=_N`8000=_
N`03001_Nfmk01E_N`03001_Nfmk01I_N`8000=_N`03001_Nfmk00I_N`06001_Nfmk001_N`000Vmk
00<006mkKg/056mk00<006mkKg/03fmk000@Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/5000;Kg/0
0`00Kg/0000=Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0;Kg/5000FKg/00`00Kg]_N`05Kg/20005Kg/2
0009Kg/00`00Kg]_N`02Kg/500000fmk001_N`04Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00P00
0fmk0P000Vmk00@006mkKg/000=_N`03001_Nfmk00A_N`h0009_N`04001_Nfmk0003Kg/00`00Kg/0
0003Kg/=0004Kg/01000Kg]_N`0016mk4@002Vmk00@006mkKg/0009_N`05001_N`00Kg/00002Kg/0
1000Kg]_N`001Fmk0P001fmk00@006mkKg]_N`8000A_N`8000A_N`03001_Nfmk01E_N`03001_Nfmk
01Q_N`04001_Nfmk0007Kg/01000Kg]_N`000Vmk00@006mkKg/001I_N`03001_Nfmk00m_N`0046mk
00<006mkKg/00fmk00<006mkKg/00Vmk200026mk00<006mk00003Vmk00<006mkKg/02fmk00<006mk
Kg/02fmk2P004fmk00<006mkKg/00fmk00<006mk00001fmk00<006mkKg/01Vmk00<006mkKg/00Vmk
1@0000=_N`00Kg/00fmk00<006mkKg/00Vmk00@006mkKg/000A_N`03001_Nfmk0080009_N`04001_
Nfmk0002Kg/00`00Kg]_N`02Kg/A0002Kg/00`00Kg/00004Kg/00`00Kg/00003Kg/?0003Kg/00`00
Kg/00004Kg/90003Kg/80007Kg/01@00Kg]_N`00Kg/00`0000=_N`00Kg/00Vmk00D006mkKg]_N`00
00I_N`8000E_N`03001_Nfmk008000A_N`03001_N`0000E_N`03001_Nfmk01A_N`03001_Nfmk01U_
N`800003Kg/006mk00A_N`05001_NfmkKg/00002Kg/01@00Kg]_Nfmk00005Fmk00<006mkKg/03fmk
000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/40004Kg/30004Kg/3000?Kg/00`00Kg]_N`0:Kg/0
0`00Kg]_N`0:Kg/200000fmk000000020005Kg/4000?Kg/00`00Kg]_N`03Kg/00`00Kg/00008Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`02Kg/400000fmk001_N`040005Kg/01@00Kg]_Nfmk000016mk0P00
00E_N`00000006mk00D0009_N`<000A_N`<00003Kg/0000000P00004Kg/000000005Kg/300000fmk
001_N`0300000fmk000000050003Kg/300000fmk0000000200000fmk0000000300001fmk00000000
Kg/006mk00L0009_N`@000A_N`D000=_N`04001_Nfmk0005Kg/00`00Kg]_N`05Kg/20002Kg/50005
Kg/20006Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0KKg/;000016mk000000000fmk00<006mkKg/04fmk
00<006mkKg/03fmk000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg/000001Vmk20003Vmk
00<006mkKg/02Fmk00<006mkKg/02Fmk0P000Vmk00@006mkKg]_N`8000Q_N`@000a_N`05001_Nfmk
Kg/00002Kg/00`00Kg]_N`07Kg/20005Kg/01@00Kg]_Nfmk00001Vmk1@001Fmk00D006mkKg]_N`00
00I_N``000I_N`03001_Nfmk00=_N`h000=_N`D000M_N`D000M_N`X00004Kg/006mk0003Kg/50003
Kg/00`00Kg]_N`03Kg/80003Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01fmk1P001Fmk00<006mk
00001Vmk00<006mkKg/04fmk00<006mkKg/07Vmk3P000Vmk00<006mkKg/04fmk00<006mkKg/03fmk
000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg/000002Fmk1@003Vmk00<006mkKg/026mk
00<006mkKg/026mk0P000fmk00<006mkKg/00Vmk0P0036mk100026mk00D006mkKg]_N`00009_N`03
001_Nfmk00U_N`03001_Nfmk009_N`04001_N`000007Kg/50005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/90009Kg/00`00Kg]_N`03Kg/c000016mk001_N`000fmk1@0016mk00<006mkKg/01Fmk1@00
0Vmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/01fmk1@001Fmk00<006mk00001fmk00<0
06mkKg/04Vmk00<006mkKg/07Vmk3P000fmk00<006mkKg/04Fmk00<006mkKg/046mk000AKg/00`00
Kg]_N`03Kg/00`00Kg]_N`03Kg/2000016mk0000000016mk1`003Vmk00<006mkKg/01fmk00<006mk
Kg/01fmk0P0016mk00<006mkKg/016mk0P003fmk10001Fmk0`0000A_N`00000000a_N`@00003Kg/0
06mk00A_N`T000E_N`03001_Nfmk009_N`<000=_N`/000A_N`<000A_Na0000=_N`D000M_N`D000Q_
N`T0009_N`<0009_N`P0009_N`D0009_N`L000E_N`03001_Nfmk00A_N`03001_Nfmk00M_N`D000A_
N`03001_N`0000Q_N`03001_Nfmk019_N`03001_Nfmk01i_N`h000=_N`03001_Nfmk015_N`03001_
Nfmk011_N`004Vmk00<006mkKg/00Vmk00<006mkKg/00fmk2P000Vmk100000=_N`00000036mk00<0
06mkKg/01Vmk00<006mkKg/01Vmk0P001Fmk00<006mkKg/01Fmk0P004fmk3@002fmk1@0000=_N`00
00000`001Fmk10001Fmk00@006mkKg]_N`/00003Kg/000000080009_N`/000=_N`P00003Kg/00000
008000A_N`<000I_N`800004Kg/00000000:Kg/300001Fmk00000000Kg/01`0000A_N`00000000A_
N`T00003Kg/0000000@000A_N`03001_Nfmk00I_N`03001_Nfmk00I_N`@000E_N`03001_N`0000Q_
N`03001_Nfmk019_N`03001_Nfmk01i_N`@00004Kg/000000002Kg/30004Kg/00`00Kg]_N`0AKg/0
0`00Kg]_N`0@Kg/0019_N`03001_Nfmk009_N`03001_Nfmk00=_N`L000A_N`03001_Nfmk00E_N`80
00]_N`03001_Nfmk00A_N`03001_Nfmk00E_N`8000M_N`03001_Nfmk00I_N`8001I_NaX000]_N`04
001_Nfmk0004Kg/01000Kg]_Nfmk1@002fmk00<006mkKg/00Vmk4P0000M_N`00Kg]_N`00Kg/00004
Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P0000=_N`00Kg/01fmk00L006mk001_N`00Kg/00003Kg/5
00000fmk001_N`09Kg/50003Kg/50004Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk
000016mk00<006mk00002Vmk00<006mkKg/04Fmk00<006mkKg/07Fmk0P0000=_N`00Kg/00fmk00H0
06mkKg/006mk0005Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0@Kg/0019_N`03001_Nfmk009_N`03001_
Nfmk00A_N`H0009_N`8000Y_N`8000U_N`03001_Nfmk00A_N`03001_Nfmk00=_N`8000Q_N`03001_
Nfmk00M_N`8001I_N`T000]_N`D000a_N`04001_NfmkKg/20002Kg/01000Kg]_Nfmk1P002Vmk00<0
06mkKg/00Vmk1@0026mk1@0000E_N`00Kg]_N`00009_N`80009_N`03001_Nfmk009_N`8000A_N`80
009_N`03001_Nfmk00E_N`07001_N`00Kg/006mk00000fmk1@0000=_N`00Kg/01Vmk20000fmk1@00
16mk00<006mkKg/01fmk00<006mkKg/00Vmk0P0016mk00D006mkKg]_N`00009_N`03001_Nfmk00Q_
N`03001_Nfmk011_N`03001_Nfmk01e_N`05001_N`00Kg/00003Kg/01@00Kg]_Nfmk00000Vmk00<0
06mkKg/00Vmk00<006mkKg/046mk00<006mkKg/046mk000BKg/00`00Kg]_N`02Kg/00`00Kg]_N`04
Kg/8000>Kg/20007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/20009Kg/00`00Kg]_N`08Kg/00`00
Kg/0000EKg/4000016mk000000003Fmk1@002Vmk00<006mkKg/016mk100000=_N`0000000`000Vmk
0P002Fmk00<006mkKg/00Vmk0`0000=_N`0000001fmk0`0000=_N`00Kg/00Vmk00<006mkKg/00Vmk
100000=_N`0000001Vmk0P000Vmk00<006mkKg/016mk00<006mk00000P0000M_N`00000006mk001_
N`050004Kg/40003Kg/400000fmk001_N`0500000fmk001_N`03000:Kg/40006Kg/01@00Kg]_Nfmk
00000Vmk00<006mkKg/026mk00<006mkKg/046mk00<006mkKg/06fmk0P0000E_N`00Kg]_N`0000=_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0@Kg/001=_N`05
001_NfmkKg/00005Kg/9000@Kg/20005Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk0P002Vmk00<006mk
Kg/02Vmk0P0056mk0P000Vmk00@006mkKg/000e_N`04001_NfmkKg/2000:Kg/00`00Kg]_N`04Kg/5
0002Kg/00`00Kg]_N`04Kg/20008Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0P001Vmk00<006mk0000
1Fmk00@006mkKg]_N`D000M_N`03001_N`0000=_N`03001_Nfmk009_N`03001_N`0000P000=_N`P0
00I_N`03001_Nfmk009_N`03001_N`0000@000=_N`D000Q_N`D000I_N`04001_Nfmk0002Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0JKg/01000Kg]_N`000fmk00D006mkKg]_N`0000=_
N`05001_NfmkKg/00004Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0@Kg/001=_N`05001_NfmkKg/00005
Kg/;000@Kg/20003Kg/01@00Kg]_Nfmk00000Vmk0P002fmk00<006mkKg/02fmk00<006mk00004Fmk
0P0000E_N`00Kg]_N`00009_N`03001_Nfmk00]_N`07001_NfmkKg/006mk00002Fmk00<006mkKg/0
16mk1@0000=_N`00Kg/026mk0P001fmk00<006mkKg/00Vmk00<006mkKg/00fmk0P0016mk00<006mk
00001Fmk00@006mkKg]_N`D000M_N`03001_N`0000A_N`06001_NfmkKg/006mk4@0026mk00<006mk
Kg/00fmk00<006mk00006@001Vmk00@006mkKg/0009_N`03001_Nfmk00Y_N`03001_Nfmk00m_N`03
001_Nfmk01U_N`05001_NfmkKg/00003Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00Vmk00<006mk
Kg/00Vmk00<006mkKg/03Vmk00<006mkKg/04Fmk000CKg/01@00Kg]_Nfmk00001Fmk2@000Vmk2@00
2Fmk0P0000=_N`0000000P0000=_N`00000036mk00<006mkKg/036mk00@006mkKg/000m_N`04001_
Nfmk0004Kg/01000Kg]_N`002fmk00<006mkKg/00fmk00<006mk000026mk00<006mkKg/016mk1P00
36mk0P001Vmk00D006mkKg]_N`0000M_N`800004Kg/000000006Kg/01000Kg]_Nfmk1@001fmk00<0
06mk00001Fmk0`000Vmk2@000fmk1@001fmk00<006mkKg/01Fmk1P0000=_N`0000001@0026mk1`00
16mk0`000Vmk00<006mkKg/02fmk00<006mkKg/03fmk00<006mkKg/066mk00D006mkKg]_N`0000A_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000046mk00<006mkKg/04Fmk000C
Kg/01@00Kg]_Nfmk00001Vmk0`0000A_N`00000000a_N`T0009_N`H000e_N`03001_Nfmk00i_N`03
001_N`0000i_N`05001_NfmkKg/00004Kg/01000Kg]_N`002Vmk00<006mkKg/016mk00@006mkKg/0
00M_N`03001_Nfmk00A_N`L000e_N`8000E_N`04001_Nfmk0009Kg/50006Kg/01000Kg]_Nfmk1000
1Vmk00@006mkKg/000A_N`H00005Kg/00000001_N`0300000fmk00000002Kg/30007Kg/00`00Kg]_
N`05Kg/80003Kg/40009Kg/30003Kg/800000fmk001_N`0=Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0H
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00fmk00<006mk
Kg/00Vmk00<006mkKg/03Fmk00<006mkKg/04Fmk000DKg/01000Kg]_N`001Vmk0P0000=_N`00Kg/0
5fmk1`003Fmk00<006mkKg/03fmk00@006mkKg/000a_N`05001_NfmkKg/00005Kg/01000Kg]_N`00
2Fmk00<006mkKg/01Vmk00@006mkKg/000I_N`03001_Nfmk00=_N`03001_Nfmk00H000i_N`8000A_
N`03001_N`0000U_N`D000I_N`04001_Nfmk0002Kg/00`00Kg/00005Kg/01000Kg]_N`0016mk1@00
0fmk0P000Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01Vmk1@00
1Vmk00D006mkKg]_N`0000U_N`8000I_N`D00003Kg/006mk00e_N`03001_Nfmk00e_N`03001_Nfmk
01M_N`03001_Nfmk009_N`03001_Nfmk00=_N`04001_Nfmk0003Kg/00`00Kg]_N`04Kg/01@00Kg]_
Nfmk00003fmk00<006mkKg/04Fmk000DKg/01000Kg]_N`001Vmk0P0000=_N`00Kg/046mk200000=_
N`0000000`0036mk00<006mkKg/046mk00@006mkKg/000]_N`03001_Nfmk009_N`03001_Nfmk00A_
N`03001_N`0000Q_N`03001_Nfmk00M_N`04001_Nfmk0006Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk
1@0000=_N`0000001@002Fmk0P000Vmk00<006mk00001fmk20001Fmk00@006mkKg/0009_N`03001_
Nfmk008000=_N`04001_Nfmk0004Kg/50003Kg/20002Kg/00`00Kg]_N`03Kg/20002Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`04Kg/80006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/20006Kg/6000?Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`0FKg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01000Kg]_N`000Vmk
00<006mkKg/01Fmk00D006mkKg]_N`0000m_N`03001_Nfmk015_N`0056mk00@006mkKg/000I_N`<0
00Y_N`P000Y_N`<000a_N`03001_Nfmk019_N`04001_Nfmk0009Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg/00007Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000=_
N`03001_N`00008000U_N`H000E_N`800003Kg/00000008000=_N`8000=_N`<0009_N`<0009_N`<0
00=_N`03001_Nfmk009_N`@00005Kg/00000001_N`02000016mk0000000016mk0P000Vmk00<006mk
Kg/01Fmk0P0000=_N`0000000P000fmk100016mk0`001fmk00<006mkKg/00fmk00<006mkKg/01Fmk
0P001fmk1@0046mk00<006mkKg/036mk00<006mkKg/05Fmk00<006mkKg/00fmk00<006mkKg/00fmk
00D006mkKg]_N`00009_N`03001_Nfmk00I_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`0AKg/001A_
N`04001_Nfmk0005Kg/500000fmk00000006000EKg/00`00Kg]_N`08Kg/00`00Kg]_N`0CKg/01000
Kg]_N`0026mk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mk00001fmk00<006mkKg/02Fmk00D0
06mkKg]_N`0000A_N`06001_NfmkKg/006mk0P000fmk00<006mkKg/03Vmk3`0016mk00@006mkKg/0
00E_N`H0009_N`03001_Nfmk009_N`T0009_N`05001_NfmkKg/00003Kg/01@00Kg/006mk00002Fmk
20001fmk00@006mkKg/000M_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_N`0000E_N`03001_
N`0000@000m_N`03001_Nfmk00]_N`03001_Nfmk01E_N`03001_Nfmk00=_N`03001_Nfmk00A_N`05
001_NfmkKg/00002Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00003Vmk00<006mkKg/04Fmk000EKg/0
1000Kg]_N`0016mk1P007Fmk00<006mkKg/01fmk00<006mkKg/05Fmk00@006mkKg/000E_N`8000E_
N`03001_Nfmk00M_N`8000I_N`03001_Nfmk00Y_N`03001_Nfmk009_N`04001_Nfmk0003Kg/00`00
Kg/00005Kg/00`00Kg]_N`0EKg/60005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/50002Kg/00`00
Kg]_N`02Kg/90002Kg/01@00Kg]_Nfmk00000fmk00D006mk001_N`0000U_N`D000Y_N`04001_Nfmk
0007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg/00005Kg/00`00Kg/00004000?Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0DKg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00000Vmk
00<006mkKg/01fmk00@006mkKg/000e_N`03001_Nfmk019_N`005Fmk00@006mkKg/000A_N`X001Y_
N`03001_Nfmk00I_N`03001_Nfmk01E_N`04001_Nfmk0004Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08
Kg/20005Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/00`00Kg/00002Kg/30006Kg/00`00Kg]_N`0>
Kg/700000fmk000000030005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/50002Kg/00`00Kg]_N`02
Kg/900000fmk001_N`04Kg/02000Kg]_N`00Kg/006mk0009Kg/50009Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg/00004Kg/00`00Kg]_N`05000@Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`0BKg/20006Kg/00`00Kg]_N`05Kg/01`00Kg]_Nfmk001_N`0000Y_
N`05001_NfmkKg/0000<Kg/00`00Kg]_N`0BKg/001E_N`04001_Nfmk0004Kg/40006Kg/6000DKg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0FKg/300000fmk000000020007Kg/00`00Kg]_N`08Kg/20004Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/60007Kg/30009Kg/60008Kg/40005Kg/00`00Kg]_N`04Kg/3
00000fmk001_N`0500001fmk00000000Kg/006mk00<00003Kg/0000000@000E_N`04001_Nfmk0002
Kg/20007Kg/2000016mk000000002Vmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01fmk
00<006mkKg/00Vmk00@006mkKg/000=_N`03001_Nfmk00D0011_N`03001_Nfmk00Y_N`03001_Nfmk
015_N`03001_Nfmk00I_N`03001_Nfmk00E_N`07001_NfmkKg/006mk00002Vmk00D006mkKg]_N`00
00a_N`03001_Nfmk019_N`005Fmk00@006mkKg/000A_N`8000i_N`D0011_N`03001_Nfmk00=_N`03
001_Nfmk01I_N`T000I_N`03001_Nfmk00Y_N`80009_N`03001_Nfmk00i_N`03001_Nfmk009_N`D0
00M_N`D00003Kg/0000000D000e_N`04001_NfmkKg/20004Kg/00`00Kg]_N`03Kg/50003Kg/90005
Kg/00`00Kg/000040006Kg/00`00Kg/00002Kg/20006Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg/0
009_N`8000A_N`03001_Nfmk00i_N`03001_Nfmk00U_N`03001_Nfmk011_N`03001_Nfmk00I_N`03
001_Nfmk00I_N`04001_Nfmk0002Kg/00`00Kg]_N`09Kg/01000Kg]_N`0036mk00<006mkKg/04Vmk
000FKg/00`00Kg/00003Kg/00`00Kg/0000CKg/5000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0DKg/<
0006Kg/00`00Kg]_N`0:Kg/200000fmk001_N`0@Kg/00`00Kg]_N`02Kg/B000DKg/01000Kg]_Nfmk
0P000fmk00<006mkKg/016mk4@001Fmk00<006mk000010001Vmk00<006mk00000Vmk0P0016mk0P00
1Vmk00<006mkKg/01fmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/02Fmk00@006mkKg/0
009_N`03001_Nfmk00<00003Kg/006mk00A_N`03001_Nfmk00e_N`03001_Nfmk00Q_N`03001_Nfmk
011_N`03001_Nfmk00I_N`03001_Nfmk00M_N`04001_Nfmk0002Kg/00`00Kg]_N`09Kg/01@00Kg]_
Nfmk00002fmk00<006mkKg/04Vmk000FKg/00`00Kg/00003Kg/2000IKg/60006Kg/4000=Kg/:0003
Kg/:00000fmk00000002000=Kg/4000BKg/01000Kg]_Nfmk1@001fmk1@0056mk00<006mkKg/00Vmk
00<006mk00000P0016mk20000fmk2`0016mk2@0016mk0`0000E_N`00000006mk008000U_N`03001_
Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00Y_N`@00003Kg/000000080009_
N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_Nfmk00Q_N`03001_Nfmk00m_N`03001_Nfmk00M_
N`03001_Nfmk00M_N`06001_Nfmk001_N`003Fmk00@006mkKg/000]_N`03001_Nfmk019_N`005Vmk
00<006mk00000fmk0P007fmk2P000fmk2P003Fmk100000=_N`000000200036mk1@004Vmk00<006mk
Kg/00Vmk0`001Vmk0P0000I_N`00000006mk000BKg/00`00Kg]_N`03Kg/90004Kg/30004Kg/80003
Kg/90004Kg/<000;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:
Kg/90002Kg/00`00Kg]_N`06Kg/2000=Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`08Kg/01P00Kg]_N`00Kg/000e_N`04001_Nfmk000:Kg/00`00Kg]_N`0CKg/001I_
N`03001_N`0000=_N`8002A_N`P001I_N`04001_Nfmk0007Kg/F000CKg/01P00Kg]_N`00Kg/000I_
N`03001_Nfmk009_N`04001_NfmkKg/2000?Kg/00`00Kg]_N`04Kg/60008Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0R000;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/01000Kg]_N`003Fmk2@0000=_N`00
Kg/02Vmk00<006mkKg/02Vmk00<006mkKg/01fmk00<006mkKg/03Fmk00<006mkKg/026mk00<006mk
Kg/026mk00H006mkKg/006mk000>Kg/01000Kg]_N`002Fmk00<006mkKg/04fmk000GKg/20002Kg/2
000RKg/8000HKg/01@00Kg]_Nfmk00001fmk1`002Vmk2`003Fmk00H006mkKg/006mk0004Kg/20005
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/80006Kg/00`00Kg]_N`020002Kg/6
0007Kg/50008Kg/:000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/01000Kg]_N`0036mk2P0000=_
N`00Kg/02fmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/036mk00<006mkKg/026mk00<0
06mkKg/02Fmk00H006mkKg/006mk000>Kg/01000Kg]_N`002Fmk00<006mkKg/04fmk000GKg/20002
Kg/2000NKg/40004Kg/4000GKg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/40002Kg/30002Kg/30000
0fmk001_N`050005Kg/60007Kg/300001Fmk00000000Kg/00P001Vmk0`001Fmk0P002Vmk00<006mk
Kg/01Vmk1@000fmk0P000fmk100000A_N`000000009_N`<000U_N`@000U_N`<00004Kg/000000002
Kg/30008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/01000Kg]_N`002Fmk0`000Vmk0`0000=_N`00
00000`003Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/036mk00<006mkKg/026mk00<0
06mkKg/02Vmk00D006mk001_N`00011_N`03001_N`0000U_N`03001_Nfmk01=_N`005fmk0P000Vmk
0P006Vmk10002Vmk00<006mk00005Fmk00<006mkKg/00fmk00<006mkKg/01fmk00@006mkKg/000A_
N`H000E_N`03001_N`0000Y_N`l000M_N`D000I_N`03001_Nfmk00I_N`03001_Nfmk00I_N`D000I_
N`P000I_N`03001_Nfmk00M_N`8000=_N`03001_Nfmk00M_N`04001_Nfmk0007Kg/20007Kg/01000
Kg]_N`0036mk00<006mk00001fmk0P0016mk00<006mkKg/00fmk1@003Vmk00<006mkKg/026mk00<0
06mkKg/01Fmk00<006mkKg/02Vmk0P002fmk00<006mkKg/02Vmk00D006mk001_N`00011_N`04001_
Nfmk0008Kg/00`00Kg]_N`0CKg/001M_N`80009_N`03001_Nfmk01E_N`@000i_N`04001_Nfmk000C
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00001Fmk1@001Fmk00@006mkKg/000m_
NaD000M_N`8000I_N`03001_Nfmk00I_N`D000Q_N`D000M_N`03001_Nfmk00M_N`8000A_N`03001_
Nfmk00I_N`04001_Nfmk0009Kg/20005Kg/01000Kg]_N`0036mk00<006mk00001Fmk0P001Vmk00<0
06mkKg/00fmk1@003fmk00<006mkKg/01fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/0
2Vmk00<006mkKg/02fmk00D006mk001_N`00015_N`03001_N`0000Q_N`03001_Nfmk01=_N`0066mk
10004fmk10004Vmk00D006mkKg]_N`00015_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk
009_N`03001_Nfmk009_N`D000I_N`04001_Nfmk000>Kg/90003Kg/>0004Kg/00`00Kg/000030005
Kg/:0004Kg/80007Kg/00`00Kg]_N`06Kg/00`00Kg/00005Kg/00`00Kg]_N`05Kg/01000Kg]_N`00
2fmk0`0000=_N`0000000P003Fmk0`000Vmk0`0016mk100016mk20003fmk00<006mkKg/01fmk00<0
06mkKg/016mk00<006mkKg/026mk00<006mkKg/02fmk00<006mkKg/02fmk00D006mk001_N`00015_
N`03001_N`0000Q_N`03001_Nfmk01=_N`0066mk10003fmk10005Vmk00<006mkKg/00Vmk00<006mk
Kg/036mk0P0026mk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/00fmk10001Vmk00D006mk
Kg]_N`0000i_N`/000E_N`@000E_N`l000A_N`X000A_N`<000Q_N`03001_Nfmk00I_N`03001_N`00
00I_N`03001_Nfmk00A_N`03001_N`0000m_N`D000a_N`H000I_N`T000=_N`<0009_N`8000i_N`03
001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00]_N`03001_Nfmk00a_N`05
001_N`00Kg/0000BKg/00`00Kg/00006Kg/00`00Kg]_N`0DKg/001Q_N`<000a_N`@001Y_N`03001_
Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk00A_N`05001_
NfmkKg/00004Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P002fmk00<006mk0000100036mk00<006mk
00002Fmk1@0026mk00<006mkKg/01@0026mk00<006mk00001fmk00<006mkKg/01Fmk00<006mk0000
1fmk00<006mkKg/016mk00<006mk00003fmk8P001fmk00<006mkKg/016mk0`0036mk00<006mkKg/0
1Fmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/036mk00<006mkKg/036mk00@006mk0000
01=_N`03001_N`0000I_N`03001_Nfmk01A_N`0066mk0`0026mk10007Vmk00<006mkKg/00fmk00<0
06mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/016mk00<006mkKg/01Fmk00D006mkKg]_N`0000E_
N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_N`0000@000e_N`03001_N`00
00Q_N`D000M_N`04001_NfmkKg/50008Kg/00`00Kg/00007Kg/00`00Kg]_N`05Kg/00`00Kg/00008
Kg/00`00Kg]_N`03Kg/00`00Kg/0000>Kg/6000<Kg/50007Kg/50007Kg/00`00Kg]_N`07Kg/2000;
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0=
Kg/01000Kg/000004fmk00<006mk00001Vmk00<006mkKg/056mk000HKg/30004Kg/4000RKg/30004
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/30007Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0400000fmk001_N`0;Kg/00`00
Kg]_N`020007Kg/30007Kg/00`00Kg]_N`02000016mk0000000026mk00D006mk001_N`0000I_N`03
001_Nfmk00A_N`04001_Nfmk0009Kg/00`00Kg]_N`02Kg/2000<Kg/9000<Kg/400000fmk001_N`03
00000fmk0000000300000fmk001_N`05Kg/00`00Kg]_N`09Kg/2000:Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0>Kg/200000fmk001_N`0CKg/0
0`00Kg/00005Kg/00`00Kg]_N`0DKg/001M_N`P002E_N`D000A_N`03001_Nfmk00E_N`03001_Nfmk
00]_N`03001_Nfmk00A_N`03001_Nfmk00E_N`D000M_N`03001_Nfmk009_N`03001_Nfmk00A_N`03
001_Nfmk00A_N`06001_Nfmk001_N`0016mk00<006mkKg/02Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`04001_Nfmk0002Kg/01@00Kg]_Nfmk00001fmk00D006mk001_N`00
00I_N`03001_Nfmk00A_N`04001_Nfmk000:Kg/01000Kg]_Nfmk0P002Fmk0`0000E_N`00001_N`00
00=_N`8000Y_N`04001_Nfmk0003Kg/50007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/30008Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0>Kg/2
00000fmk001_N`0CKg/00`00Kg/00005Kg/00`00Kg]_N`0DKg/001M_Nc8000E_N`03001_Nfmk00=_
N`03001_Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk00I_N`D000Q_N`03001_Nfmk009_N`03001_
Nfmk00A_N`03001_Nfmk00=_N`<0009_N`03001_Nfmk00=_N`8000Y_N`03001_Nfmk009_N`03001_
Nfmk009_N`05001_NfmkKg/00004Kg/01000Kg/000000fmk00D006mkKg]_N`0000M_N`03001_N`00
009_N`03001_Nfmk00=_N`03001_Nfmk00=_N`04001_Nfmk000<Kg/00`00Kg]_N`020006Kg/30003
Kg/01000Kg/0000016mk0P002Fmk00D006mkKg]_N`0000=_N`D000Q_N`8000=_N`03001_Nfmk00i_
N`8000M_N`03001_Nfmk00=_N`04001_Nfmk0006Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0?Kg/3000F
Kg/20005Kg/00`00Kg]_N`0DKg/001M_N`D002Q_N`P000=_N`05001_NfmkKg/0000?Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`06Kg/50009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/20002Kg/20004Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/01000Kg]_N`001Fmk00<006mkKg/00`00
16mk00<006mkKg/00fmk00<006mkKg/016mk00<006mk00000Vmk00<006mkKg/00fmk00<006mkKg/0
0Vmk00D006mkKg]_N`0000e_N`04001_N`000003Kg/30004Kg/200000fmk001_N`05Kg/00`00Kg/0
0007Kg/01@00Kg]_Nfmk000016mk2P001Fmk00<006mk00004fmk0`001Fmk0P000fmk00@006mkKg/0
00E_N`03001_Nfmk00i_N`03001_Nfmk00m_N`<001I_N`03001_N`0000A_N`03001_Nfmk01A_N`00
66mk0`0000=_N`00Kg/09fmk0`0016mk1`0046mk00<006mkKg/00Vmk00<006mkKg/01Vmk200026mk
00D006mkKg]_N`0000Q_N`<000A_N`03001_Nfmk00M_N`8000M_N`03001_Nfmk00A_N`<000E_N`@0
00I_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_N`0000=_N`03001_Nfmk009_N`03001_Nfmk
009_N`05001_NfmkKg/0000>Kg/60005Kg/20002Kg/00`00Kg]_N`05Kg/00`00Kg/00007Kg/01@00
Kg]_Nfmk00001Fmk0`001Vmk1@0000A_N`00000001E_N`8000E_N`04001_Nfmk0002Kg/01000Kg]_
Nfmk0P0046mk00<006mkKg/046mk0`005fmk0P000fmk00<006mkKg/05Fmk000JKg/01000Kg]_N`00
9fmk00<006mkKg/01fmk1@003fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00L006mkKg]_N`00Kg/0
0002Kg/20007Kg/01@00Kg]_Nfmk00001Vmk1@000fmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<0
06mkKg/00Vmk3@001Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mk000016mk00D006mkKg]_
N`0000=_N`03001_Nfmk009_N`03001_Nfmk00]_N`D000I_N`05001_NfmkKg/00008Kg/01000Kg]_
N`001Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/036mk1`0056mk0P0016mk00H006mk
Kg/006mk0002Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0@Kg/01000Kg/000005fmk0P000fmk00<006mk
Kg/05Fmk000JKg/01000Kg]_Nfmk0P0096mk00<006mkKg/026mk1@003fmk00D006mkKg]_N`0000M_
N`03001_Nfmk009_N`04001_Nfmk0003Kg/20006Kg/01000Kg]_N`001Vmk1@000fmk00<006mkKg/0
2Vmk00<006mkKg/016mk00<006mkKg/00Vmk1@000fmk1@001Fmk00<006mkKg/01Vmk00<006mkKg/0
0Vmk00<006mk000016mk00D006mkKg]_N`0000=_N`05001_NfmkKg/0000>Kg/50004Kg/20003Kg/0
0`00Kg]_N`07Kg/01000Kg]_N`0016mk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/02fmk
1P000Vmk2@003Fmk0`000Vmk00L006mk001_N`00Kg/0000BKg/00`00Kg]_N`0@Kg/00`00Kg/0000I
Kg/20002Kg/00`00Kg]_N`0EKg/001Y_N`03001_Nfmk00=_N`03001_Nfmk025_N`03001_Nfmk00Q_
N`L000e_N`05001_NfmkKg/00006Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000016mk0P001Fmk00@0
06mkKg/000E_N`D000=_N`03001_Nfmk00]_N`8000E_N`04001_NfmkKg/600000fmk000000050000
16mk000000002Fmk00<006mkKg/00Vmk00<006mk00001Fmk00@006mkKg/0009_N`03001_Nfmk009_
N`03001_Nfmk00Y_N`P00003Kg/0000000A_N`03001_Nfmk00Q_N`<00003Kg/00000008000I_N`05
001_NfmkKg/0000<Kg/200000fmk00000003000;Kg/80008Kg/200000fmk00000003000BKg/00`00
Kg]_N`0AKg/3000IKg/20002Kg/00`00Kg]_N`0EKg/001]_N`03001_Nfmk00=_N`80025_N`03001_
Nfmk00M_N`03001_N`00008000=_N`03001_Nfmk00Y_N`05001_NfmkKg/00005Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20004Kg/00`00Kg/00005Kg/40003Kg/00`00Kg]_N`0>
Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk10000Vmk1P000Vmk1@002Fmk00L006mkKg]_N`00Kg/00005
Kg/01000Kg]_N`000Vmk00<006mkKg/00Vmk00<006mkKg/026mk0P000fmk1P001Fmk00<006mkKg/0
26mk2@001Vmk00D006mkKg]_N`0000Y_N`8000A_N`@001=_N`T00003Kg/0000000@0019_N`03001_
Nfmk015_N`<001Y_N`04001_Nfmk000GKg/001]_N`03001_Nfmk00E_N`03001_Nfmk01e_N`03001_
Nfmk00M_N`05001_NfmkKg/00005Kg/2000:Kg/01000Kg]_N`0016mk0P001fmk00<006mkKg/00Vmk
00<006mkKg/01Fmk0P000fmk00<006mk00000fmk00<006mkKg/00Vmk00@006mkKg/0015_N`80009_
N`0:001_NfmkKg/006mk001_N`00Kg/=000:Kg/00`00Kg/00003Kg/00`00Kg]_N`03Kg/01@00Kg/0
06mk00001Fmk00<006mkKg/01fmk00<006mkKg/016mk1@000fmk0P002fmk2@001Vmk00@006mkKg/0
00U_N`8000Q_N`8001a_N`L0015_N`03001_Nfmk019_N`<001Y_N`800003Kg/006mk01I_N`006fmk
00<006mkKg/01Vmk00<006mkKg/076mk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk
00<006mkKg/01fmk00@006mkKg/000=_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk00I_
N`80009_N`8000=_N`03001_Nfmk009_N`04001_Nfmk000CKg/01P00Kg]_N`00Kg/0009_N`04001_
N`00Kg/50002Kg/90007Kg/00`00Kg/00003Kg/00`00Kg]_N`03Kg/01@00Kg/006mk000016mk00<0
06mkKg/01Vmk0P001Fmk1`000Vmk00<006mkKg/01Vmk3P001Vmk00<006mk000026mk0P002fmk0P00
7Fmk1P0046mk00<006mkKg/04Vmk0P0076mk0P0066mk000KKg/00`00Kg]_N`07Kg/2000KKg/00`00
Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/20007Kg/00`00Kg/00003Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/200000fmk000000020006Kg/3000DKg/00`00Kg/00002
00001Fmk00000000Kg/020000Vmk10000fmk100016mk0`0000A_N`00000000E_N`<000E_N`03001_
Nfmk00A_N`8000A_N`<000=_N`H000E_N`@000I_N`P000I_N`03001_N`0000I_N`8000e_N`8001]_
N`800004Kg/000000002Kg/2000=Kg/00`00Kg]_N`0CKg/2000LKg/3000GKg/001a_N`03001_Nfmk
00Q_N`03001_Nfmk01Q_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`8000E_N`03
001_N`00009_N`03001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`H000A_N`D001A_N`h0
00E_N`05001_N`00Kg/00006Kg/<0003Kg/50004Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0`001fmk
2P002Fmk00@006mkKg/000E_N`03001_Nfmk009_N`03001_N`0000E_N`8000m_N`03001_N`0001Q_
N`8000=_N`03001_Nfmk00A_N`8000Y_N`03001_Nfmk01A_N`8001]_N`D001I_N`0076mk00<006mk
Kg/02Fmk0P0066mk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/00Vmk
0P000Vmk00<006mkKg/02Vmk00<006mkKg/01Vmk00<006mkKg/026mk;`001Vmk00<006mk00000Vmk
00<006mkKg/01Vmk4@0016mk00@006mkKg]_N`800004Kg/000000009Kg/6000=Kg/01000Kg]_N`00
1fmk0P000Vmk00<006mk00000fmk0P004Vmk0P005Vmk0P001Fmk00<006mkKg/01Vmk0`001fmk00<0
06mkKg/056mk0P0066mk20005Vmk000LKg/00`00Kg]_N`0;Kg/00`00Kg]_N`0DKg/00`00Kg]_N`04
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/200000fmk00000003000=Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`08Kg/60002Kg/6000CKg/>0006Kg/01000Kg]_N`000Vmk00<006mkKg/01Fmk2@000Vmk1P00
0Vmk0`0000=_N`0000000`0016mk200000=_N`0000000`003Fmk00<006mk00002Vmk10000Vmk0P00
56mk00<006mk000056mk00<006mkKg/016mk00<006mkKg/02Vmk0P000Vmk0`005Vmk0`003Vmk2P00
0fmk1@005Vmk000MKg/00`00Kg]_N`0;Kg/00`00Kg]_N`0CKg/00`00Kg]_N`03Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`0=Kg/5000>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/40002Kg/7000BKg/20002
Kg/300001Fmk00000000Kg/00`001fmk00@006mkKg/000=_N`03001_Nfmk00E_N`L00003Kg/00000
00D00003Kg/0000000d000Q_N`D00003Kg/0000000Y_N`03001_N`0000]_N`H001I_N`04001_Nfmk
000AKg/20007Kg/00`00Kg]_N`0<Kg/6000DKg/50003Kg/:000=Kg/4000GKg/001e_N`03001_Nfmk
00a_N`80019_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00e_N`D000i_N`03001_Nfmk
00Q_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00H000m_N`<000E_N`05001_NfmkKg/0
0002Kg/00`00Kg/00007Kg/01000Kg]_N`0016mk00<006mkKg/00fmk00H006mkKg/006mk0004Kg/>
000?Kg/01P00Kg]_N`00Kg/000=_N`03001_Nfmk00M_N`8000a_N`D001Q_N`03001_N`0000m_N`80
00Q_N`03001_Nfmk00i_Nb4001I_N`8001Y_N`007Fmk00<006mkKg/03Vmk00<006mkKg/03fmk00<0
06mkKg/00fmk00<006mkKg/026mk00<006mkKg/03Fmk1P003Fmk00<006mkKg/02Fmk00<006mkKg/0
0Vmk0P001Vmk00<006mk00001@003Fmk0P0026mk00D006mkKg]_N`00009_N`03001_N`0000M_N`05
001_NfmkKg/00004Kg/00`00Kg]_N`02Kg/30002Kg/00`00Kg]_N`02Kg/50003Kg/5000?Kg/01`00
Kg]_Nfmk001_N`0000A_N`8000I_N`8000Q_N`h001A_N`04001_Nfmk000<Kg/2000:Kg/00`00Kg]_
N`0>Kg/5000DKg/5000IKg/00`00Kg]_N`0IKg/001e_N`03001_Nfmk00m_N`8000m_N`03001_Nfmk
009_N`03001_Nfmk00U_N`03001_Nfmk00i_N`<0009_N`<000Y_N`03001_Nfmk00U_N`D000U_N`D0
0003Kg/006mk00Y_N`8000]_N`03001_N`00009_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/50004Kg/00`00Kg]_N`02Kg/50004Kg/3000?Kg/01@00Kg]_Nfmk00000Vmk00<0
06mkKg/016mk0P0000=_N`0000000P001Fmk100016mk1@001Fmk100046mk00@006mkKg/000]_N`03
001_Nfmk00Y_N`03001_Nfmk00e_N`03001_N`00008001I_N`<001U_N`03001_Nfmk01Y_N`007Vmk
00<006mkKg/046mk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/03Fmk
00@006mkKg/000E_N`8000Q_N`03001_Nfmk00U_N`D000Q_N`D00003Kg/0000000U_N`8000e_N`03
001_N`00009_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/50004Kg/00`00
Kg]_N`02Kg/01`00Kg]_Nfmk001_N`0000A_N`03001_N`0000e_N`03001_Nfmk009_N`05001_Nfmk
Kg/00007Kg/:0007Kg/01@00Kg]_Nfmk00002Vmk10003Fmk00@006mkKg/000Q_N`8000a_N`03001_
Nfmk00a_N`8000=_N`03001_N`0001A_N`04001_Nfmk000HKg/00`00Kg]_N`0KKg/001i_N`03001_
Nfmk015_N`03001_Nfmk00Y_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk0000
1fmk0P001Vmk00<006mkKg/02Fmk4P0000=_N`0000001Vmk0`003fmk00<006mk00000Vmk00D006mk
Kg]_N`0000E_N`03001_Nfmk00=_N`04001_NfmkKg/50004Kg/01@00Kg]_Nfmk000016mk00<006mk
Kg/00P000Vmk00<006mk00002fmk0P001Fmk00D006mkKg]_N`0000M_N`D000]_N`03001_Nfmk009_
N`03001_Nfmk00a_N`@000U_N`04001_Nfmk0006Kg/2000>Kg/00`00Kg]_N`0:Kg/20005Kg/00`00
Kg/0000DKg/01000Kg]_N`005fmk00<006mkKg/076mk000NKg/00`00Kg]_N`0BKg/20009Kg/01@00
Kg]_Nfmk00003Vmk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/01fmk0`000Vmk0`001Vmk
2@0026mk1@000Vmk0`000Vmk0P004Vmk00D006mk001_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`04001_NfmkKg/50004Kg/01000Kg]_N`001Fmk00<006mkKg/00Vmk100000=_N`00Kg/026mk
00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/01Fmk1@002Vmk00<006mkKg/00Vmk0`004Fmk
10001Fmk0`0000E_N`00000006mk0080011_N`03001_Nfmk00U_N`03001_Nfmk00I_N`03001_N`00
019_N`05001_NfmkKg/0000FKg/00`00Kg]_N`0MKg/001m_N`03001_Nfmk01=_N`03001_Nfmk00I_
N`04001_Nfmk000?Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/;0005Kg/40009
Kg/300000fmk00000005000DKg/01@00Kg/006mk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00<006mkKg/00Vmk10000fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`H000Q_N`03001_Nfmk
00E_N`03001_Nfmk00=_N`03001_Nfmk00A_N`@000U_N`8000A_N`D001A_N`d0015_N`03001_Nfmk
00Q_N`8000U_N`04001_Nfmk000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`0BKg/2000OKg/001m_N`03
001_Nfmk01A_N`8000I_N`03001_N`00011_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk
00Y_N`D000Y_N`05001_NfmkKg/00008Kg/00`00Kg]_N`02Kg/5000EKg/01@00Kg/006mk00001Fmk
00D006mkKg]_N`0000M_N`05001_NfmkKg/00003Kg/01000Kg]_N`000Vmk00<006mkKg/016mk00<0
06mkKg/00Vmk1@0000=_N`00Kg/01Fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/00fmk
00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/016mk9P004Fmk00<006mkKg/01fmk00<006mk
Kg/02Fmk00@006mkKg/0011_N`03001_Nfmk00=_N`03001_Nfmk015_N`80021_N`007fmk00<006mk
Kg/05Vmk00<006mkKg/00Vmk00<006mk00004Fmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mk
Kg/02Vmk1@002Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/00Vmk1`004fmk00@006mk
000000M_N`04001_Nfmk0007Kg/01000Kg]_N`0016mk00H006mkKg/006mk0007Kg/00`00Kg]_N`02
Kg/500000fmk001_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P001Vmk00<0
06mkKg/00fmk00<006mkKg/00Vmk2P005Vmk2P0046mk00<006mkKg/01Fmk0P0036mk00D006mkKg]_
N`0000m_N`03001_Nfmk00=_N`03001_Nfmk015_N`03001_Nfmk01m_N`007fmk00<006mkKg/05fmk
00<006mk00000`004Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/026mk0P0000=_N`00
00000P002Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/00Vmk1@000Vmk0`0046mk00@0
06mk000000M_N`04001_Nfmk0007Kg/30006Kg/40008Kg/300000fmk001_N`0300000fmk001_N`05
0009Kg/00`00Kg]_N`04Kg/40008Kg/300000fmk00000002Kg/30004Kg/30003Kg/3000DKg/80000
0fmk0000000=Kg/00`00Kg]_N`04Kg/2000>Kg/01@00Kg]_Nfmk00003Vmk00<006mkKg/01Fmk00<0
06mkKg/03fmk00<006mkKg/086mk000PKg/00`00Kg]_N`0GKg/5000BKg/00`00Kg]_N`08Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00fmk0`003Fmk00@006mk000000M_N`04001_
Nfmk0006Kg/50004Kg/50007Kg/50004Kg/00`00Kg]_N`05000:Kg/00`00Kg]_N`03Kg/50007Kg/9
0006Kg/00`00Kg]_N`07Kg/3000@Kg/01000Kg]_N`001Fmk00<006mkKg/00P002fmk00<006mkKg/0
0fmk00<006mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/01Fmk00<006mkKg/0
3Vmk00<006mkKg/08Fmk000PKg/00`00Kg]_N`0FKg/6000BKg/00`00Kg]_N`07Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`04Kg/20009Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/01000
Kg]_N`001Vmk00<006mkKg/01Fmk10002Vmk0P002Fmk00<006mk00001Vmk6P0016mk00<006mkKg/0
1@002Fmk00<006mkKg/016mk4@002Vmk00<006mkKg/02Vmk100036mk00<006mk00001fmk00@006mk
Kg]_N`8000Q_N`03001_Nfmk009_N`80015_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_Nfmk
00I_N`03001_Nfmk00e_N`8002=_N`0086mk00<006mkKg/03fmk1`0000=_N`0000000`004Vmk00<0
06mkKg/01Vmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/016mk00<0
06mkKg/01fmk00L006mkKg]_N`00Kg/00008Kg/00`00Kg]_N`08Kg/30007Kg/20009Kg/00`00Kg/0
0005Kg/60004Kg/50007Kg/50004Kg/00`00Kg]_N`070007Kg/00`00Kg]_N`03Kg/60005Kg/70009
Kg/00`00Kg]_N`0?Kg/30008Kg/00`00Kg/00009Kg/00`00Kg]_N`02Kg/20006Kg/01@00Kg]_Nfmk
00004fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/036mk0P0096mk
000PKg/30009Kg/60008Kg/400000fmk001_N`0@Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/30000
0fmk0000000=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/300000fmk001_N`09Kg/00`00Kg]_N`0:
Kg/30003Kg/30009Kg/30002Kg/30002Kg/3000016mk000006mk1@0026mk1@0016mk00@006mkKg]_
N`<00003Kg/0000000@00004Kg/000000002Kg/80002Kg/40003Kg/300000fmk001_N`07Kg/00`00
Kg]_N`0BKg/30003Kg/4000:Kg/00`00Kg]_N`04Kg/20002Kg/300000fmk0000000EKg/00`00Kg]_
N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0:Kg/2000UKg/001m_N`D00003Kg/0
000000D000e_N`05001_N`00Kg/00002Kg/2000?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/5000@
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/5000<Kg/00`00Kg]_N`0<Kg/70007Kg/60006Kg/00`00
Kg]_N`02Kg/500000fmk001_N`05Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/0
16mk2P000Vmk20001Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/05Vmk1`002fmk00<0
06mkKg/01Fmk1P005fmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/02Fmk00<006mkKg/0
2Fmk0P009Vmk000OKg/6000BKg/20002Kg/00`00Kg/00004Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0:Kg/6000@Kg/01@00Kg]_Nfmk00002Vmk1@0036mk00<006mkKg/03Vmk4@001fmk
00<006mkKg/00Vmk1@0000=_N`00Kg/00fmk0P001fmk0P0000E_N`00Kg]_N`0000I_Na4000Q_N`03
001_Nfmk00E_N`8000A_N`03001_Nfmk01E_N`P000a_N`03001_Nfmk00E_N`D001M_N`03001_Nfmk
00A_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_Nfmk00U_N`03001_Nfmk02E_N`007fmk3000
26mk100016mk00@006mkKg/000A_N`8000a_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`H00003Kg/0
000000H000U_N`@000I_N``000Y_N`03001_Nfmk00e_N`D000M_N`L000A_N`<0009_N`H0009_N`@0
00]_N`@000A_N``000=_N`D000M_N`03001_Nfmk00Q_N`@000i_N`X000=_N`/000M_N`@0009_N`P0
01E_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk00Q_N`8002M_N`00
86mk100000=_N`0000000`0000=_N`000000100000=_N`0000000`0016mk00@006mkKg/000I_N`03
001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`80009_N`@000U_N`P00003Kg/0000000P0
00E_N`<000A_N`<000Q_N`03001_Nfmk00Y_N`800004Kg/000000006Kg/60003Kg/90002Kg/30000
0fmk00000004000;Kg/80004Kg/300000fmk000000020004Kg/30007Kg/00`00Kg]_N`09Kg/50003
Kg/:000>Kg/30007Kg/600000fmk000000040002Kg/30003Kg/2000CKg/00`00Kg]_N`05Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`06Kg/2000XKg/002=_N`04001_NfmkKg/70003Kg/6
0004Kg/01000Kg]_N`001fmk0P002Fmk00<006mkKg/00Vmk00<006mkKg/01fmk0P000fmk00<006mk
00000Vmk00<006mkKg/03Vmk1P0036mk00<006mkKg/01Fmk0P001fmk00<006mkKg/01fmk0P000Vmk
00<006mk00001Vmk00<006mk00000Vmk00<006mkKg/01Fmk1@001Vmk00<006mk0000500036mk00@0
06mkKg/000E_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`P001M_N`03001_N`0000i_N`H000=_N`03
001_Nfmk00E_N`<0011_N`03001_Nfmk00I_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`05Kg/2000Y
Kg/002A_N`03001_Nfmk00=_N`80009_N`T000A_N`05001_NfmkKg/00008Kg/00`00Kg]_N`06Kg/0
1@00Kg]_Nfmk000026mk0P001Fmk00<006mk00000fmk00<006mkKg/03Vmk1@0036mk00<006mkKg/0
1fmk0`001Fmk00<006mkKg/016mk0P000fmk00@006mkKg/000A_N`800003Kg/006mk009_N`03001_
Nfmk00E_N`L000A_N`03001_N`0000@000M_N``000Y_N`800003Kg/006mk00=_N`03001_Nfmk00A_
N`03001_Nfmk00Q_N`L001Y_N`03001_N`0000m_N`D0009_N`8000Y_N`<000e_N`03001_Nfmk00I_
N`05001_NfmkKg/0000>Kg/00`00Kg]_N`04Kg/2000ZKg/002E_N`03001_Nfmk00A_N`8000A_N`@0
0003Kg/006mk00<000=_N`03001_Nfmk00M_N`8000I_N`05001_NfmkKg/00005Kg/30006Kg/00`00
Kg/00004Kg/00`00Kg]_N`0?Kg/300000fmk001_N`0:Kg/00`00Kg]_N`0:Kg/30002Kg/400000fmk
00000004Kg/00`00Kg]_N`0300000fmk00000002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/30003
Kg/20003Kg/50003Kg/50005Kg/30004Kg/30009Kg/00`00Kg/00003Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`06Kg/30002Kg/5000IKg/01@00Kg]_Nfmk00003Vmk10000fmk00<006mkKg/036mk0P002fmk
00<006mkKg/01fmk0`0046mk00<006mkKg/00Vmk0P00:fmk000VKg/00`00Kg]_N`05Kg/30004Kg/8
0002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/01000Kg]_N`0016mk0P0026mk00@006mkKg/000E_
N`03001_Nfmk00e_N`04001_Nfmk0002Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0=Kg/70006Kg/00`00
Kg/000040003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk000016mk2`002Vmk00<0
06mkKg/01fmk10001Vmk0`000Vmk00<006mkKg/00Vmk00<006mkKg/016mk0`0016mk00<006mkKg/0
0fmk00<006mkKg/05Fmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mk000016mk0P0046mk0`00
2Fmk00<006mkKg/01Fmk1@003fmk00@006mkKg]_N`8002a_N`009fmk00<006mkKg/01fmk0P001Fmk
1@000fmk00<006mkKg/02Fmk0P000fmk00<006mk00000fmk0P002Vmk00@006mkKg/000I_N`03001_
Nfmk00a_N`04001_Nfmk0003Kg/20008Kg/00`00Kg]_N`0?Kg/50005Kg/00`00Kg]_N`050002Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00001Vmk1@003Vmk00<006mkKg/02fmk1000
16mk0P0000=_N`00Kg/00Vmk00<006mkKg/00Vmk0`001fmk00<006mkKg/016mk00<006mkKg/056mk
00<006mkKg/00Vmk00<006mkKg/02Fmk0P000Vmk00<006mkKg/00Vmk0P004fmk0`001Vmk00<006mk
Kg/01Fmk1P003Vmk00@006mkKg]_N`8002a_N`009fmk00<006mkKg/02Fmk0`000Vmk1@000fmk00<0
06mkKg/02fmk00<006mk00000P000Vmk0P002Fmk0`000fmk00<006mkKg/01Fmk00<006mkKg/02Vmk
00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/03Fmk1`000Vmk0`000Vmk
20001fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/00fmk1@003Vmk00<006mkKg/03fmk
0`000Vmk1P000Vmk0`002Fmk00<006mkKg/01Vmk00<006mkKg/04Vmk00<006mkKg/00fmk00<006mk
Kg/026mk00<006mkKg/00Vmk00@006mkKg]_N`8001M_N`80009_N`<000E_N`L00003Kg/0000000@0
00M_N`<00003Kg/0000002e_N`00:6mk00<006mkKg/02fmk0P0000=_N`0000000P000fmk00<006mk
Kg/036mk1P002Vmk1@000Vmk00<006mkKg/01Vmk00<006mkKg/02Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00<006mkKg/016mk00<006mkKg/02Vmk0`000fmk0`0000=_N`0000001@000Vmk1P001fmk
00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/00fmk10003Vmk00<006mkKg/04Vmk2P002fmk
00<006mkKg/026mk00<006mkKg/046mk00<006mkKg/016mk00<006mkKg/01fmk00<006mkKg/00fmk
00@006mkKg]_N`8001U_N`X000=_N`<000Q_N``002i_N`00:Fmk00<006mkKg/036mk0P000fmk00D0
06mkKg]_N`0000e_NaD0009_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_
Nfmk00A_N`8000A_N`03001_Nfmk00Q_N`8000M_N`04001_NfmkKg/>0007Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg/0000>Kg/00`00Kg]_N`0EKg/5000<Kg/00`00Kg]_
N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/01000Kg]_
Nfmk0P006Vmk1@002Vmk00<006mkKg/02fmk1@00;fmk000ZKg/00`00Kg]_N`0=Kg/300001Fmk0000
06mk00002Vmk20002fmk1@000Vmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/01Fmk00<0
06mkKg/01Fmk00D006mkKg]_N`0000M_N`<000U_N`04001_NfmkKg/50004Kg/50007Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/01000Kg]_N`003Fmk00<006mkKg/05Fmk1@002fmk
00<006mkKg/036mk00<006mkKg/03Fmk00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/01Fmk
00<006mkKg/00P006fmk2@001Vmk00<006mkKg/02Fmk1`00;fmk000[Kg/00`00Kg]_N`0?Kg/20000
0fmk000000020004Kg/40004Kg/3000<Kg/40003Kg/00`00Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`06Kg/40004Kg/3000;Kg/300000fmk001_N`030006Kg/40007Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00002fmk00<006mkKg/056mk
0P0000A_N`00000000]_N`03001_Nfmk00i_N`03001_Nfmk00a_N`03001_Nfmk00E_N`03001_Nfmk
00A_N`03001_Nfmk00E_N`04001_NfmkKg/2000JKg/50005Kg/30004Kg/30004Kg/40003Kg/3000`
Kg/002]_N`03001_Nfmk015_N`T000Y_N`03001_Nfmk00Y_N`80009_N`03001_N`0000a_N`03001_
Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00I_N`P000e_N`D000=_N`03001_Nfmk00A_N`03001_
Nfmk009_N`03001_Nfmk00A_N`05001_NfmkKg/0000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`0BKg/20004Kg/00`00Kg/0000:Kg/00`00Kg]_N`0?Kg/00`00Kg]_
N`0:Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/01P00Kg]_N`00Kg/001Q_N`80
00E_N`03001_Nfmk00E_N`/000I_N`<0035_N`00;6mk00<006mkKg/04Fmk1@003Fmk00<006mkKg/0
2Fmk00<006mk00000Vmk00<006mk00003Fmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mkKg/0
1Fmk6P000fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/00fmk00D006mkKg]_N`0000a_
N`05001_NfmkKg/00004Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0@Kg/20006Kg/00`00Kg/00009Kg/0
0`00Kg]_N`0AKg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`020009Kg/00`00Kg]_N`02
000GKg/20007Kg/00`00Kg]_N`08Kg/50007Kg/4000bKg/002e_N`03001_Nfmk011_N`D000e_N`03
001_Nfmk00Q_N`04001_Nfmk0003Kg/2000>Kg/01000Kg]_N`002Vmk00<006mkKg/01Fmk1@003fmk
1P000Vmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/00Vmk00@006mkKg/000e_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/20008Kg/01000Kg]_N`001fmk00<006mk
Kg/04fmk00<006mkKg/01fmk00<006mkKg/026mk00<006mk00002fmk00D006mk001_N`0001E_N`80
00U_N`03001_Nfmk00Q_N`D000I_N`04001_N`00000cKg/002i_N`03001_Nfmk011_N`H000a_N`03
001_Nfmk00I_N`04001_Nfmk0004Kg/3000>Kg/3000:Kg/00`00Kg]_N`05Kg/5000=Kg/20002Kg/3
0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/01000Kg]_N`003Vmk00@006mk
Kg/000I_N`03001_Nfmk00I_N`03001_Nfmk00a_N`8000Y_N`04001_Nfmk0006Kg/00`00Kg]_N`0E
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/3000<Kg/01@00Kg/006mk00004fmk0P002fmk00<006mk
Kg/02Fmk0`001Vmk00@006mk000003A_N`00;fmk00<006mkKg/04Fmk0`0000=_N`0000002Vmk00<0
06mkKg/01Fmk00D006mkKg]_N`0000=_NaH000Y_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_
Nfmk00Q_N`8000I_N`05001_NfmkKg/00005Kg/00`00Kg]_N`07Kg/01`00Kg]_Nfmk001_N`00011_
N`03001_N`0000M_N`03001_Nfmk00A_N`03001_Nfmk00]_N`8000a_N`05001_NfmkKg/00004Kg/0
0`00Kg]_N`0GKg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/5000:Kg/01P00Kg]_N`00Kg/0015_N`80
00e_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`05001_N`00Kg/0000dKg/002m_N`03001_Nfmk015_
N`800005Kg/006mkKg/00009Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00000fmk1@002Vmk2P001fmk
00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/01Fmk0`0026mk00D006mkKg]_N`0000A_N`03
001_Nfmk00U_N`06001_Nfmk001_N`0046mk00<006mk000026mk00<006mkKg/00fmk00<006mkKg/0
2Fmk0P003Vmk00D006mkKg]_N`0000=_N`03001_Nfmk01U_N`03001_Nfmk009_N`03001_Nfmk00E_
N`P000Y_N`05001_N`00Kg/0000@Kg/2000?Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`02000eKg/0031_N`03001_Nfmk015_N`800004Kg/006mkKg/20007Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`02Kg/01000Kg]_Nfmk1P0000A_N`00000000=_N`80009_N`D000=_N`<000A_N`D000Q_N`<0
009_N`8000]_N`05001_NfmkKg/00003Kg/00`00Kg]_N`0;Kg/4000BKg/30007Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`07Kg/2000@Kg/00`00Kg]_N`02Kg/4000LKg/40004Kg/40003Kg/60009Kg/01@00
Kg/006mk00003Vmk0P004Vmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/00P00=Vmk000a
Kg/00`00Kg]_N`0@Kg/20002Kg/01000Kg]_Nfmk0P001Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk
00H006mkKg]_N`00Kg/30002Kg/70005Kg/30007Kg/80008Kg/6000>Kg/01000Kg]_N`000fmk00<0
06mkKg/02fmk1@0046mk1@001fmk00<006mkKg/00Vmk00<006mkKg/01Fmk0P004Vmk00@006mkKg]_
N`D001a_N`P000Q_N`@00003Kg/0000000M_N`80009_N`03001_Nfmk00Y_N`8001A_N`03001_Nfmk
00I_N`03001_Nfmk00A_N`03001_Nfmk008003M_N`00<Vmk00<006mkKg/03fmk00D006mk001_N`00
00E_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01000Kg]_N`000Vmk00<006mkKg/00Vmk1@00
2Fmk00<006mkKg/026mk4P003fmk00@006mkKg/0009_N`03001_Nfmk00a_NaX000Q_N`05001_Nfmk
Kg/00005Kg/2000DKg/01000Kg]_Nfmk9P003Vmk00D006mkKg]_N`0000I_N`800003Kg/006mk00Y_
N`8001I_N`03001_Nfmk00E_N`03001_Nfmk00=_N`80009_N`8003Q_N`00<fmk00<006mkKg/03fmk
00D006mk001_N`0000E_N`8000=_N`04001_Nfmk0006Kg/00`00Kg/00003Kg/00`00Kg]_N`02Kg/5
0009Kg/00`00Kg]_N`08Kg/50008Kg/7000=Kg/01000Kg]_N`000Vmk00<006mkKg/02Vmk1`002fmk
3@001Vmk00@006mkKg/000=_N`8001I_N`04001_NfmkKg/5000LKg/5000?Kg/01000Kg]_Nfmk0P00
16mk00@006mkKg/000U_N`8001Q_N`03001_Nfmk00E_N`03001_Nfmk009_N`04001_NfmkKg/2000i
Kg/003=_N`03001_Nfmk00m_N`03001_N`00009_N`03001_Nfmk00A_N`800003Kg/00000008000A_
N`@000A_N`03001_Nfmk009_N`@000Y_N`03001_Nfmk00U_N`<00003Kg/0000000M_N`<000=_N`<0
00]_N`05001_N`00Kg/0000:Kg/30003Kg/50006Kg/40006Kg/50002Kg/30003Kg/400000fmk0000
000GKg/300000fmk001_N`04000MKg/5000>Kg/00`00Kg]_N`03Kg/00`00Kg/000020002Kg/00`00
Kg]_N`05Kg/2000JKg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/2000iKg/003A_
N`03001_Nfmk00i_N`04001_Nfmk0002Kg/00`00Kg]_N`05Kg/50003Kg/50004Kg/01@00Kg]_Nfmk
000016mk00<006mkKg/01fmk00<006mkKg/02Fmk00<006mk00000fmk0P001Vmk00<006mkKg/01Fmk
0P002Fmk0P0000=_N`00Kg/01fmk0`001Fmk00<006mk00002@002Fmk00<006mk0000100016mk2000
66mk1@000fmk00@006mkKg/001e_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`03Kg/60006Kg/2000M
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/2000jKg/003E_N`03001_Nfmk00i_
N`03001_N`0000=_N`03001_Nfmk00A_N`d000A_N`04001_N`000005Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`08Kg/01000Kg]_N`001Fmk0P0016mk00<006mkKg/01fmk0`001Vmk0P0000=_N`00Kg/016mk
0`0026mk00<006mk000010003Vmk00<006mk0000;@000fmk00D006mkKg]_N`0001a_N`03001_Nfmk
009_N`03001_Nfmk00]_N`03001_Nfmk00=_N`H000A_N`8001m_N`03001_Nfmk009_N`05001_Nfmk
Kg/00004Kg/2000kKg/003I_N`03001_Nfmk00e_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/70000
0fmk0000000400000fmk000000020008Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/01000Kg]_N`00
1fmk0P0000A_N`00000000]_N`<000=_N`<000=_N`<000Y_N`03001_Nfmk00D000e_N`03001_Nfmk
00D000M_N`D001Q_N`D000=_N`03001_Nfmk009_N`03001_Nfmk01U_N`03001_Nfmk00=_N`8000a_
N`03001_Nfmk009_N`H0009_N`80025_N`05001_NfmkKg/00003Kg/00`00Kg]_N`02Kg/2000lKg/0
03M_N`03001_Nfmk00a_N`05001_NfmkKg/00003Kg/00`00Kg]_N`03Kg/30003Kg/<0009Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`08Kg/01000Kg]_N`002Fmk1@003Fmk2@003Fmk00<006mkKg/0100000=_
N`0000002fmk00<006mkKg/010002Fmk0`006Vmk0`0016mk00<006mkKg/00fmk00<006mkKg/066mk
00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/00fmk1`008fmk00D006mkKg]_N`00009_N`03
001_Nfmk00=_N`03001_Nfmk03]_N`00=fmk00<006mkKg/03Fmk00@006mkKg/000A_N`03001_Nfmk
00A_N`03001_Nfmk00A_N`T000U_N`03001_Nfmk00I_N`03001_Nfmk00I_N`05001_NfmkKg/00009
Kg/I000>Kg/01000Kg]_N`0016mk00<006mkKg/00P0026mk00@006mkKg/000A_N`03001_Nfmk00E_
N`04001_Nfmk000IKg/01000Kg]_N`0016mk00<006mkKg/016mk00<006mkKg/05fmk00<006mkKg/0
1Vmk00<006mkKg/02Fmk00<006mkKg/00fmk1`008Vmk00D006mkKg/006mk008000E_N`8003e_N`00
>6mk00<006mkKg/036mk00D006mkKg]_N`0000A_N`03001_Nfmk00=_N`03001_Nfmk00A_N`T000Y_
N`03001_Nfmk00E_N`03001_Nfmk00I_N`05001_NfmkKg/00009Kg/8000<Kg/5000=Kg/01000Kg]_
N`001Fmk00<006mkKg/00Vmk0P001Vmk0`001Fmk00<006mkKg/01Fmk00@006mkKg/001U_N`04001_
Nfmk0004Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0EKg/00`00Kg]_N`08Kg/20009Kg/00`00Kg]_N`03
Kg/50002Kg/:000HKg/00`00Kg]_N`020006Kg/2000nKg/003U_N`03001_Nfmk00]_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/90009Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/30004Kg/3000:Kg/300000fmk0000000;Kg/00`00Kg/0
0007Kg/00`00Kg]_N`03Kg/70008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0EKg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/01Fmk00<006mkKg/056mk00<006mkKg/02Vmk00<006mkKg/0
1fmk00<006mkKg/00fmk0`003Fmk2P003Vmk10001Vmk0P00?fmk000jKg/00`00Kg]_N`0;Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00@006mkKg/0009_N`05001_NfmkKg/0
0009Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/01@00Kg]_
Nfmk00001Vmk10002Fmk00<006mkKg/00P0026mk00<006mk00002Fmk00<006mkKg/00fmk1@002Vmk
00D006mkKg]_N`0000E_N`03001_Nfmk01E_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk
00I_N`03001_Nfmk01=_N`03001_Nfmk00]_N`03001_Nfmk00M_N`03001_Nfmk009_N`<001M_N`X0
00=_N`D000E_N`80041_N`00>fmk00<006mkKg/02Vmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/00`00Kg/00003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/40006Kg/0
1000Kg]_Nfmk0P001Vmk0P002Vmk00<006mkKg/00fmk1P002Fmk00D006mkKg]_N`0000E_N`03001_
Nfmk01A_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk019_N`03001_
Nfmk00a_N`8000M_N`03001_Nfmk009_N`800003Kg/006mk01m_N`P000E_N`03001_Nfmk03m_N`00
>fmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000A_N`03001_
N`0000A_N`03001_Nfmk00=_N`8000M_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00A_
N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`<000=_N`<000=_N`800003Kg/00000
008000a_N`<0009_N`D00003Kg/00000008000I_N`<000M_N`03001_Nfmk019_N`03001_Nfmk00A_
N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk015_N`03001_Nfmk00i_N`03001_Nfmk00E_
N`04001_NfmkKg/200000fmk001_N`0RKg/50004Kg/00`00Kg]_N`10Kg/003a_N`03001_Nfmk00Y_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00003Kg/00`00Kg/00004Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/70004Kg/5000;Kg/6000016mk000000001Vmk2P00
1Vmk00<006mkKg/04Vmk00<006mkKg/01Fmk00D006mkKg]_N`0000]_N`03001_Nfmk011_N`03001_
Nfmk00m_N`03001_Nfmk00A_N`04001_NfmkKg/200000fmk001_N`0PKg/60004Kg/20012Kg/003e_
N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk00A_N`04001_Nfmk0002Kg/00`00Kg/00004
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0>Kg/N0003Kg/00`00Kg/0000:Kg/50006
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk000036mk00<006mkKg/03fmk00<006mk
Kg/046mk0P001Fmk00<006mkKg/00P000Vmk00<006mkKg/076mk1@001Vmk0P00@fmk000nKg/00`00
Kg]_N`08Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg/00002Kg/20005Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0=Kg/60003Kg/50007Kg/90003Kg/00`00Kg/0000:Kg/50007
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/03Vmk00<006mk
Kg/04Vmk00<006mkKg/00Vmk00<006mkKg/00P000Vmk00<006mkKg/06fmk00<006mk00000Vmk00<0
06mkKg/00fmk0P00A6mk000oKg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/50006
Kg/00`00Kg]_N`09Kg/20005Kg/01@00Kg]_Nfmk000016mk00<006mkKg/01Vmk00<006mkKg/00Vmk
00<006mkKg/026mk00<006mkKg/03Vmk0`000Vmk00<006mk000010000fmk1@001Fmk0`0016mk00<0
06mk00002Fmk00<006mk00000`001fmk00<006mkKg/03fmk00<006mkKg/01fmk00D006mkKg]_N`00
00e_N`03001_Nfmk00i_N`03001_Nfmk01=_N`03001_Nfmk009_N`04001_N`000003Kg/00`00Kg]_
N`0HKg/200001Fmk001_Nfmk00001Vmk00<006mkKg/0@fmk000oKg/00`00Kg]_N`08Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`04Kg/50006Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk0000
0fmk00<006mkKg/01fmk00D006mkKg]_N`0000a_N`03001_Nfmk00i_N`03001_Nfmk009_N`T000a_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`05Kg/20002Kg/01000Kg]_N`001fmk00<006mkKg/03fmk
00<006mkKg/026mk00@006mkKg/000i_N`03001_Nfmk00e_N`03001_Nfmk01A_N`80009_N`04001_
N`000003Kg/00`00Kg]_N`0FKg/20002Kg/01000Kg]_N`001Vmk00<006mkKg/0A6mk0010Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/50006Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`02
Kg/01000Kg]_N`000fmk00<006mkKg/01fmk00@006mkKg/000i_N`03001_Nfmk00a_N`8000A_N`D0
015_N`04001_Nfmk0002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001fmk00<0
06mkKg/03Fmk00<006mkKg/02Fmk00@006mkKg/000m_N`03001_Nfmk00a_N`03001_Nfmk01I_N`06
001_Nfmk001_N`000fmk00<006mkKg/05Fmk00D006mkKg]_N`0000=_N`03001_Nfmk00=_N`8004I_
N`00@Fmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mkKg/00fmk1@001Vmk00<006mkKg/03Fmk
00D006mkKg]_N`00009_N`04001_Nfmk000:Kg/01000Kg]_N`003fmk00<006mkKg/02fmk0P0016mk
2`002fmk00@006mkKg/0009_N`03001_Nfmk009_N`8000A_N`03001_Nfmk00=_N`03001_Nfmk00A_
N`03001_Nfmk00e_N`03001_Nfmk00U_N`04001_Nfmk000@Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0G
Kg/01@00Kg/006mk000016mk00<006mkKg/04Vmk0P000Vmk0P000fmk00<006mkKg/00fmk0P00Afmk
0012Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/30007Kg/00`00Kg]_N`0>Kg/2
0002Kg/00`00Kg/00002Kg/00`00Kg]_N`08Kg/3000@Kg/00`00Kg]_N`0;Kg/20005Kg/30007Kg/5
0007Kg/30002Kg/300000fmk001_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0<
Kg/00`00Kg]_N`0;Kg/00`00Kg/0000AKg/00`00Kg]_N`0:Kg/00`00Kg]_N`0HKg/50003Kg/00`00
Kg]_N`0@Kg/20003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/20018Kg/004=_N`03001_Nfmk00E_
N`03001_Nfmk00A_N`03001_Nfmk00=_N`04001_Nfmk0006Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`02
0002Kg/00`00Kg]_N`07Kg/5000@Kg/00`00Kg]_N`09Kg/00`00Kg/00004Kg/20002Kg/00`00Kg]_
N`09Kg/@0007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/0
0`00Kg/0000BKg/00`00Kg]_N`09Kg/00`00Kg]_N`0IKg/50003Kg/00`00Kg]_N`0=Kg/20004Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`17Kg/004=_N`03001_Nfmk00E_N`03001_Nfmk
00E_N`03001_Nfmk009_N`04001_Nfmk0006Kg/00`00Kg]_N`0AKg/01000Kg/006mk0P002Vmk1@00
4Fmk00<006mkKg/026mk00<006mk00000fmk00<006mk00000Vmk00<006mkKg/03fmk2P001Vmk00<0
06mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/036mk00<006mk00004fmk00<0
06mkKg/026mk00<006mkKg/06Fmk1@000fmk00<006mkKg/036mk00<006mkKg/00fmk00<006mkKg/0
16mk00<006mkKg/00Vmk00<006mkKg/0B6mk0014Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`02Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/04Vmk1@001Vmk2`0046mk00<006mkKg/01Vmk
00<006mk000016mk00<006mk00000fmk00<006mkKg/03Vmk2P001Vmk00<006mkKg/01fmk00<006mk
Kg/00fmk00<006mkKg/026mk00<006mkKg/03Fmk00<006mk000056mk00<006mkKg/01fmk00<006mk
Kg/05fmk1`0016mk00<006mkKg/02Fmk0P001Fmk00<006mkKg/016mk00<006mkKg/00Vmk0P00BVmk
0015Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/00fmk00<0
06mkKg/04fmk2P001Fmk0`000fmk0P003Vmk00<006mkKg/01Vmk00<006mk00000fmk00@006mkKg/0
00=_N`03001_Nfmk00m_N`@00004Kg/000000007Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`0>Kg/2000EKg/00`00Kg]_N`05Kg/00`00Kg]_N`0EKg/30003Kg/50003
Kg/00`00Kg]_N`07Kg/20005Kg/20006Kg/00`00Kg]_N`02Kg/2001;Kg/004I_N`03001_Nfmk00=_
N`03001_Nfmk00I_N`04001_Nfmk0004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0CKg/50009Kg/00`00
Kg/00006Kg/3000<Kg/00`00Kg]_N`05Kg/00`00Kg/00002Kg/01@00Kg]_Nfmk000016mk00<006mk
Kg/03Fmk00<006mkKg/00Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00U_N`03001_Nfmk009_N`03
001_Nfmk00M_N`03001_Nfmk00m_N`03001_N`0001E_N`03001_Nfmk00A_N`03001_Nfmk019_N`<0
00E_N`03001_Nfmk00=_N`04001_Nfmk0008Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/01000Kg]_
Nfmk0P00C6mk0017Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/01000Kg]_N`001Fmk00@006mkKg/0
01=_N`P000U_N`03001_N`0000U_N`<000Y_N`03001_Nfmk00=_N`04001_Nfmk0002Kg/01000Kg]_
N`001Vmk00<006mkKg/036mk00<006mkKg/00fmk00@006mkKg/000E_N`03001_Nfmk00Y_N`03001_
Nfmk009_N`03001_Nfmk00I_N`03001_Nfmk00m_N`03001_N`0001I_N`03001_Nfmk00=_N`03001_
Nfmk00m_N`<000Q_N`03001_Nfmk00A_N`04001_Nfmk0005Kg/20006Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`1;Kg/004M_N`03001_Nfmk00=_N`03001_Nfmk00I_N`<000E_N`04001_
Nfmk000@Kg/30004Kg/30009Kg/01000Kg]_N`0036mk0P0026mk00<006mkKg/00fmk00H006mkKg/0
06mk0003Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/200000fmk001_N`03Kg/0
0`00Kg]_N`0;Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/04Fmk0P005fmk00<006mkKg/00Vmk00<0
06mkKg/02fmk10002Vmk00<006mkKg/01Vmk1@0000=_N`0000001fmk00<006mkKg/01fmk00D006mk
Kg]_N`0004i_N`00B6mk00<006mkKg/00Vmk00<006mkKg/01Fmk1@001Fmk00<006mk000036mk1000
26mk00<006mkKg/026mk00@006mkKg/000i_N`<000I_N`03001_Nfmk009_N`06001_Nfmk001_N`00
0fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/026mk00<006mk00000Vmk00<006mkKg/0
3Fmk00@006mkKg/000I_N`03001_Nfmk019_N`8001Q_N`05001_NfmkKg/0000:Kg/3000>Kg/00`00
Kg]_N`07Kg/50008Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk0000Cfmk0019Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`04Kg/50005Kg/00`00Kg/00008Kg/4000<Kg/00`00Kg]_N`07Kg/01000Kg]_N`004Vmk
0`0016mk00@006mkKg/0009_N`03001_N`0000A_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_
Nfmk00U_N`80009_N`03001_Nfmk00i_N`04001_Nfmk0005Kg/00`00Kg]_N`0BKg/2000IKg/01000
Kg]_N`001fmk0`0046mk00<006mkKg/026mk1@001Vmk0P002Fmk00@006mkKg]_N`8004m_N`00BVmk
00D006mkKg]_N`0000I_N`L000A_N`<000A_N`<0015_N`03001_Nfmk00E_N`05001_NfmkKg/0000E
Kg/20003Kg/3000016mk000000001Fmk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/02fmk
100046mk00@006mkKg/000A_N`03001_Nfmk01=_N`<001U_N`@000=_N`<0019_N`03001_Nfmk00U_
N`D0009_N`@000]_N`03001_Nfmk0080051_N`00Bfmk00@006mkKg/000M_N`@0009_N`/001A_N`03
001_Nfmk00E_N`05001_NfmkKg/0000GKg/;0004Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`0;Kg/5000@Kg/00`00Kg/00004Kg/00`00Kg]_N`0BKg/5000HKg/7000EKg/00`00Kg]_N`08
Kg/00`00Kg/0000200000fmk00000004000:Kg/01@00Kg]_Nfmk0000DFmk001;Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk1@005fmk00<006mkKg/016mk00<006mkKg/00Vmk
00<006mkKg/05fmk2@000fmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/036mk1@004Fmk
00<006mk00000Vmk00<006mkKg/04Vmk8`005Vmk00<006mkKg/01fmk0P001Fmk00<006mk00001000
2Vmk00@006mkKg/0059_N`00C6mk00@006mkKg/000E_N`03001_Nfmk00=_N`04001_NfmkKg/6000F
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0GKg/90003Kg/00`00Kg]_N`09Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`0:Kg/=000<Kg/20002Kg/00`00Kg]_N`0<Kg/600000fmk00000003000H
Kg/5000FKg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg/000040009Kg/01000Kg]_N`00Dfmk
001=Kg/00`00Kg/00004Kg/00`00Kg]_N`05Kg/01000Kg]_Nfmk0`000Vmk0`004fmk00<006mkKg/0
0fmk00<006mkKg/00fmk00<006mkKg/05Fmk0P0000=_N`0000001@0016mk00<006mkKg/02Fmk00<0
06mkKg/00fmk00<006mkKg/026mk0`000fmk0`0000=_N`00000016mk1P001Vmk100026mk1`001Fmk
0P0000A_N`00000001Q_N`03001_N`0000800003Kg/0000001=_N`03001_Nfmk00E_N`8000U_N`03
001_N`00008000Y_N`04001_N`00001CKg/004i_N`03001_N`00009_N`03001_Nfmk00M_N`05001_
NfmkKg/00006Kg/2000AKg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0CKg/20008Kg/0
0`00Kg/00003Kg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk000026mk0`001Fmk00<006mkKg/016mk00<0
06mkKg/01fmk2P000Vmk1P002fmk00<006mkKg/00fmk00<006mkKg/056mk0P000Vmk00<006mkKg/0
0fmk0P004Fmk00<006mkKg/016mk00<006mkKg/02Fmk00D006mkKg]_N`0000U_N`04001_Nfmk001D
Kg/004m_N`80009_N`03001_Nfmk00Q_N`04001_Nfmk0008Kg/3000>Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`0AKg/2000;Kg/00`00Kg/00002Kg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk
00001Fmk0`0026mk00<006mkKg/01Fmk0P0036mk1`003fmk0P001Vmk00<006mkKg/04Vmk0P0016mk
00<006mkKg/01Fmk00<006mkKg/03Fmk00<006mkKg/00fmk0P003Fmk00@006mkKg/000Q_N`04001_
Nfmk001EKg/004m_N`@000a_N`@000Y_N`8000a_N`05001_NfmkKg/00007Kg/00`00Kg]_N`0?Kg/2
000>Kg/5000=Kg/30003Kg/3000:Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/5000@Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/2000<Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0=Kg/01000Kg]_N`0026mk00<006mk0000EVmk001?Kg/5000;Kg/5000;Kg/2000:Kg/0
1@00Kg]_Nfmk00001fmk00<006mkKg/03Fmk0P004Fmk1@002fmk1`003Fmk00<006mkKg/02Fmk0P00
2Vmk0`0000=_N`00Kg/036mk0P002Vmk00<006mkKg/03Vmk0P001fmk00<006mkKg/026mk0P002Vmk
00@006mkKg]_N`80015_N`04001_Nfmk0006Kg/00`00Kg/0001GKg/004m_NaH000a_N`<000Q_N`03
001_N`0000Q_N`03001_Nfmk00]_N`8001=_NaD000i_N`03001_Nfmk00a_N`8000Q_N`03001_Nfmk
009_N`03001_Nfmk00Q_N`8000a_N`03001_Nfmk00e_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03
001_Nfmk00I_N`05001_NfmkKg/0000DKg/00`00Kg/00006Kg/3001GKg/004m_N`D000]_N`D00003
Kg/0000000D000Q_N`8000I_N`03001_N`0000Q_N`03001_Nfmk00U_N`80011_N`X000]_N`D000i_
N`03001_Nfmk00i_N`03001_Nfmk00A_N`03001_Nfmk00A_N`8000M_N`03001_Nfmk00e_N`03001_
Nfmk00Y_N`8000Y_N`03001_Nfmk00]_N`8000I_N`04001_N`00000EKg/00`00Kg/00005Kg/00`00
Kg/0001HKg/0051_N`@000a_N`<000U_N`H000A_N`<0009_N`<000Q_N`03001_Nfmk00Q_N`8000i_
N`@000I_N`D000]_N`<00003Kg/0000000]_N`03001_Nfmk011_N`800004Kg/000000009Kg/40000
0fmk0000000@Kg/00`00Kg]_N`08Kg/2000;Kg/00`00Kg]_N`0>Kg/200001Vmk00000000Kg/001Q_
N`8000A_N`03001_N`0005U_N`00E6mk00<006mkKg/02fmk00<006mkKg/03Fmk3@001fmk00<006mk
Kg/01Vmk0P002fmk1@002Vmk00<006mkKg/00Vmk00<006mkKg/02Vmk00D006mkKg]_N`0000Y_N`03
001_Nfmk019_N`D000Q_N`D0019_N`03001_Nfmk00M_N`03001_Nfmk00]_N`03001_Nfmk011_N`D0
01U_N`03001_N`0000=_N`8005Y_N`00EFmk00<006mkKg/02Vmk00<006mkKg/056mk1P001fmk00<0
06mkKg/016mk0P0026mk1@003fmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/00Vmk0P00
1fmk00<006mkKg/04Vmk4`004fmk00<006mkKg/016mk0P003Vmk00<006mkKg/046mk1P006Fmk0P00
0Vmk0P00Ffmk001FKg/00`00Kg]_N`0:Kg/00`00Kg]_N`0DKg/60006Kg/00`00Kg]_N`02Kg/20005
Kg/5000CKg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`0<Kg/600000fmk000000030008Kg/;000=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0>Kg/00`00
Kg]_N`0?Kg/600000fmk00000006000AKg/20002Kg/00`00Kg]_N`1JKg/005M_N`8000Y_N`03001_
Nfmk01A_N`@0009_N`<0009_N`<00003Kg/0000000=_N`@001Q_N`03001_Nfmk00I_N`03001_Nfmk
00Q_N`03001_Nfmk00A_N`H000Q_N`L000Q_N`<000Y_N`<000M_N`H000I_N`<0009_N`80015_N`03
001_Nfmk00e_N`80009_N`<000Y_N`P000Y_N`@005a_N`00FFmk00<006mkKg/026mk00<006mkKg/0
4Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk2`0076mk00<006mkKg/01fmk0P0026mk00<006mkKg/0
1Fmk1@000Vmk1P0046mk00<006mk00002Vmk00<006mkKg/036mk2`004Vmk00<006mkKg/036mk0P00
0fmk00<006mkKg/04fmk200000=_N`0000000`00G6mk001JKg/00`00Kg]_N`07Kg/00`00Kg]_N`0A
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/5000QKg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`04Kg/7000FKg/00`00Kg/0000:Kg/00`00Kg]_N`0AKg/5000CKg/00`00Kg]_N`0:Kg/20004
Kg/00`00Kg]_N`0LKg/6001LKg/005]_N`03001_Nfmk00I_N`03001_Nfmk011_N`03001_Nfmk00E_
N`03001_Nfmk009_N`D0021_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00A_N`D001Q_
N`04001_Nfmk0009Kg/00`00Kg]_N`0AKg/8000@Kg/00`00Kg]_N`08Kg/20005Kg/00`00Kg]_N`0M
Kg/6001LKg/005a_N`03001_Nfmk00I_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk00=_
N`<0025_N`03001_Nfmk00a_N`03001_Nfmk00A_N`03001_Nfmk00E_N`@001Q_N`05001_NfmkKg/0
0008Kg/00`00Kg]_N`0AKg/4000016mk001_Nfmk0`003Fmk00<006mkKg/01Vmk0P001fmk00<006mk
Kg/06fmk0P000Vmk0`00GFmk001MKg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/0
1@00Kg]_Nfmk00000fmk00<006mkKg/07Vmk00<006mkKg/03Fmk0P001Fmk00<006mkKg/016mk00D0
06mkKg]_N`0001M_N`05001_NfmkKg/00008Kg/00`00Kg]_N`0@Kg/00`00Kg/00004Kg/00`00Kg]_
N`02Kg/2000;Kg/00`00Kg]_N`04Kg/20008Kg/00`00Kg]_N`0JKg/2001TKg/005i_N`03001_Nfmk
00A_N`03001_Nfmk00a_N`03001_Nfmk00U_N`05001_NfmkKg/00004Kg/00`00Kg]_N`0LKg/00`00
Kg]_N`0@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0DKg/00`00
Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?Kg/01000Kg]_N`001Fmk00<006mkKg/00fmk0`00
26mk00<006mkKg/00Vmk0P002Fmk00<006mkKg/06Fmk0P00IVmk001OKg/00`00Kg]_N`04Kg/00`00
Kg]_N`09Kg/2000=Kg/30006Kg/00`00Kg]_N`0KKg/00`00Kg]_N`0AKg/01@00Kg]_Nfmk000016mk
00<006mkKg/016mk00<006mkKg/056mk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/03Fmk
0P000Vmk00<006mkKg/016mk00<006mkKg/01Vmk0`000fmk0`000Vmk0P002Vmk00<006mkKg/066mk
0P00J6mk001PKg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/50005Kg/00`00Kg]_
N`0KKg/00`00Kg]_N`0BKg/01@00Kg]_Nfmk00000fmk00<006mkKg/01Fmk00<006mkKg/04Vmk00<0
06mkKg/016mk00<006mkKg/016mk00<006mkKg/036mk00D006mkKg]_N`0000Q_N`03001_Nfmk00Q_
N`P000a_N`03001_Nfmk01I_N`8006Y_N`00HFmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mk
Kg/03Fmk1@001Vmk00<006mkKg/06Fmk00<006mkKg/056mk00@006mkKg/0009_N`03001_Nfmk00M_
N`03001_Nfmk015_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk009_
N`03001_Nfmk00M_N`03001_Nfmk00U_N`D000a_N`03001_Nfmk01E_N`8006a_N`00HVmk00<006mk
Kg/00Vmk00<006mkKg/01Fmk00<006mkKg/02fmk20001fmk00<006mkKg/066mk00<006mkKg/05Fmk
1@002Vmk00<006mkKg/04Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mk
Kg/00Vmk00<006mkKg/02Fmk00<006mkKg/026mk1@002fmk00<006mkKg/056mk0P00KVmk001SKg/2
0002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/30004Kg/40007Kg/00`00Kg]_N`0HKg/00`00Kg]_
N`0FKg/5000:Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/2
0005Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`08Kg/3000<Kg/00`00Kg]_N`0BKg/2001`Kg/006E_N`04
001_Nfmk0004Kg/00`00Kg]_N`06Kg/4000;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0GKg/00`00Kg]_
N`0FKg/5000;Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0AKg/2
001bKg/006I_N`03001_N`0000=_N`03001_Nfmk00=_N`@0011_N`03001_Nfmk00E_N`03001_Nfmk
01E_N`03001_Nfmk01M_N`D000a_N`03001_Nfmk00i_N`03001_Nfmk00M_N`05001_NfmkKg/00008
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0@
Kg/2001dKg/006M_N`D000=_N`<001E_N`03001_Nfmk00E_N`03001_Nfmk01A_N`03001_Nfmk01I_
N`03001_N`0000@000]_N`03001_Nfmk00i_N`03001_Nfmk00M_N`05001_NfmkKg/00007Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0?Kg/2001f
Kg/006M_N`P001U_N`03001_Nfmk00A_N`03001_Nfmk01A_N`03001_Nfmk01E_N`03001_Nfmk009_
N`04001_Nfmk000;Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/01000Kg]_N`001Fmk0P001fmk00<0
06mkKg/046mk00<006mkKg/01fmk00<006mkKg/01fmk00<006mkKg/036mk0`00N6mk001WKg/5000M
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0DKg/20005Kg/01@00Kg]_Nfmk00002fmk
00<006mkKg/036mk00<006mkKg/02Fmk00<006mk000016mk00<006mkKg/01fmk00<006mkKg/04Fmk
00<006mkKg/01Vmk00<006mkKg/01Vmk00<006mkKg/02fmk0P00Nfmk001WKg/6000MKg/00`00Kg]_
N`04Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0CKg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00002Vmk00<0
06mkKg/036mk00<006mkKg/02Fmk00<006mk00000fmk00<006mkKg/01fmk00<006mkKg/04fmk00<0
06mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/02Vmk0P00OFmk001XKg/30002Kg/3000KKg/00`00
Kg]_N`03Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/20009Kg/00`00Kg]_N`02Kg/20009Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0:Kg/50009Kg/00`00Kg]_N`0EKg/00`00Kg]_N`04Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`08Kg/2001oKg/0071_N`8001Y_N`03001_Nfmk00=_N`03001_Nfmk00m_N`03001_
Nfmk015_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03001_
Nfmk00U_N`D000Y_N`03001_Nfmk01I_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00M_
N`80085_N`00LVmk0`0066mk00<006mkKg/00fmk00<006mkKg/03Vmk00<006mkKg/046mk00<006mk
Kg/02fmk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/02Vmk00<006mkKg/02Fmk1@002Fmk
00<006mkKg/066mk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01Vmk0P00Pfmk001eKg/3
000FKg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0>Kg/2000>Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_N`09Kg/50009Kg/00`00Kg]_N`0IKg/01@00Kg]_
Nfmk000016mk00<006mkKg/01Fmk0P00QFmk001hKg/2000EKg/00`00Kg]_N`02Kg/00`00Kg]_N`0=
Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`05Kg/20007Kg/00`00Kg]_N`08Kg/00`00
Kg]_N`09Kg/40009Kg/00`00Kg]_N`0KKg/01000Kg]_N`0016mk00<006mkKg/00fmk0P00Qfmk001j
Kg/3000CKg/20003Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/2000BKg/00`00Kg]_N`07Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`020009Kg/00`00Kg]_N`0KKg/0
1@00Kg]_Nfmk00000Vmk00<006mkKg/00Vmk0P00RFmk001mKg/2000CKg/01@00Kg]_Nfmk000036mk
00<006mkKg/02fmk00<006mkKg/04Vmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/01fmk
00<006mkKg/01fmk00@006mkKg]_N`8000Q_N`03001_Nfmk01e_N`06001_Nfmk001_N`000fmk0P00
Rfmk001oKg/3000AKg/01000Kg]_N`0036mk00<006mkKg/02Vmk00<006mkKg/056mk00<006mkKg/0
26mk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/00`001fmk00<006mk
Kg/07fmk10000Vmk0P00SFmk0022Kg/2000@Kg/01000Kg]_N`002Vmk00<006mkKg/02Fmk0P005fmk
00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/01Vmk00<006mkKg/01@00
1Vmk00<006mkKg/07fmk1P00Sfmk0024Kg/3000>Kg/01000Kg]_N`002Fmk00<006mkKg/026mk00<0
06mkKg/05fmk00<006mkKg/02Vmk0P0016mk00<006mkKg/01Fmk00<006mkKg/01Fmk00@006mkKg]_
N`D000E_N`03001_Nfmk021_N`D0091_N`00Qfmk0`0036mk00@006mkKg/000Q_N`03001_Nfmk00I_
N`8001]_N`03001_Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_
Nfmk009_N`D000E_N`03001_Nfmk01Y_N`/0091_N`00RVmk0P002fmk00<006mk00001fmk00<006mk
Kg/01Vmk00<006mkKg/06fmk00<006mkKg/036mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mk
Kg/016mk00<006mkKg/00Vmk00<006mk00000P0000=_N`00Kg/00Vmk00<006mkKg/05Fmk1P000fmk
0P000Vmk0`00TFmk002<Kg/30009Kg/00`00Kg/00006Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0LKg/0
0`00Kg]_N`0=Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00fmk00@006mkKg]_N`8000E_N`80009_
N`03001_Nfmk011_N`H000M_N`8009Q_N`00Sfmk0P0026mk00<006mk00001Fmk00<006mkKg/00fmk
0P0086mk00<006mkKg/03Fmk0P000Vmk00D006mkKg]_N`0000A_N`05001_NfmkKg/00007Kg/20002
Kg/00`00Kg]_N`0:Kg/6000;Kg/2002JKg/0095_N`<000I_N`8000E_N`03001_Nfmk009_N`03001_
Nfmk021_N`03001_Nfmk00m_N`04001_Nfmk0002Kg/01@00Kg]_Nfmk00000Vmk0P002Fmk0`001fmk
1P003fmk0P00W6mk002DKg/20005Kg/20003Kg/01000Kg]_Nfmk0P0096mk00<006mkKg/03fmk00<0
06mk00000Vmk00L006mkKg]_N`00Kg/0000:Kg/;000BKg/3002NKg/009I_N`<000=_N`80009_N`04
001_Nfmk000VKg/00`00Kg]_N`0@Kg/01@00Kg/006mk00000Vmk0`002Vmk1P005Vmk0P00XFmk002I
Kg/300000fmk0000000200000fmk001_N`0VKg/00`00Kg]_N`0AKg/70006Kg/<000DKg/2002SKg/0
09a_N`H002U_N`03001_Nfmk015_N`D00003Kg/0000000@000=_N`<0009_N`<001=_N`800:E_N`00
WFmk1@00:Fmk00<006mkKg/04Fmk1P001fmk0P001fmk00<006mkKg/03fmk0P00Yfmk002MKg/9000U
Kg/00`00Kg]_N`0AKg/50006Kg/20009Kg/00`00Kg]_N`0=Kg/2002YKg/009i_N`<000E_N`@0029_
N`03001_Nfmk00i_N`800003Kg/0000000<0009_N`<000]_N`03001_Nfmk00Y_N`<00:]_N`00ZVmk
1@007Fmk00<006mkKg/03Fmk00<006mkKg/00Vmk1P003Vmk00<006mkKg/026mk0P00[Vmk002_Kg/4
000IKg/00`00Kg]_N`0;Kg/20005Kg/5000?Kg/00`00Kg]_N`06Kg/2002`Kg/00;=_N`@001I_N`03
001_Nfmk00U_N`03001_Nfmk00E_N`X000Y_N`03001_Nfmk00A_N`800;9_N`00]fmk1@004Fmk00<0
06mkKg/01fmk0P001fmk1@001Vmk10001Vmk0`000Vmk0P00]6mk002lKg/4000>Kg/00`00Kg]_N`04
Kg/20008Kg/5000;Kg/;002fKg/00<1_N`D000U_N`03001_Nfmk00=_N`03001_Nfmk00Q_NaX00;M_
N`00aFmk10001Fmk0`0000=_N`0000001Fmk5`0016mk1@00]fmk0039Kg/900000fmk0000000>000B
Kg/3002hKg/00<e_N`T00=Y_N`00cFmk1@00gVmk003>Kg/3003OKg/00?m_Nk5_N`00ofmk/Fmk003o
Kg^aKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00001\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-5.21058, -5.16468, 0.0362685, \
0.0362685}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell[TextData[{
  "But before we can plot these meshbars, we need to process the return \
values from ",
  StyleBox["DelaunayTriangulation",
    FontFamily->"Courier"],
  " to get the unique meshbars. "
}], "Text"],

Cell[BoxData[
    \(\(\( (*\ 
      the\ input\ is\ directly\ from\ DelaunayTriangulation\ function*) \)\(\
\[IndentingNewLine]\)\(meshbar[t_] := 
      Union[Sort /@ \((\(Thread[List[Sequence @@ #]] &\) /@ t // 
              Flatten[#, 1] &)\)]\)\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[TextData[{
  "Get the unique bars (",
  StyleBox["step 4 ",
    FontSlant->"Italic"],
  "in the paper)"
}], "Text"],

Cell[BoxData[
    \(\(bars = meshbar[t];\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(meshbarPlot[p_, bar_List] := 
      Show[Graphics[Line /@ \((\(Part[p, #] &\) /@ bar)\)], 
        AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[26]:="],

Cell["Our version of \"PlanarGraphPlot\"", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(meshbarPlot[p, bars]\)], "Input",
  CellLabel->"In[27]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99724 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0962001 0.494206 0.0962001 [
[ 0 0 0 0 ]
[ 1 .99724 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .99724 L
0 .99724 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.47114 .02374 m
.46152 .04041 L
s
.47114 .02374 m
.52886 .04041 L
s
.47114 .02374 m
.56253 .04874 L
s
.47114 .02374 m
.52405 .0654 L
s
.47114 .02374 m
.28355 .08206 L
s
.47114 .02374 m
.31241 .08206 L
s
.47114 .02374 m
.37013 .08206 L
s
.47114 .02374 m
.72607 .08206 L
s
.46152 .04041 m
.4519 .05707 L
s
.46152 .04041 m
.52405 .0654 L
s
.46152 .04041 m
.47114 .07373 L
s
.46152 .04041 m
.37013 .08206 L
s
.52886 .04041 m
.56253 .04874 L
s
.52886 .04041 m
.52405 .0654 L
s
.56253 .04874 m
.52405 .0654 L
s
.56253 .04874 m
.63949 .08206 L
s
.56253 .04874 m
.72607 .08206 L
s
.56253 .04874 m
.58177 .09872 L
s
.4519 .05707 m
.47114 .07373 L
s
.4519 .05707 m
.37013 .08206 L
s
.4519 .05707 m
.42785 .09872 L
s
.52405 .0654 m
.47114 .07373 L
s
.52405 .0654 m
.5 .09039 L
s
.52405 .0654 m
.58177 .09872 L
s
.52405 .0654 m
.55291 .11539 L
s
.47114 .07373 m
.5 .09039 L
s
.47114 .07373 m
.42785 .09872 L
s
.47114 .07373 m
.5 .10706 L
s
.28355 .08206 m
.31241 .08206 L
s
.28355 .08206 m
.27393 .11539 L
s
.28355 .08206 m
.31241 .11539 L
s
.28355 .08206 m
.24988 .15704 L
s
.28355 .08206 m
.12001 .24869 L
s
.28355 .08206 m
.09115 .26535 L
s
.31241 .08206 m
.37013 .08206 L
s
.31241 .08206 m
.3557 .10706 L
s
.31241 .08206 m
.31241 .11539 L
s
.37013 .08206 m
.42785 .09872 L
s
.37013 .08206 m
.3557 .10706 L
s
.63949 .08206 m
.72607 .08206 L
s
.63949 .08206 m
.58177 .09872 L
s
.63949 .08206 m
.5962 .10706 L
s
.63949 .08206 m
.66354 .10706 L
s
.63949 .08206 m
.62025 .11539 L
s
.72607 .08206 m
.66354 .10706 L
s
.72607 .08206 m
.77417 .11539 L
s
.72607 .08206 m
.79822 .12372 L
s
.72607 .08206 m
.70202 .20703 L
s
.5 .09039 m
.5 .10706 L
s
.5 .09039 m
.55291 .11539 L
s
.42785 .09872 m
.3557 .10706 L
s
.42785 .09872 m
.5 .10706 L
s
.42785 .09872 m
.48557 .14871 L
s
.42785 .09872 m
.44709 .16537 L
s
.42785 .09872 m
.45671 .16537 L
s
.42785 .09872 m
.39899 .18204 L
s
.58177 .09872 m
.5962 .10706 L
s
.58177 .09872 m
.55291 .11539 L
s
.3557 .10706 m
.31241 .11539 L
s
.3557 .10706 m
.36051 .18204 L
s
.3557 .10706 m
.39899 .18204 L
s
.5 .10706 m
.55291 .11539 L
s
.5 .10706 m
.48557 .14871 L
s
.5 .10706 m
.49519 .14871 L
s
.5 .10706 m
.50481 .14871 L
s
.5962 .10706 m
.55291 .11539 L
s
.5962 .10706 m
.62025 .11539 L
s
.5962 .10706 m
.58177 .14871 L
s
.5962 .10706 m
.60582 .15704 L
s
.66354 .10706 m
.62025 .11539 L
s
.66354 .10706 m
.64911 .18204 L
s
.66354 .10706 m
.70202 .20703 L
s
.27393 .11539 m
.31241 .11539 L
s
.27393 .11539 m
.24988 .15704 L
s
.27393 .11539 m
.27874 .19037 L
s
.27393 .11539 m
.3076 .19037 L
s
.31241 .11539 m
.36051 .18204 L
s
.31241 .11539 m
.3076 .19037 L
s
.55291 .11539 m
.50481 .14871 L
s
.55291 .11539 m
.58177 .14871 L
s
.55291 .11539 m
.50962 .15704 L
s
.62025 .11539 m
.60582 .15704 L
s
.62025 .11539 m
.64911 .18204 L
s
.77417 .11539 m
.79822 .12372 L
s
.77417 .11539 m
.80784 .1737 L
s
.77417 .11539 m
.70202 .20703 L
s
.77417 .11539 m
.7405 .22369 L
s
.79822 .12372 m
.80784 .1737 L
s
.79822 .12372 m
.91366 .25702 L
s
.48557 .14871 m
.49519 .14871 L
s
.48557 .14871 m
.45671 .16537 L
s
.48557 .14871 m
.48557 .18204 L
s
.48557 .14871 m
.49519 .18204 L
s
.49519 .14871 m
.50481 .14871 L
s
.49519 .14871 m
.50962 .15704 L
s
.49519 .14871 m
.49519 .18204 L
s
.50481 .14871 m
.50962 .15704 L
s
.58177 .14871 m
.50962 .15704 L
s
.58177 .14871 m
.60582 .15704 L
s
.58177 .14871 m
.61544 .19037 L
s
.58177 .14871 m
.51443 .1987 L
s
.58177 .14871 m
.57215 .21536 L
s
.24988 .15704 m
.23064 .19037 L
s
.24988 .15704 m
.27874 .19037 L
s
.24988 .15704 m
.24988 .20703 L
s
.24988 .15704 m
.12001 .24869 L
s
.50962 .15704 m
.49519 .18204 L
s
.50962 .15704 m
.51443 .1987 L
s
.60582 .15704 m
.64911 .18204 L
s
.60582 .15704 m
.61544 .19037 L
s
.44709 .16537 m
.45671 .16537 L
s
.44709 .16537 m
.39899 .18204 L
s
.44709 .16537 m
.42785 .18204 L
s
.44709 .16537 m
.44709 .18204 L
s
.44709 .16537 m
.45671 .18204 L
s
.45671 .16537 m
.45671 .18204 L
s
.45671 .16537 m
.48557 .18204 L
s
.80784 .1737 m
.81265 .21536 L
s
.80784 .1737 m
.7405 .22369 L
s
.80784 .1737 m
.79822 .22369 L
s
.80784 .1737 m
.91366 .25702 L
s
.36051 .18204 m
.39899 .18204 L
s
.36051 .18204 m
.3076 .19037 L
s
.36051 .18204 m
.3076 .20703 L
s
.36051 .18204 m
.39418 .22369 L
s
.36051 .18204 m
.36532 .24035 L
s
.39899 .18204 m
.42785 .18204 L
s
.39899 .18204 m
.42785 .1987 L
s
.39899 .18204 m
.39418 .22369 L
s
.39899 .18204 m
.4038 .22369 L
s
.42785 .18204 m
.44709 .18204 L
s
.42785 .18204 m
.42785 .1987 L
s
.42785 .18204 m
.44709 .1987 L
s
.44709 .18204 m
.45671 .18204 L
s
.44709 .18204 m
.44709 .1987 L
s
.45671 .18204 m
.48557 .18204 L
s
.45671 .18204 m
.44709 .1987 L
s
.45671 .18204 m
.46633 .1987 L
s
.48557 .18204 m
.49519 .18204 L
s
.48557 .18204 m
.46633 .1987 L
s
.48557 .18204 m
.49038 .22369 L
s
.49519 .18204 m
.51443 .1987 L
s
.49519 .18204 m
.49038 .22369 L
s
.64911 .18204 m
.61544 .19037 L
s
.64911 .18204 m
.70202 .20703 L
s
.64911 .18204 m
.67316 .22369 L
s
.64911 .18204 m
.63949 .23202 L
s
.64911 .18204 m
.65873 .23202 L
s
.23064 .19037 m
.24988 .20703 L
s
.23064 .19037 m
.18254 .24035 L
s
.23064 .19037 m
.12001 .24869 L
s
.27874 .19037 m
.3076 .19037 L
s
.27874 .19037 m
.24988 .20703 L
s
.27874 .19037 m
.3076 .20703 L
s
.27874 .19037 m
.29317 .21536 L
s
.3076 .19037 m
.3076 .20703 L
s
.61544 .19037 m
.57215 .21536 L
s
.61544 .19037 m
.61063 .21536 L
s
.61544 .19037 m
.63949 .23202 L
s
.42785 .1987 m
.44709 .1987 L
s
.42785 .1987 m
.4038 .22369 L
s
.42785 .1987 m
.44228 .24035 L
s
.44709 .1987 m
.46633 .1987 L
s
.44709 .1987 m
.44228 .24035 L
s
.46633 .1987 m
.49038 .22369 L
s
.46633 .1987 m
.44228 .24035 L
s
.51443 .1987 m
.57215 .21536 L
s
.51443 .1987 m
.49038 .22369 L
s
.51443 .1987 m
.50481 .23202 L
s
.51443 .1987 m
.5481 .24035 L
s
.24988 .20703 m
.29317 .21536 L
s
.24988 .20703 m
.18254 .24035 L
s
.24988 .20703 m
.29798 .27368 L
s
.24988 .20703 m
.23545 .29867 L
s
.3076 .20703 m
.29317 .21536 L
s
.3076 .20703 m
.36532 .24035 L
s
.3076 .20703 m
.3076 .25702 L
s
.3076 .20703 m
.3557 .25702 L
s
.70202 .20703 m
.70683 .21536 L
s
.70202 .20703 m
.67316 .22369 L
s
.70202 .20703 m
.7405 .22369 L
s
.29317 .21536 m
.3076 .25702 L
s
.29317 .21536 m
.29798 .27368 L
s
.57215 .21536 m
.61063 .21536 L
s
.57215 .21536 m
.5481 .24035 L
s
.57215 .21536 m
.56734 .25702 L
s
.57215 .21536 m
.58177 .26535 L
s
.61063 .21536 m
.63949 .23202 L
s
.61063 .21536 m
.58177 .26535 L
s
.70683 .21536 m
.67316 .22369 L
s
.70683 .21536 m
.7405 .22369 L
s
.70683 .21536 m
.73569 .23202 L
s
.70683 .21536 m
.69721 .24869 L
s
.70683 .21536 m
.72607 .24869 L
s
.81265 .21536 m
.79822 .22369 L
s
.81265 .21536 m
.82227 .24869 L
s
.81265 .21536 m
.91366 .25702 L
s
.39418 .22369 m
.4038 .22369 L
s
.39418 .22369 m
.36532 .24035 L
s
.39418 .22369 m
.39418 .24035 L
s
.4038 .22369 m
.39418 .24035 L
s
.4038 .22369 m
.44228 .24035 L
s
.49038 .22369 m
.50481 .23202 L
s
.49038 .22369 m
.44228 .24035 L
s
.49038 .22369 m
.48076 .27368 L
s
.67316 .22369 m
.65873 .23202 L
s
.67316 .22369 m
.69721 .24869 L
s
.67316 .22369 m
.6924 .25702 L
s
.7405 .22369 m
.79822 .22369 L
s
.7405 .22369 m
.73569 .23202 L
s
.7405 .22369 m
.79341 .26535 L
s
.79822 .22369 m
.82227 .24869 L
s
.79822 .22369 m
.79341 .26535 L
s
.50481 .23202 m
.5481 .24035 L
s
.50481 .23202 m
.48076 .27368 L
s
.50481 .23202 m
.52886 .29034 L
s
.63949 .23202 m
.65873 .23202 L
s
.63949 .23202 m
.58177 .26535 L
s
.63949 .23202 m
.64911 .28201 L
s
.65873 .23202 m
.6924 .25702 L
s
.65873 .23202 m
.64911 .28201 L
s
.73569 .23202 m
.72607 .24869 L
s
.73569 .23202 m
.79341 .26535 L
s
.18254 .24035 m
.12001 .24869 L
s
.18254 .24035 m
.17773 .24869 L
s
.18254 .24035 m
.21621 .29867 L
s
.18254 .24035 m
.23545 .29867 L
s
.36532 .24035 m
.39418 .24035 L
s
.36532 .24035 m
.3557 .25702 L
s
.36532 .24035 m
.38456 .27368 L
s
.39418 .24035 m
.44228 .24035 L
s
.39418 .24035 m
.43747 .26535 L
s
.39418 .24035 m
.38456 .27368 L
s
.39418 .24035 m
.42785 .28201 L
s
.44228 .24035 m
.43747 .26535 L
s
.44228 .24035 m
.48076 .27368 L
s
.5481 .24035 m
.56734 .25702 L
s
.5481 .24035 m
.56253 .26535 L
s
.5481 .24035 m
.52886 .29034 L
s
.5481 .24035 m
.53848 .29034 L
s
.12001 .24869 m
.17773 .24869 L
s
.12001 .24869 m
.09115 .26535 L
s
.12001 .24869 m
.1633 .307 L
s
.12001 .24869 m
.12963 .332 L
s
.17773 .24869 m
.21621 .29867 L
s
.17773 .24869 m
.1633 .307 L
s
.69721 .24869 m
.72607 .24869 L
s
.69721 .24869 m
.6924 .25702 L
s
.72607 .24869 m
.6924 .25702 L
s
.72607 .24869 m
.79341 .26535 L
s
.72607 .24869 m
.73088 .29034 L
s
.82227 .24869 m
.91366 .25702 L
s
.82227 .24869 m
.79341 .26535 L
s
.82227 .24869 m
.82708 .32367 L
s
.82227 .24869 m
.84632 .32367 L
s
.3076 .25702 m
.3557 .25702 L
s
.3076 .25702 m
.29798 .27368 L
s
.3076 .25702 m
.35089 .29867 L
s
.3557 .25702 m
.38456 .27368 L
s
.3557 .25702 m
.36532 .29034 L
s
.3557 .25702 m
.35089 .29867 L
s
.56734 .25702 m
.56253 .26535 L
s
.56734 .25702 m
.58177 .26535 L
s
.6924 .25702 m
.64911 .28201 L
s
.6924 .25702 m
.73088 .29034 L
s
.6924 .25702 m
.6924 .34033 L
s
.91366 .25702 m
.84632 .32367 L
s
.91366 .25702 m
.88961 .332 L
s
.91366 .25702 m
.89923 .34866 L
s
.91366 .25702 m
.95695 .38198 L
s
.09115 .26535 m
.05748 .307 L
s
.09115 .26535 m
.07191 .332 L
s
.09115 .26535 m
.12963 .332 L
s
.43747 .26535 m
.48076 .27368 L
s
.43747 .26535 m
.42785 .28201 L
s
.56253 .26535 m
.58177 .26535 L
s
.56253 .26535 m
.53848 .29034 L
s
.56253 .26535 m
.5481 .29034 L
s
.56253 .26535 m
.56734 .307 L
s
.58177 .26535 m
.64911 .28201 L
s
.58177 .26535 m
.60101 .29867 L
s
.58177 .26535 m
.56734 .307 L
s
.79341 .26535 m
.73088 .29034 L
s
.79341 .26535 m
.7405 .307 L
s
.79341 .26535 m
.82708 .32367 L
s
.79341 .26535 m
.77417 .332 L
s
.29798 .27368 m
.23545 .29867 L
s
.29798 .27368 m
.28355 .29867 L
s
.29798 .27368 m
.35089 .29867 L
s
.29798 .27368 m
.31722 .32367 L
s
.38456 .27368 m
.42785 .28201 L
s
.38456 .27368 m
.36532 .29034 L
s
.38456 .27368 m
.39418 .29034 L
s
.48076 .27368 m
.42785 .28201 L
s
.48076 .27368 m
.52886 .29034 L
s
.48076 .27368 m
.51924 .32367 L
s
.48076 .27368 m
.45671 .332 L
s
.48076 .27368 m
.47595 .332 L
s
.48076 .27368 m
.50481 .332 L
s
.42785 .28201 m
.39418 .29034 L
s
.42785 .28201 m
.40861 .31533 L
s
.42785 .28201 m
.43266 .32367 L
s
.42785 .28201 m
.45671 .332 L
s
.64911 .28201 m
.60101 .29867 L
s
.64911 .28201 m
.6924 .34033 L
s
.64911 .28201 m
.62025 .34866 L
s
.36532 .29034 m
.39418 .29034 L
s
.36532 .29034 m
.35089 .29867 L
s
.36532 .29034 m
.37494 .307 L
s
.39418 .29034 m
.37494 .307 L
s
.39418 .29034 m
.40861 .31533 L
s
.39418 .29034 m
.39418 .32367 L
s
.52886 .29034 m
.53848 .29034 L
s
.52886 .29034 m
.51924 .32367 L
s
.52886 .29034 m
.5481 .32367 L
s
.53848 .29034 m
.5481 .29034 L
s
.53848 .29034 m
.55291 .31533 L
s
.53848 .29034 m
.5481 .32367 L
s
.5481 .29034 m
.56734 .307 L
s
.5481 .29034 m
.55291 .31533 L
s
.73088 .29034 m
.7405 .307 L
s
.73088 .29034 m
.6924 .34033 L
s
.21621 .29867 m
.23545 .29867 L
s
.21621 .29867 m
.1633 .307 L
s
.21621 .29867 m
.2114 .32367 L
s
.23545 .29867 m
.28355 .29867 L
s
.23545 .29867 m
.2114 .32367 L
s
.23545 .29867 m
.22102 .34033 L
s
.23545 .29867 m
.24988 .34033 L
s
.28355 .29867 m
.31722 .32367 L
s
.28355 .29867 m
.24988 .34033 L
s
.28355 .29867 m
.26912 .34033 L
s
.28355 .29867 m
.29798 .34033 L
s
.35089 .29867 m
.37494 .307 L
s
.35089 .29867 m
.31722 .32367 L
s
.35089 .29867 m
.34608 .32367 L
s
.60101 .29867 m
.56734 .307 L
s
.60101 .29867 m
.56253 .34866 L
s
.60101 .29867 m
.62025 .34866 L
s
.05748 .307 m
.07191 .332 L
s
.05748 .307 m
.06229 .41531 L
s
.05748 .307 m
.02381 .49862 L
s
.1633 .307 m
.2114 .32367 L
s
.1633 .307 m
.12963 .332 L
s
.1633 .307 m
.20659 .332 L
s
.1633 .307 m
.15368 .34033 L
s
.37494 .307 m
.34608 .32367 L
s
.37494 .307 m
.38456 .32367 L
s
.37494 .307 m
.39418 .32367 L
s
.37494 .307 m
.36051 .332 L
s
.56734 .307 m
.55291 .31533 L
s
.56734 .307 m
.55772 .34033 L
s
.56734 .307 m
.56253 .34866 L
s
.7405 .307 m
.77417 .332 L
s
.7405 .307 m
.6924 .34033 L
s
.7405 .307 m
.74531 .34866 L
s
.40861 .31533 m
.39418 .32367 L
s
.40861 .31533 m
.43266 .32367 L
s
.40861 .31533 m
.41823 .332 L
s
.55291 .31533 m
.5481 .32367 L
s
.55291 .31533 m
.55772 .34033 L
s
.2114 .32367 m
.20659 .332 L
s
.2114 .32367 m
.22102 .34033 L
s
.31722 .32367 m
.34608 .32367 L
s
.31722 .32367 m
.29798 .34033 L
s
.31722 .32367 m
.32684 .37365 L
s
.34608 .32367 m
.36051 .332 L
s
.34608 .32367 m
.32684 .37365 L
s
.38456 .32367 m
.39418 .32367 L
s
.38456 .32367 m
.36051 .332 L
s
.38456 .32367 m
.37494 .34033 L
s
.39418 .32367 m
.41823 .332 L
s
.39418 .32367 m
.37494 .34033 L
s
.39418 .32367 m
.39899 .36532 L
s
.43266 .32367 m
.41823 .332 L
s
.43266 .32367 m
.42785 .332 L
s
.43266 .32367 m
.45671 .332 L
s
.51924 .32367 m
.5481 .32367 L
s
.51924 .32367 m
.50481 .332 L
s
.51924 .32367 m
.53848 .34033 L
s
.51924 .32367 m
.50962 .35699 L
s
.5481 .32367 m
.53848 .34033 L
s
.5481 .32367 m
.55772 .34033 L
s
.82708 .32367 m
.84632 .32367 L
s
.82708 .32367 m
.77417 .332 L
s
.82708 .32367 m
.81265 .34866 L
s
.82708 .32367 m
.82708 .35699 L
s
.84632 .32367 m
.88961 .332 L
s
.84632 .32367 m
.82708 .35699 L
s
.84632 .32367 m
.85113 .36532 L
s
.07191 .332 m
.12963 .332 L
s
.07191 .332 m
.14887 .39865 L
s
.07191 .332 m
.06229 .41531 L
s
.12963 .332 m
.15368 .34033 L
s
.12963 .332 m
.14887 .39865 L
s
.20659 .332 m
.15368 .34033 L
s
.20659 .332 m
.22102 .34033 L
s
.20659 .332 m
.20178 .35699 L
s
.20659 .332 m
.18735 .36532 L
s
.36051 .332 m
.37494 .34033 L
s
.36051 .332 m
.32684 .37365 L
s
.36051 .332 m
.3557 .39032 L
s
.41823 .332 m
.42785 .332 L
s
.41823 .332 m
.42304 .35699 L
s
.41823 .332 m
.39899 .36532 L
s
.42785 .332 m
.45671 .332 L
s
.42785 .332 m
.42304 .35699 L
s
.45671 .332 m
.47595 .332 L
s
.45671 .332 m
.48557 .34866 L
s
.45671 .332 m
.42304 .35699 L
s
.45671 .332 m
.45671 .36532 L
s
.47595 .332 m
.50481 .332 L
s
.47595 .332 m
.48557 .34866 L
s
.50481 .332 m
.48557 .34866 L
s
.50481 .332 m
.50962 .35699 L
s
.77417 .332 m
.74531 .34866 L
s
.77417 .332 m
.81265 .34866 L
s
.77417 .332 m
.80303 .38198 L
s
.88961 .332 m
.89923 .34866 L
s
.88961 .332 m
.85113 .36532 L
s
.88961 .332 m
.87518 .37365 L
s
.15368 .34033 m
.18735 .36532 L
s
.15368 .34033 m
.17292 .39032 L
s
.15368 .34033 m
.14887 .39865 L
s
.22102 .34033 m
.24988 .34033 L
s
.22102 .34033 m
.20178 .35699 L
s
.22102 .34033 m
.22102 .37365 L
s
.24988 .34033 m
.26912 .34033 L
s
.24988 .34033 m
.22102 .37365 L
s
.24988 .34033 m
.2595 .39032 L
s
.26912 .34033 m
.29798 .34033 L
s
.26912 .34033 m
.2595 .39032 L
s
.29798 .34033 m
.32684 .37365 L
s
.29798 .34033 m
.2595 .39032 L
s
.29798 .34033 m
.29798 .40698 L
s
.37494 .34033 m
.39899 .36532 L
s
.37494 .34033 m
.38937 .38198 L
s
.37494 .34033 m
.3557 .39032 L
s
.37494 .34033 m
.36532 .39032 L
s
.53848 .34033 m
.55772 .34033 L
s
.53848 .34033 m
.50962 .35699 L
s
.53848 .34033 m
.5481 .35699 L
s
.53848 .34033 m
.51443 .36532 L
s
.53848 .34033 m
.54329 .36532 L
s
.55772 .34033 m
.56253 .34866 L
s
.55772 .34033 m
.5481 .35699 L
s
.6924 .34033 m
.62025 .34866 L
s
.6924 .34033 m
.74531 .34866 L
s
.6924 .34033 m
.62506 .35699 L
s
.6924 .34033 m
.68278 .37365 L
s
.6924 .34033 m
.70202 .37365 L
s
.48557 .34866 m
.50962 .35699 L
s
.48557 .34866 m
.45671 .36532 L
s
.48557 .34866 m
.48076 .37365 L
s
.56253 .34866 m
.62025 .34866 L
s
.56253 .34866 m
.5481 .35699 L
s
.56253 .34866 m
.61544 .35699 L
s
.56253 .34866 m
.56253 .36532 L
s
.62025 .34866 m
.61544 .35699 L
s
.62025 .34866 m
.62506 .35699 L
s
.74531 .34866 m
.70202 .37365 L
s
.74531 .34866 m
.7405 .37365 L
s
.74531 .34866 m
.80303 .38198 L
s
.81265 .34866 m
.82708 .35699 L
s
.81265 .34866 m
.80303 .38198 L
s
.89923 .34866 m
.87518 .37365 L
s
.89923 .34866 m
.91366 .37365 L
s
.89923 .34866 m
.95695 .38198 L
s
.20178 .35699 m
.18735 .36532 L
s
.20178 .35699 m
.22102 .37365 L
s
.42304 .35699 m
.39899 .36532 L
s
.42304 .35699 m
.42785 .36532 L
s
.42304 .35699 m
.45671 .36532 L
s
.50962 .35699 m
.51443 .36532 L
s
.50962 .35699 m
.48076 .37365 L
s
.50962 .35699 m
.50962 .37365 L
s
.5481 .35699 m
.54329 .36532 L
s
.5481 .35699 m
.56253 .36532 L
s
.61544 .35699 m
.62506 .35699 L
s
.61544 .35699 m
.56253 .36532 L
s
.61544 .35699 m
.61544 .37365 L
s
.61544 .35699 m
.61063 .38198 L
s
.62506 .35699 m
.61544 .37365 L
s
.62506 .35699 m
.68278 .37365 L
s
.62506 .35699 m
.64911 .39865 L
s
.82708 .35699 m
.85113 .36532 L
s
.82708 .35699 m
.84632 .37365 L
s
.82708 .35699 m
.80303 .38198 L
s
.18735 .36532 m
.22102 .37365 L
s
.18735 .36532 m
.17292 .39032 L
s
.39899 .36532 m
.42785 .36532 L
s
.39899 .36532 m
.38937 .38198 L
s
.39899 .36532 m
.4038 .39032 L
s
.42785 .36532 m
.45671 .36532 L
s
.42785 .36532 m
.43747 .38198 L
s
.42785 .36532 m
.4038 .39032 L
s
.42785 .36532 m
.43266 .39032 L
s
.45671 .36532 m
.46152 .37365 L
s
.45671 .36532 m
.48076 .37365 L
s
.45671 .36532 m
.43747 .38198 L
s
.45671 .36532 m
.45671 .38198 L
s
.51443 .36532 m
.54329 .36532 L
s
.51443 .36532 m
.50962 .37365 L
s
.51443 .36532 m
.51924 .37365 L
s
.54329 .36532 m
.56253 .36532 L
s
.54329 .36532 m
.51924 .37365 L
s
.54329 .36532 m
.55772 .37365 L
s
.54329 .36532 m
.53367 .38198 L
s
.56253 .36532 m
.55772 .37365 L
s
.56253 .36532 m
.61063 .38198 L
s
.56253 .36532 m
.57215 .39865 L
s
.85113 .36532 m
.84632 .37365 L
s
.85113 .36532 m
.87518 .37365 L
s
.22102 .37365 m
.17292 .39032 L
s
.22102 .37365 m
.2595 .39032 L
s
.22102 .37365 m
.25469 .39865 L
s
.22102 .37365 m
.24026 .4403 L
s
.32684 .37365 m
.3557 .39032 L
s
.32684 .37365 m
.29798 .40698 L
s
.32684 .37365 m
.31722 .40698 L
s
.46152 .37365 m
.48076 .37365 L
s
.46152 .37365 m
.45671 .38198 L
s
.46152 .37365 m
.46633 .39865 L
s
.48076 .37365 m
.50962 .37365 L
s
.48076 .37365 m
.46633 .39865 L
s
.48076 .37365 m
.5 .40698 L
s
.50962 .37365 m
.51924 .37365 L
s
.50962 .37365 m
.52405 .38198 L
s
.50962 .37365 m
.51443 .39865 L
s
.50962 .37365 m
.5 .40698 L
s
.51924 .37365 m
.52405 .38198 L
s
.51924 .37365 m
.53367 .38198 L
s
.55772 .37365 m
.53367 .38198 L
s
.55772 .37365 m
.53848 .39032 L
s
.55772 .37365 m
.55291 .39865 L
s
.55772 .37365 m
.57215 .39865 L
s
.61544 .37365 m
.61063 .38198 L
s
.61544 .37365 m
.64911 .39865 L
s
.68278 .37365 m
.70202 .37365 L
s
.68278 .37365 m
.68278 .39032 L
s
.68278 .37365 m
.70202 .39032 L
s
.68278 .37365 m
.64911 .39865 L
s
.70202 .37365 m
.7405 .37365 L
s
.70202 .37365 m
.70202 .39032 L
s
.70202 .37365 m
.73088 .39032 L
s
.7405 .37365 m
.80303 .38198 L
s
.7405 .37365 m
.73088 .39032 L
s
.7405 .37365 m
.74531 .39865 L
s
.84632 .37365 m
.87518 .37365 L
s
.84632 .37365 m
.80303 .38198 L
s
.84632 .37365 m
.86556 .39032 L
s
.84632 .37365 m
.84632 .42364 L
s
.87518 .37365 m
.91366 .37365 L
s
.87518 .37365 m
.86556 .39032 L
s
.87518 .37365 m
.87999 .39865 L
s
.87518 .37365 m
.88961 .39865 L
s
.91366 .37365 m
.95695 .38198 L
s
.91366 .37365 m
.88961 .39865 L
s
.91366 .37365 m
.90404 .42364 L
s
.38937 .38198 m
.36532 .39032 L
s
.38937 .38198 m
.38456 .39032 L
s
.38937 .38198 m
.39418 .39032 L
s
.38937 .38198 m
.4038 .39032 L
s
.43747 .38198 m
.45671 .38198 L
s
.43747 .38198 m
.43266 .39032 L
s
.43747 .38198 m
.4519 .40698 L
s
.45671 .38198 m
.46633 .39865 L
s
.45671 .38198 m
.4519 .40698 L
s
.52405 .38198 m
.53367 .38198 L
s
.52405 .38198 m
.52886 .39032 L
s
.52405 .38198 m
.51443 .39865 L
s
.53367 .38198 m
.52886 .39032 L
s
.53367 .38198 m
.53848 .39032 L
s
.61063 .38198 m
.57215 .39865 L
s
.61063 .38198 m
.64911 .39865 L
s
.61063 .38198 m
.57696 .40698 L
s
.61063 .38198 m
.61544 .40698 L
s
.61063 .38198 m
.60101 .41531 L
s
.80303 .38198 m
.74531 .39865 L
s
.80303 .38198 m
.79822 .40698 L
s
.80303 .38198 m
.84632 .42364 L
s
.95695 .38198 m
.90404 .42364 L
s
.95695 .38198 m
.97619 .4653 L
s
.17292 .39032 m
.14887 .39865 L
s
.17292 .39032 m
.15849 .41531 L
s
.17292 .39032 m
.24026 .4403 L
s
.17292 .39032 m
.16811 .44863 L
s
.2595 .39032 m
.25469 .39865 L
s
.2595 .39032 m
.29798 .40698 L
s
.3557 .39032 m
.36532 .39032 L
s
.3557 .39032 m
.31722 .40698 L
s
.3557 .39032 m
.38456 .40698 L
s
.3557 .39032 m
.32684 .42364 L
s
.3557 .39032 m
.37975 .43197 L
s
.3557 .39032 m
.34608 .4403 L
s
.36532 .39032 m
.38456 .39032 L
s
.36532 .39032 m
.38456 .40698 L
s
.38456 .39032 m
.39418 .39032 L
s
.38456 .39032 m
.38937 .39865 L
s
.38456 .39032 m
.38456 .40698 L
s
.39418 .39032 m
.4038 .39032 L
s
.39418 .39032 m
.38937 .39865 L
s
.4038 .39032 m
.43266 .39032 L
s
.4038 .39032 m
.38937 .39865 L
s
.4038 .39032 m
.40861 .39865 L
s
.43266 .39032 m
.40861 .39865 L
s
.43266 .39032 m
.42785 .39865 L
s
.43266 .39032 m
.4519 .40698 L
s
.52886 .39032 m
.53848 .39032 L
s
.52886 .39032 m
.51443 .39865 L
s
.52886 .39032 m
.54329 .39865 L
s
.52886 .39032 m
.53367 .41531 L
s
.53848 .39032 m
.54329 .39865 L
s
.53848 .39032 m
.55291 .39865 L
s
.68278 .39032 m
.70202 .39032 L
s
.68278 .39032 m
.64911 .39865 L
s
.68278 .39032 m
.72126 .42364 L
s
.68278 .39032 m
.65873 .44863 L
s
.70202 .39032 m
.73088 .39032 L
s
.70202 .39032 m
.72126 .42364 L
s
.73088 .39032 m
.74531 .39865 L
s
.73088 .39032 m
.72126 .42364 L
s
.73088 .39032 m
.73088 .42364 L
s
.86556 .39032 m
.87999 .39865 L
s
.86556 .39032 m
.84632 .42364 L
s
.14887 .39865 m
.06229 .41531 L
s
.14887 .39865 m
.15849 .41531 L
s
.25469 .39865 m
.29798 .40698 L
s
.25469 .39865 m
.24026 .4403 L
s
.25469 .39865 m
.27874 .4403 L
s
.38937 .39865 m
.40861 .39865 L
s
.38937 .39865 m
.38456 .40698 L
s
.40861 .39865 m
.42785 .39865 L
s
.40861 .39865 m
.38456 .40698 L
s
.40861 .39865 m
.41342 .42364 L
s
.42785 .39865 m
.4519 .40698 L
s
.42785 .39865 m
.41342 .42364 L
s
.42785 .39865 m
.44228 .42364 L
s
.46633 .39865 m
.4519 .40698 L
s
.46633 .39865 m
.46152 .40698 L
s
.46633 .39865 m
.5 .40698 L
s
.46633 .39865 m
.46633 .41531 L
s
.46633 .39865 m
.48557 .41531 L
s
.51443 .39865 m
.5 .40698 L
s
.51443 .39865 m
.53367 .41531 L
s
.51443 .39865 m
.50962 .42364 L
s
.51443 .39865 m
.51924 .42364 L
s
.54329 .39865 m
.55291 .39865 L
s
.54329 .39865 m
.53367 .41531 L
s
.54329 .39865 m
.54329 .41531 L
s
.55291 .39865 m
.57215 .39865 L
s
.55291 .39865 m
.54329 .41531 L
s
.55291 .39865 m
.55291 .41531 L
s
.57215 .39865 m
.57696 .40698 L
s
.57215 .39865 m
.55291 .41531 L
s
.64911 .39865 m
.61544 .40698 L
s
.64911 .39865 m
.65873 .44863 L
s
.74531 .39865 m
.79822 .40698 L
s
.74531 .39865 m
.73088 .42364 L
s
.74531 .39865 m
.7886 .42364 L
s
.74531 .39865 m
.77417 .44863 L
s
.87999 .39865 m
.88961 .39865 L
s
.87999 .39865 m
.84632 .42364 L
s
.87999 .39865 m
.90404 .42364 L
s
.87999 .39865 m
.87518 .4403 L
s
.88961 .39865 m
.90404 .42364 L
s
.29798 .40698 m
.31722 .40698 L
s
.29798 .40698 m
.31722 .42364 L
s
.29798 .40698 m
.27874 .4403 L
s
.31722 .40698 m
.31722 .42364 L
s
.31722 .40698 m
.32684 .42364 L
s
.38456 .40698 m
.38456 .42364 L
s
.38456 .40698 m
.41342 .42364 L
s
.38456 .40698 m
.37975 .43197 L
s
.4519 .40698 m
.46152 .40698 L
s
.4519 .40698 m
.45671 .41531 L
s
.4519 .40698 m
.44228 .42364 L
s
.46152 .40698 m
.45671 .41531 L
s
.46152 .40698 m
.46633 .41531 L
s
.5 .40698 m
.48557 .41531 L
s
.5 .40698 m
.49519 .41531 L
s
.5 .40698 m
.50962 .42364 L
s
.57696 .40698 m
.55291 .41531 L
s
.57696 .40698 m
.60101 .41531 L
s
.57696 .40698 m
.55772 .42364 L
s
.57696 .40698 m
.58177 .43197 L
s
.61544 .40698 m
.60101 .41531 L
s
.61544 .40698 m
.60582 .4403 L
s
.61544 .40698 m
.65873 .44863 L
s
.61544 .40698 m
.62506 .45696 L
s
.79822 .40698 m
.7886 .42364 L
s
.79822 .40698 m
.84632 .42364 L
s
.79822 .40698 m
.81265 .43197 L
s
.06229 .41531 m
.15849 .41531 L
s
.06229 .41531 m
.08634 .49029 L
s
.06229 .41531 m
.02381 .49862 L
s
.06229 .41531 m
.04786 .50695 L
s
.15849 .41531 m
.16811 .44863 L
s
.15849 .41531 m
.1633 .45696 L
s
.15849 .41531 m
.08634 .49029 L
s
.45671 .41531 m
.46633 .41531 L
s
.45671 .41531 m
.44228 .42364 L
s
.45671 .41531 m
.45671 .43197 L
s
.46633 .41531 m
.48557 .41531 L
s
.46633 .41531 m
.45671 .43197 L
s
.46633 .41531 m
.48557 .43197 L
s
.48557 .41531 m
.49519 .41531 L
s
.48557 .41531 m
.48557 .43197 L
s
.49519 .41531 m
.50962 .42364 L
s
.49519 .41531 m
.48557 .43197 L
s
.53367 .41531 m
.54329 .41531 L
s
.53367 .41531 m
.51924 .42364 L
s
.53367 .41531 m
.52886 .42364 L
s
.53367 .41531 m
.53848 .42364 L
s
.54329 .41531 m
.55291 .41531 L
s
.54329 .41531 m
.53848 .42364 L
s
.54329 .41531 m
.55772 .42364 L
s
.54329 .41531 m
.54329 .43197 L
s
.55291 .41531 m
.55772 .42364 L
s
.60101 .41531 m
.58177 .43197 L
s
.60101 .41531 m
.5962 .4403 L
s
.60101 .41531 m
.60582 .4403 L
s
.31722 .42364 m
.32684 .42364 L
s
.31722 .42364 m
.27874 .4403 L
s
.31722 .42364 m
.31722 .4403 L
s
.32684 .42364 m
.31722 .4403 L
s
.32684 .42364 m
.33646 .4403 L
s
.32684 .42364 m
.34608 .4403 L
s
.38456 .42364 m
.41342 .42364 L
s
.38456 .42364 m
.37975 .43197 L
s
.41342 .42364 m
.44228 .42364 L
s
.41342 .42364 m
.37975 .43197 L
s
.41342 .42364 m
.41823 .43197 L
s
.44228 .42364 m
.41823 .43197 L
s
.44228 .42364 m
.43747 .43197 L
s
.44228 .42364 m
.45671 .43197 L
s
.44228 .42364 m
.44228 .4403 L
s
.50962 .42364 m
.51924 .42364 L
s
.50962 .42364 m
.48557 .43197 L
s
.50962 .42364 m
.5 .4403 L
s
.50962 .42364 m
.51924 .4403 L
s
.51924 .42364 m
.52886 .42364 L
s
.51924 .42364 m
.51924 .4403 L
s
.52886 .42364 m
.53848 .42364 L
s
.52886 .42364 m
.51924 .4403 L
s
.52886 .42364 m
.52886 .4403 L
s
.53848 .42364 m
.54329 .43197 L
s
.53848 .42364 m
.52886 .4403 L
s
.55772 .42364 m
.54329 .43197 L
s
.55772 .42364 m
.58177 .43197 L
s
.55772 .42364 m
.56734 .4403 L
s
.55772 .42364 m
.55291 .44863 L
s
.72126 .42364 m
.73088 .42364 L
s
.72126 .42364 m
.73088 .4403 L
s
.72126 .42364 m
.65873 .44863 L
s
.72126 .42364 m
.69721 .4653 L
s
.73088 .42364 m
.73088 .4403 L
s
.73088 .42364 m
.77417 .44863 L
s
.7886 .42364 m
.81265 .43197 L
s
.7886 .42364 m
.77417 .44863 L
s
.84632 .42364 m
.81265 .43197 L
s
.84632 .42364 m
.87518 .4403 L
s
.84632 .42364 m
.84151 .4653 L
s
.90404 .42364 m
.87518 .4403 L
s
.90404 .42364 m
.97619 .4653 L
s
.90404 .42364 m
.93771 .48196 L
s
.90404 .42364 m
.89442 .49029 L
s
.37975 .43197 m
.41823 .43197 L
s
.37975 .43197 m
.34608 .4403 L
s
.37975 .43197 m
.41823 .44863 L
s
.37975 .43197 m
.36532 .45696 L
s
.37975 .43197 m
.38937 .4653 L
s
.41823 .43197 m
.43747 .43197 L
s
.41823 .43197 m
.41823 .44863 L
s
.43747 .43197 m
.44228 .4403 L
s
.43747 .43197 m
.41823 .44863 L
s
.45671 .43197 m
.48557 .43197 L
s
.45671 .43197 m
.44228 .4403 L
s
.45671 .43197 m
.47595 .44863 L
s
.45671 .43197 m
.46152 .45696 L
s
.48557 .43197 m
.5 .4403 L
s
.48557 .43197 m
.47595 .44863 L
s
.48557 .43197 m
.48557 .44863 L
s
.54329 .43197 m
.52886 .4403 L
s
.54329 .43197 m
.55291 .44863 L
s
.54329 .43197 m
.53848 .45696 L
s
.58177 .43197 m
.56734 .4403 L
s
.58177 .43197 m
.5962 .4403 L
s
.58177 .43197 m
.58177 .44863 L
s
.81265 .43197 m
.77417 .44863 L
s
.81265 .43197 m
.84151 .4653 L
s
.81265 .43197 m
.82227 .48196 L
s
.24026 .4403 m
.27874 .4403 L
s
.24026 .4403 m
.16811 .44863 L
s
.24026 .4403 m
.23545 .4653 L
s
.24026 .4403 m
.20659 .48196 L
s
.27874 .4403 m
.31722 .4403 L
s
.27874 .4403 m
.31241 .44863 L
s
.27874 .4403 m
.23545 .4653 L
s
.27874 .4403 m
.28836 .50695 L
s
.31722 .4403 m
.33646 .4403 L
s
.31722 .4403 m
.31241 .44863 L
s
.31722 .4403 m
.33646 .45696 L
s
.33646 .4403 m
.34608 .4403 L
s
.33646 .4403 m
.33646 .45696 L
s
.34608 .4403 m
.33646 .45696 L
s
.34608 .4403 m
.36532 .45696 L
s
.34608 .4403 m
.35089 .4653 L
s
.44228 .4403 m
.41823 .44863 L
s
.44228 .4403 m
.43266 .45696 L
s
.44228 .4403 m
.44228 .45696 L
s
.44228 .4403 m
.46152 .45696 L
s
.5 .4403 m
.51924 .4403 L
s
.5 .4403 m
.48557 .44863 L
s
.5 .4403 m
.49038 .45696 L
s
.5 .4403 m
.50962 .45696 L
s
.51924 .4403 m
.52886 .4403 L
s
.51924 .4403 m
.50962 .45696 L
s
.51924 .4403 m
.51924 .45696 L
s
.52886 .4403 m
.51924 .45696 L
s
.52886 .4403 m
.52886 .45696 L
s
.52886 .4403 m
.53848 .45696 L
s
.56734 .4403 m
.55291 .44863 L
s
.56734 .4403 m
.56253 .44863 L
s
.56734 .4403 m
.58177 .44863 L
s
.5962 .4403 m
.60582 .4403 L
s
.5962 .4403 m
.58177 .44863 L
s
.5962 .4403 m
.59139 .4653 L
s
.60582 .4403 m
.62506 .45696 L
s
.60582 .4403 m
.59139 .4653 L
s
.73088 .4403 m
.77417 .44863 L
s
.73088 .4403 m
.75012 .45696 L
s
.73088 .4403 m
.69721 .4653 L
s
.73088 .4403 m
.72126 .49029 L
s
.87518 .4403 m
.84151 .4653 L
s
.87518 .4403 m
.89442 .49029 L
s
.16811 .44863 m
.1633 .45696 L
s
.16811 .44863 m
.20659 .48196 L
s
.31241 .44863 m
.33646 .45696 L
s
.31241 .44863 m
.32684 .47363 L
s
.31241 .44863 m
.32203 .48196 L
s
.31241 .44863 m
.28836 .50695 L
s
.41823 .44863 m
.43266 .45696 L
s
.41823 .44863 m
.38937 .4653 L
s
.41823 .44863 m
.42785 .4653 L
s
.41823 .44863 m
.41342 .47363 L
s
.47595 .44863 m
.48557 .44863 L
s
.47595 .44863 m
.46152 .45696 L
s
.47595 .44863 m
.47114 .45696 L
s
.47595 .44863 m
.48076 .45696 L
s
.48557 .44863 m
.48076 .45696 L
s
.48557 .44863 m
.49038 .45696 L
s
.55291 .44863 m
.56253 .44863 L
s
.55291 .44863 m
.53848 .45696 L
s
.55291 .44863 m
.54329 .4653 L
s
.55291 .44863 m
.56253 .4653 L
s
.56253 .44863 m
.58177 .44863 L
s
.56253 .44863 m
.56734 .45696 L
s
.56253 .44863 m
.56253 .4653 L
s
.58177 .44863 m
.56734 .45696 L
s
.58177 .44863 m
.59139 .4653 L
s
.65873 .44863 m
.62506 .45696 L
s
.65873 .44863 m
.66354 .45696 L
s
.65873 .44863 m
.65873 .4653 L
s
.65873 .44863 m
.69721 .4653 L
s
.77417 .44863 m
.75012 .45696 L
s
.77417 .44863 m
.75493 .48196 L
s
.77417 .44863 m
.82227 .48196 L
s
.77417 .44863 m
.81746 .49029 L
s
.1633 .45696 m
.20659 .48196 L
s
.1633 .45696 m
.08634 .49029 L
s
.1633 .45696 m
.1633 .49029 L
s
.1633 .45696 m
.17292 .49029 L
s
.33646 .45696 m
.35089 .4653 L
s
.33646 .45696 m
.32684 .47363 L
s
.33646 .45696 m
.33646 .47363 L
s
.36532 .45696 m
.35089 .4653 L
s
.36532 .45696 m
.38937 .4653 L
s
.36532 .45696 m
.3557 .47363 L
s
.43266 .45696 m
.44228 .45696 L
s
.43266 .45696 m
.42785 .4653 L
s
.44228 .45696 m
.46152 .45696 L
s
.44228 .45696 m
.42785 .4653 L
s
.44228 .45696 m
.45671 .4653 L
s
.44228 .45696 m
.44228 .47363 L
s
.44228 .45696 m
.4519 .47363 L
s
.46152 .45696 m
.47114 .45696 L
s
.46152 .45696 m
.45671 .4653 L
s
.46152 .45696 m
.46633 .4653 L
s
.47114 .45696 m
.48076 .45696 L
s
.47114 .45696 m
.46633 .4653 L
s
.47114 .45696 m
.47595 .4653 L
s
.48076 .45696 m
.49038 .45696 L
s
.48076 .45696 m
.47595 .4653 L
s
.48076 .45696 m
.48557 .4653 L
s
.49038 .45696 m
.50962 .45696 L
s
.49038 .45696 m
.48557 .4653 L
s
.49038 .45696 m
.50481 .4653 L
s
.50962 .45696 m
.51924 .45696 L
s
.50962 .45696 m
.50481 .4653 L
s
.50962 .45696 m
.52405 .4653 L
s
.50962 .45696 m
.50962 .47363 L
s
.51924 .45696 m
.52886 .45696 L
s
.51924 .45696 m
.52405 .4653 L
s
.52886 .45696 m
.53848 .45696 L
s
.52886 .45696 m
.52405 .4653 L
s
.52886 .45696 m
.53367 .4653 L
s
.53848 .45696 m
.53367 .4653 L
s
.53848 .45696 m
.54329 .4653 L
s
.56734 .45696 m
.56253 .4653 L
s
.56734 .45696 m
.59139 .4653 L
s
.62506 .45696 m
.59139 .4653 L
s
.62506 .45696 m
.65873 .4653 L
s
.62506 .45696 m
.60101 .48196 L
s
.62506 .45696 m
.63949 .48196 L
s
.62506 .45696 m
.63468 .49029 L
s
.66354 .45696 m
.65873 .4653 L
s
.66354 .45696 m
.69721 .4653 L
s
.66354 .45696 m
.67797 .48196 L
s
.75012 .45696 m
.75493 .48196 L
s
.75012 .45696 m
.72126 .49029 L
s
.23545 .4653 m
.20659 .48196 L
s
.23545 .4653 m
.2114 .49029 L
s
.23545 .4653 m
.23545 .49862 L
s
.23545 .4653 m
.24988 .50695 L
s
.23545 .4653 m
.28836 .50695 L
s
.35089 .4653 m
.33646 .47363 L
s
.35089 .4653 m
.34608 .47363 L
s
.35089 .4653 m
.3557 .47363 L
s
.38937 .4653 m
.3557 .47363 L
s
.38937 .4653 m
.41342 .47363 L
s
.38937 .4653 m
.38937 .48196 L
s
.42785 .4653 m
.41342 .47363 L
s
.42785 .4653 m
.42304 .47363 L
s
.42785 .4653 m
.44228 .47363 L
s
.45671 .4653 m
.46633 .4653 L
s
.45671 .4653 m
.4519 .47363 L
s
.45671 .4653 m
.45671 .48196 L
s
.46633 .4653 m
.47595 .4653 L
s
.46633 .4653 m
.47114 .47363 L
s
.46633 .4653 m
.45671 .48196 L
s
.47595 .4653 m
.48557 .4653 L
s
.47595 .4653 m
.47114 .47363 L
s
.47595 .4653 m
.48076 .47363 L
s
.48557 .4653 m
.50481 .4653 L
s
.48557 .4653 m
.48076 .47363 L
s
.48557 .4653 m
.49038 .47363 L
s
.50481 .4653 m
.49038 .47363 L
s
.50481 .4653 m
.5 .47363 L
s
.50481 .4653 m
.50962 .47363 L
s
.52405 .4653 m
.53367 .4653 L
s
.52405 .4653 m
.50962 .47363 L
s
.52405 .4653 m
.53848 .47363 L
s
.52405 .4653 m
.51443 .48196 L
s
.53367 .4653 m
.54329 .4653 L
s
.53367 .4653 m
.53848 .47363 L
s
.54329 .4653 m
.56253 .4653 L
s
.54329 .4653 m
.53848 .47363 L
s
.54329 .4653 m
.5481 .47363 L
s
.56253 .4653 m
.59139 .4653 L
s
.56253 .4653 m
.5481 .47363 L
s
.56253 .4653 m
.55291 .48196 L
s
.56253 .4653 m
.59139 .48196 L
s
.56253 .4653 m
.55772 .49029 L
s
.59139 .4653 m
.59139 .48196 L
s
.59139 .4653 m
.60101 .48196 L
s
.65873 .4653 m
.63949 .48196 L
s
.65873 .4653 m
.67797 .48196 L
s
.65873 .4653 m
.64911 .49862 L
s
.69721 .4653 m
.67797 .48196 L
s
.69721 .4653 m
.72126 .49029 L
s
.84151 .4653 m
.82227 .48196 L
s
.84151 .4653 m
.89442 .49029 L
s
.84151 .4653 m
.82708 .50695 L
s
.97619 .4653 m
.93771 .48196 L
s
.97619 .4653 m
.90404 .54028 L
s
.97619 .4653 m
.94733 .66524 L
s
.32684 .47363 m
.33646 .47363 L
s
.32684 .47363 m
.32203 .48196 L
s
.32684 .47363 m
.33646 .49029 L
s
.33646 .47363 m
.34608 .47363 L
s
.33646 .47363 m
.35089 .48196 L
s
.33646 .47363 m
.33646 .49029 L
s
.34608 .47363 m
.3557 .47363 L
s
.34608 .47363 m
.35089 .48196 L
s
.3557 .47363 m
.35089 .48196 L
s
.3557 .47363 m
.38937 .48196 L
s
.3557 .47363 m
.37975 .49862 L
s
.41342 .47363 m
.42304 .47363 L
s
.41342 .47363 m
.38937 .48196 L
s
.41342 .47363 m
.41342 .49029 L
s
.41342 .47363 m
.42304 .49029 L
s
.42304 .47363 m
.44228 .47363 L
s
.42304 .47363 m
.42304 .49029 L
s
.42304 .47363 m
.44228 .49029 L
s
.44228 .47363 m
.4519 .47363 L
s
.44228 .47363 m
.44709 .48196 L
s
.44228 .47363 m
.44228 .49029 L
s
.4519 .47363 m
.44709 .48196 L
s
.4519 .47363 m
.45671 .48196 L
s
.47114 .47363 m
.48076 .47363 L
s
.47114 .47363 m
.45671 .48196 L
s
.47114 .47363 m
.48557 .48196 L
s
.47114 .47363 m
.46152 .49029 L
s
.47114 .47363 m
.47114 .49029 L
s
.48076 .47363 m
.49038 .47363 L
s
.48076 .47363 m
.48557 .48196 L
s
.49038 .47363 m
.5 .47363 L
s
.49038 .47363 m
.48557 .48196 L
s
.49038 .47363 m
.49519 .48196 L
s
.5 .47363 m
.50962 .47363 L
s
.5 .47363 m
.49519 .48196 L
s
.5 .47363 m
.5 .49029 L
s
.50962 .47363 m
.51443 .48196 L
s
.50962 .47363 m
.5 .49029 L
s
.53848 .47363 m
.5481 .47363 L
s
.53848 .47363 m
.51443 .48196 L
s
.53848 .47363 m
.55291 .48196 L
s
.53848 .47363 m
.53848 .49029 L
s
.5481 .47363 m
.55291 .48196 L
s
.20659 .48196 m
.17292 .49029 L
s
.20659 .48196 m
.2114 .49029 L
s
.20659 .48196 m
.17773 .49862 L
s
.20659 .48196 m
.20178 .50695 L
s
.32203 .48196 m
.33646 .49029 L
s
.32203 .48196 m
.32203 .49862 L
s
.32203 .48196 m
.28836 .50695 L
s
.35089 .48196 m
.33646 .49029 L
s
.35089 .48196 m
.37975 .49862 L
s
.38937 .48196 m
.41342 .49029 L
s
.38937 .48196 m
.37975 .49862 L
s
.38937 .48196 m
.39899 .49862 L
s
.44709 .48196 m
.45671 .48196 L
s
.44709 .48196 m
.44228 .49029 L
s
.44709 .48196 m
.44709 .49862 L
s
.45671 .48196 m
.46152 .49029 L
s
.45671 .48196 m
.44709 .49862 L
s
.48557 .48196 m
.49519 .48196 L
s
.48557 .48196 m
.47114 .49029 L
s
.48557 .48196 m
.48076 .49029 L
s
.48557 .48196 m
.49038 .49029 L
s
.49519 .48196 m
.49038 .49029 L
s
.49519 .48196 m
.5 .49029 L
s
.51443 .48196 m
.5 .49029 L
s
.51443 .48196 m
.53848 .49029 L
s
.51443 .48196 m
.50481 .49862 L
s
.51443 .48196 m
.51443 .49862 L
s
.51443 .48196 m
.53367 .49862 L
s
.55291 .48196 m
.53848 .49029 L
s
.55291 .48196 m
.55772 .49029 L
s
.55291 .48196 m
.54329 .49862 L
s
.59139 .48196 m
.60101 .48196 L
s
.59139 .48196 m
.55772 .49029 L
s
.59139 .48196 m
.58177 .49862 L
s
.59139 .48196 m
.60582 .50695 L
s
.60101 .48196 m
.63468 .49029 L
s
.60101 .48196 m
.60582 .50695 L
s
.63949 .48196 m
.63468 .49029 L
s
.63949 .48196 m
.64911 .49862 L
s
.67797 .48196 m
.72126 .49029 L
s
.67797 .48196 m
.64911 .49862 L
s
.67797 .48196 m
.67797 .51528 L
s
.75493 .48196 m
.72126 .49029 L
s
.75493 .48196 m
.81746 .49029 L
s
.75493 .48196 m
.72607 .49862 L
s
.75493 .48196 m
.76936 .50695 L
s
.75493 .48196 m
.75012 .52361 L
s
.82227 .48196 m
.81746 .49029 L
s
.82227 .48196 m
.82708 .50695 L
s
.93771 .48196 m
.89442 .49029 L
s
.93771 .48196 m
.90404 .54028 L
s
.08634 .49029 m
.1633 .49029 L
s
.08634 .49029 m
.04786 .50695 L
s
.08634 .49029 m
.12963 .51528 L
s
.08634 .49029 m
.09596 .52361 L
s
.08634 .49029 m
.10558 .52361 L
s
.1633 .49029 m
.17292 .49029 L
s
.1633 .49029 m
.17773 .49862 L
s
.1633 .49029 m
.12963 .51528 L
s
.17292 .49029 m
.17773 .49862 L
s
.2114 .49029 m
.23545 .49862 L
s
.2114 .49029 m
.20178 .50695 L
s
.2114 .49029 m
.2114 .50695 L
s
.33646 .49029 m
.32203 .49862 L
s
.33646 .49029 m
.37975 .49862 L
s
.33646 .49029 m
.32203 .51528 L
s
.33646 .49029 m
.32684 .52361 L
s
.33646 .49029 m
.34127 .53195 L
s
.41342 .49029 m
.42304 .49029 L
s
.41342 .49029 m
.39899 .49862 L
s
.41342 .49029 m
.41823 .49862 L
s
.41342 .49029 m
.41342 .50695 L
s
.42304 .49029 m
.44228 .49029 L
s
.42304 .49029 m
.41823 .49862 L
s
.42304 .49029 m
.43747 .49862 L
s
.44228 .49029 m
.43747 .49862 L
s
.44228 .49029 m
.44709 .49862 L
s
.46152 .49029 m
.47114 .49029 L
s
.46152 .49029 m
.44709 .49862 L
s
.46152 .49029 m
.47595 .49862 L
s
.46152 .49029 m
.4519 .50695 L
s
.46152 .49029 m
.46152 .50695 L
s
.46152 .49029 m
.47114 .50695 L
s
.47114 .49029 m
.48076 .49029 L
s
.47114 .49029 m
.47595 .49862 L
s
.48076 .49029 m
.49038 .49029 L
s
.48076 .49029 m
.47595 .49862 L
s
.49038 .49029 m
.5 .49029 L
s
.49038 .49029 m
.47595 .49862 L
s
.49038 .49029 m
.49519 .49862 L
s
.49038 .49029 m
.48076 .50695 L
s
.5 .49029 m
.49519 .49862 L
s
.5 .49029 m
.50481 .49862 L
s
.53848 .49029 m
.53367 .49862 L
s
.53848 .49029 m
.54329 .49862 L
s
.55772 .49029 m
.54329 .49862 L
s
.55772 .49029 m
.55291 .49862 L
s
.55772 .49029 m
.56253 .49862 L
s
.55772 .49029 m
.58177 .49862 L
s
.63468 .49029 m
.64911 .49862 L
s
.63468 .49029 m
.60582 .50695 L
s
.63468 .49029 m
.6443 .50695 L
s
.63468 .49029 m
.62987 .51528 L
s
.72126 .49029 m
.72607 .49862 L
s
.72126 .49029 m
.67797 .51528 L
s
.72126 .49029 m
.72607 .51528 L
s
.81746 .49029 m
.76936 .50695 L
s
.81746 .49029 m
.82708 .50695 L
s
.81746 .49029 m
.80784 .52361 L
s
.89442 .49029 m
.82708 .50695 L
s
.89442 .49029 m
.90404 .54028 L
s
.02381 .49862 m
.04786 .50695 L
s
.02381 .49862 m
.04786 .52361 L
s
.02381 .49862 m
.05748 .64025 L
s
.17773 .49862 m
.20178 .50695 L
s
.17773 .49862 m
.12963 .51528 L
s
.17773 .49862 m
.19697 .53195 L
s
.23545 .49862 m
.2114 .50695 L
s
.23545 .49862 m
.24988 .50695 L
s
.23545 .49862 m
.24026 .52361 L
s
.32203 .49862 m
.28836 .50695 L
s
.32203 .49862 m
.32203 .51528 L
s
.32203 .49862 m
.3076 .52361 L
s
.37975 .49862 m
.39899 .49862 L
s
.37975 .49862 m
.38456 .50695 L
s
.37975 .49862 m
.34127 .53195 L
s
.39899 .49862 m
.38456 .50695 L
s
.39899 .49862 m
.4038 .50695 L
s
.39899 .49862 m
.41342 .50695 L
s
.41823 .49862 m
.43747 .49862 L
s
.41823 .49862 m
.41342 .50695 L
s
.41823 .49862 m
.42304 .50695 L
s
.43747 .49862 m
.44709 .49862 L
s
.43747 .49862 m
.42304 .50695 L
s
.43747 .49862 m
.44228 .50695 L
s
.44709 .49862 m
.44228 .50695 L
s
.44709 .49862 m
.4519 .50695 L
s
.47595 .49862 m
.47114 .50695 L
s
.47595 .49862 m
.48076 .50695 L
s
.49519 .49862 m
.50481 .49862 L
s
.49519 .49862 m
.48076 .50695 L
s
.49519 .49862 m
.49038 .50695 L
s
.49519 .49862 m
.5 .50695 L
s
.50481 .49862 m
.51443 .49862 L
s
.50481 .49862 m
.5 .50695 L
s
.50481 .49862 m
.50962 .50695 L
s
.51443 .49862 m
.53367 .49862 L
s
.51443 .49862 m
.50962 .50695 L
s
.51443 .49862 m
.51924 .50695 L
s
.53367 .49862 m
.54329 .49862 L
s
.53367 .49862 m
.51924 .50695 L
s
.53367 .49862 m
.53848 .50695 L
s
.54329 .49862 m
.55291 .49862 L
s
.54329 .49862 m
.53848 .50695 L
s
.55291 .49862 m
.56253 .49862 L
s
.55291 .49862 m
.53848 .50695 L
s
.55291 .49862 m
.56734 .50695 L
s
.55291 .49862 m
.56253 .51528 L
s
.56253 .49862 m
.58177 .49862 L
s
.56253 .49862 m
.56734 .50695 L
s
.58177 .49862 m
.56734 .50695 L
s
.58177 .49862 m
.60582 .50695 L
s
.58177 .49862 m
.57215 .51528 L
s
.58177 .49862 m
.58658 .52361 L
s
.64911 .49862 m
.6443 .50695 L
s
.64911 .49862 m
.64911 .51528 L
s
.64911 .49862 m
.67797 .51528 L
s
.72607 .49862 m
.72607 .51528 L
s
.72607 .49862 m
.75012 .52361 L
s
.04786 .50695 m
.04786 .52361 L
s
.04786 .50695 m
.09596 .52361 L
s
.20178 .50695 m
.2114 .50695 L
s
.20178 .50695 m
.19697 .53195 L
s
.2114 .50695 m
.24026 .52361 L
s
.2114 .50695 m
.19697 .53195 L
s
.24988 .50695 m
.28836 .50695 L
s
.24988 .50695 m
.24026 .52361 L
s
.24988 .50695 m
.27874 .52361 L
s
.24988 .50695 m
.25469 .53195 L
s
.28836 .50695 m
.27874 .52361 L
s
.28836 .50695 m
.3076 .52361 L
s
.38456 .50695 m
.4038 .50695 L
s
.38456 .50695 m
.4038 .52361 L
s
.38456 .50695 m
.34127 .53195 L
s
.38456 .50695 m
.38456 .54028 L
s
.4038 .50695 m
.41342 .50695 L
s
.4038 .50695 m
.40861 .51528 L
s
.4038 .50695 m
.4038 .52361 L
s
.41342 .50695 m
.42304 .50695 L
s
.41342 .50695 m
.40861 .51528 L
s
.41342 .50695 m
.41823 .51528 L
s
.42304 .50695 m
.44228 .50695 L
s
.42304 .50695 m
.41823 .51528 L
s
.42304 .50695 m
.42785 .51528 L
s
.44228 .50695 m
.4519 .50695 L
s
.44228 .50695 m
.42785 .51528 L
s
.44228 .50695 m
.43266 .52361 L
s
.44228 .50695 m
.4519 .52361 L
s
.4519 .50695 m
.46152 .50695 L
s
.4519 .50695 m
.4519 .52361 L
s
.4519 .50695 m
.46152 .52361 L
s
.46152 .50695 m
.47114 .50695 L
s
.46152 .50695 m
.46152 .52361 L
s
.47114 .50695 m
.48076 .50695 L
s
.47114 .50695 m
.47595 .51528 L
s
.47114 .50695 m
.46152 .52361 L
s
.48076 .50695 m
.49038 .50695 L
s
.48076 .50695 m
.47595 .51528 L
s
.48076 .50695 m
.49519 .51528 L
s
.49038 .50695 m
.5 .50695 L
s
.49038 .50695 m
.49519 .51528 L
s
.5 .50695 m
.50962 .50695 L
s
.5 .50695 m
.49519 .51528 L
s
.50962 .50695 m
.51924 .50695 L
s
.50962 .50695 m
.49519 .51528 L
s
.50962 .50695 m
.50962 .52361 L
s
.51924 .50695 m
.53848 .50695 L
s
.51924 .50695 m
.53367 .51528 L
s
.51924 .50695 m
.50962 .52361 L
s
.51924 .50695 m
.52886 .52361 L
s
.53848 .50695 m
.53367 .51528 L
s
.53848 .50695 m
.56253 .51528 L
s
.56734 .50695 m
.56253 .51528 L
s
.56734 .50695 m
.57215 .51528 L
s
.60582 .50695 m
.62987 .51528 L
s
.60582 .50695 m
.58658 .52361 L
s
.60582 .50695 m
.61544 .52361 L
s
.6443 .50695 m
.62987 .51528 L
s
.6443 .50695 m
.64911 .51528 L
s
.76936 .50695 m
.75012 .52361 L
s
.76936 .50695 m
.80784 .52361 L
s
.82708 .50695 m
.80784 .52361 L
s
.82708 .50695 m
.90404 .54028 L
s
.82708 .50695 m
.87999 .56527 L
s
.12963 .51528 m
.10558 .52361 L
s
.12963 .51528 m
.19697 .53195 L
s
.12963 .51528 m
.10077 .56527 L
s
.12963 .51528 m
.14406 .59026 L
s
.32203 .51528 m
.3076 .52361 L
s
.32203 .51528 m
.32684 .52361 L
s
.40861 .51528 m
.41823 .51528 L
s
.40861 .51528 m
.4038 .52361 L
s
.40861 .51528 m
.41342 .52361 L
s
.41823 .51528 m
.42785 .51528 L
s
.41823 .51528 m
.41342 .52361 L
s
.41823 .51528 m
.43266 .52361 L
s
.42785 .51528 m
.43266 .52361 L
s
.47595 .51528 m
.49519 .51528 L
s
.47595 .51528 m
.46152 .52361 L
s
.47595 .51528 m
.47114 .52361 L
s
.47595 .51528 m
.47595 .53195 L
s
.49519 .51528 m
.50962 .52361 L
s
.49519 .51528 m
.47595 .53195 L
s
.49519 .51528 m
.49038 .54028 L
s
.53367 .51528 m
.56253 .51528 L
s
.53367 .51528 m
.52886 .52361 L
s
.53367 .51528 m
.53367 .53195 L
s
.53367 .51528 m
.55291 .53195 L
s
.56253 .51528 m
.57215 .51528 L
s
.56253 .51528 m
.56734 .52361 L
s
.56253 .51528 m
.55291 .53195 L
s
.57215 .51528 m
.56734 .52361 L
s
.57215 .51528 m
.58658 .52361 L
s
.57215 .51528 m
.57215 .53195 L
s
.62987 .51528 m
.64911 .51528 L
s
.62987 .51528 m
.61544 .52361 L
s
.62987 .51528 m
.64911 .53195 L
s
.64911 .51528 m
.67797 .51528 L
s
.64911 .51528 m
.64911 .53195 L
s
.64911 .51528 m
.65873 .53195 L
s
.67797 .51528 m
.72607 .51528 L
s
.67797 .51528 m
.65873 .53195 L
s
.67797 .51528 m
.66354 .54028 L
s
.67797 .51528 m
.66835 .54861 L
s
.67797 .51528 m
.70683 .54861 L
s
.72607 .51528 m
.75012 .52361 L
s
.72607 .51528 m
.74531 .53195 L
s
.72607 .51528 m
.73088 .54028 L
s
.72607 .51528 m
.70683 .54861 L
s
.04786 .52361 m
.09596 .52361 L
s
.04786 .52361 m
.0671 .55694 L
s
.04786 .52361 m
.07191 .58193 L
s
.04786 .52361 m
.05748 .64025 L
s
.09596 .52361 m
.10558 .52361 L
s
.09596 .52361 m
.0671 .55694 L
s
.09596 .52361 m
.10077 .56527 L
s
.10558 .52361 m
.10077 .56527 L
s
.24026 .52361 m
.19697 .53195 L
s
.24026 .52361 m
.25469 .53195 L
s
.24026 .52361 m
.2114 .55694 L
s
.27874 .52361 m
.3076 .52361 L
s
.27874 .52361 m
.25469 .53195 L
s
.27874 .52361 m
.29317 .54861 L
s
.3076 .52361 m
.32684 .52361 L
s
.3076 .52361 m
.29317 .54861 L
s
.3076 .52361 m
.33165 .54861 L
s
.32684 .52361 m
.34127 .53195 L
s
.32684 .52361 m
.33165 .54861 L
s
.4038 .52361 m
.41342 .52361 L
s
.4038 .52361 m
.38456 .54028 L
s
.4038 .52361 m
.39418 .54028 L
s
.4038 .52361 m
.4038 .54028 L
s
.41342 .52361 m
.43266 .52361 L
s
.41342 .52361 m
.4038 .54028 L
s
.43266 .52361 m
.4519 .52361 L
s
.43266 .52361 m
.4038 .54028 L
s
.43266 .52361 m
.4519 .54028 L
s
.43266 .52361 m
.41823 .56527 L
s
.4519 .52361 m
.46152 .52361 L
s
.4519 .52361 m
.45671 .53195 L
s
.4519 .52361 m
.4519 .54028 L
s
.46152 .52361 m
.47114 .52361 L
s
.46152 .52361 m
.45671 .53195 L
s
.46152 .52361 m
.46633 .53195 L
s
.47114 .52361 m
.46633 .53195 L
s
.47114 .52361 m
.47595 .53195 L
s
.50962 .52361 m
.52886 .52361 L
s
.50962 .52361 m
.52405 .53195 L
s
.50962 .52361 m
.49038 .54028 L
s
.50962 .52361 m
.50962 .54028 L
s
.52886 .52361 m
.52405 .53195 L
s
.52886 .52361 m
.53367 .53195 L
s
.56734 .52361 m
.55291 .53195 L
s
.56734 .52361 m
.56253 .53195 L
s
.56734 .52361 m
.57215 .53195 L
s
.58658 .52361 m
.61544 .52361 L
s
.58658 .52361 m
.57215 .53195 L
s
.58658 .52361 m
.58177 .53195 L
s
.58658 .52361 m
.58658 .54028 L
s
.61544 .52361 m
.64911 .53195 L
s
.61544 .52361 m
.58658 .54028 L
s
.61544 .52361 m
.59139 .54861 L
s
.61544 .52361 m
.60582 .55694 L
s
.61544 .52361 m
.63949 .56527 L
s
.75012 .52361 m
.80784 .52361 L
s
.75012 .52361 m
.74531 .53195 L
s
.80784 .52361 m
.74531 .53195 L
s
.80784 .52361 m
.7405 .54028 L
s
.80784 .52361 m
.87999 .56527 L
s
.80784 .52361 m
.77898 .65691 L
s
.19697 .53195 m
.2114 .55694 L
s
.19697 .53195 m
.14406 .59026 L
s
.25469 .53195 m
.29317 .54861 L
s
.25469 .53195 m
.2114 .55694 L
s
.25469 .53195 m
.27874 .5736 L
s
.34127 .53195 m
.34608 .54028 L
s
.34127 .53195 m
.38456 .54028 L
s
.34127 .53195 m
.33165 .54861 L
s
.45671 .53195 m
.46633 .53195 L
s
.45671 .53195 m
.4519 .54028 L
s
.45671 .53195 m
.46152 .54028 L
s
.46633 .53195 m
.47595 .53195 L
s
.46633 .53195 m
.46152 .54028 L
s
.46633 .53195 m
.48076 .54028 L
s
.46633 .53195 m
.46633 .54861 L
s
.47595 .53195 m
.48076 .54028 L
s
.47595 .53195 m
.49038 .54028 L
s
.52405 .53195 m
.53367 .53195 L
s
.52405 .53195 m
.50962 .54028 L
s
.52405 .53195 m
.52886 .54028 L
s
.53367 .53195 m
.55291 .53195 L
s
.53367 .53195 m
.52886 .54028 L
s
.53367 .53195 m
.54329 .54861 L
s
.55291 .53195 m
.56253 .53195 L
s
.55291 .53195 m
.55772 .54028 L
s
.55291 .53195 m
.54329 .54861 L
s
.56253 .53195 m
.57215 .53195 L
s
.56253 .53195 m
.55772 .54028 L
s
.57215 .53195 m
.58177 .53195 L
s
.57215 .53195 m
.55772 .54028 L
s
.57215 .53195 m
.58658 .54028 L
s
.57215 .53195 m
.57696 .55694 L
s
.58177 .53195 m
.58658 .54028 L
s
.64911 .53195 m
.65873 .53195 L
s
.64911 .53195 m
.66354 .54028 L
s
.64911 .53195 m
.63949 .56527 L
s
.65873 .53195 m
.66354 .54028 L
s
.74531 .53195 m
.73088 .54028 L
s
.74531 .53195 m
.7405 .54028 L
s
.34608 .54028 m
.38456 .54028 L
s
.34608 .54028 m
.33165 .54861 L
s
.34608 .54028 m
.37975 .54861 L
s
.34608 .54028 m
.34608 .55694 L
s
.34608 .54028 m
.36051 .56527 L
s
.38456 .54028 m
.39418 .54028 L
s
.38456 .54028 m
.37975 .54861 L
s
.39418 .54028 m
.4038 .54028 L
s
.39418 .54028 m
.37975 .54861 L
s
.39418 .54028 m
.40861 .56527 L
s
.4038 .54028 m
.40861 .56527 L
s
.4038 .54028 m
.41823 .56527 L
s
.4519 .54028 m
.46152 .54028 L
s
.4519 .54028 m
.45671 .54861 L
s
.4519 .54028 m
.4519 .55694 L
s
.4519 .54028 m
.41823 .56527 L
s
.46152 .54028 m
.45671 .54861 L
s
.46152 .54028 m
.46633 .54861 L
s
.48076 .54028 m
.49038 .54028 L
s
.48076 .54028 m
.46633 .54861 L
s
.48076 .54028 m
.49519 .54861 L
s
.48076 .54028 m
.47114 .55694 L
s
.48076 .54028 m
.48557 .56527 L
s
.49038 .54028 m
.50962 .54028 L
s
.49038 .54028 m
.49519 .54861 L
s
.49038 .54028 m
.50481 .54861 L
s
.50962 .54028 m
.52886 .54028 L
s
.50962 .54028 m
.50481 .54861 L
s
.50962 .54028 m
.51443 .54861 L
s
.52886 .54028 m
.51443 .54861 L
s
.52886 .54028 m
.54329 .54861 L
s
.52886 .54028 m
.51924 .55694 L
s
.52886 .54028 m
.52886 .55694 L
s
.55772 .54028 m
.54329 .54861 L
s
.55772 .54028 m
.57696 .55694 L
s
.55772 .54028 m
.56253 .56527 L
s
.58658 .54028 m
.59139 .54861 L
s
.58658 .54028 m
.57696 .55694 L
s
.66354 .54028 m
.66835 .54861 L
s
.66354 .54028 m
.63949 .56527 L
s
.73088 .54028 m
.7405 .54028 L
s
.73088 .54028 m
.70683 .54861 L
s
.73088 .54028 m
.70683 .56527 L
s
.7405 .54028 m
.70683 .56527 L
s
.7405 .54028 m
.71164 .59026 L
s
.7405 .54028 m
.71645 .59859 L
s
.7405 .54028 m
.77898 .65691 L
s
.90404 .54028 m
.87999 .56527 L
s
.90404 .54028 m
.88961 .56527 L
s
.90404 .54028 m
.89923 .56527 L
s
.90404 .54028 m
.94733 .66524 L
s
.29317 .54861 m
.33165 .54861 L
s
.29317 .54861 m
.27874 .5736 L
s
.29317 .54861 m
.28836 .5736 L
s
.29317 .54861 m
.32684 .5736 L
s
.33165 .54861 m
.34608 .55694 L
s
.33165 .54861 m
.32684 .5736 L
s
.37975 .54861 m
.36051 .56527 L
s
.37975 .54861 m
.40861 .56527 L
s
.37975 .54861 m
.39418 .5736 L
s
.37975 .54861 m
.37975 .58193 L
s
.45671 .54861 m
.46633 .54861 L
s
.45671 .54861 m
.4519 .55694 L
s
.45671 .54861 m
.46152 .55694 L
s
.46633 .54861 m
.46152 .55694 L
s
.46633 .54861 m
.47114 .55694 L
s
.49519 .54861 m
.50481 .54861 L
s
.49519 .54861 m
.48557 .56527 L
s
.49519 .54861 m
.50481 .56527 L
s
.50481 .54861 m
.51443 .54861 L
s
.50481 .54861 m
.51924 .55694 L
s
.50481 .54861 m
.50481 .56527 L
s
.51443 .54861 m
.51924 .55694 L
s
.54329 .54861 m
.52886 .55694 L
s
.54329 .54861 m
.53848 .55694 L
s
.54329 .54861 m
.56253 .56527 L
s
.59139 .54861 m
.57696 .55694 L
s
.59139 .54861 m
.58658 .55694 L
s
.59139 .54861 m
.60582 .55694 L
s
.66835 .54861 m
.70683 .54861 L
s
.66835 .54861 m
.63949 .56527 L
s
.66835 .54861 m
.70683 .56527 L
s
.66835 .54861 m
.6443 .5736 L
s
.66835 .54861 m
.65873 .58193 L
s
.66835 .54861 m
.68759 .58193 L
s
.70683 .54861 m
.70683 .56527 L
s
.0671 .55694 m
.10077 .56527 L
s
.0671 .55694 m
.07672 .5736 L
s
.0671 .55694 m
.07191 .58193 L
s
.2114 .55694 m
.27874 .5736 L
s
.2114 .55694 m
.14406 .59026 L
s
.2114 .55694 m
.23064 .60693 L
s
.2114 .55694 m
.24026 .60693 L
s
.2114 .55694 m
.15849 .61526 L
s
.34608 .55694 m
.36051 .56527 L
s
.34608 .55694 m
.32684 .5736 L
s
.4519 .55694 m
.46152 .55694 L
s
.4519 .55694 m
.41823 .56527 L
s
.4519 .55694 m
.46633 .56527 L
s
.4519 .55694 m
.44228 .5736 L
s
.46152 .55694 m
.47114 .55694 L
s
.46152 .55694 m
.46633 .56527 L
s
.47114 .55694 m
.46633 .56527 L
s
.47114 .55694 m
.47595 .56527 L
s
.47114 .55694 m
.48557 .56527 L
s
.51924 .55694 m
.52886 .55694 L
s
.51924 .55694 m
.50481 .56527 L
s
.51924 .55694 m
.53367 .56527 L
s
.52886 .55694 m
.53848 .55694 L
s
.52886 .55694 m
.53367 .56527 L
s
.53848 .55694 m
.53367 .56527 L
s
.53848 .55694 m
.56253 .56527 L
s
.57696 .55694 m
.58658 .55694 L
s
.57696 .55694 m
.56253 .56527 L
s
.57696 .55694 m
.57215 .56527 L
s
.57696 .55694 m
.58658 .5736 L
s
.58658 .55694 m
.60582 .55694 L
s
.58658 .55694 m
.60101 .56527 L
s
.58658 .55694 m
.58658 .5736 L
s
.60582 .55694 m
.60101 .56527 L
s
.60582 .55694 m
.63949 .56527 L
s
.60582 .55694 m
.62506 .5736 L
s
.10077 .56527 m
.07672 .5736 L
s
.10077 .56527 m
.08153 .58193 L
s
.10077 .56527 m
.14406 .59026 L
s
.36051 .56527 m
.32684 .5736 L
s
.36051 .56527 m
.37975 .58193 L
s
.36051 .56527 m
.3557 .60693 L
s
.40861 .56527 m
.41823 .56527 L
s
.40861 .56527 m
.39418 .5736 L
s
.41823 .56527 m
.39418 .5736 L
s
.41823 .56527 m
.44228 .5736 L
s
.41823 .56527 m
.44709 .59859 L
s
.46633 .56527 m
.47595 .56527 L
s
.46633 .56527 m
.44228 .5736 L
s
.46633 .56527 m
.47114 .5736 L
s
.47595 .56527 m
.48557 .56527 L
s
.47595 .56527 m
.47114 .5736 L
s
.48557 .56527 m
.50481 .56527 L
s
.48557 .56527 m
.47114 .5736 L
s
.48557 .56527 m
.50481 .58193 L
s
.48557 .56527 m
.47114 .59026 L
s
.48557 .56527 m
.49519 .59859 L
s
.50481 .56527 m
.53367 .56527 L
s
.50481 .56527 m
.50481 .58193 L
s
.53367 .56527 m
.56253 .56527 L
s
.53367 .56527 m
.50481 .58193 L
s
.53367 .56527 m
.5481 .59026 L
s
.53367 .56527 m
.52405 .59859 L
s
.53367 .56527 m
.53367 .59859 L
s
.56253 .56527 m
.57215 .56527 L
s
.56253 .56527 m
.56253 .58193 L
s
.56253 .56527 m
.5481 .59026 L
s
.57215 .56527 m
.58658 .5736 L
s
.57215 .56527 m
.56253 .58193 L
s
.57215 .56527 m
.57215 .58193 L
s
.60101 .56527 m
.58658 .5736 L
s
.60101 .56527 m
.62506 .5736 L
s
.60101 .56527 m
.59139 .58193 L
s
.63949 .56527 m
.62506 .5736 L
s
.63949 .56527 m
.6443 .5736 L
s
.63949 .56527 m
.63949 .58193 L
s
.70683 .56527 m
.68759 .58193 L
s
.70683 .56527 m
.71164 .59026 L
s
.87999 .56527 m
.88961 .56527 L
s
.87999 .56527 m
.77898 .65691 L
s
.87999 .56527 m
.81746 .67358 L
s
.87999 .56527 m
.87518 .67358 L
s
.88961 .56527 m
.89923 .56527 L
s
.88961 .56527 m
.87518 .67358 L
s
.89923 .56527 m
.94733 .66524 L
s
.89923 .56527 m
.87518 .67358 L
s
.07672 .5736 m
.07191 .58193 L
s
.07672 .5736 m
.08153 .58193 L
s
.27874 .5736 m
.28836 .5736 L
s
.27874 .5736 m
.24026 .60693 L
s
.27874 .5736 m
.25469 .61526 L
s
.27874 .5736 m
.29317 .61526 L
s
.28836 .5736 m
.32684 .5736 L
s
.28836 .5736 m
.29317 .61526 L
s
.32684 .5736 m
.3557 .60693 L
s
.32684 .5736 m
.29317 .61526 L
s
.32684 .5736 m
.34608 .62359 L
s
.39418 .5736 m
.37975 .58193 L
s
.39418 .5736 m
.38456 .59026 L
s
.39418 .5736 m
.44709 .59859 L
s
.44228 .5736 m
.47114 .5736 L
s
.44228 .5736 m
.47114 .59026 L
s
.44228 .5736 m
.44709 .59859 L
s
.47114 .5736 m
.47114 .59026 L
s
.58658 .5736 m
.57215 .58193 L
s
.58658 .5736 m
.59139 .58193 L
s
.62506 .5736 m
.59139 .58193 L
s
.62506 .5736 m
.63949 .58193 L
s
.62506 .5736 m
.63468 .59026 L
s
.62506 .5736 m
.60101 .59859 L
s
.6443 .5736 m
.63949 .58193 L
s
.6443 .5736 m
.65873 .58193 L
s
.07191 .58193 m
.08153 .58193 L
s
.07191 .58193 m
.07191 .59859 L
s
.07191 .58193 m
.05748 .64025 L
s
.08153 .58193 m
.14406 .59026 L
s
.08153 .58193 m
.07191 .59859 L
s
.37975 .58193 m
.38456 .59026 L
s
.37975 .58193 m
.3557 .60693 L
s
.50481 .58193 m
.49519 .59859 L
s
.50481 .58193 m
.52405 .59859 L
s
.50481 .58193 m
.50962 .60693 L
s
.56253 .58193 m
.57215 .58193 L
s
.56253 .58193 m
.5481 .59026 L
s
.56253 .58193 m
.56253 .61526 L
s
.56253 .58193 m
.57215 .61526 L
s
.57215 .58193 m
.59139 .58193 L
s
.57215 .58193 m
.60101 .59859 L
s
.57215 .58193 m
.57215 .61526 L
s
.59139 .58193 m
.60101 .59859 L
s
.63949 .58193 m
.65873 .58193 L
s
.63949 .58193 m
.63468 .59026 L
s
.65873 .58193 m
.68759 .58193 L
s
.65873 .58193 m
.63468 .59026 L
s
.65873 .58193 m
.68759 .61526 L
s
.65873 .58193 m
.64911 .63192 L
s
.68759 .58193 m
.71164 .59026 L
s
.68759 .58193 m
.68759 .61526 L
s
.68759 .58193 m
.69721 .61526 L
s
.14406 .59026 m
.07191 .59859 L
s
.14406 .59026 m
.15849 .61526 L
s
.38456 .59026 m
.44709 .59859 L
s
.38456 .59026 m
.3557 .60693 L
s
.38456 .59026 m
.38456 .60693 L
s
.47114 .59026 m
.44709 .59859 L
s
.47114 .59026 m
.49519 .59859 L
s
.47114 .59026 m
.48076 .60693 L
s
.47114 .59026 m
.45671 .61526 L
s
.5481 .59026 m
.53367 .59859 L
s
.5481 .59026 m
.53848 .60693 L
s
.5481 .59026 m
.56253 .61526 L
s
.63468 .59026 m
.60101 .59859 L
s
.63468 .59026 m
.61063 .63192 L
s
.63468 .59026 m
.64911 .63192 L
s
.71164 .59026 m
.71645 .59859 L
s
.71164 .59026 m
.69721 .61526 L
s
.07191 .59859 m
.15849 .61526 L
s
.07191 .59859 m
.05748 .64025 L
s
.44709 .59859 m
.38456 .60693 L
s
.44709 .59859 m
.45671 .61526 L
s
.44709 .59859 m
.4519 .62359 L
s
.44709 .59859 m
.41823 .63192 L
s
.49519 .59859 m
.48076 .60693 L
s
.49519 .59859 m
.5 .60693 L
s
.49519 .59859 m
.50962 .60693 L
s
.52405 .59859 m
.53367 .59859 L
s
.52405 .59859 m
.50962 .60693 L
s
.52405 .59859 m
.53367 .61526 L
s
.53367 .59859 m
.53848 .60693 L
s
.53367 .59859 m
.53367 .61526 L
s
.60101 .59859 m
.57215 .61526 L
s
.60101 .59859 m
.61063 .63192 L
s
.71645 .59859 m
.69721 .61526 L
s
.71645 .59859 m
.70202 .62359 L
s
.71645 .59859 m
.77898 .65691 L
s
.23064 .60693 m
.24026 .60693 L
s
.23064 .60693 m
.15849 .61526 L
s
.23064 .60693 m
.25469 .61526 L
s
.23064 .60693 m
.18735 .64858 L
s
.23064 .60693 m
.23064 .67358 L
s
.24026 .60693 m
.25469 .61526 L
s
.3557 .60693 m
.38456 .60693 L
s
.3557 .60693 m
.34608 .62359 L
s
.3557 .60693 m
.3557 .62359 L
s
.38456 .60693 m
.3557 .62359 L
s
.38456 .60693 m
.38456 .62359 L
s
.38456 .60693 m
.41823 .63192 L
s
.48076 .60693 m
.5 .60693 L
s
.48076 .60693 m
.45671 .61526 L
s
.48076 .60693 m
.48076 .62359 L
s
.5 .60693 m
.50962 .60693 L
s
.5 .60693 m
.50481 .61526 L
s
.5 .60693 m
.48076 .62359 L
s
.50962 .60693 m
.50481 .61526 L
s
.50962 .60693 m
.53367 .61526 L
s
.53848 .60693 m
.53367 .61526 L
s
.53848 .60693 m
.56253 .61526 L
s
.15849 .61526 m
.05748 .64025 L
s
.15849 .61526 m
.1633 .64025 L
s
.15849 .61526 m
.18735 .64858 L
s
.25469 .61526 m
.29317 .61526 L
s
.25469 .61526 m
.27874 .62359 L
s
.25469 .61526 m
.26912 .64025 L
s
.25469 .61526 m
.23064 .67358 L
s
.29317 .61526 m
.27874 .62359 L
s
.29317 .61526 m
.34608 .62359 L
s
.29317 .61526 m
.33165 .64858 L
s
.29317 .61526 m
.32203 .66524 L
s
.45671 .61526 m
.4519 .62359 L
s
.45671 .61526 m
.48076 .62359 L
s
.45671 .61526 m
.45671 .63192 L
s
.50481 .61526 m
.53367 .61526 L
s
.50481 .61526 m
.48076 .62359 L
s
.50481 .61526 m
.50481 .66524 L
s
.53367 .61526 m
.56253 .61526 L
s
.53367 .61526 m
.56253 .64858 L
s
.53367 .61526 m
.50481 .66524 L
s
.53367 .61526 m
.51924 .67358 L
s
.56253 .61526 m
.57215 .61526 L
s
.56253 .61526 m
.56253 .64858 L
s
.57215 .61526 m
.61063 .63192 L
s
.57215 .61526 m
.56253 .64858 L
s
.68759 .61526 m
.69721 .61526 L
s
.68759 .61526 m
.70202 .62359 L
s
.68759 .61526 m
.64911 .63192 L
s
.68759 .61526 m
.67797 .63192 L
s
.69721 .61526 m
.70202 .62359 L
s
.27874 .62359 m
.26912 .64025 L
s
.27874 .62359 m
.32203 .66524 L
s
.34608 .62359 m
.3557 .62359 L
s
.34608 .62359 m
.35089 .63192 L
s
.34608 .62359 m
.33165 .64858 L
s
.3557 .62359 m
.38456 .62359 L
s
.3557 .62359 m
.35089 .63192 L
s
.38456 .62359 m
.35089 .63192 L
s
.38456 .62359 m
.41823 .63192 L
s
.38456 .62359 m
.40861 .64858 L
s
.38456 .62359 m
.39899 .66524 L
s
.4519 .62359 m
.41823 .63192 L
s
.4519 .62359 m
.45671 .63192 L
s
.4519 .62359 m
.42785 .64858 L
s
.48076 .62359 m
.45671 .63192 L
s
.48076 .62359 m
.47595 .66524 L
s
.48076 .62359 m
.48557 .66524 L
s
.48076 .62359 m
.50481 .66524 L
s
.70202 .62359 m
.67797 .63192 L
s
.70202 .62359 m
.69721 .64858 L
s
.70202 .62359 m
.77898 .65691 L
s
.35089 .63192 m
.33165 .64858 L
s
.35089 .63192 m
.34127 .66524 L
s
.35089 .63192 m
.39899 .66524 L
s
.41823 .63192 m
.40861 .64858 L
s
.41823 .63192 m
.42785 .64858 L
s
.45671 .63192 m
.42785 .64858 L
s
.45671 .63192 m
.44228 .65691 L
s
.45671 .63192 m
.47595 .66524 L
s
.61063 .63192 m
.64911 .63192 L
s
.61063 .63192 m
.56253 .64858 L
s
.61063 .63192 m
.56734 .65691 L
s
.61063 .63192 m
.61544 .65691 L
s
.61063 .63192 m
.62506 .65691 L
s
.61063 .63192 m
.57215 .66524 L
s
.64911 .63192 m
.67797 .63192 L
s
.64911 .63192 m
.66354 .64025 L
s
.64911 .63192 m
.62506 .65691 L
s
.64911 .63192 m
.6443 .67358 L
s
.67797 .63192 m
.66354 .64025 L
s
.67797 .63192 m
.69721 .64858 L
s
.05748 .64025 m
.1633 .64025 L
s
.05748 .64025 m
.13925 .69857 L
s
.05748 .64025 m
.07672 .7069 L
s
.1633 .64025 m
.18735 .64858 L
s
.1633 .64025 m
.13925 .69857 L
s
.26912 .64025 m
.32203 .66524 L
s
.26912 .64025 m
.23064 .67358 L
s
.26912 .64025 m
.30279 .68191 L
s
.26912 .64025 m
.26912 .69024 L
s
.66354 .64025 m
.69721 .64858 L
s
.66354 .64025 m
.6443 .67358 L
s
.18735 .64858 m
.23064 .67358 L
s
.18735 .64858 m
.13925 .69857 L
s
.18735 .64858 m
.18735 .73189 L
s
.33165 .64858 m
.32203 .66524 L
s
.33165 .64858 m
.34127 .66524 L
s
.40861 .64858 m
.42785 .64858 L
s
.40861 .64858 m
.42304 .65691 L
s
.40861 .64858 m
.39899 .66524 L
s
.40861 .64858 m
.40861 .66524 L
s
.40861 .64858 m
.41823 .66524 L
s
.42785 .64858 m
.42304 .65691 L
s
.42785 .64858 m
.44228 .65691 L
s
.56253 .64858 m
.56734 .65691 L
s
.56253 .64858 m
.51924 .67358 L
s
.69721 .64858 m
.77898 .65691 L
s
.69721 .64858 m
.6443 .67358 L
s
.69721 .64858 m
.71164 .69024 L
s
.69721 .64858 m
.72126 .69024 L
s
.42304 .65691 m
.44228 .65691 L
s
.42304 .65691 m
.41823 .66524 L
s
.44228 .65691 m
.41823 .66524 L
s
.44228 .65691 m
.47595 .66524 L
s
.44228 .65691 m
.46633 .68191 L
s
.44228 .65691 m
.45671 .69857 L
s
.44228 .65691 m
.43266 .7069 L
s
.56734 .65691 m
.57215 .66524 L
s
.56734 .65691 m
.51924 .67358 L
s
.61544 .65691 m
.62506 .65691 L
s
.61544 .65691 m
.57215 .66524 L
s
.61544 .65691 m
.60101 .68191 L
s
.62506 .65691 m
.6443 .67358 L
s
.62506 .65691 m
.60101 .68191 L
s
.77898 .65691 m
.81746 .67358 L
s
.77898 .65691 m
.72126 .69024 L
s
.77898 .65691 m
.75974 .7069 L
s
.32203 .66524 m
.34127 .66524 L
s
.32203 .66524 m
.33646 .67358 L
s
.32203 .66524 m
.30279 .68191 L
s
.32203 .66524 m
.33165 .68191 L
s
.34127 .66524 m
.39899 .66524 L
s
.34127 .66524 m
.33646 .67358 L
s
.34127 .66524 m
.34608 .69024 L
s
.39899 .66524 m
.40861 .66524 L
s
.39899 .66524 m
.34608 .69024 L
s
.39899 .66524 m
.4038 .7069 L
s
.40861 .66524 m
.41823 .66524 L
s
.40861 .66524 m
.4038 .7069 L
s
.41823 .66524 m
.4038 .7069 L
s
.41823 .66524 m
.43266 .7069 L
s
.47595 .66524 m
.48557 .66524 L
s
.47595 .66524 m
.46633 .68191 L
s
.48557 .66524 m
.50481 .66524 L
s
.48557 .66524 m
.5 .67358 L
s
.48557 .66524 m
.46633 .68191 L
s
.48557 .66524 m
.47595 .69857 L
s
.50481 .66524 m
.5 .67358 L
s
.50481 .66524 m
.51924 .67358 L
s
.57215 .66524 m
.51924 .67358 L
s
.57215 .66524 m
.60101 .68191 L
s
.57215 .66524 m
.53367 .69857 L
s
.57215 .66524 m
.58177 .69857 L
s
.57215 .66524 m
.55772 .7069 L
s
.94733 .66524 m
.87518 .67358 L
s
.94733 .66524 m
.88961 .73189 L
s
.94733 .66524 m
.78379 .86519 L
s
.23064 .67358 m
.26912 .69024 L
s
.23064 .67358 m
.24026 .7069 L
s
.23064 .67358 m
.18735 .73189 L
s
.33646 .67358 m
.33165 .68191 L
s
.33646 .67358 m
.34608 .69024 L
s
.5 .67358 m
.51924 .67358 L
s
.5 .67358 m
.51924 .69024 L
s
.5 .67358 m
.47595 .69857 L
s
.5 .67358 m
.50481 .69857 L
s
.51924 .67358 m
.51924 .69024 L
s
.51924 .67358 m
.53367 .69857 L
s
.6443 .67358 m
.60101 .68191 L
s
.6443 .67358 m
.6443 .69024 L
s
.6443 .67358 m
.71164 .69024 L
s
.6443 .67358 m
.61063 .69857 L
s
.81746 .67358 m
.87518 .67358 L
s
.81746 .67358 m
.75974 .7069 L
s
.81746 .67358 m
.84632 .72356 L
s
.81746 .67358 m
.82227 .73189 L
s
.87518 .67358 m
.84632 .72356 L
s
.87518 .67358 m
.88961 .73189 L
s
.30279 .68191 m
.33165 .68191 L
s
.30279 .68191 m
.26912 .69024 L
s
.30279 .68191 m
.32684 .7069 L
s
.30279 .68191 m
.29317 .71523 L
s
.33165 .68191 m
.34608 .69024 L
s
.33165 .68191 m
.32684 .7069 L
s
.46633 .68191 m
.45671 .69857 L
s
.46633 .68191 m
.47595 .69857 L
s
.60101 .68191 m
.58177 .69857 L
s
.60101 .68191 m
.61063 .69857 L
s
.26912 .69024 m
.24026 .7069 L
s
.26912 .69024 m
.29317 .71523 L
s
.34608 .69024 m
.32684 .7069 L
s
.34608 .69024 m
.4038 .7069 L
s
.34608 .69024 m
.37494 .72356 L
s
.51924 .69024 m
.50481 .69857 L
s
.51924 .69024 m
.53367 .69857 L
s
.51924 .69024 m
.52405 .71523 L
s
.6443 .69024 m
.71164 .69024 L
s
.6443 .69024 m
.61063 .69857 L
s
.6443 .69024 m
.70202 .7069 L
s
.6443 .69024 m
.62987 .71523 L
s
.71164 .69024 m
.72126 .69024 L
s
.71164 .69024 m
.70202 .7069 L
s
.72126 .69024 m
.70202 .7069 L
s
.72126 .69024 m
.75974 .7069 L
s
.72126 .69024 m
.74531 .71523 L
s
.13925 .69857 m
.07672 .7069 L
s
.13925 .69857 m
.12001 .71523 L
s
.13925 .69857 m
.13444 .72356 L
s
.13925 .69857 m
.18735 .73189 L
s
.13925 .69857 m
.15368 .74022 L
s
.45671 .69857 m
.47595 .69857 L
s
.45671 .69857 m
.43266 .7069 L
s
.45671 .69857 m
.47114 .7069 L
s
.45671 .69857 m
.45671 .71523 L
s
.47595 .69857 m
.50481 .69857 L
s
.47595 .69857 m
.47114 .7069 L
s
.47595 .69857 m
.48557 .71523 L
s
.50481 .69857 m
.48557 .71523 L
s
.50481 .69857 m
.52405 .71523 L
s
.53367 .69857 m
.5481 .7069 L
s
.53367 .69857 m
.55772 .7069 L
s
.53367 .69857 m
.52405 .71523 L
s
.58177 .69857 m
.61063 .69857 L
s
.58177 .69857 m
.55772 .7069 L
s
.58177 .69857 m
.57696 .7069 L
s
.61063 .69857 m
.57696 .7069 L
s
.61063 .69857 m
.62987 .71523 L
s
.61063 .69857 m
.58177 .73189 L
s
.07672 .7069 m
.12001 .71523 L
s
.07672 .7069 m
.13444 .72356 L
s
.07672 .7069 m
.15368 .74022 L
s
.07672 .7069 m
.18735 .84853 L
s
.24026 .7069 m
.29317 .71523 L
s
.24026 .7069 m
.18735 .73189 L
s
.24026 .7069 m
.22583 .73189 L
s
.24026 .7069 m
.23545 .74856 L
s
.24026 .7069 m
.27393 .74856 L
s
.32684 .7069 m
.29317 .71523 L
s
.32684 .7069 m
.37494 .72356 L
s
.32684 .7069 m
.32684 .74022 L
s
.4038 .7069 m
.43266 .7069 L
s
.4038 .7069 m
.37494 .72356 L
s
.4038 .7069 m
.4038 .72356 L
s
.4038 .7069 m
.38937 .73189 L
s
.43266 .7069 m
.45671 .71523 L
s
.43266 .7069 m
.4038 .72356 L
s
.43266 .7069 m
.40861 .73189 L
s
.43266 .7069 m
.43266 .75689 L
s
.47114 .7069 m
.45671 .71523 L
s
.47114 .7069 m
.48557 .71523 L
s
.47114 .7069 m
.48076 .72356 L
s
.5481 .7069 m
.55772 .7069 L
s
.5481 .7069 m
.52405 .71523 L
s
.5481 .7069 m
.58177 .73189 L
s
.55772 .7069 m
.57696 .7069 L
s
.55772 .7069 m
.58177 .73189 L
s
.57696 .7069 m
.58177 .73189 L
s
.70202 .7069 m
.62987 .71523 L
s
.70202 .7069 m
.74531 .71523 L
s
.70202 .7069 m
.70683 .74856 L
s
.70202 .7069 m
.67316 .75689 L
s
.75974 .7069 m
.74531 .71523 L
s
.75974 .7069 m
.82227 .73189 L
s
.75974 .7069 m
.73569 .76522 L
s
.75974 .7069 m
.7405 .77355 L
s
.12001 .71523 m
.13444 .72356 L
s
.29317 .71523 m
.32684 .74022 L
s
.29317 .71523 m
.27393 .74856 L
s
.29317 .71523 m
.3076 .75689 L
s
.45671 .71523 m
.48076 .72356 L
s
.45671 .71523 m
.43266 .75689 L
s
.45671 .71523 m
.48076 .75689 L
s
.48557 .71523 m
.52405 .71523 L
s
.48557 .71523 m
.48076 .72356 L
s
.52405 .71523 m
.48076 .72356 L
s
.52405 .71523 m
.58177 .73189 L
s
.52405 .71523 m
.51443 .76522 L
s
.62987 .71523 m
.58177 .73189 L
s
.62987 .71523 m
.5962 .75689 L
s
.62987 .71523 m
.67316 .75689 L
s
.74531 .71523 m
.70683 .74856 L
s
.74531 .71523 m
.73569 .76522 L
s
.13444 .72356 m
.15368 .74022 L
s
.37494 .72356 m
.38937 .73189 L
s
.37494 .72356 m
.32684 .74022 L
s
.37494 .72356 m
.37494 .74022 L
s
.4038 .72356 m
.38937 .73189 L
s
.4038 .72356 m
.40861 .73189 L
s
.48076 .72356 m
.48076 .75689 L
s
.48076 .72356 m
.51443 .76522 L
s
.84632 .72356 m
.82227 .73189 L
s
.84632 .72356 m
.88961 .73189 L
s
.84632 .72356 m
.85594 .74022 L
s
.18735 .73189 m
.22583 .73189 L
s
.18735 .73189 m
.15368 .74022 L
s
.18735 .73189 m
.19697 .76522 L
s
.22583 .73189 m
.23545 .74856 L
s
.22583 .73189 m
.19697 .76522 L
s
.22583 .73189 m
.21621 .76522 L
s
.38937 .73189 m
.40861 .73189 L
s
.38937 .73189 m
.37494 .74022 L
s
.38937 .73189 m
.38456 .77355 L
s
.40861 .73189 m
.43266 .75689 L
s
.40861 .73189 m
.38456 .77355 L
s
.58177 .73189 m
.5962 .75689 L
s
.58177 .73189 m
.51443 .76522 L
s
.58177 .73189 m
.58177 .76522 L
s
.82227 .73189 m
.85594 .74022 L
s
.82227 .73189 m
.7405 .77355 L
s
.82227 .73189 m
.83189 .78188 L
s
.88961 .73189 m
.85594 .74022 L
s
.88961 .73189 m
.83189 .78188 L
s
.88961 .73189 m
.78379 .86519 L
s
.15368 .74022 m
.19697 .76522 L
s
.15368 .74022 m
.20659 .79854 L
s
.15368 .74022 m
.20178 .82354 L
s
.15368 .74022 m
.18735 .84853 L
s
.32684 .74022 m
.37494 .74022 L
s
.32684 .74022 m
.3076 .75689 L
s
.32684 .74022 m
.33646 .75689 L
s
.37494 .74022 m
.33646 .75689 L
s
.37494 .74022 m
.38456 .77355 L
s
.85594 .74022 m
.83189 .78188 L
s
.23545 .74856 m
.27393 .74856 L
s
.23545 .74856 m
.24988 .75689 L
s
.23545 .74856 m
.21621 .76522 L
s
.23545 .74856 m
.23064 .77355 L
s
.27393 .74856 m
.24988 .75689 L
s
.27393 .74856 m
.3076 .75689 L
s
.27393 .74856 m
.28355 .81521 L
s
.70683 .74856 m
.67316 .75689 L
s
.70683 .74856 m
.73569 .76522 L
s
.70683 .74856 m
.7405 .80687 L
s
.24988 .75689 m
.23064 .77355 L
s
.24988 .75689 m
.28355 .81521 L
s
.3076 .75689 m
.33646 .75689 L
s
.3076 .75689 m
.33646 .77355 L
s
.3076 .75689 m
.31722 .80687 L
s
.3076 .75689 m
.28355 .81521 L
s
.33646 .75689 m
.33646 .77355 L
s
.33646 .75689 m
.38456 .77355 L
s
.43266 .75689 m
.48076 .75689 L
s
.43266 .75689 m
.43747 .76522 L
s
.43266 .75689 m
.38456 .77355 L
s
.43266 .75689 m
.41342 .79021 L
s
.48076 .75689 m
.43747 .76522 L
s
.48076 .75689 m
.48557 .76522 L
s
.48076 .75689 m
.51443 .76522 L
s
.48076 .75689 m
.46633 .78188 L
s
.5962 .75689 m
.67316 .75689 L
s
.5962 .75689 m
.58177 .76522 L
s
.5962 .75689 m
.60101 .83187 L
s
.5962 .75689 m
.66835 .83187 L
s
.67316 .75689 m
.7405 .80687 L
s
.67316 .75689 m
.66835 .83187 L
s
.19697 .76522 m
.21621 .76522 L
s
.19697 .76522 m
.22102 .77355 L
s
.19697 .76522 m
.20659 .79854 L
s
.21621 .76522 m
.22102 .77355 L
s
.21621 .76522 m
.23064 .77355 L
s
.43747 .76522 m
.46633 .78188 L
s
.43747 .76522 m
.41342 .79021 L
s
.43747 .76522 m
.4519 .79021 L
s
.48557 .76522 m
.51443 .76522 L
s
.48557 .76522 m
.46633 .78188 L
s
.48557 .76522 m
.5 .79021 L
s
.51443 .76522 m
.58177 .76522 L
s
.51443 .76522 m
.5 .79021 L
s
.51443 .76522 m
.53848 .8402 L
s
.58177 .76522 m
.60101 .83187 L
s
.58177 .76522 m
.53848 .8402 L
s
.73569 .76522 m
.7405 .77355 L
s
.73569 .76522 m
.7405 .80687 L
s
.22102 .77355 m
.23064 .77355 L
s
.22102 .77355 m
.20659 .79854 L
s
.23064 .77355 m
.20659 .79854 L
s
.23064 .77355 m
.28355 .81521 L
s
.23064 .77355 m
.22583 .83187 L
s
.33646 .77355 m
.38456 .77355 L
s
.33646 .77355 m
.39418 .79021 L
s
.33646 .77355 m
.31722 .80687 L
s
.33646 .77355 m
.37975 .83187 L
s
.38456 .77355 m
.39418 .79021 L
s
.38456 .77355 m
.41342 .79021 L
s
.7405 .77355 m
.83189 .78188 L
s
.7405 .77355 m
.7405 .80687 L
s
.7405 .77355 m
.75974 .82354 L
s
.46633 .78188 m
.4519 .79021 L
s
.46633 .78188 m
.5 .79021 L
s
.46633 .78188 m
.46152 .80687 L
s
.46633 .78188 m
.47114 .80687 L
s
.83189 .78188 m
.75974 .82354 L
s
.83189 .78188 m
.77417 .83187 L
s
.83189 .78188 m
.78379 .86519 L
s
.39418 .79021 m
.41342 .79021 L
s
.39418 .79021 m
.40861 .79854 L
s
.39418 .79021 m
.37975 .83187 L
s
.39418 .79021 m
.38937 .83187 L
s
.41342 .79021 m
.4519 .79021 L
s
.41342 .79021 m
.40861 .79854 L
s
.4519 .79021 m
.40861 .79854 L
s
.4519 .79021 m
.46152 .80687 L
s
.5 .79021 m
.47114 .80687 L
s
.5 .79021 m
.48557 .83187 L
s
.5 .79021 m
.53848 .8402 L
s
.20659 .79854 m
.20178 .82354 L
s
.20659 .79854 m
.22583 .83187 L
s
.40861 .79854 m
.46152 .80687 L
s
.40861 .79854 m
.38937 .83187 L
s
.40861 .79854 m
.39899 .84853 L
s
.40861 .79854 m
.43747 .84853 L
s
.31722 .80687 m
.28355 .81521 L
s
.31722 .80687 m
.37975 .83187 L
s
.31722 .80687 m
.28836 .85686 L
s
.31722 .80687 m
.31241 .86519 L
s
.46152 .80687 m
.47114 .80687 L
s
.46152 .80687 m
.48557 .83187 L
s
.46152 .80687 m
.43747 .84853 L
s
.47114 .80687 m
.48557 .83187 L
s
.7405 .80687 m
.75974 .82354 L
s
.7405 .80687 m
.66835 .83187 L
s
.7405 .80687 m
.71164 .85686 L
s
.28355 .81521 m
.22583 .83187 L
s
.28355 .81521 m
.28836 .85686 L
s
.20178 .82354 m
.22583 .83187 L
s
.20178 .82354 m
.18735 .84853 L
s
.20178 .82354 m
.22583 .84853 L
s
.75974 .82354 m
.77417 .83187 L
s
.75974 .82354 m
.71164 .85686 L
s
.75974 .82354 m
.78379 .86519 L
s
.22583 .83187 m
.22583 .84853 L
s
.22583 .83187 m
.28836 .85686 L
s
.37975 .83187 m
.38937 .83187 L
s
.37975 .83187 m
.39899 .84853 L
s
.37975 .83187 m
.31241 .86519 L
s
.38937 .83187 m
.39899 .84853 L
s
.48557 .83187 m
.53848 .8402 L
s
.48557 .83187 m
.43747 .84853 L
s
.48557 .83187 m
.52886 .85686 L
s
.48557 .83187 m
.46633 .86519 L
s
.60101 .83187 m
.66835 .83187 L
s
.60101 .83187 m
.53848 .8402 L
s
.60101 .83187 m
.55772 .85686 L
s
.60101 .83187 m
.61063 .86519 L
s
.66835 .83187 m
.71164 .85686 L
s
.66835 .83187 m
.61063 .86519 L
s
.66835 .83187 m
.65873 .88185 L
s
.77417 .83187 m
.78379 .86519 L
s
.53848 .8402 m
.52886 .85686 L
s
.53848 .8402 m
.55772 .85686 L
s
.18735 .84853 m
.22583 .84853 L
s
.18735 .84853 m
.24507 .89852 L
s
.22583 .84853 m
.28836 .85686 L
s
.22583 .84853 m
.24507 .89852 L
s
.39899 .84853 m
.43747 .84853 L
s
.39899 .84853 m
.31241 .86519 L
s
.39899 .84853 m
.4519 .89019 L
s
.39899 .84853 m
.37013 .9485 L
s
.43747 .84853 m
.46633 .86519 L
s
.43747 .84853 m
.4519 .89019 L
s
.28836 .85686 m
.31241 .86519 L
s
.28836 .85686 m
.30279 .88185 L
s
.28836 .85686 m
.24507 .89852 L
s
.52886 .85686 m
.55772 .85686 L
s
.52886 .85686 m
.46633 .86519 L
s
.52886 .85686 m
.55772 .90685 L
s
.52886 .85686 m
.52405 .9485 L
s
.55772 .85686 m
.61063 .86519 L
s
.55772 .85686 m
.55772 .90685 L
s
.71164 .85686 m
.78379 .86519 L
s
.71164 .85686 m
.65873 .88185 L
s
.71164 .85686 m
.66354 .92351 L
s
.31241 .86519 m
.30279 .88185 L
s
.31241 .86519 m
.37013 .9485 L
s
.46633 .86519 m
.4519 .89019 L
s
.46633 .86519 m
.52405 .9485 L
s
.61063 .86519 m
.65873 .88185 L
s
.61063 .86519 m
.55772 .90685 L
s
.61063 .86519 m
.66354 .92351 L
s
.61063 .86519 m
.56734 .94017 L
s
.78379 .86519 m
.66354 .92351 L
s
.30279 .88185 m
.24507 .89852 L
s
.30279 .88185 m
.37013 .9485 L
s
.65873 .88185 m
.66354 .92351 L
s
.4519 .89019 m
.37013 .9485 L
s
.4519 .89019 m
.52405 .9485 L
s
.4519 .89019 m
.48076 .9735 L
s
.24507 .89852 m
.37013 .9485 L
s
.55772 .90685 m
.55772 .92351 L
s
.55772 .90685 m
.56734 .94017 L
s
.55772 .90685 m
.52405 .9485 L
s
.55772 .92351 m
.56734 .94017 L
s
.55772 .92351 m
.52405 .9485 L
s
.66354 .92351 m
.56734 .94017 L
s
.66354 .92351 m
.57215 .96517 L
s
.56734 .94017 m
.52405 .9485 L
s
.56734 .94017 m
.52886 .95684 L
s
.56734 .94017 m
.57215 .96517 L
s
.37013 .9485 m
.48076 .9735 L
s
.52405 .9485 m
.52886 .95684 L
s
.52405 .9485 m
.52405 .96517 L
s
.52405 .9485 m
.48076 .9735 L
s
.52886 .95684 m
.52405 .96517 L
s
.52886 .95684 m
.57215 .96517 L
s
.52405 .96517 m
.57215 .96517 L
s
.52405 .96517 m
.48076 .9735 L
s
.57215 .96517 m
.48076 .9735 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{282.375, 281.563},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006W0001YQ000`40O003h00OofmkZ6mk003oKg^X
Kg/00?m_NjQ_N`00ofmkZ6mk003oKg^XKg/00?m_NjQ_N`00ofmkZ6mk003oKg^XKg/00?m_NjQ_N`00
ofmkZ6mk0036Kg/4003MKg/00<=_N`@00003Kg/0000000@00=U_N`00`6mk1@0000A_N`00Kg]_N`80
009_N`D00=E_N`00_6mk1`000Vmk00<006mkKg/00fmk00<006mkKg/00Vmk1P00dFmk002iKg/50002
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/8003<Kg/00;I_N`D000=_N`8000A_
N`03001_Nfmk00I_N`03001_Nfmk00M_N`<00003Kg/0000000800<Q_N`00/fmk1P000fmk0P001Vmk
00<006mkKg/01fmk00<006mkKg/02Fmk100000=_N`0000000P00a6mk002`Kg/60005Kg/00`00Kg]_
N`04Kg/3000:Kg/2000=Kg/30002Kg/5002oKg/00:a_N`@00003Kg/0000000I_N`8000E_N`@00003
Kg/0000000Y_N`03001_Nfmk00]_N`03001_N`0000<000=_N`@00;]_N`00ZFmk0`000Vmk0`001Vmk
0P001Fmk0P000Vmk00<006mk00000Vmk0P002Fmk00<006mkKg/02Vmk00<006mkKg/00fmk0`0016mk
1000]fmk002VKg/30002Kg/30007Kg/20005Kg/20003Kg/01000Kg]_N`0016mk0`001fmk00<006mk
Kg/026mk00<006mkKg/01fmk100016mk1000/fmk002SKg/30003Kg/20009Kg/00`00Kg]_N`03Kg/2
0004Kg/01@00Kg]_Nfmk00001fmk0P001Vmk0P0026mk00<006mkKg/02fmk100016mk1@00[Vmk002P
Kg/30003Kg/30009Kg/20004Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/20006Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`09Kg/200000fmk001_N`060004Kg/4002ZKg/009a_N`@000=_N`<000Y_
N`8000=_N`<000M_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`<000A_N`03001_Nfmk00A_N`03001_
Nfmk00M_N`8000A_N`03001_Nfmk0080009_N`D000=_N`@00:I_N`00VFmk0`001Fmk0P0036mk00@0
06mkKg]_N`8000Q_N`8000I_N`03001_Nfmk00]_N`8000=_N`03001_Nfmk00=_N`03001_Nfmk00E_
N`8000I_N`03001_Nfmk009_N`<000A_N`D0009_N`D00:5_N`00UVmk0`001Fmk0`0036mk0P000Vmk
0P001fmk100000=_N`00Kg/016mk00<006mkKg/03Fmk0`0000=_N`00Kg/00fmk00<006mkKg/00Vmk
0`002Fmk00<006mkKg/016mk0P001fmk1@000Vmk1000WFmk002CKg/30005Kg/3000=Kg/20002Kg/2
0006Kg/30003Kg/00`00Kg]_N`020004Kg/00`00Kg]_N`0?Kg/400000fmk001_N`02Kg/2000<Kg/0
0`00Kg]_N`06Kg/2000:Kg/500000fmk00000002002IKg/0091_N`<000I_N`8000i_N`80009_N`80
00E_N`<000E_N`03001_Nfmk00=_N`05001_NfmkKg/0000CKg/400000fmk0000000>Kg/00`00Kg]_
N`08Kg/3000<Kg/9002EKg/008a_N`@000I_N`<000m_N`03001_Nfmk008000A_N`<000Q_N`03001_
Nfmk00A_N`04001_Nfmk000CKg/5000AKg/00`00Kg]_N`0:Kg/2000?Kg/9002@Kg/008U_N`<000M_
N`<0011_N`D000=_N`<000Y_N`03001_Nfmk00I_N`<000a_N`L0009_N`04001_N`00000@Kg/00`00
Kg]_N`0<Kg/3000@Kg/9002<Kg/008I_N`<000Q_N`80015_N`@0009_N`@000e_N`03001_Nfmk00Q_
N`8000=_N`P000Q_N`05001_Nfmk001_N`02000>Kg/00`00Kg]_N`0?Kg/2000CKg/80028Kg/008=_
N`<000Q_N`<0019_N`<00004Kg/00000000@Kg/00`00Kg]_N`0:Kg/4000?Kg/00`00Kg]_N`02Kg/0
1000Kg]_N`003Vmk00<006mkKg/046mk0P005Vmk2000Pfmk0020Kg/30008Kg/3000CKg/6000CKg/0
0`00Kg]_N`08Kg/200000fmk0000000?Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0P0036mk00<006mk
Kg/04Vmk0`0066mk1`00Ofmk001lKg/40009Kg/2000DKg/5000EKg/00`00Kg]_N`07Kg/20004Kg/3
000<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/2000;Kg/00`00Kg]_N`0DKg/2000KKg/6001kKg/0
07U_N`<000Y_N`<001A_N`@001M_N`03001_Nfmk00I_N`8000M_N`03001_N`0000Y_N`03001_Nfmk
00I_N`03001_Nfmk00A_N`8000U_N`03001_Nfmk01I_N`8001i_N`D007M_N`00Mfmk9`006Vmk00<0
06mkKg/01Fmk00<006mkKg/01fmk00<006mkKg/00P001fmk00<006mkKg/026mk00<006mkKg/01Fmk
00<006mkKg/01Vmk00<006mkKg/066mk9P00M6mk001fKg/3000;Kg/3000DKg/00`00Kg]_N`04000E
Kg/00`00Kg]_N`04Kg/2000;Kg/01000Kg]_Nfmk0P0016mk00<006mkKg/02Vmk00<006mkKg/01Fmk
0P001fmk00<006mkKg/04fmk1@0000=_N`00Kg/07Vmk0P0000A_N`000000079_N`00MFmk0P000Vmk
00<006mkKg/026mk00<006mkKg/00P004Vmk00<006mkKg/016mk0`004Vmk00<006mkKg/00Vmk0P00
3Vmk00<006mkKg/00Vmk0P0000=_N`00Kg/036mk00<006mkKg/01fmk0P001Fmk00<006mkKg/046mk
0`0000E_N`00001_N`00009_N`03001_Nfmk01U_N`<000=_N`03001_Nfmk0080071_N`00M6mk00<0
06mk00000fmk00<006mkKg/01fmk00<006mkKg/00Vmk0P003fmk00<006mkKg/026mk0`003Vmk00<0
06mkKg/00Vmk00<006mkKg/03fmk00<006mkKg/00fmk00<006mkKg/03Fmk00<006mkKg/026mk00<0
06mkKg/00Vmk00<006mkKg/036mk10000Vmk0P000Vmk00<006mkKg/00Vmk00<006mkKg/05Fmk0`00
1Fmk00<006mkKg/00Vmk0`00KVmk001cKg/01000Kg/0000016mk00<006mkKg/01Vmk00<006mkKg/0
16mk0P003Fmk00<006mkKg/02fmk10002Vmk00<006mkKg/00P004fmk00<006mkKg/00Vmk0`003Fmk
00<006mkKg/02Fmk0P000fmk00<006mkKg/01fmk100016mk0P0016mk00<006mkKg/00fmk00<006mk
Kg/04Vmk0P0026mk00<006mkKg/016mk0`00K6mk001bKg/00`00Kg]_N`020005Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0@Kg/30006Kg/01000Kg/000005Vmk00D0
06mkKg]_N`00009_N`8000a_N`03001_Nfmk00Y_N`800003Kg/006mk00E_N`<000I_N`8000E_N`03
001_Nfmk00E_N`03001_Nfmk00i_N`<000Y_N`03001_Nfmk00E_N`@006Y_N`00LFmk00<006mkKg/0
0P001fmk00<006mkKg/016mk00<006mkKg/01fmk0P0026mk00<006mkKg/056mk10000Vmk0P006Fmk
00@006mkKg/000A_N`8000Y_N`03001_Nfmk00a_N`<00003Kg/00000008000M_N`8000M_N`03001_
Nfmk00I_N`03001_Nfmk00]_N`8000e_N`03001_Nfmk00M_N`03001_N`0006U_N`00L6mk00@006mk
Kg]_N`8000M_N`03001_Nfmk00A_N`03001_Nfmk00U_N`8000I_N`03001_Nfmk01E_N`X001I_N`04
001_Nfmk0006Kg/20009Kg/00`00Kg]_N`0=Kg/20009Kg/20008Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`07Kg/3000?Kg/00`00Kg]_N`08Kg/4001WKg/006m_N`07001_NfmkKg/006mk000026mk00<006mk
Kg/00fmk00<006mkKg/02fmk0P000fmk00<006mkKg/036mk2P0016mk0P0016mk2P003Fmk00<006mk
000026mk0P0026mk00<006mkKg/02Vmk0P0000=_N`0000001Vmk0P002Fmk00<006mkKg/02Vmk00<0
06mkKg/00fmk0`004Fmk00<006mkKg/02fmk00@006mk000006E_N`00KVmk00<006mkKg/00Vmk0P00
2Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk0P0000=_N`00Kg/00fmk2P003Fmk00@006mk000000e_
N`X000A_N`8000Y_N`8000I_N`03001_Nfmk00Q_N`8000E_N`80009_N`8000]_N`03001_Nfmk00]_
N`03001_Nfmk008001A_N`03001_Nfmk00a_N`800003Kg/0000006=_N`00K6mk0P001Fmk0P002fmk
00D006mkKg]_N`0000m_N`P001M_N`04001_N`00Kg/2000EKg/8000:Kg/20005Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`06Kg/4000;Kg/00`00Kg]_N`0;Kg/4000FKg/00`00Kg]_N`0>Kg/00`00Kg]_N`02
001QKg/006]_N`8000E_N`03001_N`0000a_N`04001_Nfmk000;Kg/40002Kg/2000KKg/01000Kg/0
00000Vmk00<006mkKg/05fmk00<006mkKg/01P001Vmk0P000fmk00<006mkKg/016mk0P001Fmk1000
0Vmk00<006mk00000P0026mk00<006mkKg/01fmk10000Vmk00<006mkKg/05Fmk00<006mkKg/03fmk
0P000Vmk00<006mkKg/0GVmk001ZKg/20006Kg/00`00Kg/0000=Kg/00`00Kg/00006Kg/50006Kg/2
000JKg/00`00Kg]_N`020003Kg/00`00Kg]_N`0EKg/20008Kg/50003Kg/20002Kg/01000Kg]_Nfmk
0P000Vmk1@001Fmk0P0016mk0P001Fmk00<006mkKg/00fmk1@001Vmk0P005Vmk00<006mkKg/04Fmk
00<006mkKg/00P00GVmk001YKg/20006Kg/00`00Kg/0000?Kg/20002Kg/4000;Kg/00`00Kg/0000I
Kg/01000Kg]_Nfmk0P000fmk00<006mkKg/056mk0P003Fmk200000=_N`00000010002Vmk00<006mk
00001Fmk0`000Vmk00<006mk00000`002Vmk00<006mk00005Vmk00<006mkKg/04Vmk0P000Vmk0P00
G6mk001XKg/20007Kg/00`00Kg/0000C000?Kg/00`00Kg/0000IKg/01000Kg]_Nfmk0P0016mk00<0
06mkKg/04fmk0P004fmk1@003Vmk00<006mk000026mk10003Vmk00<006mk00005Fmk00<006mkKg/0
5Fmk0P000Vmk0P00FVmk001WKg/20007Kg/01000Kg/0000046mk0P0046mk00@006mkKg/001M_N`03
001_Nfmk009_N`8000E_N`80019_N`800003Kg/006mk015_N`800003Kg/006mk00e_N`04001_Nfmk
0009Kg/00`00Kg]_N`0>Kg/01000Kg]_N`0056mk00<006mkKg/056mk1P0000=_N`000000F6mk001V
Kg/20008Kg/00`00Kg/00002000?Kg/2000@Kg/01000Kg]_N`005fmk00<006mkKg/00fmk0P001Vmk
00<006mkKg/03fmk0P0000=_N`00Kg/046mk0P000fmk00<006mkKg/02fmk00@006mkKg/000Q_N`03
001_N`0000m_N`04001_Nfmk000DKg/00`00Kg]_N`0CKg/200000fmk001_N`02Kg/5001FKg/006E_
N`8000U_N`800003Kg/0000000m_N`03001_N`0000m_N`05001_NfmkKg/0000FKg/00`00Kg]_N`03
Kg/20007Kg/00`00Kg]_N`0>Kg/200000fmk001_N`0?Kg/20005Kg/00`00Kg]_N`0:Kg/01000Kg]_
N`0026mk00<006mk00003fmk00D006mkKg]_N`0001=_N`03001_Nfmk01=_N`80009_N`03001_Nfmk
00A_N`8005E_N`00I6mk0P002Fmk00L006mk001_N`00Kg/0000>Kg/01000Kg]_N`003Vmk00D006mk
Kg]_N`0001E_N`03001_Nfmk00A_N`03001_N`0000M_N`03001_Nfmk00a_N`05001_N`00Kg/0000>
Kg/30006Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00001fmk00D006mkKg]_N`0000e_N`03001_Nfmk
009_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_N`00009_N`03001_Nfmk00E_N`8005A_N`00
Hfmk0P002Vmk0P000Vmk00<006mk00003Vmk00D006mkKg]_N`0000i_N`05001_NfmkKg/0000DKg/0
0`00Kg]_N`04Kg/00`00Kg/00008Kg/00`00Kg]_N`0;Kg/01@00Kg/006mk00003Fmk00<006mk0000
26mk00<006mkKg/026mk00<006mkKg/00Vmk00<006mkKg/016mk00D006mkKg]_N`0000e_N`03001_
Nfmk009_N`03001_Nfmk011_N`03001_Nfmk019_N`03001_N`0000A_N`03001_Nfmk00A_N`03001_
N`0005=_N`00HVmk0P002Vmk00<006mk00000Vmk00@006mkKg/000a_N`03001_Nfmk009_N`03001_
Nfmk00a_N`03001_Nfmk009_N`03001_Nfmk015_N`03001_Nfmk00E_N`03001_N`0000Q_N`8000]_
N`05001_N`00Kg/0000;Kg/200000fmk001_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0?Kg/00`00
Kg]_N`0AKg/01000Kg]_N`0016mk00<006mkKg/01Fmk00<006mk0000DVmk001QKg/2000;Kg/20003
Kg/01000Kg]_N`0036mk00<006mkKg/00fmk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/0
46mk00<006mkKg/01Vmk00<006mk00002Vmk00<006mkKg/01fmk00H006mkKg/006mk000:Kg/01000
Kg]_N`0036mk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/00fmk00<0
06mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/03fmk00<006mkKg/046mk00D006mkKg]_N`0000E_
N`03001_Nfmk00A_N`03001_N`00059_N`00H6mk0P002fmk00<006mk00000fmk00@006mkKg/000a_
N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00m_N`03001_Nfmk00I_
N`03001_N`0000]_N`03001_Nfmk00I_N`06001_Nfmk001_N`0026mk0P000Vmk00<006mkKg/036mk
00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/02Vmk
00<006mkKg/00fmk00<006mkKg/03fmk00<006mkKg/046mk00@006mkKg/000I_N`03001_Nfmk00A_
N`04001_Nfmk001AKg/005m_N`8000a_N`8000E_N`04001_Nfmk000;Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`07Kg/00`00Kg/0000;Kg/00`00
Kg]_N`05Kg/01P00Kg]_N`00Kg/000M_N`05001_NfmkKg/0000@Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`0>Kg/00`00Kg]_N`0?Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/00fmk00D006mkKg]_N`00051_
N`00GVmk0P0036mk0P001Vmk00@006mkKg/000]_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_
Nfmk00A_N`03001_Nfmk00e_N`03001_Nfmk00Q_N`03001_N`0000a_N`03001_Nfmk00=_N`04001_
Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00004Vmk00D006mkKg]_N`0000M_N`05001_Nfmk
Kg/00007Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0?Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`1=Kg/005e_
N`8000e_N`8000I_N`05001_NfmkKg/0000:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/01000Kg]_N`0036mk0P000fmk00@006mkKg/000=_
N`04001_NfmkKg/20003Kg/00`00Kg]_N`0AKg/01@00Kg]_Nfmk00001fmk00D006mkKg]_N`0000Q_
N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00a_N`03001_Nfmk00i_N`03001_Nfmk009_
N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk04a_N`00G6mk0P003Vmk
00<006mkKg/01Fmk00D006mkKg]_N`0000Y_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk
00E_N`03001_Nfmk00]_N`03001_Nfmk00U_N`04001_Nfmk000>Kg/01000Kg]_N`000Vmk00D006mk
Kg]_N`00009_N`03001_Nfmk009_N`03001_Nfmk01=_N`04001_Nfmk0007Kg/01000Kg]_N`002Fmk
00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/036mk00<006mkKg/03Fmk00<006mkKg/00fmk
00<006mkKg/026mk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/0Bfmk001KKg/2000>Kg/2
0007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/01000Kg]_N`003Vmk0P000fmk00@006mkKg]_N`<0
00A_N`03001_Nfmk01E_N`8000Q_N`04001_Nfmk000:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0<Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`1:Kg/005Y_N`8000m_N`03001_Nfmk00I_N`03001_Nfmk009_N`03
001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`03
001_Nfmk00Y_N`04001_Nfmk000?Kg/90005Kg/00`00Kg]_N`0DKg/50007Kg/01000Kg]_N`002Vmk
00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/02fmk00<006mkKg/036mk00<006mkKg/00fmk
00<006mkKg/02Vmk00D006mkKg]_N`0000I_N`03001_Nfmk04Y_N`00F6mk0`003fmk0P0026mk00<0
06mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/01fmk00<0
06mkKg/026mk00<006mkKg/02fmk00@006mkKg/000e_N`<000=_N`<00003Kg/006mk00=_N`03001_
Nfmk00e_N`P0009_N`D000E_N`03001_N`0000]_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`03001_
Nfmk00]_N`03001_Nfmk00]_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`05001_NfmkKg/00007Kg/0
0`00Kg]_N`19Kg/005M_N`03001_N`00011_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk
00E_N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk
00a_N`04001_Nfmk000:Kg/20002Kg/20002Kg/01P00Kg]_N`00Kg/0009_N`03001_Nfmk00M_N`L0
00Q_N`800005Kg/006mk001_N`030003Kg/2000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0026mk00<0
06mkKg/0B6mk001FKg/00`00Kg/0000@Kg/20009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/01000
Kg]_N`0026mk0P0016mk0P000Vmk00@006mkKg]_N`800004Kg/006mkKg/8000>Kg/01`00Kg]_Nfmk
001_N`0000A_N`800003Kg/006mk00a_N`03001_Nfmk00A_N`03001_Nfmk00U_N`03001_Nfmk00U_
N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk00e_N`04001_Nfmk0008Kg/00`00Kg]_N`17
Kg/005E_N`03001_N`00015_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_
Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`03001_Nfmk00e_N`05001_
NfmkKg/00005Kg/20006Kg/20002Kg/00`00Kg]_N`03Kg/4000EKg/01@00Kg]_Nfmk00000fmk00<0
06mkKg/00fmk0P003Vmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/0
2Vmk00<006mkKg/01Fmk00<006mkKg/03Fmk00@006mkKg/000U_N`03001_Nfmk04I_N`00E6mk00<0
06mk000046mk10002Fmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/03Fmk00<006mkKg/0
0Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/03Fmk00D006mkKg]_N`0000=_N`8000Q_
N`80009_N`03001_Nfmk009_N`8001I_N`8000A_N`03001_Nfmk009_N`03001_Nfmk00=_N`<000a_
N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk00Q_N`03001_Nfmk00U_N`03001_Nfmk00I_
N`03001_Nfmk00i_N`03001_N`0000Y_N`03001_Nfmk04E_N`00Dfmk00<006mk000046mk00H006mk
000006mk0008Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0>Kg/01000Kg]_Nfmk0`002Vmk00D006mk001_
N`0000A_N`8001E_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00=_N`04001_N`00000;
Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/026mk00<006mkKg/026mk00<006mkKg/01Vmk00<006mk
Kg/03fmk00<006mk00002fmk00<006mkKg/0A6mk001BKg/00`00Kg/0000?Kg/2000016mk001_N`00
0Vmk00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/03Vmk00<006mkKg/0
0Vmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/03Vmk1P0036mk00D006mk001_N`0000=_
N`03001_N`0001A_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk009_N`04001_NfmkKg/2
0009Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/01fmk00<0
06mkKg/046mk0P002fmk00<006mkKg/0A6mk001AKg/01000Kg]_N`003Vmk00L006mkKg]_N`00Kg/0
0002Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/01@00Kg]_
Nfmk000036mk00<006mkKg/00Vmk00<006mkKg/02fmk1P000Vmk0`002Vmk00D006mk001_N`0000=_
N`03001_N`00019_N`8000Q_N`03001_Nfmk00E_N`05001_NfmkKg/00005Kg/20007Kg/01@00Kg]_
Nfmk00003Vmk00<006mkKg/01Vmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/046mk0P00
36mk00<006mkKg/0@fmk001@Kg/01000Kg]_N`003Vmk00D006mkKg]_N`00009_N`05001_NfmkKg/0
0006Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/01@00Kg]_Nfmk000036mk00<0
06mkKg/00Vmk00<006mkKg/026mk0`000Vmk00@006mk0000009_N`03001_Nfmk008000Q_N`03001_
Nfmk0080009_N`05001_NfmkKg/0000@Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/20006Kg/01000Kg]_N`003Vmk00<006mkKg/01Vmk00<006mkKg/01fmk00<0
06mkKg/01fmk00<006mkKg/04Vmk0P0036mk00<006mkKg/0@Vmk001?Kg/01000Kg]_N`003Fmk0P00
16mk00@006mkKg/000A_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk
011_N`04001_Nfmk000=Kg/01000Kg]_N`002Fmk0P0016mk00P006mkKg/006mk001_N`0016mk0P00
1Vmk00<006mkKg/00P0000=_N`00Kg/00fmk00<006mkKg/03Fmk00<006mkKg/02Fmk00<006mkKg/0
1Vmk00D006mkKg]_N`0000Q_N`8000A_N`04001_Nfmk000>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0BKg/2000=Kg/00`00Kg]_N`11Kg/004i_N`04001_Nfmk000=
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00fmk00<006mkKg/01Vmk00D006mk
Kg]_N`0001=_N`03001_N`0000e_N`04001_Nfmk0006Kg/30004Kg/20003Kg/01@00Kg/006mk0000
1Vmk0P0016mk00<006mkKg/00P0000=_N`00Kg/00fmk00<006mkKg/02fmk0P002fmk00<006mkKg/0
26mk00@006mkKg/000Y_N`8000=_N`03001_N`0000m_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03
001_Nfmk00U_N`03001_Nfmk01=_N`03001_Nfmk00a_N`03001_Nfmk041_N`00CFmk00@006mkKg/0
00a_N`8000E_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00I_N`05
001_NfmkKg/0000DKg/2000>Kg/00`00Kg/00003Kg/30006Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
0008Kg/20002Kg/00`00Kg]_N`030005Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09
Kg/01000Kg]_N`002fmk0P0000=_N`00000046mk00<006mkKg/016mk00<006mkKg/01Fmk00<006mk
Kg/02Vmk00<006mkKg/04Fmk10003Vmk00<006mkKg/0?fmk001<Kg/01000Kg]_N`0036mk00<006mk
Kg/01Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00D006mkKg]_N`0000U_N`03001_N`0001E_N`80
00i_N`800004Kg/000000008Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02000:Kg/30003Kg/20005Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0:Kg/00`00Kg/0000=Kg/3000AKg/00`00Kg]_
N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0AKg/01@00Kg]_N`00Kg/00P003Fmk
00<006mkKg/0?Vmk001;Kg/01000Kg]_N`002fmk0P001fmk00<006mkKg/00fmk00<006mkKg/01Vmk
00@006mkKg/000U_N`03001_N`0001A_Nc`000I_N`03001_Nfmk00M_N`8000m_N`03001_Nfmk00]_
N`03001_N`0000e_N`80015_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_
Nfmk011_N`03001_Nfmk008000=_N`03001_Nfmk00Y_N`03001_Nfmk03i_N`00BVmk00@006mkKg/0
00]_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk00I_N`04001_Nfmk000:Kg/2000>Kg/7
00000fmk0000000>Kg/30009Kg/20006Kg/01P00Kg]_N`00Kg/000Y_N`8000=_N`8000E_N`03001_
Nfmk00I_N`03001_Nfmk00m_N`03001_Nfmk00]_N`03001_N`0000U_N`@00004Kg/00000000?Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0>Kg/20003Kg/20004Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`0mKg/004U_N`04001_Nfmk000:Kg/20009Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`07Kg/00`00Kg/0000:Kg/20008Kg/60003Kg/20003Kg/00`00Kg/0000=Kg/00`00Kg]_
N`020007Kg/00`00Kg/00005Kg/01P00Kg]_N`00Kg/000U_N`03001_N`0000=_N`03001_N`0000A_
N`03001_Nfmk00E_N`03001_Nfmk011_N`03001_Nfmk00a_N`8000I_N`<000E_N`800003Kg/00000
00i_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00i_N`03001_Nfmk
00=_N`03001_N`0000A_N`8000]_N`03001_Nfmk03a_N`00B6mk00@006mkKg/000Y_N`03001_Nfmk
00U_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`8000]_N`03001_Nfmk00H000M_N`8000E_N`03001_
N`0000e_N`03001_Nfmk009_N`03001_Nfmk00A_N`04001_Nfmk0004Kg/00`00Kg/00003Kg/00`00
Kg]_N`05Kg/01000Kg]_N`000fmk00@006mkKg/000A_N`03001_Nfmk009_N`8001=_N`03001_Nfmk
00e_N`800003Kg/00000008000M_N`04001_N`000002Kg/2000<Kg/00`00Kg]_N`02Kg/01@00Kg]_
Nfmk00003Vmk00<006mkKg/03Fmk00<006mkKg/016mk00<006mk00001Vmk00<006mkKg/02Fmk00<0
06mkKg/0>fmk0017Kg/01000Kg]_N`002Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/0
2Fmk3`002fmk0P001fmk00@006mkKg/000a_N`03001_Nfmk00=_N`8000A_N`04001_NfmkKg/20002
Kg/00`00Kg/00004Kg/00`00Kg]_N`02Kg/20003Kg/01@00Kg]_Nfmk00000fmk0P000Vmk00D006mk
Kg]_N`0001A_N`03001_Nfmk00m_N`8000]_N`04001_N`000004Kg/2000:Kg/01@00Kg]_Nfmk0000
16mk00<006mkKg/036mk00<006mkKg/02fmk0P001fmk00<006mk00001fmk00<006mkKg/02Fmk00<0
06mkKg/0>Vmk0016Kg/01000Kg]_N`002Fmk0P002Vmk0P0000=_N`00Kg/01Fmk00<006mkKg/01fmk
0P0000=_N`0000002Fmk00<006mkKg/02Fmk0P002Fmk00D006mkKg]_N`0000Y_N`03001_N`0000I_
N`80009_N`03001_Nfmk00=_N`04001_N`000006Kg/01000Kg]_N`001Vmk00<006mk00001Vmk00<0
06mk00000Vmk00<006mkKg/04fmk00<006mkKg/03Fmk10002fmk00D006mk001_N`0000E_N`8000U_
N`04001_Nfmk0003Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`06Kg/01000Kg]_N`00
26mk00<006mkKg/02Fmk00<006mkKg/0>Fmk0014Kg/20002Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08
Kg/30003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/20003Kg/01000Kg/000001fmk00<006mkKg/0
1fmk0P002fmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mk000026mk0`001Vmk0`001Vmk00<0
06mk00001fmk00<006mk00001fmk10005Vmk00<006mkKg/02fmk0P000Vmk0P002fmk00D006mk001_
N`0000M_N`8000M_N`04001_Nfmk0002Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`09Kg/20009Kg/01000
Kg]_N`002Fmk0P002Vmk00<006mkKg/0>6mk0013Kg/01@00Kg]_Nfmk000026mk0P002Fmk0P0000=_
N`00Kg/016mk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/016mk00@006mkKg/000I_N`03
001_Nfmk00E_N`8000i_N`05001_NfmkKg/00009Kg/00`00Kg/0000:Kg/B0008Kg/00`00Kg/00008
Kg/2000GKg/00`00Kg]_N`09Kg/20003Kg/01000Kg]_N`002Vmk00<006mk00000Vmk00<006mkKg/0
1Vmk0P001Vmk00D006mk001_N`00011_N`03001_Nfmk00Q_N`03001_Nfmk00U_N`04001_Nfmk000;
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0gKg/0049_N`05001_NfmkKg/00008Kg/00`00Kg]_N`07Kg/2
0002Kg/00`00Kg]_N`05Kg/20002Kg/00`00Kg]_N`02Kg/20007Kg/01000Kg]_Nfmk0P0016mk00<0
06mkKg/00fmk0P0046mk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mk00002Fmk0P001fmk00<0
06mkKg/01Fmk00<006mk00001fmk00<006mk00001fmk1`004fmk00<006mkKg/01fmk0P001Fmk00@0
06mkKg/000U_N`07001_NfmkKg/006mk00002Vmk0P0016mk00@006mk0000011_N`03001_Nfmk00Q_
N`03001_Nfmk00Y_N`04001_Nfmk000<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0gKg/0045_N`05001_
NfmkKg/00007Kg/20008Kg/20003Kg/00`00Kg]_N`08Kg/00`00Kg/00002Kg/2000:Kg/00`00Kg]_
N`02Kg/20002Kg/01000Kg]_Nfmk0P004Vmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mk0000
26mk00@006mkKg/000I_N`03001_Nfmk00E_N`04001_Nfmk0006Kg/00`00Kg/00006Kg/20002Kg/0
1000Kg]_Nfmk0`0046mk00<006mkKg/01Fmk0P001fmk00D006mkKg]_N`0000Q_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`09Kg/20002Kg/200000fmk001_N`0?Kg/00`00Kg]_N`06Kg/2000=Kg/01000
Kg]_N`003Fmk0P0026mk00<006mkKg/0=Vmk0010Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/01Vmk
0P0016mk00<006mkKg/02Vmk10003Fmk00<006mkKg/00fmk0`0000=_N`00000056mk00<006mkKg/0
16mk00<006mkKg/016mk00<006mk00001fmk00D006mkKg]_N`0000I_N`03001_Nfmk00A_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_N`0000E_N`03001_N`00009_N`03001_Nfmk00A_N`<000e_
N`03001_Nfmk00=_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00E_N`05001_NfmkKg/00003Kg/0
0`00Kg]_N`0:Kg/200000fmk0000000AKg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/01@00Kg]_Nfmk
00003Vmk00<006mkKg/01Vmk00<006mkKg/0=Fmk000oKg/01@00Kg]_Nfmk00001Vmk0P001fmk0P00
1Fmk00<006mkKg/036mk0`003Fmk00<006mkKg/01Fmk0P005Vmk00<006mkKg/01Fmk00<006mkKg/0
0fmk00<006mk00001Vmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/0
0fmk00<006mkKg/00Vmk00<006mk000016mk00@006mkKg/000=_N`03001_Nfmk00I_N`@000Q_N`03
001_Nfmk009_N`8000]_N`03001_Nfmk009_N`03001_Nfmk00E_N`05001_NfmkKg/00003Kg/00`00
Kg]_N`0<Kg/3000@Kg/00`00Kg]_N`04Kg/2000?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`0dKg/003i_N`05001_NfmkKg/00006Kg/00`00Kg]_N`05Kg/20006Kg/0
0`00Kg]_N`0;Kg/400000fmk000000040008Kg/00`00Kg]_N`02Kg/5000EKg/00`00Kg]_N`05Kg/0
0`00Kg]_N`03Kg/00`00Kg/00005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`05Kg/01`00Kg]_Nfmk001_N`0000=_N`05001_NfmkKg/00004Kg/00`00Kg]_N`09Kg/3
0005Kg/00`00Kg]_N`02000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk000016mk
00<006mkKg/02Vmk0P0000A_N`00000000i_N`03001_Nfmk00=_N`03001_Nfmk00m_N`03001_Nfmk
009_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk03=_N`00?Fmk00D006mkKg]_N`0000E_
N`8000I_N`8000M_N`03001_Nfmk00Y_N`80009_N`8000M_N`H0009_N`03001_Nfmk0080009_N`03
001_N`00008001=_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_N`0000E_N`03001_Nfmk00A_
N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00I_N`07001_NfmkKg/006mk00000fmk00@0
06mkKg/000I_N`03001_Nfmk00]_N`@00004Kg/00000000>Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04
Kg/01@00Kg]_Nfmk000016mk00<006mkKg/026mk0P000fmk00<006mkKg/00P0036mk00<006mkKg/0
0Vmk00<006mkKg/046mk00<006mkKg/00Vmk00<006mkKg/03fmk0P001fmk00<006mkKg/0<Vmk000l
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/016mk0P0026mk00<006mkKg/02Fmk0P0016mk00<006mk
000036mk1@0016mk00D006mkKg/006mk0080015_N`03001_Nfmk00M_N`04001_Nfmk0003Kg/01@00
Kg]_Nfmk00001fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01fmk00D006mkKg]_N`00
00=_N`05001_NfmkKg/00006Kg/00`00Kg]_N`0?Kg/C0007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/30002Kg/20009Kg/01000Kg]_Nfmk
0P004fmk00<006mkKg/00Vmk0P004Vmk00<006mkKg/01Fmk00<006mkKg/0<Fmk000kKg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00fmk0P002Vmk00<006mkKg/01fmk0P001Fmk00D006mkKg]_N`0000i_
N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/2000?Kg/00`00Kg]_N`08Kg/00`00Kg/00003Kg/0
1000Kg]_N`002Fmk00D006mkKg]_N`0000A_N`03001_Nfmk00U_N`04001_Nfmk0002Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0>Kg/2000?Kg/01000Kg/000001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/016mk0P000Vmk100000=_N`0000001`001Vmk
00@006mkKg/001E_N`03001_Nfmk00<00003Kg/00000015_N`03001_Nfmk00A_N`03001_Nfmk035_
N`00>Vmk00D006mkKg]_N`0000A_N`8000A_N`8000]_N`03001_Nfmk00I_N`8000M_N`03001_Nfmk
009_N`03001_Nfmk00]_N`8000A_N`03001_Nfmk009_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`08
Kg/00`00Kg/00003Kg/00`00Kg/0000:Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02fmk00D006mk
001_N`0000A_N`03001_Nfmk00M_N`03001_Nfmk00a_N`03001_N`0000m_N`04001_NfmkKg/20004
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00fmk00@006mkKg]_N`800004Kg/000000004Kg/01000
Kg/006mk0P0000=_N`0000000`0016mk00<006mk00005Fmk00@006mkKg/000=_N`03001_Nfmk0080
011_N`8000E_N`03001_Nfmk031_N`00>Fmk00D006mkKg]_N`0000A_N`03001_Nfmk009_N`8000a_
N`03001_Nfmk00E_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00]_N`8000A_N`03001_Nfmk00=_
N`04001_NfmkKg/2000<Kg/00`00Kg]_N`09Kg/20003Kg/2000;Kg/01@00Kg]_Nfmk00000fmk00<0
06mkKg/036mk0`001Fmk00<006mkKg/026mk00<006mkKg/02Vmk00<006mkKg/00P003Fmk00<006mk
Kg/016mk00<006mkKg/00Vmk00@006mkKg/000E_N`03001_Nfmk00=_N`03001_N`0000@000M_N`04
001_Nfmk0002Kg/01000Kg]_Nfmk100000A_N`00000001I_N`<000A_N`03001_Nfmk009_N`<000m_
N`03001_Nfmk00=_N`03001_Nfmk02m_N`00>6mk00D006mkKg]_N`0000=_N`8000=_N`8000e_N`03
001_Nfmk00A_N`8000]_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`8000A_N`03001_Nfmk00A_N`03
001_Nfmk009_N`8000Y_N`03001_Nfmk00Y_N`H000a_N`04001_Nfmk0002Kg/00`00Kg]_N`0=Kg/2
0006Kg/00`00Kg]_N`09Kg/00`00Kg]_N`08Kg/01000Kg]_Nfmk0P003Fmk00<006mkKg/01Fmk0P00
0Vmk00@006mkKg/000E_N`03001_Nfmk00A_N`8000]_N`04001_Nfmk0003Kg/20005Kg/K0006Kg/0
0`00Kg]_N`05Kg/2000>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0^Kg/003M_N`05001_NfmkKg/00003
Kg/01000Kg]_Nfmk0P003Vmk00<006mkKg/00fmk0P003Fmk00<006mkKg/016mk00<006mkKg/02Fmk
00<006mk00000fmk00<006mkKg/01Fmk00<006mkKg/00fmk0P002Fmk00<006mkKg/01fmk0`000Vmk
00<006mkKg/00P002Vmk00@006mkKg/0009_N`03001_Nfmk00Y_N`<00004Kg/000000004Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`07Kg/01`00Kg]_Nfmk001_N`0000a_N`03001_Nfmk00Q_N`800003Kg/0
000000M_N`04001_NfmkKg/200000fmk001_N`0:Kg/01@00Kg]_Nfmk000016mk0P000fmk00@006mk
000001I_N`8000E_N`03001_Nfmk00M_N`<000a_N`03001_Nfmk00=_N`03001_Nfmk02e_N`00=Vmk
00D006mkKg]_N`00009_N`80009_N`8000m_N`03001_Nfmk009_N`8000m_N`03001_Nfmk00A_N`03
001_Nfmk00U_N`03001_N`0000=_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03
001_Nfmk00E_N`80009_N`04001_Nfmk0004Kg/20008Kg/01P00Kg]_N`00Kg/000Y_N`<000A_N`03
001_Nfmk00800003Kg/006mk00a_N`03001_Nfmk00I_N`07001_NfmkKg/006mk00002fmk00<006mk
Kg/02fmk0`001fmk00@006mk000000=_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00A_N`800003
Kg/006mk009_N`03001_Nfmk01=_N`03001_N`0000E_N`03001_Nfmk00U_N`8000]_N`8000A_N`03
001_Nfmk02a_N`00=Fmk00D006mkKg]_N`00009_N`03001_Nfmk0080011_N`04001_NfmkKg/2000@
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/20003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/20006
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg/00007Kg/20007Kg/200000fmk001_N`07Kg/3
0006Kg/00`00Kg]_N`03Kg/4000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg/0000;Kg/0
0`00Kg]_N`0=Kg/:0006Kg/20008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0BKg/01000Kg]_N`0016mk00<006mkKg/02fmk0P002fmk00<006mkKg/00Vmk00<006mk
Kg/0:fmk000dKg/01P00Kg]_Nfmk001_N`800003Kg/00000015_N`03001_Nfmk0080019_N`03001_
Nfmk00M_N`03001_Nfmk00Q_N`03001_N`00009_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`8000A_
N`03001_Nfmk009_N`8000E_N`03001_N`0000U_N`<000A_N`800003Kg/006mk00A_N`<000U_N`03
001_Nfmk00=_N`80009_N`@000U_N`03001_Nfmk009_N`03001_Nfmk00=_N`04001_Nfmk0009Kg/0
0`00Kg]_N`0<Kg/30007Kg/20006Kg/00`00Kg/00007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/0
1000Kg/0000016mk0P004Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00e_N`<000U_N`05001_Nfmk
Kg/0000]Kg/003=_N`08001_NfmkKg/006mk001_N`80019_N`04001_N`00000DKg/00`00Kg]_N`08
Kg/00`00Kg]_N`07Kg/00`00Kg/00002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/20002Kg/00`00
Kg]_N`020007Kg/2000=Kg/20002Kg/30003Kg/3000<Kg/00`00Kg]_N`03Kg/00`00Kg/00005Kg/5
0004Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000Q_N`03001_Nfmk00]_N`80009_N`03001_Nfmk
00E_N`04001_N`000005Kg/00`00Kg/00005Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/01000Kg]_
Nfmk0P0016mk00<006mkKg/03Vmk00<006mkKg/00fmk00D006mkKg]_N`00015_N`8000Q_N`80009_
N`03001_Nfmk02Y_N`00<Vmk00H006mkKg]_N`00Kg/3000CKg/3000FKg/00`00Kg]_N`08Kg/00`00
Kg]_N`07Kg/00`00Kg/00002Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/50009Kg/2000?Kg/20000
0fmk00000003000?Kg/00`00Kg]_N`02Kg/01000Kg]_N`002Vmk100000A_N`00Kg/000M_N`04001_
Nfmk0008Kg/00`00Kg]_N`09Kg/20005Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/01000Kg]_N`0016mk00<006mkKg/01Vmk00D006mkKg]_N`0000I_N`8000=_N`03001_Nfmk00e_
N`03001_Nfmk00A_N`04001_Nfmk000CKg/30007Kg/01000Kg]_N`00:fmk000`Kg/20003Kg/4000@
Kg/6000HKg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/01P00Kg]_N`00Kg/000e_N`03001_Nfmk00Q_
Nb80019_N`03001_Nfmk009_N`05001_NfmkKg/0000=Kg/30008Kg/01000Kg]_N`001fmk00<006mk
Kg/026mk0P001fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/00Vmk00@006mkKg/000=_
N`03001_Nfmk00I_N`05001_NfmkKg/00008Kg/20002Kg/2000=Kg/00`00Kg]_N`05Kg/00`00Kg/0
000FKg/20006Kg/01000Kg]_N`00:Vmk000_Kg/00`00Kg]_N`02Kg/30009Kg/90003Kg/00`00Kg/0
000HKg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/01P00Kg]_N`00Kg/000i_N`03001_Nfmk00I_N`03
001_N`0000Y_N`<0015_N`80015_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00e_N`80
00M_N`04001_Nfmk0007Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`02Kg/01000Kg]_N`000Vmk00<006mkKg/01fmk00<006mk00002fmk00D006mk
Kg]_N`0000a_N`03001_Nfmk00I_N`8001Q_N`8000E_N`04001_Nfmk000YKg/002i_N`03001_Nfmk
009_N`80009_N`T000a_N`04001_N`00000FKg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/01P00Kg]_
N`00Kg/000m_N`03001_Nfmk00E_N`03001_N`0000U_N`03001_Nfmk00<000m_N`04001_N`00000?
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/40006Kg/01000Kg]_N`001Vmk00<0
06mkKg/01Vmk0P002Vmk00<006mkKg/00fmk00<006mkKg/01Fmk0P000Vmk00@006mkKg]_N`8000Y_
N`03001_N`0000a_N`80009_N`03001_Nfmk00U_N`03001_Nfmk00M_N`8001U_N`<000=_N`800003
Kg/006mk02M_N`00;Fmk00<006mkKg/00Vmk6P000fmk0P005Fmk00<006mkKg/036mk00<006mkKg/0
16mk00@006mkKg]_N`80011_N`03001_Nfmk00=_N`05001_NfmkKg/00008Kg/01000Kg]_N`000Vmk
0P0036mk00<006mkKg/00Vmk00<006mkKg/036mk00D006mkKg]_N`0000I_N`03001_Nfmk00]_N`03
001_Nfmk008000A_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00E_N`8000a_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`04001_Nfmk0003Kg/?000=Kg/200000fmk00000009Kg/00`00Kg]_
N`08Kg/5000HKg/20003Kg/00`00Kg/0000WKg/002a_N`04001_NfmkKg/4000GKg/20002Kg/00`00
Kg/0000DKg/00`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0P004Fmk00<006mkKg/00Vmk
00D006mkKg]_N`0000Q_N`05001_NfmkKg/00003Kg/2000:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;
Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/02Vmk0P000Vmk00@006mk0000009_N`03001_Nfmk009_
N`03001_Nfmk009_N`03001_Nfmk00=_N`8000m_N`05001_NfmkKg/0000;Kg/00`00Kg/00002Kg/0
0`00Kg]_N`05Kg/4000016mk001_Nfmk10002fmk0P0000=_N`00Kg/01fmk00<006mkKg/01Vmk0`00
16mk2P0046mk0`0000=_N`0000009fmk000[Kg/00`00Kg]_N`020002Kg/00`00Kg/0000FKg/00`00
Kg/00002Kg/00`00Kg/0000CKg/00`00Kg]_N`0>Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk0P004Vmk
00@006mkKg/000E_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00M_
N`03001_Nfmk00A_N`03001_Nfmk00Y_N`04001_Nfmk0008Kg/00`00Kg]_N`09Kg/20003Kg/01P00
Kg]_N`00Kg/000A_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0?Kg/01@00Kg]_Nfmk000036mk0`00
00=_N`00Kg/00fmk0`001Fmk00<006mkKg/016mk10002Fmk00<006mk00001fmk00<006mkKg/016mk
0P000Vmk0P003Fmk2P002Fmk10009Vmk000ZKg/01000Kg]_N`0016mk00<006mk00005Fmk00@006mk
Kg/0009_N`03001_N`0001=_N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk015_N`03001_N`0000E_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk009_N`8000M_
N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_N`0000U_N`03001_Nfmk00U_N`8000A_N`03001_
Nfmk008000A_N`04001_Nfmk0004Kg/2000BKg/01@00Kg]_Nfmk00003Vmk0P0000=_N`0000000P00
26mk00<006mkKg/026mk10001Vmk100016mk00<006mkKg/016mk00<006mkKg/00Vmk0P005fmk2P00
00A_N`00000002E_N`00:Fmk00@006mk000000E_N`04001_Nfmk000DKg/01@00Kg]_Nfmk00000Vmk
00<006mk00004Vmk00<006mkKg/03fmk00D006mkKg]_N`0000A_NaH000M_N`03001_Nfmk00=_N`03
001_Nfmk00E_N`03001_Nfmk00=_N`8000E_N`03001_Nfmk00I_N`8000Q_N`04001_Nfmk0009Kg/0
0`00Kg]_N`08Kg/00`00Kg/00004Kg/01@00Kg]_Nfmk000016mk00@006mkKg/0009_N`8001A_N`05
001_NfmkKg/0000?Kg/2000<Kg/00`00Kg]_N`0<Kg/40004Kg/30003Kg/00`00Kg]_N`02Kg/20005
Kg/2000QKg/5000TKg/002Q_N`<000Q_N`04001_Nfmk000CKg/00`00Kg]_N`02Kg/01P00Kg]_N`00
Kg/0015_N`03001_Nfmk011_N`05001_NfmkKg/00002Kg/00`00Kg/0000CKg/30006Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/20002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05Kg/0
0`00Kg/0000;Kg/00`00Kg]_N`07Kg/20006Kg/01000Kg/006mk0P000fmk0P0000=_N`0000005Vmk
00D006mkKg]_N`0000e_N`@000e_N`03001_Nfmk00m_N`@0009_N`80009_N`03001_Nfmk008000M_
N`03001_N`0002=_N`8002A_N`009fmk0P002Vmk00D006mkKg]_N`00019_N`03001_Nfmk00=_N`03
001_N`00009_N`03001_Nfmk00e_N`03001_Nfmk015_N`05001_NfmkKg/00002Kg/01000Kg]_N`00
4Vmk0P0000=_N`00000016mk00D006mkKg]_N`0000U_N`03001_Nfmk00I_N`<000a_N`03001_Nfmk
00A_N`03001_N`0000]_N`03001_Nfmk00M_N`8000I_N`03001_N`0000=_N`800004Kg/00000000H
Kg/01@00Kg]_Nfmk00002fmk0P000Vmk00<006mk000036mk00<006mkKg/04fmk2@002Fmk00<006mk
00008Vmk10008fmk000VKg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk00004Fmk00<006mkKg/016mk00@0
06mkKg/0009_N`03001_Nfmk00a_N`03001_Nfmk019_N`06001_Nfmk001_N`0016mk00<006mkKg/0
3fmk0P000fmk00<006mkKg/00Vmk00@006mkKg/000Y_N`03001_Nfmk00M_N`<000]_N`03001_Nfmk
00=_N`8000e_N`03001_Nfmk00E_N`03001_N`0000M_N`/001U_N`03001_N`0000Y_N`8000A_N`04
001_Nfmk000;Kg/00`00Kg]_N`0GKg/3000;Kg/00`00Kg/0000QKg/01@00Kg/006mk00008fmk000U
Kg/3000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`05Kg/00`00Kg/00003Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0CKg/01@00Kg/006mk00001Fmk0P003fmk0P0016mk0P000Vmk00@006mk
Kg/000]_N`03001_Nfmk00E_N`04001_NfmkKg/50007Kg/00`00Kg]_N`02Kg/2000=Kg/00`00Kg]_
N`05Kg/00`00Kg/00006Kg/20007Kg/200000fmk00000002000EKg/00`00Kg/00008Kg/20006Kg/0
1000Kg]_Nfmk0P002Fmk00<006mkKg/05Vmk1@002Vmk00<006mk000086mk00H006mkKg/006mk000S
Kg/002A_N`800003Kg/006mk00Y_N`03001_Nfmk00=_N`03001_Nfmk00e_N`03001_Nfmk00I_N`03
001_N`0000=_N`03001_Nfmk00Y_N`03001_Nfmk01A_N`<000Q_N`03001_Nfmk00]_N`03001_N`00
00I_N`800004Kg/006mk000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/40004Kg/200000fmk0000
000>Kg/00`00Kg]_N`04Kg/01000Kg]_N`001Fmk0`001Vmk00<006mk00001Fmk10004Fmk00<006mk
00001fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/04fmk1P0000=_
N`00Kg/02Vmk00<006mk00007Vmk00<006mkKg/00P000Vmk00<006mkKg/086mk000TKg/20002Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`07Kg/00`00Kg/00003Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`0DKg/30009Kg/00`00Kg]_N`0:Kg/01000Kg]_N`001fmk0`003Vmk
00<006mkKg/00Vmk00<006mkKg/02fmk1@0000A_N`00000000m_N`03001_Nfmk00=_N`04001_Nfmk
0004Kg/200000fmk001_N`05Kg/01000Kg]_N`0026mk10003Fmk00<006mk00001Fmk0P002Fmk00<0
06mkKg/016mk00<006mkKg/01Fmk00<006mkKg/04Fmk0P000Vmk00@006mkKg/0009_N`03001_Nfmk
00Q_N`03001_N`0001e_N`04001_NfmkKg/20002Kg/00`00Kg]_N`0PKg/002=_N`03001_N`00009_
N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk00Q_N`03001_N`0000A_
N`03001_Nfmk00Q_N`03001_Nfmk01A_N`<000Y_N`03001_Nfmk00U_N`04001_Nfmk0009Kg/3000=
Kg/01@00Kg]_Nfmk00004Fmk1@003fmk00<006mkKg/00fmk00<006mk000016mk00D006mk001_N`00
00I_N`04001_Nfmk000<Kg/40009Kg/00`00Kg/00003Kg/2000;Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`0>Kg/30003Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/026mk00<006mk0000
76mk00<006mkKg/00Vmk0P000Vmk00<006mkKg/086mk000RKg/01000Kg]_N`000fmk00<006mkKg/0
1fmk00<006mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/02Fmk00<006mk000016mk00<006mkKg/0
1Vmk00<006mkKg/04fmk100000=_N`0000002Fmk00<006mkKg/026mk00@006mkKg/000Q_N`04001_
N`00Kg/60007Kg/01000Kg]_N`002Vmk20000fmk1@003Fmk00D006mkKg]_N`00009_N`07001_Nfmk
Kg/006mk00000fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk10001Vmk00<006mk
Kg/00P003Fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/036mk0P0016mk0P0016mk00D0
06mkKg]_N`0000U_N`04001_Nfmk000JKg/00`00Kg]_N`02Kg/00`00Kg/00003Kg/00`00Kg]_N`0O
Kg/0025_N`04001_Nfmk0004Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00
Kg]_N`0:Kg/20005Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0@Kg/30002Kg/00`00Kg/00002Kg/20008
Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000M_N`H0009_N`03001_N`00009_
N`P000Y_N`@0009_N`<000Y_N`05001_NfmkKg/00002Kg/01`00Kg]_Nfmk001_N`0000=_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk015_N`@0009_N`<000m_N`03001_Nfmk00M_N`03001_
Nfmk009_N`03001_Nfmk00Y_N`8000E_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00M_
N`04001_Nfmk000IKg/00`00Kg]_N`03Kg/20004Kg/00`00Kg]_N`0OKg/0025_N`04001_Nfmk0005
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0;Kg/20005Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`0=Kg/30004Kg/01000Kg]_N`0016mk0`001Vmk00<006mkKg/01Vmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00Y_N`L0019_N`@000E_N`8000Q_N`05001_
NfmkKg/00002Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk
01A_N`<0015_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00I_N`<000I_N`03001_Nfmk
00A_N`03001_Nfmk00=_N`03001_Nfmk00I_N`04001_Nfmk000HKg/00`00Kg]_N`03Kg/00`00Kg/0
0004Kg/00`00Kg]_N`0OKg/0021_N`05001_NfmkKg/00006Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/20005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/20007
Kg/01@00Kg]_Nfmk00001Vmk0P001Fmk00<006mkKg/01Fmk00D006mkKg]_N`0000=_N`8000E_N`03
001_Nfmk00Q_N`L001=_N`04001_N`00Kg/20006Kg/30006Kg/00`00Kg/00003Kg/00`00Kg/00002
Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/04Fmk0`0000=_N`00000046mk00<0
06mkKg/02Fmk0P000Vmk00<006mkKg/016mk0P0026mk00<006mkKg/01Fmk00<006mkKg/00fmk00<0
06mkKg/01Vmk00D006mkKg]_N`0001I_N`03001_Nfmk00A_N`03001_N`0000E_N`03001_Nfmk01i_
N`007fmk00D006mkKg]_N`0000M_N`03001_Nfmk00I_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03
001_Nfmk00e_N`8000E_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`<000Q_N`03001_Nfmk009_N`03
001_Nfmk00I_N`8000A_N`03001_Nfmk00A_N`05001_NfmkKg/00002Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`04Kg/30004Kg/3000CKg/01`00Kg/006mk001_N`0000Q_N`<000=_N`03001_N`00009_N`03
001_N`00009_N`03001_Nfmk00=_N`05001_NfmkKg/00007Kg/00`00Kg]_N`0>Kg/30003Kg/00`00
Kg/0000@Kg/00`00Kg]_N`0;Kg/00`00Kg/00003Kg/30008Kg/20007Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`05Kg/01@00Kg]_Nfmk00005Fmk00<006mkKg/01Fmk00<006mk00001Fmk00<006mkKg/07Vmk
000NKg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0>Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/2000:Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`07Kg/20003Kg/20003Kg/00`00Kg]_N`03Kg/20009Kg/00`00Kg]_N`040006
Kg/01@00Kg/006mk00004Fmk00<006mk00000Vmk00@006mkKg/000Y_N`<00003Kg/006mk009_N`80
00=_N`03001_Nfmk00=_N`05001_NfmkKg/00008Kg/00`00Kg]_N`0:Kg/30006Kg/01000Kg]_N`00
3fmk00<006mkKg/036mk0P0000=_N`0000002Vmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mk
Kg/016mk00D006mkKg]_N`0001A_N`03001_Nfmk00E_N`04001_Nfmk0005Kg/00`00Kg]_N`0NKg/0
01e_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_Nfmk
00A_N`03001_Nfmk00m_N`03001_Nfmk00A_N`04001_Nfmk0006Kg/3000<Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`09Kg/30002Kg/01000Kg]_N`001Fmk3P002Vmk00D006mk001_N`00015_N`03001_N`00
00=_N`03001_N`0000e_N`X000I_N`04001_Nfmk0009Kg/00`00Kg]_N`07Kg/30008Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0=Kg/2000;Kg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/20008Kg/00`00Kg/00007Kg/00`00Kg]_
N`0MKg/001e_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00U_N`03
001_Nfmk00=_N`03001_Nfmk011_N`8000I_N`03001_N`0000=_N`<000i_N`03001_Nfmk00E_N`03
001_Nfmk00a_N`800004Kg/006mk0003Kg/200000fmk001_N`08Kg/30009Kg/01`00Kg]_Nfmk001_
N`0000m_N`04001_Nfmk0003Kg/01000Kg]_N`003Fmk0P000Vmk0P000Vmk0P001Fmk00@006mkKg/0
00Y_N`03001_Nfmk00=_N`<000]_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00a_N`03
001_N`0000Y_N`03001_Nfmk00U_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk009_N`03
001_Nfmk00i_N`03001_Nfmk00Q_N`03001_N`0000M_N`03001_Nfmk01e_N`0076mk00<006mkKg/0
0fmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/0
4Fmk00<006mkKg/01Fmk0P0000=_N`0000004Fmk00<006mkKg/01Vmk00<006mkKg/03Fmk100000=_
N`0000000fmk00<006mkKg/01Vmk00@006mk000000U_N`07001_NfmkKg/006mk00003fmk00@006mk
Kg/000A_N`04001_Nfmk000;Kg/00`00Kg/00003Kg/01P00Kg]_N`00Kg/000A_N`04001_Nfmk000:
Kg/00`00Kg]_N`03000=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0;Kg/01000Kg]_
N`0026mk0P002fmk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/03Fmk
00<006mkKg/026mk00@006mkKg/000M_N`03001_Nfmk01e_N`006fmk00<006mkKg/016mk00<006mk
Kg/02Fmk00<006mkKg/00fmk00<006mkKg/02fmk00D006mkKg]_N`00019_Nal000U_N`03001_Nfmk
00m_N`<000I_N`03001_Nfmk00A_N`06001_Nfmk001_N`001fmk00<006mkKg/00Vmk00@006mkKg/0
00e_N`05001_NfmkKg/00004Kg/01@00Kg]_Nfmk00002Vmk00@006mkKg/0009_N`80009_N`03001_
N`0000A_N`8000]_N`<0011_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`03001_Nfmk00]_N`05001_
NfmkKg/00006Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/01000Kg]_N`0026mk00<006mkKg/076mk000JKg/00`00Kg]_
N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0036mk1P000Vmk
00<006mkKg/016mk0P004Vmk100026mk00<006mkKg/03Vmk0P0000=_N`00000016mk00<006mkKg/0
0Vmk0P000fmk00<006mk00001Vmk00<006mkKg/00fmk00D006mkKg]_N`0000a_N`05001_NfmkKg/0
0005Kg/01000Kg]_N`002Vmk00@006mkKg/0009_N`80009_N`03001_Nfmk0080009_N`8000M_N`H0
015_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk
00=_N`03001_Nfmk00a_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk
00Y_N`03001_Nfmk00Y_N`04001_Nfmk0008Kg/00`00Kg]_N`0LKg/001Y_N`03001_Nfmk00A_N`03
001_Nfmk00]_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_N`0000Q_N`D000Q_N`03001_Nfmk
00=_N`800003Kg/006mk00m_N`800004Kg/006mk0007Kg/00`00Kg]_N`0<Kg/200000fmk001_N`02
Kg/30002Kg/01000Kg]_N`001Fmk00@006mkKg/000E_N`03001_Nfmk00=_N`05001_NfmkKg/0000;
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00002Fmk00/006mkKg]_N`00Kg/006mk
001_N`0000A_N`04001_N`000004Kg/30003Kg/01000Kg]_N`003fmk00<006mkKg/01fmk00<006mk
Kg/02Fmk00<006mkKg/02Fmk00<006mkKg/016mk00<006mkKg/00P003Vmk00<006mkKg/02fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`04001_Nfmk0009Kg/00`00Kg]_N`0L
Kg/001U_N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_Nfmk009_N`03001_Nfmk00a_N`80009_
N`H000a_N`03001_Nfmk00=_N`05001_N`00Kg/0000@Kg/200001Fmk001_Nfmk00001fmk00<006mk
Kg/02Vmk00@006mkKg/000M_N`<00003Kg/006mk00E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/01@00Kg]_N`00Kg/00P001Fmk0P0000=_N`0000000P00
1Vmk00@006mkKg/000m_N`03001_Nfmk00Q_N`03001_Nfmk00Q_N`03001_Nfmk00Q_N`03001_Nfmk
00E_N`03001_N`00011_N`03001_Nfmk00a_N`04001_Nfmk0005Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`0;Kg/01000Kg]_N`002Vmk00<006mkKg/06fmk000HKg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/3000BKg/00`00Kg]_N`02Kg/01P00Kg]_N`00Kg/000m_N`05
001_N`00Kg/00003Kg/20005Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00002Fmk0P001fmk00D006mk
Kg]_N`0000=_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03
001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00=_N`04001_N`00Kg/20006
Kg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/01Vmk00<006mkKg/036mk00@006mkKg/000Y_N`03001_Nfmk01]_N`0066mk0P001fmk
00<006mkKg/03Fmk00D006mkKg]_N`0000e_N`L0011_N`05001_NfmkKg/00002Kg/01@00Kg]_Nfmk
00003Fmk00<006mk00000fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mk
Kg/00Vmk00<006mkKg/01Vmk0P0000=_N`00Kg/01Fmk00<006mkKg/00Vmk00<006mk00001fmk00<0
06mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/00Vmk00<0
06mkKg/016mk00<006mkKg/016mk0P000Vmk0P000fmk0`002Fmk00<006mkKg/00fmk00<006mkKg/0
2fmk00<006mkKg/02fmk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/01Fmk1@003fmk00<0
06mkKg/03Fmk00@006mkKg/000E_N`03001_Nfmk00E_N`03001_Nfmk00a_N`05001_NfmkKg/0000:
Kg/00`00Kg]_N`0KKg/001Q_N`8000I_N`03001_Nfmk00i_N`05001_NfmkKg/0000<Kg/00`00Kg/0
0003Kg/5000=Kg/01@00Kg]_Nfmk00000Vmk00D006mkKg]_N`0000a_N`04001_Nfmk0003Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/20005Kg/00`00Kg]_N`04Kg/200000fmk001_
N`020005Kg/00`00Kg]_N`02Kg/00`00Kg/00007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/01000
Kg/006mk0P0000A_N`00001_N`8000Q_N`03001_Nfmk00E_N`03001_Nfmk00U_N`03001_Nfmk00a_
N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00E_N`04001_Nfmk0002Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`0>Kg/01000Kg]_N`001Fmk00<006mkKg/016mk00<006mkKg/03Fmk00D006mkKg]_
N`0000]_N`03001_Nfmk01Y_N`005fmk0P0000=_N`00Kg/016mk00<006mkKg/03fmk00@006mkKg/0
00Y_N`80009_N`03001_Nfmk00=_N`800003Kg/0000000]_N`04001_Nfmk0003Kg/01@00Kg]_Nfmk
000036mk00@006mkKg/000=_N`03001_Nfmk00A_N`80009_N`03001_Nfmk00A_N`03001_Nfmk00E_
N`03001_Nfmk00=_N`04001_Nfmk0003Kg/20004Kg/00`00Kg]_N`03Kg/20008Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
000026mk0P000Vmk0P000fmk0P0026mk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/03Fmk
00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/01Fmk00D006mkKg]_N`0000=_N`8000]_N`03
001_Nfmk00m_N`03001_N`0000I_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk009_N`03
001_Nfmk00U_N`03001_Nfmk01Y_N`005fmk0P0000=_N`00Kg/016mk00<006mkKg/046mk00<006mk
00002Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk0P0000A_N`00000000Q_N`03001_N`0000=_N`03
001_Nfmk00=_N`03001_Nfmk00Q_N`04001_Nfmk0005Kg/00`00Kg]_N`05Kg/01000Kg]_N`0016mk
00<006mkKg/01Vmk00@006mkKg]_N`8000=_N`06001_NfmkKg/006mk0P000Vmk00@006mkKg]_N`80
0004Kg/000000006Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`04Kg/01000Kg]_N`0026mk0P0000=_N`00000016mk0P001fmk00<006mkKg/01Vmk
00<006mkKg/02Fmk00<006mkKg/03Vmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/00fmk
0P0016mk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/03fmk00<006mk00001Vmk00D006mk
Kg]_N`00011_N`05001_NfmkKg/0000<Kg/00`00Kg]_N`0JKg/001M_N`80009_N`05001_NfmkKg/0
000CKg/00`00Kg/00007Kg/20004Kg/00`00Kg]_N`08Kg/01000Kg]_Nfmk0`0016mk00<006mk0000
16mk00<006mkKg/00fmk00<006mkKg/01fmk00D006mkKg]_N`0000E_N`03001_Nfmk00I_N`03001_
N`00009_N`8000Q_N`03001_Nfmk008000A_N`03001_Nfmk00=_N`06001_Nfmk001_N`000Vmk00D0
06mkKg]_N`00009_N`<000=_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_
Nfmk00M_N`03001_Nfmk00=_N`04001_Nfmk0009Kg/01000Kg/0000016mk00<006mkKg/01Fmk00<0
06mkKg/026mk00<006mkKg/01fmk00<006mkKg/046mk00<006mkKg/00fmk00<006mkKg/016mk00<0
06mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/00fmk0P001fmk00<006mkKg/04Fmk0P001Vmk00@0
06mkKg/0015_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0IKg/001M_N`8000=_N`04001_Nfmk000D
Kg/00`00Kg/00005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/20004Kg/300000fmk00000005Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/4
000:Kg/30005Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk10001Fmk00<006mkKg/00Vmk0P0000=_N`00
Kg/01Vmk00D006mkKg]_N`0000I_N`03001_Nfmk00M_N`03001_Nfmk00A_N`8000Y_N`80009_N`03
001_Nfmk008000I_N`03001_Nfmk00U_N`03001_Nfmk00M_N`03001_Nfmk011_N`03001_Nfmk00=_
N`03001_Nfmk00=_N`03001_Nfmk009_N`8000Q_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_
Nfmk015_N`8000M_N`80015_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk01U_N`005fmk
0P000fmk00@006mkKg/001A_N`03001_N`0000=_N`8000I_N`03001_Nfmk00a_N`8000E_N`8000E_
N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk00Q_
N`d000M_N`03001_Nfmk00A_N`L000I_N`03001_Nfmk00A_N`<000I_N`04001_Nfmk0007Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`04Kg/=0002Kg/00`00Kg]_N`020006Kg/00`00Kg]_N`0:Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0BKg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`06Kg/20004Kg/00`00Kg]_N`0?Kg/>000@Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`0HKg/001M_N`8000A_N`03001_N`0001E_N`80009_N`03001_Nfmk00I_N`03
001_Nfmk00i_N`8000=_N`03001_N`0000A_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk
009_N`03001_Nfmk00E_N`03001_Nfmk00M_N`8000]_N`<000A_N`03001_Nfmk009_N`@000=_N`80
0004Kg/000000004Kg/00`00Kg]_N`02Kg/20002Kg/30004Kg/00`00Kg/00007Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`02Kg/40009Kg/01@00Kg/006mk00000Vmk0P001Fmk00<006mkKg/02fmk00<006mk
Kg/01Fmk00<006mkKg/04fmk00D006mkKg]_N`0000A_N`03001_Nfmk008000]_N`03001_Nfmk00Q_
N`05001_NfmkKg/0000:Kg/70002Kg/20006Kg/20002Kg/6000:Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`0HKg/001I_N`03001_N`0000A_N`8001I_N`@000U_N`03001_Nfmk011_N`80
0004Kg/006mk0004Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`05Kg/200000fmk001_N`09Kg/01000Kg]_Nfmk0P000Vmk1@000fmk00H006mkKg/0
06mk0004Kg/50002Kg/200000fmk001_N`04Kg/60008Kg/00`00Kg]_N`09Kg/01P00Kg/00000Kg/0
009_N`03001_Nfmk00I_N`09001_N`00Kg/006mk001_N`0000A_N`03001_Nfmk00e_N`03001_Nfmk
00=_N`03001_Nfmk01A_N`05001_NfmkKg/00003Kg/01000Kg]_N`003Fmk00<006mkKg/02Fmk0`00
0fmk20002Fmk0P001Vmk0P0026mk1P000fmk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/0
66mk000FKg/00`00Kg/00005Kg/J0009Kg/00`00Kg]_N`0AKg/30003Kg/01000Kg]_N`002Fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00M_
N`03001_Nfmk00=_N`<000I_N`04001_Nfmk0002Kg/00`00Kg]_N`06Kg/X0003Kg/01@00Kg]_Nfmk
00001Vmk00@006mkKg]_N`800004Kg/006mk0003Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0EKg/01000Kg]_N`000Vmk00@006mkKg/000i_N`03001_Nfmk00]_N`@0011_N`03001_N`00
00E_N`03001_N`0000i_N`@000A_N`03001_Nfmk00i_N`03001_Nfmk01M_N`005Vmk00<006mk0000
1Fmk0P005Vmk00@006mk000000M_N`03001_Nfmk00]_N`H00003Kg/0000000800005Kg/006mkKg/0
0009Kg/01000Kg]_N`001Vmk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk
Kg/01Vmk00<006mkKg/016mk10001Fmk0`000fmk00<006mkKg/01Vmk0P000fmk00<006mkKg/026mk
10001fmk00<006mkKg/01fmk0P0016mk00<006mkKg/00Vmk0P0016mk00@006mkKg]_N`800004Kg/0
06mk0003Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0FKg/01P00Kg/006mk001_N`80
00m_N`03001_Nfmk00U_N`800004Kg/00000000@Kg/00`00Kg/00005Kg/00`00Kg/0000@Kg/30003
Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0GKg/001I_N`04001_Nfmk0004Kg/00`00Kg/0000FKg/00`00
Kg]_N`030004Kg/00`00Kg]_N`05Kg/60007Kg/20002Kg/01@00Kg/006mk00002Fmk00@006mkKg/0
00I_N`03001_Nfmk00M_N`03001_Nfmk008000I_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_
N`00009_N`04001_NfmkKg/20006Kg/00`00Kg]_N`05Kg/20003Kg/00`00Kg]_N`06Kg/2000016mk
001_Nfmk0P001Fmk00<006mkKg/01Vmk00<006mk000016mk00<006mkKg/016mk00@006mkKg/000E_
N`<00005Kg/006mkKg/0000BKg/01@00Kg]_Nfmk00006Vmk0P0000=_N`0000004Fmk00<006mkKg/0
1fmk0P000fmk00<006mkKg/00P003Fmk00@006mkKg/000A_N`05001_NfmkKg/0000>Kg/200000fmk
001_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0GKg/001I_N`04001_Nfmk0004Kg/01000Kg]_N`00
5Fmk00<006mkKg/00fmk0P0000A_N`00Kg]_N`H000a_N`8000A_N`<000]_N`8000I_N`03001_Nfmk
00U_N`8000Q_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_N`0000=_N`800003Kg/006mk00I_
N`03001_Nfmk00A_N`06001_Nfmk001_N`0026mk00D006mkKg]_N`0000A_N`8000A_N`03001_Nfmk
00A_N`05001_NfmkKg/00002Kg/00`00Kg]_N`06Kg/00`00Kg/00005Kg/200001Fmk001_Nfmk0000
4fmk00D006mkKg]_N`0001Y_N`@001=_N`03001_Nfmk00A_N`8000I_N`04001_NfmkKg/2000:Kg/0
1@00Kg]_Nfmk000016mk00D006mkKg]_N`0000e_N`03001_N`00009_N`04001_Nfmk000AKg/00`00
Kg]_N`0FKg/001I_N`04001_Nfmk0004Kg/01@00Kg]_Nfmk000056mk00<006mkKg/01Fmk10004Vmk
0P001Vmk8@002Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00@006mkKg/000E_N`03001_Nfmk00I_
N`03001_Nfmk00A_N`06001_Nfmk001_N`001fmk00<006mkKg/00Vmk00<006mkKg/016mk0P000Vmk
00<006mkKg/00Vmk0P0016mk00@006mkKg/000U_N`T00004Kg/006mk000EKg/00`00Kg/0000HKg/8
000BKg/00`00Kg]_N`02Kg/20008Kg/00`00Kg]_N`03Kg/30007Kg/01@00Kg]_Nfmk00000fmk00<0
06mkKg/00Vmk00<006mkKg/02Vmk00@006mkKg/0009_N`04001_Nfmk000AKg/00`00Kg]_N`0FKg/0
01E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`03Kg/2000BKg/00`00Kg]_N`06Kg/3000AKg/00`00
Kg/00005Kg/2000:Kg/20007Kg/00`00Kg]_N`08Kg/30009Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02
Kg/01@00Kg]_Nfmk00001Fmk0P001fmk00<006mkKg/00fmk00L006mkKg]_N`00Kg/00006Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`06Kg/200001Fmk001_Nfmk00001Vmk00@006mkKg/000M_N`@000E_N`06
001_N`00001_N`005Fmk00<006mk00003Vmk3@0000=_N`00Kg/00Vmk1`002fmk00<006mkKg/00P00
2fmk00<006mkKg/01Fmk0P0016mk00<006mkKg/00Vmk00@006mkKg/000E_N`03001_Nfmk00U_N`04
001_Nfmk0004Kg/2000BKg/00`00Kg]_N`0FKg/001E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`05Kg/200000fmk001_N`0?Kg/00`00Kg/00004Kg/00`00Kg/0
0009Kg/00`00Kg/00007Kg/00`00Kg]_N`07Kg/01@00Kg/006mk000026mk00<006mkKg/016mk00D0
06mkKg]_N`0000A_N`03001_Nfmk009_N`@000I_N`03001_Nfmk00=_N`07001_NfmkKg/006mk0000
16mk0P001Vmk00<006mkKg/026mk0P0000=_N`00Kg/01Vmk00<006mk00001Vmk0`0000=_N`000000
1Fmk00<006mk00000P005fmk00<006mkKg/00fmk2P001Fmk100016mk00<006mk00002Fmk20000fmk
0`003Fmk00<006mkKg/01fmk0P000Vmk00<006mkKg/00Vmk00@006mkKg/000E_N`03001_Nfmk00Q_
N`05001_NfmkKg/00004Kg/2000CKg/00`00Kg]_N`0EKg/001E_N`05001_NfmkKg/00003Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`05Kg/20002Kg/00`00Kg]_N`0<Kg/01000Kg]_N`00
0fmk00@006mkKg/000Q_N`05001_NfmkKg/00005Kg/00`00Kg]_N`08Kg/00`00Kg/00002Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001Fmk00D006mk001_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_N`0000=_N`03001_Nfmk00I_N`03001_Nfmk
00Y_N`8000M_N`03001_N`0000E_N`03001_N`0000=_N`8000=_N`04001_NfmkKg/O000;Kg/40008
Kg/00`00Kg/0000AKg/4000@Kg/00`00Kg]_N`08Kg/20005Kg/00`00Kg/00006Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0EKg/001E_N`05001_
NfmkKg/00003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`05Kg/00`00Kg/00002Kg/2
000<Kg/01@00Kg]_N`00Kg/00P000fmk00<006mkKg/01Vmk00D006mkKg]_N`0000E_N`03001_Nfmk
00M_N`04001_Nfmk0003Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000016mk00<0
06mkKg/00Vmk0P0000E_N`00Kg]_N`0000A_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_N`00
009_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`<00003Kg/0000000E_N`03001_N`0000=_N`800003
Kg/006mk00=_N`8000=_N`03001_N`000080009_N`H000m_N`8000a_N`@000a_N`03001_N`00019_
N`D000i_N`03001_Nfmk00U_N`<000=_N`03001_N`0000I_N`03001_Nfmk00E_N`8000A_N`03001_
Nfmk00=_N`04001_N`00000AKg/00`00Kg]_N`0EKg/001E_N`05001_NfmkKg/00003Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`05Kg/00`00Kg/00004Kg/00`00Kg]_N`08Kg/01P00Kg]_
N`00Kg/000E_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00I_N`05
001_NfmkKg/00004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk0P000Vmk00@006mkKg/000=_N`05001_NfmkKg/00006Kg/01000Kg/000002Vmk00<006mk
Kg/01Vmk0P000Vmk00@006mkKg]_N`<000=_N`800003Kg/00000009_N`03001_Nfmk00=_N`07001_
N`00Kg/006mk00000Vmk00<006mkKg/01Vmk1P002Fmk00<006mk00001fmk100046mk00<006mk0000
46mk0P000Vmk00<006mkKg/00P003Fmk00<006mkKg/01fmk00D006mkKg]_N`00009_N`8000M_N`03
001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk009_N`05001_Nfmk001_N`02000@Kg/00`00Kg]_
N`0DKg/001E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`04
Kg/01000Kg]_N`0016mk00<006mkKg/01fmk00<006mkKg/00P001Vmk00<006mkKg/016mk00<006mk
Kg/00fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk
Kg/00Vmk00<006mkKg/00Vmk00@006mkKg/000I_N`03001_Nfmk009_N`80009_N`04001_Nfmk0003
Kg/01@00Kg]_Nfmk00001Vmk0P0036mk00<006mkKg/01Fmk00D006mkKg]_N`0000M_N`800004Kg/0
00000004Kg/00`00Kg]_N`03Kg/01000Kg/006mk0P000fmk00<006mkKg/036mk1P000Vmk00@006mk
Kg/000=_N`@001=_N`05001_NfmkKg/0000>Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/02Vmk00<0
06mkKg/01fmk00<006mkKg/00Vmk10001fmk00<006mkKg/00fmk00<006mkKg/01Fmk00D006mkKg]_
N`0000A_N`04001_Nfmk000?Kg/00`00Kg]_N`0DKg/001A_N`03001_Nfmk009_N`05001_NfmkKg/0
000<Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk0P001Vmk00D006mkKg]_
N`0000M_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00=_N`07001_NfmkKg/006mk00001fmk00L006mkKg]_
N`00Kg/00002Kg/01@00Kg]_Nfmk00000fmk00<006mk00001Vmk0`0036mk00<006mkKg/00fmk0P00
16mk00<006mkKg/01fmk0P001Fmk00<006mkKg/016mk00@006mkKg/000E_N`03001_Nfmk019_N`T0
01M_N`05001_NfmkKg/0000<Kg/20004Kg/00`00Kg]_N`04Kg/2000;Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`04Kg/20008Kg/01@00Kg]_Nfmk00001fmk00D006mkKg]_N`0000I_N`03001_Nfmk008000e_
N`03001_Nfmk01A_N`0056mk00<006mkKg/00Vmk00D006mkKg]_N`0000e_N`03001_Nfmk00]_N`03
001_Nfmk00=_N`05001_NfmkKg/00007Kg/00`00Kg]_N`03Kg/01P00Kg/00000Kg/000I_N`03001_
Nfmk009_N`03001_Nfmk00I_N`05001_NfmkKg/00007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`02Kg/01000Kg]_N`000Vmk00<006mkKg/01Fmk00@006mkKg]_N`8000A_N`05001_Nfmk
Kg/00002Kg/00`00Kg/00004Kg/200000fmk001_N`040008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`06Kg/30004Kg/00`00Kg]_N`05Kg/01000Kg/006mk0P000fmk00<006mkKg/036mk
1P000Vmk00D006mkKg/006mk00D001A_N`05001_NfmkKg/0000;Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`06Kg/2000:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg/000020006Kg/01000Kg]_N`00
26mk00@006mkKg/000M_N`03001_Nfmk009_N`8000a_N`03001_Nfmk01=_N`0056mk00<006mkKg/0
0Vmk00D006mkKg]_N`0000i_N`03001_Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00E_N`07001_NfmkKg/006mk000016mk00<006mkKg/00fmk00D006mkKg]_N`0000U_N`05001_
NfmkKg/00006Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00000Vmk00<006mk0000
26mk00@006mkKg]_N`8000A_N`03001_Nfmk009_N`04001_N`000002Kg/30004Kg/00`00Kg]_N`02
Kg/30005Kg/00`00Kg]_N`020007Kg/00`00Kg]_N`04Kg/20002Kg/20002Kg/00`00Kg]_N`07Kg/2
0003Kg/01000Kg]_N`0026mk1P0026mk00H006mkKg/006mk0004Kg/3000@Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`06Kg/20007Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`03Kg/01P00Kg]_Nfmk001_N`<000=_N`03001_N`0000U_N`04001_Nfmk0008Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0CKg/001A_N`03001_Nfmk009_N`04001_Nfmk000@Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/200000fmk00000006Kg/0
0`00Kg]_N`02Kg/01000Kg]_N`002Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00E_N`03001_Nfmk
00I_N`04001_Nfmk0002Kg/20009Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk00=_N`D000M_N`03
001_Nfmk00E_N`@00004Kg/000000009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/200000fmk001_
N`09Kg/00`00Kg]_N`03Kg/30002Kg/6000=Kg/200000fmk001_N`02Kg/00`00Kg]_N`04Kg/3000=
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/20009Kg/00`00Kg]_N`09Kg/20008Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0P0000=_N`0000002Fmk00@006mkKg/0
00U_N`03001_Nfmk00A_N`8000U_N`03001_Nfmk01=_N`0056mk00<006mkKg/00Vmk00@006mkKg/0
015_N`8000Y_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00M_N`<000M_N`80009_N`04
001_Nfmk000:Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Fmk00<006mkKg/01fmk00@006mk001_
N`8000Y_N`06001_Nfmk001_N`001Fmk00<006mkKg/00fmk6P002Vmk00@006mkKg]_N`8000E_N`03
001_N`0001H001=_N`800003Kg/006mk009_N`03001_Nfmk00M_N`@000U_N`03001_Nfmk00=_N`03
001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00]_N`8000I_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00007Kg/20003Kg/30009Kg/00`00Kg/0000;Kg/00`00Kg]_N`05Kg/20008Kg/00`00Kg]_N`0B
Kg/001A_N`03001_Nfmk009_N`04001_Nfmk000CKg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`06Kg/01000Kg]_Nfmk10001Fmk00D006mk001_N`0000]_N`05001_Nfmk
Kg/00004Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg/00002000:Kg/00`00Kg/00002Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/2000:Kg/30009Kg/70005Kg/00`00Kg]_N`020007Kg/20000
0fmk001_N`05Kg/400000fmk00000004Kg/2000016mk000000004Fmk0`001Fmk00<006mkKg/02Vmk
0`001Vmk00<006mkKg/00fmk00@006mkKg]_N`8000]_N`03001_Nfmk00i_N`03001_Nfmk00A_N`03
001_Nfmk009_N`04001_Nfmk000:Kg/01000Kg]_N`000Vmk0`001Vmk0P003Fmk00<006mkKg/01Vmk
00<006mkKg/01Fmk00<006mkKg/04Vmk000CKg/00`00Kg]_N`03Kg/01000Kg]_N`0056mk00<006mk
Kg/01fmk00D006mkKg]_N`0000I_N`03001_Nfmk00E_N`03001_Nfmk00E_N`D00004Kg/00000000<
Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/01fmk00<006mkKg/02Fmk0`002fmk00<006mk00000Vmk
00<006mkKg/00fmk00<006mkKg/00Vmk0P002Fmk00@006mk000000Q_N`05001_N`00Kg/00003Kg/4
000016mk000000002Fmk0P0000A_N`00Kg]_N`@000=_N`04001_NfmkKg/20002Kg/00`00Kg/00003
Kg/3000>Kg/30005Kg/00`00Kg]_N`0=Kg/400000fmk001_N`06Kg/3000=Kg/00`00Kg]_N`0?Kg/2
0004Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02Fmk00<006mk00001Fmk100000=_N`0000003Vmk
00<006mkKg/01fmk0P001Fmk00<006mkKg/04Vmk000CKg/00`00Kg]_N`03Kg/01000Kg]_N`005Fmk
00<006mkKg/01Vmk00D006mkKg]_N`0000I_N`03001_Nfmk00A_N`03001_Nfmk00]_N`@000e_N`03
001_N`0000=_N`03001_Nfmk00Q_N`03001_Nfmk00Y_N`03001_Nfmk00Y_N`05001_N`00Kg/00007
Kg/01000Kg]_N`000Vmk00<006mkKg/01Fmk00@006mkKg]_N`8000I_N`04001_Nfmk0002Kg/J0006
Kg/00`00Kg]_N`04Kg/20002Kg/00`00Kg]_N`04Kg/3000;Kg/20007Kg/00`00Kg]_N`0@Kg/M000@
Kg/20003Kg/01000Kg]_N`000Vmk00<006mkKg/02Fmk8P0026mk0P0016mk00<006mkKg/04Fmk000C
Kg/00`00Kg]_N`03Kg/01000Kg]_N`005Vmk00<006mkKg/01Fmk00D006mkKg]_N`0000I_N`03001_
Nfmk00A_N`03001_Nfmk00U_N`<00003Kg/00000008000]_N`03001_N`0000=_N`03001_Nfmk00Q_
N`03001_Nfmk00U_N`@000U_N`03001_N`00009_N`03001_Nfmk00E_N`04001_Nfmk0002Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`02Kg/20004Kg/20003Kg/01000Kg/000001Vmk00<006mk00002Vmk0`00
00A_N`00000000E_N`03001_Nfmk009_N`D00003Kg/006mk00Q_N`<000Q_N`03001_N`0000I_N`03
001_Nfmk011_N`<000I_N`<000a_N`8000=_N`L000]_N`04001_Nfmk0002Kg/00`00Kg/00008Kg/4
0002Kg/20009Kg/3000>Kg/20002Kg/40006Kg/01@00Kg]_Nfmk00004fmk000CKg/00`00Kg]_N`03
Kg/01000Kg]_N`005fmk00<006mkKg/01Fmk00@006mkKg/000M_N`03001_Nfmk009_N`03001_Nfmk
00M_N`<000E_N`D000U_N`03001_N`00009_N`03001_Nfmk00U_N`03001_Nfmk00Q_N`8000=_N`80
00M_N`03001_N`00009_N`03001_Nfmk00E_N`03001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk
00=_N`03001_N`00009_N`03001_Nfmk00=_N`800003Kg/006mk00E_N`03001_N`0000U_N`80009_
N`05001_N`00Kg/00003Kg/00`00Kg]_N`0300000fmk001_N`0200000fmk001_N`0;Kg/30004Kg/2
0002Kg/20005Kg/00`00Kg]_N`0=Kg/2000016mk001_N`001Fmk00<006mkKg/00P002Vmk0P002Vmk
1P001Vmk0P0000=_N`00Kg/00P0016mk1@001Vmk00<006mk000026mk0`003Fmk00<006mk00001Vmk
1@000Vmk0P0000=_N`00Kg/04Vmk000CKg/00`00Kg]_N`03Kg/01000Kg]_N`0066mk00<006mkKg/0
16mk00@006mkKg/000M_N`05001_NfmkKg/00008Kg/20008Kg/01@00Kg]_N`00Kg/00P001fmk00D0
06mk001_N`0000a_N`03001_Nfmk00M_N`03001_N`0000E_N`03001_Nfmk00A_N`03001_N`00009_
N`03001_Nfmk00I_N`8000=_N`03001_Nfmk009_N`03001_Nfmk00A_N`05001_N`00Kg/00006Kg/2
0002Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk000026mk00<006mk00000Vmk0P000Vmk0P0000A_N`00
000000=_N`03001_N`00009_N`03001_N`0000i_N`<00003Kg/006mk00A_N`03001_Nfmk00=_N`03
001_Nfmk00]_N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06
Kg/01000Kg]_N`003fmk1`0000=_N`0000000P0000=_N`0000000P002fmk00@006mkKg/000I_N`03
001_Nfmk008000]_N`03001_N`0000a_N`L0019_N`004Vmk00<006mkKg/016mk00@006mkKg/001U_
N`03001_Nfmk00=_N`04001_Nfmk0008Kg/01000Kg]_N`001Fmk0`002Vmk00D006mkKg]_N`00009_
N`<000A_N`04001_N`00000=Kg/00`00Kg]_N`06Kg/01000Kg]_N`001Vmk0P0016mk0P000fmk00<0
06mkKg/01Fmk0P0016mk00D006mkKg]_N`0000M_N`03001_Nfmk00T000=_N`03001_Nfmk009_N`05
001_NfmkKg/00008Kg/00`00Kg/00004Kg/60003Kg/20002Kg/01P00Kg]_N`00Kg/0015_N`<000E_
N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_Nfmk009_N`04001_NfmkKg/20002Kg/00`00Kg]_
N`03Kg/20006Kg/01000Kg]_N`005Vmk1P003fmk00@006mkKg]_N`8000A_N`03001_Nfmk008000Y_
N`04001_Nfmk000@Kg/3000BKg/0019_N`03001_Nfmk00A_N`03001_N`0001]_N`03001_Nfmk009_
N`03001_N`0000U_N`03001_N`0000=_N`<000e_N`03001_Nfmk009_N`03001_Nfmk009_N`8000=_
N`03001_N`0000e_N`03001_Nfmk00E_N`05001_NfmkKg/00008Kg/20002Kg/20002Kg/00`00Kg]_
N`03Kg/400000fmk00000003Kg/00`00Kg/00009Kg/200000fmk001_N`05Kg/20002Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/01Fmk00<006mk00000fmk00L006mk001_N`00Kg/00002Kg/00`00Kg]_
N`02Kg/01000Kg]_Nfmk0P003fmk100000=_N`00000016mk00<006mkKg/00Vmk00<006mkKg/026mk
00<006mkKg/00fmk00<006mkKg/00fmk00<006mk00001fmk0P000fmk00D006mkKg]_N`0001A_N`@0
0003Kg/00000011_N`03001_Nfmk00=_N`04001_Nfmk0003Kg/00`00Kg/00008Kg/01@00Kg]_Nfmk
000046mk0`004Vmk000BKg/00`00Kg]_N`04Kg/00`00Kg/0000LKg/20003Kg/2000:Kg/5000AKg/0
0`00Kg]_N`02Kg/20004Kg/200000fmk0000000>Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00002fmk
0`000fmk00<006mk00000`000fmk00@006mk001_N`800003Kg/0000000Y_N`800003Kg/006mk00E_
N`80009_N`05001_NfmkKg/00005Kg/00`00Kg]_N`04Kg/01000Kg]_N`000fmk00T006mk001_N`00
Kg/006mk00001Fmk00L006mkKg]_N`00Kg/0000;Kg/400000fmk00000003Kg/20003Kg/20002Kg/0
0`00Kg]_N`06Kg/20006Kg/00`00Kg]_N`04Kg/20009Kg/200000fmk001_N`02Kg/00`00Kg]_N`0?
Kg/30005Kg/00`00Kg/0000?Kg/00`00Kg]_N`04Kg/00`00Kg/00003Kg/00`00Kg/00007Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0=Kg/01000Kg]_N`004Vmk000BKg/00`00Kg]_N`05Kg/2000NKg/00`00
Kg]_N`020009Kg/3000DKg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/3000>Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/R0003Kg/00`00Kg]_N`02Kg/01P00Kg]_N`00Kg/0009_N`03
001_Nfmk00E_N`03001_Nfmk00=_N`04001_Nfmk0002Kg/01000Kg]_Nfmk1@001Vmk00<006mkKg/0
0Vmk0P002Fmk0P0000=_N`0000000Vmk00<006mk000016mk0P000fmk00@006mkKg/000I_N`03001_
Nfmk00E_NaH000A_N`03001_Nfmk00]_N`@000M_N`05001_NfmkKg/0000>Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`02Kg/01000Kg]_N`001Fmk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/00Vmk
00<006mkKg/03fmk000BKg/00`00Kg]_N`05Kg/2000OKg/01000Kg/000001Vmk1P0056mk00<006mk
Kg/01Fmk00<006mkKg/00Vmk00<006mkKg/00P0036mk00<006mkKg/00fmk00<006mkKg/00Vmk00<0
06mkKg/026mk1P000Vmk00<006mkKg/016mk00@006mkKg/0009_N`<000Q_N`<00005Kg/006mkKg/0
0004Kg/01000Kg]_Nfmk0P000Vmk00<006mkKg/01Vmk00<006mkKg/00Vmk00@006mkKg/0009_N`03
001_N`0000@00004Kg/000000004Kg/00`00Kg]_N`02Kg/20007Kg/20002Kg/00`00Kg]_N`02Kg/0
0`00Kg/00006Kg/3000016mk001_N`001Fmk00<006mkKg/00Vmk100000=_N`0000001fmk00<006mk
Kg/026mk0`000Vmk00<006mkKg/01fmk10002fmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mk
Kg/016mk00@006mk0000009_N`04001_Nfmk0004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/20005
Kg/00`00Kg]_N`0?Kg/0019_N`03001_Nfmk00E_N`80021_N`<000A_N`8000=_N`800003Kg/00000
01=_N`03001_Nfmk00E_N`80009_N`03001_Nfmk009_N`8000Y_N`03001_Nfmk009_N`03001_Nfmk
009_N`03001_Nfmk00M_N`800003Kg/006mk00800005Kg/00000Kg/00005Kg/2000016mk001_N`00
0fmk00<006mkKg/00Vmk0`000Vmk00@006mkKg/0009_N`05001_NfmkKg/00004Kg/30009Kg/01@00
Kg]_Nfmk000016mk0P0000E_N`00Kg]_N`00009_N`05001_N`00Kg/00002Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`02Kg/30002Kg/20004Kg/01000Kg]_N`002Fmk1@000Vmk0P000Vmk0`0016mk00@006mk
Kg/000I_N`03001_Nfmk00M_N`80009_N`04001_Nfmk0005Kg/3000?Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg/0009_N`03001_Nfmk00A_
N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk00m_N`004Fmk00<006mkKg/01Vmk0P008Fmk
0P0000A_N`00000000A_N`03001_N`0000=_N`03001_Nfmk011_N`03001_Nfmk00M_N`8000M_N`80
00Q_N`05001_NfmkKg/00005Kg/00`00Kg]_N`05Kg/20002Kg/00`00Kg/00002Kg/01P00Kg]_N`00
Kg/000A_N`D000A_N`03001_Nfmk008000A_N`03001_Nfmk009_N`04001_Nfmk0002Kg/00`00Kg]_
N`02Kg/3000:Kg/01000Kg]_N`0016mk0`0016mk00<006mkKg/00P000Vmk0`001Vmk0P0000=_N`00
000016mk00<006mkKg/016mk00@006mkKg/000]_N`<00003Kg/0000000<000M_N`05001_NfmkKg/0
0006Kg/00`00Kg]_N`06Kg/20003Kg/300000fmk00000002000BKg/00`00Kg]_N`04Kg/00`00Kg]_
N`09Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/30002Kg/00`00Kg/00007Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0?Kg/0015_N`03001_Nfmk00I_N`80021_N`@000M_N`03001_N`00
00A_N`03001_Nfmk00m_N`03001_Nfmk00Q_N`<000M_N`<000E_N`04001_Nfmk0006Kg/00`00Kg]_
N`02Kg/30004Kg/00`00Kg/00002Kg/01000Kg]_Nfmk10000Vmk00<006mk00004@0016mk0`000Vmk
00<006mkKg/00Vmk10002Fmk00@006mkKg/000A_N`03001_Nfmk00A_N`03001_Nfmk009_N`h000A_
N`8000I_N`05001_NfmkKg/0000<Kg/4000:Kg/00`00Kg]_N`03Kg/20004Kg/00`00Kg]_N`06Kg/2
0005Kg/4000DKg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/5
0007Kg/00`00Kg]_N`08Kg/2000:Kg/00`00Kg]_N`0>Kg/0015_N`03001_Nfmk00I_N`8001]_N`D0
00=_N`03001_Nfmk00A_N`04001_Nfmk0005Kg/2000?Kg/00`00Kg]_N`08Kg/200000fmk00000004
0004Kg/20003Kg/00`00Kg/00007Kg/00`00Kg]_N`020006Kg/01000Kg]_N`000fmk00<006mkKg/0
0Vmk0`0000=_N`00000016mk0`0000=_N`00Kg/01Fmk00<006mk00000`000fmk0`000fmk1@0000=_
N`0000000P001Vmk00<006mk00000Vmk10001Fmk00@006mkKg]_N`80009_N`8000I_N`03001_N`00
00=_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00E_N`@0009_N`03001_Nfmk00U_N`03
001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00E_N`8000A_N`05001_N`00001_N`08000;Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/40003Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0>Kg/0015_N`03001_Nfmk00I_N`80
01I_N`D000Q_N`03001_Nfmk00A_N`04001_Nfmk0007Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`06Kg/0
0`00Kg/00007Kg/800000fmk00000007Kg/01000Kg/000001fmk00D006mkKg]_N`0000=_N`03001_
Nfmk00A_N`P000A_N`03001_Nfmk00A_N`03001_N`0000=_N`H00003Kg/00000009_N`800003Kg/0
06mk00=_N`D00004Kg/00000Kg/20002Kg/00`00Kg/00004Kg/01000Kg]_Nfmk0P000Vmk0P001Fmk
00D006mkKg/006mk008000U_N`03001_Nfmk009_N`03001_Nfmk00D000I_N`03001_Nfmk00U_N`03
001_Nfmk00I_N`05001_NfmkKg/00006Kg/00`00Kg/00004Kg/01000Kg/006mk0P001fmk20000fmk
00<006mkKg/026mk0P001fmk00<006mkKg/00Vmk00<006mkKg/00fmk00H006mkKg/006mk0002Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0>Kg/0015_N`03001_Nfmk
00I_N`03001_Nfmk011_N`D000i_N`03001_Nfmk009_N`04001_Nfmk0009Kg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`06Kg/01000Kg]_N`0036mk3P0026mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mk
Kg/01Fmk0P002Fmk00<006mkKg/00Vmk00D006mkKg]_N`0000I_N`L00005Kg/006mkKg/00008Kg/4
0003Kg/01@00Kg/006mk00000fmk00X006mkKg/006mk001_N`00Kg/000A_N`04001_NfmkKg/30009
Kg/00`00Kg]_N`03Kg/3000<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk00001Fmk
00<006mk00000fmk00D006mkKg]_N`00009_N`8000e_N`D000]_N`03001_Nfmk00A_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg/000E_N`03001_Nfmk00A_N`8000i_N`03001_
Nfmk00i_N`004Fmk00<006mkKg/01Vmk00<006mkKg/02Vmk1P0056mk00D006mkKg]_N`00009_N`03
001_Nfmk00Q_N`8000a_N`03001_Nfmk00I_N`04001_Nfmk000>Kg/00`00Kg/00007Kg/20007Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/30008Kg/00`00Kg]_N`02Kg/01@00Kg]_
Nfmk00001Vmk0P000fmk0P0000=_N`00Kg/00Vmk0P001Vmk0P0000=_N`00Kg/00Vmk00<006mk0000
0Vmk0P0000]_N`00Kg]_N`00Kg/006mk001_N`00009_N`80009_N`@00003Kg/0000000M_N`04001_
NfmkKg/4000=Kg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk000016mk00<006mk0000
0fmk00D006mkKg]_N`0000A_N`8000e_N`03001_N`0000<000U_N`03001_Nfmk00=_N`04001_Nfmk
0004Kg/20004Kg/01`00Kg]_Nfmk001_N`0000A_N`03001_Nfmk00A_N`03001_Nfmk00m_N`03001_
Nfmk00e_N`0046mk00<006mkKg/01fmk00<006mkKg/01Fmk1@006fmk00<006mk00000fmk00<006mk
Kg/02Vmk00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mk
Kg/00P001Fmk0P001Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/0
0P001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00=_N`05001_N`00Kg/00002Kg/20005Kg/00`00
Kg]_N`02Kg/01@00Kg/006mk00000fmk00<006mk000016mk00@006mk0000009_N`80009_N`04001_
N`00Kg/3000016mk001_N`000fmk0`0016mk00D006mk000006mk00800003Kg/006mk00]_N`03001_
Nfmk00I_N`03001_Nfmk00]_N`04001_Nfmk0003Kg/01000Kg]_N`000Vmk00<006mkKg/00fmk00<0
06mkKg/00fmk0P002fmk00<006mk00000fmk0`001fmk00<006mkKg/00Vmk00@006mkKg/000=_N`03
001_Nfmk00=_N`03001_Nfmk00=_N`03001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk011_N`03
001_Nfmk00e_N`0046mk00<006mkKg/01fmk00<006mkKg/01@0086mk00<006mk00000fmk00<006mk
Kg/02fmk00<006mkKg/02Fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mk
Kg/00fmk00<006mkKg/00Vmk00<006mk000016mk00<006mkKg/016mk00<006mkKg/01Fmk00<006mk
Kg/00Vmk0P0016mk00<006mkKg/00fmk00@006mkKg/000M_N`05001_NfmkKg/00002Kg/00`00Kg/0
0002Kg/20006Kg/01P00Kg/00000Kg/000=_N`06001_Nfmk001_N`001Fmk0`000Vmk0P000Vmk1000
0fmk00D006mkKg]_N`0000E_N`800004Kg/000000003Kg/01@00Kg/006mk00002fmk00<006mkKg/0
1Vmk00<006mkKg/036mk00@006mkKg/0009_N`06001_Nfmk001_N`001fmk00<006mkKg/016mk0P00
26mk00D006mkKg]_N`0000E_N`8000I_N`07001_NfmkKg/006mk00000Vmk0P001Vmk00<006mkKg/0
16mk00<006mk00000Vmk00@006mkKg]_N`8001=_N`03001_Nfmk00e_N`0046mk00<006mkKg/01fmk
:P0016mk00<006mkKg/036mk0P002Fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/02Fmk
00<006mkKg/016mk00L006mkKg]_N`00Kg/00004Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`02Kg/20005Kg/20003Kg/01000Kg]_N`001fmk00D006mkKg]_N`0000=_Na8000=_N`06001_
Nfmk001_N`001Vmk2P000fmk0P0016mk00<006mkKg/01Fmk0P001Fmk00<006mk00000Vmk00<006mk
Kg/026mk00<006mkKg/01Vmk00<006mkKg/03Fmk0`000Vmk00H006mkKg/006mk0007Kg/00`00Kg]_
N`06Kg/20006Kg/01@00Kg]_Nfmk00001fmk0`0016mk00P006mkKg/006mk001_N`0026mk00<006mk
Kg/01Fmk0P000Vmk00@006mkKg/001E_N`03001_Nfmk00e_N`0046mk00<006mkKg/01fmk00<006mk
Kg/09Fmk0P0016mk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/01Fmk
00<006mkKg/01fmk00<006mkKg/01Vmk0P0000E_N`00Kg]_N`00009_N`03001_Nfmk00E_N`03001_
Nfmk00I_N`04001_NfmkKg/20007Kg/20002Kg/20009Kg/00`00Kg/00002Kg/30003Kg/00`00Kg/0
0006Kg/01@00Kg]_N`00Kg/00P000Vmk0P000fmk00@006mkKg]_N`800003Kg/006mk00@0009_N`04
001_Nfmk0006Kg/00`00Kg]_N`05Kg/20004Kg/01000Kg]_N`000fmk00<006mkKg/026mk00<006mk
Kg/016mk00<006mkKg/046mk0P0000A_N`00Kg]_N`8000U_N`03001_Nfmk00M_N`8000=_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`<0009_N`06001_N`00001_N`002Fmk00<006mkKg/01Vmk0`000Vmk
00<006mkKg/056mk00<006mkKg/03Fmk000@Kg/00`00Kg]_N`06Kg/3000UKg/01000Kg/000000fmk
00<006mkKg/03fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/01fmk
00<006mkKg/026mk0P000Vmk00<006mk000026mk00<006mkKg/01Vmk00@006mkKg]_N`8000U_N`@0
00U_N`03001_N`000080009_N`05001_NfmkKg/00002Kg/00`00Kg]_N`03Kg/01000Kg]_N`000fmk
10000fmk00T006mk000006mk001_N`00Kg/00P000Vmk0`0000=_N`00Kg/01Vmk00<006mkKg/016mk
00<006mk000016mk00@006mkKg/000A_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk015_
N`8000=_N`8000Y_N`03001_Nfmk00Q_N`800003Kg/006mk00A_N`03001_Nfmk00Y_N`L000Y_N`03
001_Nfmk00M_N`@001Q_N`03001_Nfmk00a_N`0046mk00<006mkKg/01Vmk0`0096mk00<006mkKg/0
0P000fmk00<006mkKg/046mk0P001Vmk00D006mkKg]_N`0000U_N`03001_Nfmk00E_N`03001_Nfmk
00U_N`H000Q_N`03001_Nfmk00Q_N`03001_Nfmk01/000A_N`04001_Nfmk0004Kg/00`00Kg]_N`02
Kg/00`00Kg/00006Kg/>00000fmk001_N`03Kg/30007Kg/00`00Kg]_N`03Kg/01@00Kg/006mk0000
0Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk019_N`H000]_
N`03001_Nfmk00Y_N`8000I_N`03001_Nfmk00a_N`8000a_N`03001_Nfmk00Q_N`03001_Nfmk01Q_
N`03001_Nfmk00a_N`003fmk00<006mkKg/01Vmk0P0000=_N`00Kg/08Vmk00@006mkKg]_N`8000=_
N`03001_Nfmk019_N`03001_Nfmk00=_N`05001_NfmkKg/00009Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`08Kg/200001fmk001_Nfmk001_N`0000M_N`03001_Nfmk00Q_N`04001_Nfmk0007Kg/400000fmk
001_N`07Kg/60003Kg/00`00Kg/00006Kg/20002Kg/00`00Kg/00004Kg/300001Fmk001_Nfmk0000
0Vmk0P000Vmk0P0000=_N`00Kg/00Vmk1P001Fmk00@006mkKg]_N`80009_N`03001_N`00009_N`03
001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk011_N`<0
0004Kg/006mkKg/3000:Kg/00`00Kg]_N`08Kg/00`00Kg]_N`020004Kg/00`00Kg]_N`08Kg/40000
16mk000000002Vmk00<006mkKg/01Vmk1@0066mk00<006mkKg/036mk000?Kg/00`00Kg]_N`06Kg/2
0002Kg/00`00Kg]_N`0OKg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00005Fmk00<006mkKg/00fmk00@0
06mkKg/000Y_N`03001_Nfmk00=_N`03001_Nfmk00E_N`<000=_N`05001_Nfmk001_N`020006Kg/0
0`00Kg]_N`09Kg/30004Kg/30006Kg/00`00Kg]_N`02Kg/30002Kg/20002Kg/00`00Kg]_N`020009
Kg/01000Kg/000000Vmk0`000Vmk00<006mk00000Vmk00<006mkKg/00P000Vmk00@006mk0000009_
N`03001_Nfmk0080009_N`<000=_N`03001_N`0000A_N`03001_N`00009_N`03001_Nfmk009_N`03
001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00i_N`80009_N`03001_N`00
009_N`03001_Nfmk008000Q_N`03001_Nfmk00Q_N`03001_Nfmk009_N`<0009_N`03001_Nfmk00A_
N`<000E_N`03001_Nfmk008000Q_N`03001_Nfmk00A_N`80009_N`800003Kg/0000001I_N`03001_
Nfmk00a_N`003fmk00<006mkKg/01Fmk00<006mk00000Vmk00<006mkKg/07Vmk00<006mkKg/016mk
0P000Vmk00<006mkKg/056mk0P000fmk00<006mk000036mk00D006mkKg]_N`0000I_N`8000I_N`03
001_N`0000=_N`8000E_N`03001_Nfmk00U_N`800003Kg/00000008000U_N`03001_Nfmk008000A_
N`03001_N`0000=_N`@000Y_N`D000A_N`0=001_NfmkKg/006mk001_N`00Kg/006mk00000Vmk1000
0Vmk00@006mkKg/000A_N`800003Kg/0000000E_N`05001_N`00Kg/00005Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/30003Kg/01`00Kg]_Nfmk001_N`0000A_
N`8000M_N`03001_Nfmk00I_N`03001_Nfmk00I_N`<0009_N`@000Q_N`03001_Nfmk009_N`03001_
Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_N`00009_N`8001E_N`03001_Nfmk00]_
N`003fmk00<006mkKg/01Fmk00<006mk00000Vmk00<006mkKg/07Fmk00<006mkKg/01Fmk0P000Vmk
00<006mkKg/05Vmk00H006mkKg/006mk000<Kg/01@00Kg]_Nfmk000016mk0P0026mk00<006mk0000
0fmk00@006mk000000=_N`03001_Nfmk00Q_Na/00003Kg/006mk00A_N`l000I_N`0=001_NfmkKg/0
06mk001_N`00Kg/006mk00000fmk00<006mkKg/00Vmk00@006mkKg/000I_N`8000I_N`05001_N`00
Kg/00005Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000036mk0P001Vmk00L006mk
Kg]_N`00Kg/00006Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/3000<Kg/00`00
Kg]_N`03Kg/20004Kg/00`00Kg]_N`02Kg/20004Kg/01000Kg]_N`0016mk00<006mkKg/04Vmk00<0
06mkKg/02fmk000?Kg/00`00Kg]_N`04Kg/01000Kg]_N`000fmk00<006mkKg/06fmk00<006mkKg/0
1Vmk0P0000=_N`00Kg/06Fmk00D006mk001_N`0000e_N`03001_N`00009_N`<000Y_N`8000E_N`06
001_Nfmk001_N`001fmk100000A_N`00001_N`8000a_N`03001_Nfmk00A_N`04001_N`000003Kg/4
000:Kg/40004Kg/00`00Kg]_N`03Kg/30002Kg/20002Kg/40003Kg/01@00Kg]_Nfmk000016mk1@00
0fmk00@006mkKg]_N`8000E_N`03001_Nfmk00M_N`03001_Nfmk009_N`04001_Nfmk000;Kg/20007
Kg/00`00Kg]_N`03Kg/20007Kg/20005Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/200000fmk0000
000;Kg/00`00Kg]_N`06Kg/20002Kg/00`00Kg]_N`020006Kg/01@00Kg]_Nfmk000016mk0P004Vmk
00<006mkKg/02fmk000>Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk00<006mkKg/06Vmk00<006mk
Kg/01fmk00@006mk000001]_N`<000i_N`03001_N`00008000e_N`8000E_N`04001_NfmkKg/20002
Kg/50005Kg/00`00Kg/00002Kg/2000:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0200000fmk00000003
Kg/30008Kg/20002Kg/20002Kg/00`00Kg]_N`03Kg/30002Kg/40002Kg/20003Kg/01@00Kg]_Nfmk
00000Vmk0P000Vmk00<006mkKg/00P0000=_N`00Kg/00Vmk00<006mkKg/016mk00<006mkKg/026mk
00D006mkKg]_N`00009_N`03001_Nfmk00I_N`<000U_N`03001_Nfmk00=_N`8000U_N`8000A_N`03
001_Nfmk00=_N`03001_Nfmk00E_N`8000=_N`03001_N`0000Y_N`03001_Nfmk00Q_N`D000Q_N`03
001_Nfmk009_N`03001_Nfmk00=_N`80011_N`03001_Nfmk00]_N`003Vmk00<006mkKg/016mk00@0
06mkKg/000A_N`03001_Nfmk01U_N`03001_Nfmk00Q_N`04001_N`00000JKg/c0009Kg/01000Kg]_
N`0016mk0P0026mk00<006mkKg/00Vmk00@006mkKg]_N`<000E_N`04001_Nfmk0006Kg/00`00Kg/0
0004Kg/?0003Kg/01000Kg]_N`000Vmk00<006mkKg/00Vmk0P0016mk00<006mkKg/00Vmk1P001fmk
00<006mkKg/026mk00@006mkKg/0009_N`03001_Nfmk00A_N`8000]_N`03001_Nfmk00E_N`<000U_
N`03001_Nfmk009_N`05001_NfmkKg/00006Kg/20006Kg/00`00Kg/00009Kg/00`00Kg]_N`0:Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0;Kg/0
00i_N`03001_Nfmk00A_N`04001_Nfmk0005Kg/00`00Kg]_N`0GKg/00`00Kg]_N`09Kg/01000Kg/0
00004Vmk20000Vmk0P003Fmk0`0000=_N`0000000P002Vmk00<006mk00001Vmk00<006mkKg/00`00
2Vmk00@006mkKg/000I_N`<000E_N`03001_Nfmk0080009_N`D000E_N`05001_NfmkKg/00005Kg/0
0`00Kg/00003Kg/200000fmk001_N`04Kg/20002Kg/30003Kg/01000Kg]_N`000Vmk00<006mkKg/0
0P0000=_N`0000000fmk00@006mkKg]_N`<0009_N`03001_N`0000I_N`03001_Nfmk00U_N`05001_
N`00Kg/00004Kg/3000=Kg/00`00Kg]_N`04Kg/300000fmk000000030005Kg/20002Kg/01@00Kg]_
Nfmk00000fmk0`0026mk00<006mk00002Fmk00<006mkKg/02Fmk0P002Vmk00<006mkKg/00fmk00<0
06mkKg/01Fmk0P003Vmk00<006mkKg/02Vmk000>Kg/00`00Kg]_N`04Kg/01000Kg]_N`001Fmk00<0
06mkKg/05Vmk00<006mkKg/02Vmk00@006mk000000]_N`L000U_N`03001_N`0000]_N`80009_N`03
001_Nfmk00=_N`@000I_N`04001_Nfmk0005Kg/00`00Kg]_N`0200000fmk001_N`07Kg/01@00Kg]_
Nfmk00002Fmk0P000fmk00@006mk001_N`<0009_N`800003Kg/0000000=_N`03001_Nfmk009_N`80
009_N`04001_Nfmk0002Kg/01@00Kg/006mk00001Fmk0P000Vmk0`000fmk00@006mkKg]_N`80009_
N`03001_N`0000=_N`04001_Nfmk0002Kg/01000Kg]_N`000Vmk00<006mkKg/00P0016mk00<006mk
Kg/02Vmk00@006mk0000009_N`8000m_N`03001_Nfmk00=_N`800004Kg/006mk0005Kg/40003Kg/2
000016mk001_N`000Vmk0P002fmk00@006mkKg/000Q_N`03001_Nfmk00M_N`80009_N`03001_Nfmk
00M_N`03001_Nfmk00=_N`03001_Nfmk00M_N`8000a_N`03001_Nfmk00Y_N`003Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk01E_N`03001_Nfmk00a_N`03001_N`0000=_N`P0011_
N`8000]_N`03001_Nfmk009_N`03001_Nfmk00M_N`@00003Kg/006mk00=_N`03001_Nfmk009_N`03
001_N`00009_N`03001_N`0000I_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`800003Kg/000000080
00A_N`03001_N`0000=_N`05001_NfmkKg/00005Kg/00`00Kg/00002Kg/300000fmk001_N`02Kg/0
3@00Kg]_Nfmk001_N`00Kg/006mk001_N`00009_N`04001_NfmkKg/400000fmk001_N`04Kg/50002
Kg/01000Kg]_N`001Fmk00D006mkKg]_N`0000e_N`800003Kg/00000011_N`03001_Nfmk00=_N`04
001_Nfmk0003Kg/00`00Kg]_N`06Kg/7000016mk000000003Fmk00D006mkKg]_N`0000M_N`03001_
Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`8000Y_
N`03001_Nfmk00Y_N`003Vmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`03001_Nfmk01=_N`03
001_Nfmk00e_N`03001_N`0000<001M_N`03001_N`0000U_N`8000I_N`03001_Nfmk00Y_N`<000A_
N`80009_N`03001_N`00009_N`03001_Nfmk008000A_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`<0
00I_N`03001_N`0000A_N`04001_Nfmk0006Kg/50003Kg/01@00Kg]_Nfmk00000fmk00T006mk001_
N`00Kg/006mk00000Vmk00<006mkKg/00Vmk3@0016mk00@006mkKg/000I_N`04001_Nfmk000<Kg/4
000BKg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk000016mk0P002fmk10003fmk00<006mkKg/00Vmk00<0
06mkKg/016mk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/01Vmk00<0
06mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/02Vmk000=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0>Kg/200000fmk001_N`0GKg/01000Kg]_
N`0026mk00<006mkKg/01Vmk00<006mkKg/02fmk1@000fmk00@006mk000000=_N`03001_Nfmk009_
N`04001_Nfmk0006Kg/00`00Kg]_N`09Kg/50004Kg/01000Kg]_N`001Fmk0`0016mk0P0000Q_N`00
Kg/006mk001_N`001Fmk00<006mk00000Vmk0P000Vmk00<006mkKg/00P000fmk0P0000A_N`00Kg]_
N`8000A_N`800003Kg/006mk009_N`03001_N`0000Q_N`800003Kg/006mk00I_N`@0009_N`@000m_
N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00E_N`D00003Kg/00000
00m_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk
00E_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`8000Q_N`03001_Nfmk00U_N`003Fmk00<006mkKg/0
0fmk00D006mkKg]_N`0000M_N`03001_Nfmk015_N`03001_Nfmk00m_N`80009_N`03001_Nfmk01A_
N`05001_NfmkKg/00006Kg/20009Kg/00`00Kg]_N`0:Kg/00`00Kg/00003Kg/70003Kg/00`00Kg]_
N`03Kg/00`00Kg/00007Kg/00`00Kg]_N`06Kg/20002Kg/200000fmk00000002Kg/01000Kg]_N`00
1fmk0P0000e_N`00001_N`00Kg/006mk001_N`00Kg/00005Kg/00`00Kg/00002Kg/20002Kg/00`00
Kg]_N`0200001fmk000006mk001_N`00009_N`80009_N`8000=_N`07001_NfmkKg/006mk00002Vmk
0P000Vmk1@001Vmk0P000Vmk0P003Fmk00<006mkKg/00P001Fmk00<006mkKg/01Fmk00<006mkKg/0
100016mk00<006mkKg/00P003Vmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00Vmk0P00
26mk00<006mkKg/01Fmk00<006mkKg/01fmk00<006mkKg/02fmk0P001Vmk00<006mkKg/02Fmk000=
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0?
Kg/20004Kg/00`00Kg]_N`0CKg/01@00Kg]_Nfmk000016mk0P002fmk00<006mkKg/02Vmk00@006mk
000000I_N`8000A_N`03001_Nfmk00A_N`8000M_N`03001_Nfmk00E_N`05001_NfmkKg/00002Kg/0
0`00Kg]_N`0`0002Kg/02000Kg]_Nfmk001_N`00Kg/20006Kg/00`00Kg]_N`02000;Kg/4000;Kg/0
1000Kg/000000Vmk0P002Vmk00@006mkKg/000M_N`03001_Nfmk00I_N`8000M_N`03001_Nfmk009_
N`8000e_N`03001_Nfmk00A_N`04001_Nfmk0004Kg/00`00Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/000e_N`03001_Nfmk009_
N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_Nfmk00i_N`03001_Nfmk00i_N`800004Kg/00000
0003Kg/2000BKg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/02Fmk00<006mkKg/0
0P001Vmk10000Vmk00<006mkKg/00Vmk0P000Vmk0P001Fmk00<006mkKg/00fmk0P0016mk00@006mk
Kg/0009_N`03001_Nfmk00D000E_N`80009_N`80009_N`80009_N`04001_N`000004Kg/4000016mk
001_Nfmk0P000Vmk0P000fmk00H006mkKg]_N`00Kg/20002Kg/20004Kg/00`00Kg]_N`020007Kg/;
0008Kg/200000fmk000000060007Kg/00`00Kg/00007Kg/00`00Kg]_N`06Kg/20007Kg/00`00Kg]_
N`04Kg/3000;Kg/00`00Kg]_N`04Kg/01000Kg]_N`000fmk00<006mkKg/02Vmk00<006mkKg/016mk
00<006mkKg/026mk00<006mkKg/03Fmk0P000fmk00<006mkKg/02Fmk000=Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/01Vmk00<006mkKg/03Fmk00<006mkKg/03Fmk0P000fmk0P0000=_N`0000000fmk
00<006mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/00P003Vmk00<006mkKg/02Fmk00H006mkKg/0
06mk0005Kg/20002Kg/01000Kg]_N`000Vmk00<006mk000016mk0`000Vmk00@006mkKg]_N`8000I_
N`09001_NfmkKg/006mk001_N`00009_N`800003Kg/006mk009_N`0>001_Nfmk001_N`00Kg/006mk
001_N`00Kg/000=_N`04001_NfmkKg/20002Kg/03@00Kg/006mk001_N`00Kg/006mk001_N`0000E_
N`<000A_N`<0009_N`<000A_N`@000=_N`04001_Nfmk0004Kg/30005Kg/200000fmk001_N`03Kg/5
0004Kg/30008Kg/00`00Kg]_N`05Kg/00`00Kg/00007Kg/00`00Kg]_N`05Kg/00`00Kg/0000:Kg/0
0`00Kg]_N`05Kg/01000Kg/006mk0P003Fmk00<006mkKg/016mk00<006mkKg/02Fmk00<006mkKg/0
3Vmk0P000Vmk00<006mkKg/026mk000=Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Vmk00<006mk
Kg/036mk00<006mkKg/02fmk0`001Fmk0P000fmk00D006mkKg]_N`0000i_N`03001_Nfmk00=_N`<0
011_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_N`0000=_N`03001_N`0000=_N`D00003Kg/0
06mk00M_N`800004Kg/000000008Kg/01000Kg]_Nfmk10000fmk00@006mk001_N`800004Kg/006mk
Kg/20002Kg/20002Kg/20005Kg/300000fmk001_N`02Kg/30002Kg/20002Kg/00`00Kg/00005Kg/2
0008Kg/90006Kg/01000Kg]_Nfmk0P001Vmk100000=_N`00Kg/00Vmk00<006mkKg/016mk10000Vmk
00<006mkKg/026mk00<006mkKg/016mk00D006mkKg]_N`0000E_N`03001_Nfmk00M_N`04001_N`00
0008Kg/00`00Kg]_N`06Kg/3000@Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0@Kg/3
000:Kg/000a_N`05001_NfmkKg/00006Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:
Kg/20008Kg/20004Kg/20002Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/00`00
Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg/00003Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00002Fmk
10002Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk00000fmk5P0000=_N`00Kg/016mk7P00
2Fmk00<006mkKg/00Vmk0P002Vmk0P000fmk00<006mkKg/026mk0P002fmk00<006mkKg/016mk00D0
06mkKg]_N`0000A_N`03001_Nfmk00U_N`04001_Nfmk0008Kg/00`00Kg]_N`06Kg/2000@Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0@Kg/2000:Kg/000a_N`05001_NfmkKg/00006Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_N`09Kg/2000:Kg/20006Kg/01000Kg]_N`002fmk
00<006mkKg/00Vmk10004Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00H006mkKg/006mk0002Kg/0
1000Kg]_Nfmk0P0000A_N`00Kg/000I_N`@0009_N`03001_N`00008000E_N`04001_NfmkKg/20000
0fmk00000003Kg/01@00Kg]_N`00Kg/00P000fmk00/006mk001_N`00Kg/006mk001_N`0000A_N`80
0003Kg/0000000=_N`800003Kg/00000009_N`05001_N`00Kg/00004Kg/50009Kg/20008Kg/00`00
Kg]_N`03Kg/00`00Kg/00009Kg/30003Kg/00`00Kg]_N`07Kg/00`00Kg/0000:Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`020006Kg/00`00Kg]_
N`05Kg/200000fmk0000000?Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/03Vmk10002Vmk000<Kg/0
1000Kg]_N`001Vmk00<006mkKg/026mk00<006mkKg/026mk00<006mkKg/01fmk0`0036mk00<006mk
00001Vmk0P0000=_N`00Kg/026mk00@006mkKg]_N`<00003Kg/000000080011_N`03001_Nfmk00I_
N`03001_Nfmk00A_N`05001_N`00Kg/00002Kg/02`00Kg/00000Kg/006mk001_N`00Kg/01@001Vmk
00<006mkKg/00Vmk100000=_N`00Kg/00P0000=_N`00Kg/00Vmk0P0000I_N`00Kg]_N`00Kg/20003
Kg/02`00Kg/006mk001_N`00Kg/006mk00000Vmk0P0000=_N`00Kg/00P0000E_N`00001_N`0000=_
N`<00004Kg/006mk0002Kg/200000fmk00000002Kg/20007Kg/20007Kg/00`00Kg]_N`05Kg/20008
Kg/20002Kg/01000Kg]_N`0026mk00D006mkKg]_N`0000U_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/0000>Kg/20002Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/20004Kg/2000=Kg/0
1@00Kg]_Nfmk00003Vmk00<006mkKg/02fmk0P0000A_N`00Kg/000Y_N`0036mk00@006mkKg/000I_
N`03001_Nfmk00U_N`03001_Nfmk00I_N`03001_Nfmk00I_N`8000m_N`03001_N`0000Q_N`<000M_
N`07001_NfmkKg/006mk00000Vmk0P000Vmk00<006mkKg/03Fmk00<006mkKg/01Fmk00<006mkKg/0
1Fmk00<006mkKg/03`002fmk00<006mkKg/01Vmk4P0000E_N`00Kg]_N`0000=_Na80009_N`03001_
Nfmk00A_N`L0009_N`8000E_N`03001_Nfmk00A_N`03001_N`0000E_N`03001_Nfmk00I_N`03001_
N`0000I_N`03001_N`0000=_N`04001_Nfmk0006Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk000046mk00@006mkKg/000A_N`03001_Nfmk00=_
N`03001_N`0000I_N`8000]_N`05001_NfmkKg/0000?Kg/00`00Kg]_N`08Kg/20002Kg/01000Kg]_
N`002Vmk000<Kg/01000Kg]_N`001Vmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/016mk
0`004Fmk00<006mk00002Vmk0`0016mk00<006mkKg/00P0000=_N`00Kg/00Vmk0P000fmk00<006mk
Kg/036mk00<006mkKg/01Fmk00<006mkKg/01Fmk00D006mk001_N`00009_N`<00006Kg/006mkKg/0
06mk1@0026mk00<006mkKg/016mk0P0000=_N`0000000Vmk0P001Vmk00<006mkKg/00P0000A_N`00
Kg/0009_N`D00004Kg/006mkKg/20002Kg/20002Kg/20003Kg/00`00Kg]_N`02Kg/200001Vmk0000
0000Kg/000=_N`8000I_N`8000A_N`03001_N`0000A_N`03001_Nfmk00M_N`03001_N`0000A_N`80
009_N`03001_Nfmk009_N`<000A_N`8000M_N`03001_Nfmk00A_N`05001_NfmkKg/00007Kg/01000
Kg]_N`004Vmk00<006mkKg/00P000Vmk00@006mkKg]_N`80009_N`03001_Nfmk00I_N`8000Y_N`04
001_Nfmk000?Kg/00`00Kg]_N`05Kg/30003Kg/01000Kg]_N`002fmk000<Kg/00`00Kg/00007Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/2000DKg/01000Kg]_N`002Vmk0`000fmk
0`000Vmk00<006mkKg/00Vmk00<006mk00000fmk0P0036mk00<006mkKg/016mk00<006mkKg/01Vmk
00D006mk001_N`00009_N`08001_Nfmk001_N`00Kg/0009_N`04001_NfmkKg/30005Kg/01000Kg]_
Nfmk0`000fmk0P000Vmk00<006mk00001Fmk0P0000=_N`00Kg/00`0000A_N`00001_N`80009_N`08
001_N`00Kg/006mk001_N`80009_N`05001_N`00Kg/00002Kg/30003Kg/02P00Kg]_N`00Kg/006mk
001_N`0026mk0P000Vmk00@006mkKg/0009_N`03001_Nfmk00U_N`03001_N`00009_N`03001_Nfmk
009_N`03001_Nfmk00A_N`80009_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`04001_Nfmk0009Kg/2
000DKg/01@00Kg]_Nfmk00000Vmk00<006mk00000fmk00<006mkKg/02Fmk0`001fmk00@006mkKg/0
011_N`03001_Nfmk009_N`8000E_N`05001_NfmkKg/0000;Kg/000]_N`04001_Nfmk0007Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/2000FKg/01000Kg]_N`0036mk0P0000=_N`00
00000fmk00<006mkKg/00fmk00<006mk00001Fmk00<006mkKg/02Fmk00<006mkKg/016mk00<006mk
Kg/01fmk00L006mkKg]_N`00Kg/00003Kg/30004Kg/00`00Kg]_N`03Kg/400000fmk001_N`020006
Kg/01@00Kg/006mk00000Vmk00<006mkKg/00Vmk0`000Vmk10000Vmk00<006mk00000fmk0`000Vmk
0P0000A_N`00Kg/0009_N`03001_N`00008000I_N`04001_NfmkKg/2000016mk001_N`002Vmk0`00
0Vmk00<006mk000036mk00D006mk001_N`0000A_N`03001_Nfmk00I_N`03001_N`0000a_N`03001_
Nfmk009_N`03001_N`0000Y_N`8001E_N`04001_NfmkKg/40004Kg/00`00Kg]_N`0<Kg/20005Kg/0
1000Kg]_N`0046mk00<006mkKg/00P001Vmk00<006mkKg/00Vmk00<006mkKg/02Fmk000;Kg/00`00
Kg/00008Kg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk00000Vmk0`0066mk00@006mkKg/000a_N`<000A_
N`03001_Nfmk00A_N`03001_N`0000I_N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00M_
N`07001_NfmkKg/006mk00001Fmk00<006mkKg/00fmk00<006mkKg/01Vmk0`0026mk00D006mk001_
N`0000=_N`80009_N`03001_N`0000@000A_N`03001_N`0000E_N`D00004Kg/006mk0003Kg/20008
Kg/00`00Kg]_N`03Kg/01000Kg]_N`002Vmk2@002fmk00@006mkKg/000E_N`03001_Nfmk00M_N`<0
00a_N`07001_NfmkKg/006mk000026mk1`004fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mk
Kg/03Vmk0P0016mk0P003fmk1@001fmk00<006mkKg/00fmk00<006mkKg/02Fmk000;Kg/00`00Kg/0
0007Kg/00`00Kg]_N`0;Kg/01@00Kg]_N`00Kg/00P006fmk00@006mkKg/000Q_N`P0009_N`03001_
Nfmk00E_N`04001_Nfmk0006Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/50002
Kg/20003Kg/200000fmk00000004Kg/00`00Kg]_N`05Kg/00`00Kg/000030005Kg/00`00Kg]_N`02
0005Kg/00`00Kg/000020002Kg/00`00Kg/00002Kg/01000Kg]_N`000fmk0P0000E_N`00Kg/006mk
00<0009_N`L000E_N`04001_NfmkKg/200000fmk00000007Kg/4000016mk001_N`000Vmk00<006mk
Kg/01@001Vmk00D006mk001_N`0000A_N`03001_Nfmk00E_N`<0009_N`H000M_N`05001_N`00Kg/0
0005Kg/80003Kg/9000;Kg/00`00Kg]_N`020004Kg/00`00Kg]_N`0AKg/20002Kg/20009Kg/60002
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/000]_N`8000Q_N`03001_Nfmk00a_
N`@001e_N`05001_NfmkKg/00002Kg/50002Kg/20002Kg/200000fmk001_N`07Kg/01000Kg]_N`00
1fmk0P0026mk00<006mkKg/00Vmk00<006mkKg/01Fmk00@006mkKg/0009_N`@00003Kg/0000000E_
N`80009_N`03001_Nfmk00E_N`03001_N`0000=_N`@00004Kg/006mkKg/20006Kg/40002Kg/01P00
Kg]_N`00Kg/0009_N`0;001_N`00001_N`00Kg/006mk001_N`0500001Fmk000006mk00000Vmk1000
00=_N`00Kg/00P0000=_N`00Kg/00P000Vmk1@001Fmk00<006mk00000Vmk00<006mkKg/01Fmk1@00
0Vmk0P0000=_N`00Kg/00Vmk00<006mkKg/016mk0P000Vmk00<006mkKg/01Vmk1P000Vmk0`0000=_
N`0000000`000Vmk0P000Vmk0P0036mk2@000fmk00@006mk000000A_N`03001_Nfmk01=_N`800003
Kg/006mk009_N`H000Q_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00U_N`002fmk0P00
26mk00<006mkKg/02fmk:@001Vmk00D006mkKg]_N`00009_N`8000Q_N`05001_NfmkKg/00008Kg/0
0`00Kg]_N`05Kg/01@00Kg]_Nfmk00001Vmk0P000fmk00<006mkKg/00Vmk100026mk00@006mkKg/0
00E_N`05001_NfmkKg/00006Kg/>000016mk001_N`0016mk4P000Vmk00<006mk00000Vmk00<006mk
Kg/00fmk0`000Vmk00@006mkKg]_N`<000U_N`05001_NfmkKg/00002Kg/00`00Kg]_N`09Kg/30003
Kg/01000Kg]_N`001Fmk00<006mkKg/00Vmk00<006mkKg/036mk1P001Vmk00<006mkKg/00Vmk00<0
06mk000056mk1@000Vmk00@006mkKg/001Q_N`D000e_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03
001_Nfmk00U_N`002fmk00<006mkKg/01fmk00<006mkKg/02Fmk0P0000A_N`00000001a_N`800005
Kg/00000Kg/00006Kg/20004Kg/01@00Kg/00000Kg/00P001Vmk00D006mkKg]_N`0000U_N`03001_
Nfmk00A_N`05001_NfmkKg/00005Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0`000Vmk10001Fmk0P00
00=_N`00Kg/00fmk00D006mkKg]_N`0000E_N`<0009_N`04001_N`000004Kg/2000016mk001_N`00
0Vmk1@0000E_N`00Kg]_N`00009_N`<0009_N`8000=_N`03001_N`0000=_N`8000=_N`8000=_N`03
001_N`0000800003Kg/0000000Q_N`05001_NfmkKg/00002Kg/00`00Kg]_N`09Kg/500001Fmk001_
Nfmk00000fmk0P001Fmk00<006mkKg/03Fmk0`001Vmk0P001Fmk00@006mkKg/001=_N`<00005Kg/0
0000Kg/00002Kg/00`00Kg]_N`0BKg/400000fmk001_N`0>Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`0:Kg/000Y_N`8000U_N`03001_Nfmk00M_N`8000A_N`04001_N`00000IKg/00`00
Kg]_N`03Kg/00`00Kg/00003Kg/20006Kg/01000Kg/000000fmk0`000fmk00D006mkKg]_N`0000Y_
N`8000A_N`04001_Nfmk0004Kg/20006Kg/01@00Kg]_N`00Kg/00P001Vmk1@000Vmk0`000Vmk00<0
06mkKg/00fmk00D006mkKg]_N`00009_N`800003Kg/006mk009_N`06001_NfmkKg/006mk0`0000A_
N`00001_N`<0000BKg/006mk001_N`00Kg/006mk001_N`00Kg/006mk001_N`000Vmk00<006mkKg/0
0fmk00h006mkKg/006mk001_N`00Kg/006mk001_N`000Vmk0`0016mk00<006mkKg/00fmk00<006mk
00002Fmk0P000Vmk0P0000M_N`00Kg/006mk001_N`020007Kg/00`00Kg]_N`0;Kg/20002Kg/20003
Kg/20006Kg/01@00Kg]_Nfmk000046mk0`000fmk00D006mk001_N`00009_N`03001_Nfmk00i_N`@0
00E_N`03001_Nfmk00e_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`002Vmk00<0
06mkKg/026mk00<006mkKg/01Fmk0P001Vmk0P000Vmk00<006mkKg/05Fmk00<006mkKg/01Fmk0P00
00=_N`00000026mk0P0000=_N`00Kg/01Fmk0P0000=_N`00Kg/00fmk00<006mkKg/02Fmk00D006mk
Kg]_N`00009_N`05001_NfmkKg/00008Kg/3000016mk000000002fmk1P0000=_N`00Kg/016mk00@0
06mk000000=_N`<000E_N`<0009_N`@0009_N`06001_N`00Kg/006mk1@0000A_N`00Kg]_N`80009_
N`03001_N`00009_N`03001_Nfmk00A_N`80009_N`06001_N`00001_N`000Vmk00<006mkKg/00fmk
0P000Vmk00<006mkKg/016mk0P001fmk0P000fmk00D006mkKg/006mk00D000U_N`03001_Nfmk00Y_
N`03001_Nfmk00=_N`04001_N`000008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/20006Kg/00`00
Kg]_N`0200000fmk001_N`0<Kg/4000:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`0:Kg/000Y_N`8000Q_N`03001_Nfmk00=_N`<000Q_N`8000=_N`8001=_N`8000U_
N`<000U_N`800003Kg/006mk00M_N`8000A_N`03001_Nfmk00Y_N`04001_NfmkKg/20002Kg/20007
Kg/30003Kg/3000?Kg/;0005Kg/00`00Kg/0000<0003Kg/01P00Kg]_N`00Kg/000=_N`05001_Nfmk
Kg/00003Kg/V0006Kg/20005Kg/20005Kg/01000Kg]_N`000fmk00<006mkKg/02Fmk00<006mkKg/0
26mk0P001Vmk0P002Vmk00<006mkKg/00fmk00<006mkKg/01fmk0`0026mk00<006mkKg/00P0000=_
N`00Kg/026mk10003Vmk00<006mkKg/02fmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/0
2Vmk000:Kg/50005Kg/01000Kg]_Nfmk0P002fmk00<006mk000016mk00<006mkKg/03fmk00<006mk
Kg/01Vmk0`000Vmk10001Fmk0P000Vmk00<006mkKg/00fmk0`0000A_N`000000009_N`03001_Nfmk
00]_N`800005Kg/00000Kg/00004Kg/500000fmk00000002Kg/01@00Kg/006mk00003fmk00<006mk
000016mk0P0000=_N`0000000fmk0P0000=_N`00Kg/00fmk0P0000Q_N`00Kg/006mk001_N`000fmk
00X006mkKg/006mk001_N`00Kg/0009_N`80000:Kg/006mk001_N`00Kg/006mk0004Kg/2000016mk
001_N`000Vmk0P0000=_N`0000000Vmk00<006mkKg/00Vmk0`0000A_N`00000000A_N`80009_N`80
00M_N`06001_NfmkKg/006mk10002Fmk00<006mkKg/01fmk00<006mkKg/01Vmk0`002Fmk00<006mk
Kg/016mk00<006mkKg/00fmk0`002fmk00@006mkKg]_N`<000E_N`@0019_N`03001_Nfmk00Y_N`03
001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk00Y_N`002Vmk00<006mk00000Vmk100000=_N`00
Kg/00P003Vmk0P001Fmk0P003Vmk00<006mkKg/016mk0`001Fmk00@006mkKg]_N`@00003Kg/00000
009_N`03001_N`0000<000A_N`03001_Nfmk00800003Kg/006mk00e_N`T000I_N`80009_N`80009_
N`03001_Nfmk00a_N`04001_Nfmk0002Kg/20003Kg/01@00Kg/00000Kg/00P0000A_N`00Kg]_N`80
00=_N`07001_N`00Kg/006mk00000fmk00T006mkKg/006mk001_N`00Kg/00`0000a_N`00Kg/006mk
001_N`00Kg/006mk0002Kg/20003Kg/00`00Kg/000020003Kg/00`00Kg/000020002Kg/200000fmk
00000004Kg/80009Kg/01P00Kg]_Nfmk001_N`80009_N`8000M_N`03001_Nfmk00E_N`8000U_N`80
0003Kg/006mk00M_N`03001_Nfmk00A_N`03001_Nfmk00<000e_N`03001_Nfmk009_N`80009_N`@0
01I_N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00Y_N`002fmk00<0
06mk00001Fmk0`0046mk00<006mk00001Vmk0P002Vmk0P0016mk0`002Fmk00<006mkKg/016mk1`00
2Fmk00@006mkKg]_Na@000Y_N`07001_N`00Kg/006mk00000Vmk00<006mkKg/02fmk00<006mkKg/0
0Vmk@`001Vmk00<006mkKg/00`000Vmk00@006mkKg/000M_N`<000Y_N`03001_Nfmk009_N`03001_
N`0000A_N`03001_Nfmk00A_N`03001_Nfmk00=_N`8000]_N`80009_N`03001_Nfmk00E_N`03001_
Nfmk00E_N`80011_N`03001_Nfmk00=_N`<001Y_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_
Nfmk00a_N`03001_Nfmk00Y_N`002fmk00@006mkKg/000E_N`03001_N`00008000e_N`04001_Nfmk
0007Kg/00`00Kg]_N`06Kg/01000Kg]_Nfmk0`0036mk00<006mkKg/01Fmk00D006mkKg/006mk0080
00Q_N`04001_NfmkKg/4000<Kg/00`00Kg/0000:Kg/02000Kg]_N`00Kg/006mk0002Kg/00`00Kg]_
N`09Kg/20003Kg/40006Kg/00`00Kg]_N`020002Kg/20005Kg/2000016mk001_Nfmk0P000fmk00<0
06mkKg/00P000Vmk00H006mk000006mk0002Kg/00`00Kg]_N`030002Kg/01000Kg/0000016mk00<0
06mkKg/00P0016mk00<006mkKg/00P000fmk00@006mkKg/000M_N`03001_N`0000<000M_N`03001_
Nfmk00<00003Kg/006mk00A_N`8000A_N`03001_Nfmk009_N`03001_Nfmk00]_N`8000=_N`03001_
Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk008000i_N`03001_Nfmk009_N`03001_N`00008001Y_
N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk00]_N`002fmk00D006mk
Kg]_N`0000A_N`03001_Nfmk009_N`<000]_N`03001_N`0000Q_N`8000E_N`03001_N`000080011_
N`03001_Nfmk00A_N`04001_Nfmk0003Kg/20006Kg/01000Kg]_Nfmk0P000Vmk0P002Vmk00@006mk
Kg/000Q_N`04001_NfmkKg/200000fmk001_N`02Kg/00`00Kg]_N`08Kg/01000Kg]_Nfmk0P000Vmk
00<006mk00001Fmk0P0000Q_N`00Kg/006mk001_N`000fmk00D006mk001_N`00009_N`8000=_N`08
001_Nfmk001_N`00Kg/000=_N`07001_N`00Kg/006mk00000Vmk00P006mkKg/006mk001_N`000fmk
00<006mkKg/00Vmk0`000Vmk00L006mk001_N`00Kg/00003Kg/00`00Kg]_N`04Kg/01000Kg]_N`00
0fmk0P0016mk00@006mkKg/000=_N`8000M_N`80009_N`03001_Nfmk008000m_N`03001_Nfmk009_
N`03001_Nfmk00=_N`03001_Nfmk009_N`8000E_N`8000]_N`03001_Nfmk009_N`06001_NfmkKg/0
06mk0P0066mk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/02fmk000;
Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001fmk0P002Fmk00@006mkKg/000U_N`800003Kg/00000
008001=_N`03001_Nfmk00=_N`04001_Nfmk0006Kg/00`00Kg]_N`03Kg/01000Kg]_N`000Vmk00D0
06mkKg]_N`0000Q_N`03001_Nfmk009_N`03001_Nfmk00E_N`04001_NfmkKg/200000fmk001_N`02
Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk000016mk00@006mkKg/000A_N`<0009_N`80009_N`06001_
N`00001_N`000fmk00D006mk001_N`00009_N`03001_N`00009_N`8000E_N`D000=_N`03001_N`00
00=_N`03001_N`00008000Q_N`@0009_N`03001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk009_
N`03001_Nfmk009_N`<00004Kg/000000004Kg/20009Kg/5000AKg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk000016mk00<006mkKg/01fmk0P002Fmk00D006mkKg]_N`0000E_N`03001_Nfmk008001I_N`03
001_Nfmk00I_N`05001_NfmkKg/0000@Kg/00`00Kg]_N`0;Kg/000a_N`03001_Nfmk009_N`04001_
Nfmk0009Kg/30006Kg/01000Kg]_N`002Vmk10005Vmk00<006mkKg/00Vmk00@006mkKg/000M_N`80
00=_N`04001_Nfmk0002Kg/00`00Kg]_N`02Kg/20006Kg/00`00Kg]_N`03Kg/20004Kg/01000Kg]_
Nfmk0P000Vmk00D006mkKg]_N`0000Q_N`03001_Nfmk008000E_N`04001_NfmkKg/20002Kg/00`00
Kg/000080003Kg/01`00Kg]_Nfmk001_N`00009_N`05001_N`00Kg/00003Kg/90005Kg/00`00Kg/0
0003Kg/01000Kg]_Nfmk4@0016mk00@006mkKg]_N`8000I_N`03001_Nfmk00A_Nb/000E_N`04001_
Nfmk0003Kg/00`00Kg]_N`0:Kg/30006Kg/01000Kg/000001fmk00@006mkKg]_N`<001=_N`03001_
Nfmk00E_N`05001_NfmkKg/0000AKg/00`00Kg]_N`0;Kg/000a_N`03001_Nfmk00=_N`03001_N`00
00a_N`<000=_N`05001_NfmkKg/00006Kg/50002Kg/4000CKg/01`00Kg]_Nfmk001_N`0000Y_N`80
009_N`8000=_N`03001_Nfmk00A_N`8000=_N`03001_Nfmk00I_N`04001_Nfmk0002Kg/20002Kg/0
0`00Kg/00003Kg/00`00Kg]_N`05Kg/01000Kg]_N`001fmk00<006mkKg/00fmk00T006mk000006mk
001_N`00Kg/00P000Vmk00<006mk00001Fmk0P000fmk0`000Vmk0`001Vmk10000fmk0P001Fmk00<0
06mk00000P002Fmk00@006mk001_N`@000=_N`03001_N`0000U_N`03001_Nfmk009_N`800003Kg/0
06mk00E_N`8000U_N`<0015_N`H000=_N`04001_N`00Kg/2000@Kg/20004Kg/20009Kg/00`00Kg]_
N`04Kg/2000AKg/00`00Kg]_N`05Kg/01000Kg]_N`004Vmk00<006mkKg/02fmk000<Kg/00`00Kg]_
N`04Kg/2000?Kg/300001Fmk001_Nfmk00000Vmk10000fmk0P001Vmk10003fmk00L006mkKg]_N`00
Kg/0000<Kg/40003Kg/00`00Kg]_N`06Kg/200000fmk001_N`08Kg/00`00Kg/000020004Kg/20004
Kg/00`00Kg]_N`04Kg/01000Kg/0000026mk00<006mkKg/016mk0`0000A_N`00Kg/000=_N`<00003
Kg/006mk00A_N`8000=_N`D00003Kg/0000000E_N`03001_N`00009_N`800003Kg/0000000E_N`06
001_N`00001_N`0026mk00@006mk001_N`80009_N`800003Kg/0000000Y_N`03001_Nfmk008000A_
N`03001_Nfmk00=_N`8000Q_N`80009_N`03001_Nfmk00i_N`800004Kg/006mkKg/7000DKg/20000
0fmk0000000;Kg/00`00Kg]_N`05Kg/2000?Kg/00`00Kg]_N`04Kg/01000Kg]_N`004fmk00<006mk
Kg/02fmk000<Kg/00`00Kg]_N`05Kg/J0006Kg/01000Kg]_N`002Fmk100036mk00<006mkKg/00P00
3Fmk0`0016mk00<006mkKg/01fmk5`001Fmk00<006mkKg/00Vmk0`002Vmk00<006mkKg/01Fmk7P00
00=_N`00Kg/00fmk00<006mk00001Fmk2P0000E_N`00Kg]_N`0000I_N`07001_NfmkKg/006mk0000
16mk40001fmk00<006mkKg/00Vmk00<006mk00001Vmk0`000fmk00<006mkKg/036mk00H006mkKg/0
06mk0005Kg/K000=Kg/00`00Kg]_N`06Kg/3000=Kg/00`00Kg]_N`02Kg/01000Kg]_N`0056mk00<0
06mkKg/02fmk000=Kg/00`00Kg]_N`04Kg/2000AKg/20003Kg/00`00Kg]_N`05Kg/01000Kg]_N`00
3Fmk100026mk00<006mkKg/00P002Fmk100000=_N`00Kg/00P000Vmk00<006mkKg/01Fmk0P000Vmk
00<006mkKg/01fmk00<006mk00001fmk0`000fmk00<006mkKg/00`0036mk00<006mkKg/016mk0P00
0Vmk00<006mkKg/016mk10001Vmk00@006mkKg]_N`80009_N`800004Kg/006mkKg/20002Kg/00`00
Kg]_N`03Kg/40004Kg/200000fmk001_N`02Kg/20004Kg/00`00Kg/0000200000fmk001_N`02Kg/3
000:Kg/80004Kg/20002Kg/00`00Kg/00004Kg/200000fmk00000003Kg/00`00Kg]_N`0<Kg/01000
Kg]_N`000Vmk0P000fmk00<006mkKg/03Fmk20000Vmk0`0036mk00<006mkKg/026mk0P002fmk00<0
06mkKg/00Vmk00<006mk000056mk00<006mkKg/036mk000=Kg/00`00Kg]_N`04Kg/2000@Kg/00`00
Kg/00003Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00004Fmk10001Fmk0`001Fmk1@0016mk00<006mk
Kg/00Vmk00@006mkKg/000=_N`<000A_N`03001_Nfmk00M_N`04001_Nfmk0006Kg/01000Kg]_N`00
0Vmk00<006mk00000P003Fmk00<006mkKg/00fmk0`000Vmk00<006mkKg/00Vmk0P0000E_N`00Kg]_
N`0000E_N`800008Kg/006mkKg/006mk001_N`800003Kg/006mk00=_N`03001_Nfmk009_N`03001_
N`00009_N`06001_NfmkKg/006mk0P001Fmk00T006mkKg/006mk001_N`00Kg/00P000Vmk00@006mk
000000Q_N`@00003Kg/006mk00=_N`<000=_N`03001_N`00009_N`04001_Nfmk0002Kg/00`00Kg/0
0004Kg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk000016mk00@006mkKg/000U_N`X000I_N`03001_Nfmk
008000]_N`03001_Nfmk00U_N`8000U_N`07001_NfmkKg/006mk00005Fmk00<006mkKg/036mk000=
Kg/00`00Kg]_N`04Kg/3000>Kg/01000Kg]_N`000fmk00<006mkKg/016mk00D006mkKg]_N`0001E_
N`@00005Kg/00000001_N`040008Kg/00`00Kg]_N`04Kg/300000fmk00000008Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05000?Kg/00`00Kg]_N`02Kg/2000016mk
001_N`0016mk00D006mkKg]_N`0000=_N`03001_Nfmk009_N`800004Kg/006mkKg/20002Kg/30005
Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg]_N`<0009_N`8000I_N`06001_N`00001_N`000Vmk1000
00A_N`00Kg/000I_N`800004Kg/006mk0002Kg/00`00Kg]_N`04Kg/60002Kg/00`00Kg/00002Kg/0
0`00Kg/00006Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00001Fmk0P000fmk1`000Vmk10002Fmk00<0
06mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/02Vmk0P001fmk00H006mkKg/006mk000FKg/00`00
Kg]_N`0<Kg/000e_N`03001_Nfmk00A_N`03001_N`0000i_N`04001_Nfmk0003Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0GKg/5000<Kg/00`00Kg]_N`06Kg/2000:Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/3000?Kg/00`00Kg]_N`0200001Vmk
001_N`00Kg/0009_N`8000A_N`03001_Nfmk009_N`80009_N`03001_N`0000T000I_N`04001_N`00
0003Kg/00`00Kg]_N`03Kg/I00000fmk001_N`03Kg/20002Kg/01000Kg]_N`000Vmk00<006mkKg/0
26mk1P000fmk00<006mk00001fmk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/016mk1000
1Fmk10003Fmk00<006mkKg/016mk0P002Vmk00<006mkKg/02fmk0`0016mk00<006mkKg/00P005fmk
00<006mkKg/036mk000=Kg/00`00Kg]_N`04Kg/01000Kg/0000036mk00<006mkKg/00Vmk00<006mk
00001Fmk00<006mkKg/00fmk00<006mkKg/066mk00<006mk000036mk00<006mkKg/01Fmk0P0000A_
N`00000000U_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk009_N`08001_NfmkKg/006mk
001_N`H000U_N`03001_N`00009_N`03001_Nfmk00800003Kg/0000000E_N`03001_Nfmk00E_N`06
001_N`00001_N`000Vmk10000Vmk0P000fmk00<006mk00001Fmk00@006mkKg]_N`800006Kg/006mk
001_N`001Fmk00D006mk001_N`00009_N`D0009_N`80009_N`8000=_N`04001_Nfmk0004Kg/00`00
Kg]_N`08Kg/30002Kg/00`00Kg/00002Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04
Kg/01000Kg]_Nfmk0P001Fmk10004Fmk00<006mkKg/01Vmk0P002Fmk00<006mkKg/03Fmk0P000fmk
0`0066mk00<006mkKg/036mk000>Kg/00`00Kg]_N`03Kg/01000Kg/000002fmk00<006mkKg/00fmk
00<006mk00001Fmk00<006mkKg/016mk00<006mkKg/05Vmk00@006mkKg/000]_N`03001_Nfmk00A_
N`8000=_N`03001_Nfmk008000M_N`03001_Nfmk00=_N`03001_Nfmk00I_N`05001_NfmkKg/00003
Kg/00`00Kg/00007Kg/60003Kg/20003Kg/00`00Kg]_N`030007Kg/00`00Kg]_N`06Kg/30002Kg/0
1000Kg/000000Vmk0`0000A_N`00001_N`8000I_N`04001_N`000003Kg/01@00Kg/006mk00001Fmk
00@006mk001_N`<0009_N`03001_Nfmk00H000A_N`05001_NfmkKg/00004Kg/00`00Kg]_N`07Kg/0
1000Kg]_Nfmk0`0000A_N`00Kg/000Y_N`03001_Nfmk00A_N`03001_Nfmk00A_N`07001_N`00001_
N`00Kg/010005Fmk00<006mkKg/026mk00<006mkKg/01Vmk00<006mkKg/03fmk0P0000=_N`000000
6Fmk00<006mkKg/036mk000>Kg/00`00Kg]_N`04Kg/01000Kg/000002Fmk00<006mkKg/016mk00<0
06mk000016mk00<006mkKg/01Fmk00<006mkKg/05Fmk00<006mkKg/00Vmk00<006mkKg/01fmk00<0
06mkKg/00fmk0P001Vmk00@006mkKg]_N`8000I_N`05001_NfmkKg/0000:Kg/01000Kg]_N`000Vmk
00@006mkKg]_NaT000U_N`03001_Nfmk00M_N`H00003Kg/006mk00=_NaH000=_N`05001_NfmkKg/0
0003Kg/20005Kg/01000Kg]_Nfmk0P001Fmk00D006mkKg]_N`0000I_N`03001_Nfmk00I_N`03001_
Nfmk00=_N`80009_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk00A_N`P001U_N`03001_
Nfmk00U_N`8000M_N`03001_Nfmk011_N`8001Y_N`03001_Nfmk00a_N`003Vmk00<006mkKg/016mk
00D006mk001_N`0000M_N`03001_Nfmk00E_N`03001_N`0000A_N`03001_Nfmk00E_N`03001_Nfmk
01A_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk009_N`8000Q_N`03001_Nfmk00=_N`<0
00=_N`05001_NfmkKg/0000;Kg/00`00Kg/00002Kg/00`00Kg/000070009Kg/00`00Kg]_N`020000
16mk001_Nfmk0P001fmk00<006mkKg/01fmk0P000fmk0P0000=_N`00Kg/00Vmk1@0000A_N`000000
00A_N`8000E_N`D00003Kg/006mk009_N`03001_N`0000<000E_N`04001_NfmkKg/20004Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/20002Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/30003Kg/2000JKg/00`00Kg]_N`0<Kg/20006Kg/00`00
Kg]_N`0?Kg/2000IKg/00`00Kg]_N`0=Kg/000i_N`03001_Nfmk00A_N`03001_Nfmk008000I_N`03
001_Nfmk00I_N`03001_N`0000=_N`03001_Nfmk00I_N`03001_Nfmk01=_N`03001_Nfmk00E_N`03
001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00U_N`03001_Nfmk00E_N`80009_N`03001_N`00
00e_N`06001_N`00001_N`000Vmk0P0016mk0`001Vmk00<006mk00000fmk00<006mkKg/00P001fmk
00<006mkKg/01Fmk0P0000E_N`00001_N`00009_N`80009_N`04001_N`000002Kg/01@00Kg/006mk
00000fmk00<006mk00000fmk00@006mk0000009_N`07001_N`00Kg/006mk00000Vmk00<006mk0000
16mk00L006mkKg]_N`00Kg/00002Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`02Kg/01P00Kg]_N`00Kg/000a_N`04001_Nfmk0002Kg/3000016mk001_Nfmk0`0000=_
N`00Kg/066mk00<006mkKg/03Vmk00<006mkKg/016mk00<006mkKg/03Fmk100066mk00<006mkKg/0
3Fmk000?Kg/00`00Kg]_N`03Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk00M_N`03001_N`0000=_
N`03001_Nfmk00I_N`03001_Nfmk019_N`03001_Nfmk00M_N`03001_Nfmk009_N`04001_NfmkKg/2
000<Kg/00`00Kg]_N`07Kg/300000fmk001_N`0=Kg/40003Kg/00`00Kg/00006Kg/4000016mk0000
00001Fmk00<006mkKg/00P001Vmk00<006mkKg/016mk00@006mkKg]_N`800004Kg/006mkKg/40000
1Fmk001_Nfmk00000Vmk0P000Vmk0`000Vmk00P006mk000006mk001_N`000fmk0P0000=_N`000000
16mk00<006mk00000fmk00@006mkKg/0009_N`03001_N`0000E_N`03001_Nfmk00M_N`03001_Nfmk
00=_N`03001_Nfmk009_N`04001_NfmkKg/2000>Kg/00`00Kg/000020003Kg/01@00Kg]_N`00Kg/0
0P0000=_N`00Kg/066mk00<006mkKg/03fmk0P001Fmk00<006mkKg/02fmk0`0000=_N`00Kg/05fmk
00<006mkKg/03Fmk000?Kg/00`00Kg]_N`03Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk00M_N`03
001_N`00009_N`03001_Nfmk00Q_N`03001_Nfmk015_N`03001_Nfmk00M_N`03001_Nfmk009_N`04
001_N`00000?Kg/00`00Kg]_N`08Kg/C0005Kg/00`00Kg/0000:Kg/20007Kg/00`00Kg]_N`020005
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg/000050003Kg/01000Kg]_N`0016mk2@000fmk
00<006mk00001Fmk00<006mkKg/016mk00<006mkKg/00P0000E_N`00Kg]_N`0000=_N`03001_Nfmk
00A_N`03001_Nfmk00M_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/B0004Kg/01000Kg]_N`00
0Vmk00@006mkKg/001U_N`03001_Nfmk015_N`8000A_N`03001_Nfmk00U_N`06001_N`00001_N`00
66mk00<006mkKg/03Fmk000?Kg/00`00Kg]_N`03Kg/01`00Kg]_Nfmk001_N`00009_N`03001_Nfmk
00Q_N`05001_N`00Kg/0000;Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03000AKg/0
0`00Kg]_N`08Kg/4000>Kg/30003Kg/01000Kg]_N`002Fmk10001Vmk00D006mk001_N`0000A_N`03
001_Nfmk00=_N`03001_Nfmk00=_N`800009Kg/006mkKg/006mk001_N`0000=_N`07001_NfmkKg/0
06mk00000Vmk0`000Vmk00<006mk00000Vmk00@006mkKg]_N`800003Kg/006mk00A_N`03001_Nfmk
009_N`04001_N`000002Kg/200000fmk00000004Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/01000
Kg]_N`0016mk1P0036mk00<006mkKg/00Vmk00@006mkKg/0009_N`8000=_N`03001_Nfmk01E_N`03
001_Nfmk01A_N`03001_Nfmk009_N`03001_Nfmk00M_N`05001_N`00Kg/00002Kg/00`00Kg]_N`0E
Kg/00`00Kg]_N`0=Kg/000m_N`03001_Nfmk00=_N`09001_NfmkKg/006mk001_N`0000]_N`05001_
N`00Kg/0000;Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0:Kg/01000Kg/0000056mk00<006mkKg/01fmk
0P000Vmk00<006mkKg/02fmk00<006mkKg/00P0000E_N`00Kg]_N`0000Q_N`05001_N`00001_N`02
0004Kg/01@00Kg/006mk000016mk00@006mkKg]_N`8000I_N`80009_N`07001_N`00Kg/006mk0000
0fmk00L006mkKg]_N`00Kg/00002Kg/00`00Kg]_N`0300001Vmk001_Nfmk001_N`800005Kg/006mk
Kg/00004Kg/00`00Kg]_N`03Kg/500000fmk001_N`02Kg/200000fmk001_N`0:Kg/01@00Kg]_Nfmk
00000fmk00<006mkKg/0100000A_N`00Kg]_N`8000Y_N`03001_Nfmk009_N`<000=_N`8000=_N`03
001_Nfmk01E_N`03001_Nfmk01E_N`8000=_N`03001_Nfmk00I_N`05001_N`00Kg/00002Kg/00`00
Kg]_N`0EKg/00`00Kg]_N`0=Kg/0011_N`03001_Nfmk009_N`03001_Nfmk009_N`04001_N`00000<
Kg/00`00Kg/0000<Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0<Kg/2000FKg/00`00Kg]_N`05Kg/20004
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/20003Kg/00`00Kg]_N`04Kg/01P00Kg]_N`00Kg/0009_
N`03001_Nfmk009_N`80009_N`04001_Nfmk0003Kg/00`00Kg]_N`05Kg/;0004Kg/01000Kg]_N`00
0fmk00<006mk000016mk2`000fmk00D006mkKg]_N`0000I_N`h000]_N`04001_Nfmk0002Kg/02000
Kg]_N`00Kg/006mk0002Kg/01000Kg]_Nfmk0P0026mk00@006mkKg]_N`8000A_N`8000A_N`03001_
Nfmk01E_N`03001_Nfmk01M_N`800003Kg/006mk00I_N`03001_N`00009_N`05001_NfmkKg/0000F
Kg/00`00Kg]_N`0=Kg/0011_N`03001_Nfmk009_N`03001_Nfmk009_N`04001_N`00Kg/40008Kg/0
0`00Kg/0000<Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0;Kg/8000BKg/00`00Kg]_N`05Kg/20005Kg/2
0009Kg/00`00Kg]_N`03Kg/01P00Kg/00000Kg/000A_N`8000=_N`03001_N`0000=_N`80009_N`80
009_N`04001_Nfmk0002Kg/00`00Kg]_N`02Kg/500000fmk00000002Kg/00`00Kg]_N`040002Kg/0
1000Kg]_N`000fmk00<006mk00000fmk0P0000E_N`00001_N`00009_N`03001_Nfmk0080009_N`80
0003Kg/006mk00=_N`<000=_N`<000A_N`03001_N`0000@000M_N`07001_Nfmk001_N`00Kg/00P00
00E_N`00Kg]_N`00009_N`03001_Nfmk00=_N`<000E_N`03001_Nfmk008000E_N`8000E_N`03001_
Nfmk01A_N`03001_Nfmk01U_N`03001_N`0000E_N`04001_Nfmk0002Kg/01@00Kg]_Nfmk00005Fmk
00<006mkKg/03Vmk000@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01000Kg/0000016mk0`001Fmk
0P003Vmk00<006mkKg/02fmk00<006mkKg/02Vmk0`000Vmk00<006mkKg/00Vmk0`0046mk00<006mk
Kg/00fmk00<006mk00001fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mk
00000Vmk00<006mkKg/00fmk00@006mkKg/000A_N`800003Kg/00000009_N`03001_N`000080009_
N`<000A_N`04001_NfmkKg/2000026mk001_N`00Kg/006mk0002Kg/20005Kg/20002Kg/00`00Kg]_
N`03Kg/01@00Kg/006mk000016mk0`0000A_N`00Kg/0009_N`05001_N`00Kg/00002Kg/01000Kg]_
N`000fmk00@006mkKg/000=_N`@000A_N`03001_N`0000<0009_N`05001_NfmkKg/00003Kg/00`00
Kg]_N`05Kg/20003Kg/01000Kg/000001Fmk0P001Vmk00<006mkKg/056mk00<006mkKg/06Vmk0`00
0fmk00@006mkKg/0009_N`03001_Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk00i_N`0046mk00<0
06mkKg/00Vmk00<006mkKg/00fmk00<006mk00001fmk100000=_N`0000003Vmk00<006mkKg/02Vmk
00<006mkKg/02Fmk0P0000=_N`00Kg/00Vmk0P001Vmk100036mk00<006mkKg/00fmk00<006mk0000
26mk00<006mkKg/01Fmk00D006mkKg]_N`0000I_N`800003Kg/006mk00E_N`04001_Nfmk0006Kg/3
0002Kg/70006Kg/00`00Kg]_N`04Kg/30002Kg/00`00Kg]_N`040005Kg/40007Kg/30008Kg/60000
1Fmk001_Nfmk00000Vmk00@006mkKg]_N`<000A_N`03001_Nfmk00A_N`P000A_N`04001_Nfmk0004
Kg/00`00Kg]_N`07Kg/200000fmk00000007Kg/20006Kg/00`00Kg]_N`0CKg/00`00Kg]_N`0MKg/2
00000fmk001_N`02Kg/01000Kg]_N`001Fmk00<006mkKg/04Vmk00<006mkKg/03Vmk000AKg/01@00
Kg]_Nfmk00001Fmk00@006mk000000Y_N`8000m_N`03001_Nfmk00U_N`03001_Nfmk00Q_N`80009_
N`03001_Nfmk009_N`8000Y_N`<000Y_N`05001_NfmkKg/00002Kg/00`00Kg]_N`07Kg/20005Kg/0
1000Kg]_N`0026mk0P001fmk00D006mkKg]_N`0000M_N`H000Y_N`03001_Nfmk00E_Nbh000=_N`03
001_N`0000E_N`8000A_N`8000Q_N`8000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`08Kg/20007
Kg/00`00Kg/00007Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0OKg/90005Kg/00`00Kg]_N`0BKg/00`00
Kg]_N`0>Kg/0015_N`03001_Nfmk009_N`03001_Nfmk00=_N`<000Q_N`<00003Kg/0000000e_N`03
001_Nfmk00Q_N`03001_Nfmk00M_N`8000A_N`03001_Nfmk00=_N`8000a_N`@000I_N`05001_Nfmk
Kg/00002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg/00005Kg/400000fmk00000006Kg/0
1@00Kg]_Nfmk00001Fmk0P0000=_N`0000000Vmk0`001fmk00<006mkKg/00fmk0`0000E_N`00Kg]_
N`00009_N`@000I_N`03001_Nfmk00M_N`@000U_N`80009_N`@00004Kg/006mk0003Kg/20002Kg/3
0003Kg/00`00Kg]_N`04Kg/30004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/2
0006Kg/00`00Kg/00008Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0NKg/20003Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/04Vmk00<006mkKg/03Vmk000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20000
0fmk001_N`03Kg/300000fmk001_N`03Kg/2000;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/20005
Kg/00`00Kg]_N`04Kg/2000@Kg/30004Kg/00`00Kg/00002Kg/00`00Kg]_N`0;Kg/01P00Kg]_N`00
Kg/000=_N`<000E_N`03001_N`0000E_N`03001_Nfmk009_N`04001_NfmkKg/40005Kg/00`00Kg/0
00020004Kg/01000Kg]_Nfmk0P001Fmk00P006mk001_N`00Kg/006mk0P001Fmk00<006mkKg/01Fmk
0P0000A_N`00000000U_N`80009_N`80009_N`04001_N`000002Kg/00`00Kg/00005Kg/20002Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`020002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06
Kg/00`00Kg/00006Kg/00`00Kg/00008Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0MKg/30003Kg/01000
Kg]_Nfmk0P001Fmk00<006mkKg/04Fmk00<006mkKg/03Vmk000AKg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/2000016mk001_Nfmk0P000fmk00<006mkKg/01Fmk00<006mkKg/026mk00<006mkKg/01Vmk
00<006mkKg/01Fmk0P001Vmk00<006mkKg/01Vmk0P004Vmk1@0000E_N`00Kg]_N`0000i_N`P000Q_
N`04001_Nfmk0004Kg/00`00Kg]_N`02Kg/00`00Kg/000020009Kg/01000Kg]_Nfmk0P0000=_N`00
Kg/00`001fmk100000M_N`00Kg]_N`00Kg/00004Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P0000=_
N`00Kg/01Vmk00L006mk001_N`00Kg/00003Kg/500000fmk001_N`07Kg/400000fmk00000003Kg/2
00000fmk001_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk000016mk00<006mk
00002Vmk00<006mkKg/04Fmk00<006mkKg/076mk0P0000=_N`00Kg/00Vmk00H006mkKg/006mk0005
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0>Kg/0015_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_
Nfmk008000=_N`8000U_N`8000U_N`03001_Nfmk00A_N`03001_Nfmk00A_N`8000M_N`03001_Nfmk
00M_N`8001I_NaP000a_N`04001_NfmkKg/20002Kg/00`00Kg]_N`03Kg/2000;Kg/00`00Kg]_N`03
Kg/?0003Kg/01000Kg]_N`000Vmk0P000Vmk00<006mkKg/00Vmk0P0016mk0P0000=_N`00Kg/01Vmk
00L006mk001_N`00Kg/00005Kg/01@00Kg]_Nfmk00002Vmk0`001Fmk00<006mk00001Vmk00<006mk
Kg/01Vmk00<006mkKg/00Vmk0P0016mk00<006mkKg/00Vmk00<006mk00002Vmk00<006mkKg/046mk
00<006mkKg/076mk00D006mk001_N`00009_N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0@Kg/00`00Kg]_N`0?Kg/0019_N`05001_NfmkKg/00006Kg/300001Fmk001_Nfmk00003Fmk
00<006mkKg/01Vmk00<006mkKg/016mk00<006mkKg/00Vmk0P0026mk00<006mkKg/026mk00<006mk
00005Fmk0P000fmk00<006mkKg/03Fmk0`002fmk00<006mkKg/016mk00<006mk00000fmk0P000Vmk
0P002Vmk00<006mkKg/00fmk0`002Vmk00@006mkKg/000=_N`03001_Nfmk009_N`03001_N`00009_
N`8000I_N`80009_N`03001_Nfmk00=_N`03001_Nfmk0080009_N`04001_NfmkKg/2000016mk001_
N`001Vmk1@0000=_N`00Kg/00P000fmk0P0000=_N`00000016mk00<006mkKg/01fmk00@006mkKg/0
00I_N`05001_NfmkKg/00002Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0KKg/00`00
Kg/00002Kg/01000Kg]_N`000fmk00@006mkKg/000E_N`03001_Nfmk00m_N`03001_Nfmk00m_N`00
4Vmk00D006mkKg]_N`0000M_N`800004Kg/006mk000?Kg/20006Kg/00`00Kg]_N`03Kg/01000Kg]_
Nfmk0P002Fmk00<006mkKg/02Vmk0P0056mk0P0000E_N`00Kg]_N`0000i_N`03001_Nfmk008000Y_
N`03001_Nfmk00E_N`800005Kg/00000Kg/00004Kg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
0008Kg/01000Kg]_N`0016mk00<006mkKg/00Vmk10001fmk00<006mk00000Vmk00<006mkKg/00fmk
00<006mkKg/00P000Vmk00@006mk000000=_N`04001_N`00Kg/50005Kg/01@00Kg]_N`00Kg/00P00
00=_N`0000000fmk0P0000=_N`00Kg/02Fmk00<006mk00001fmk00L006mkKg]_N`00Kg/0000<Kg/0
0`00Kg]_N`0?Kg/00`00Kg]_N`0JKg/01000Kg]_N`000Vmk00@006mkKg/000=_N`05001_NfmkKg/0
0004Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0?Kg/0019_N`05001_NfmkKg/00007Kg/8000?Kg/20004
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02000:Kg/00`00Kg]_N`0;Kg/00`00Kg/0000BKg/20002Kg/0
1000Kg]_N`003Fmk00L006mkKg]_N`00Kg/00009Kg/00`00Kg]_N`06Kg/20002Kg/00`00Kg]_N`05
Kg/20008Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk0P001Vmk00<006mk00001Fmk00<006mkKg/00fmk
00<006mkKg/01fmk00<006mk00000fmk00D006mkKg]_N`0000=_N`l000U_N`03001_Nfmk009_N`03
001_Nfmk01L000M_N`04001_Nfmk0002Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0H
Kg/20002Kg/01@00Kg]_Nfmk00000Vmk00@006mkKg/000A_N`03001_Nfmk009_N`03001_Nfmk00m_
N`03001_Nfmk00m_N`004Vmk00D006mkKg]_N`0000M_N`04001_Nfmk0004Kg/6000;Kg/01@00Kg]_
Nfmk00000fmk00@006mk000000]_N`03001_Nfmk00a_N`04001_Nfmk000?Kg/200001Fmk001_Nfmk
00000Vmk00<006mkKg/02Vmk00<006mkKg/00fmk0P002Fmk00<006mkKg/01Fmk0P000fmk00<006mk
Kg/01fmk0P001fmk00D006mkKg]_N`0000E_N`8000A_N`03001_N`0000E_N`03001_Nfmk009_N`<0
00Q_N`03001_N`0000=_N`06001_NfmkKg/006mk0`000fmk0`001Vmk00<006mkKg/01fmk00<006mk
Kg/00fmk00@006mkKg/000E_N`800003Kg/0000000Y_N`04001_N`000005Kg/01P00Kg]_N`00Kg/0
00e_N`03001_Nfmk00m_N`03001_Nfmk01M_N`05001_NfmkKg/00004Kg/01000Kg]_N`000Vmk00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/03fmk000CKg/01000Kg]_N`00
1fmk00@006mkKg/000Y_N`L000E_N`80009_N`03001_N`00008000e_N`03001_Nfmk00e_N`03001_
N`0000i_N`04001_Nfmk0004Kg/01000Kg]_N`002fmk00<006mkKg/00fmk00<006mk000026mk00<0
06mkKg/016mk00H006mkKg/006mk000<Kg/30005Kg/01000Kg]_N`001fmk0P000Vmk0P001fmk00@0
06mkKg]_N`800003Kg/006mk00E_N`04001_Nfmk0004Kg/01@00Kg/006mk00000Vmk0P000Vmk00<0
06mkKg/00P0016mk00<006mkKg/01Fmk0P001fmk00<006mk00000Vmk0`000fmk00<006mk00002Fmk
0P000Vmk0`000fmk0P000Vmk00<006mkKg/036mk00<006mkKg/03Fmk00<006mkKg/05fmk00<006mk
Kg/00Vmk00<006mkKg/00Vmk00@006mkKg/0009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk00i_N`03001_Nfmk00m_N`004fmk00@006mkKg/000I_N`800003Kg/006mk015_N`H00003Kg/0
000000<000i_N`03001_Nfmk00i_N`04001_Nfmk000<Kg/01000Kg]_N`001Fmk00@006mkKg/000Y_
N`03001_Nfmk00A_N`04001_Nfmk0007Kg/00`00Kg]_N`03Kg/01`00Kg]_Nfmk001_N`0000m_N`80
00A_N`03001_N`0000U_N`@000M_N`04001_Nfmk0002Kg/00`00Kg/00005Kg/01000Kg]_N`0016mk
00@006mk000000=_N`80009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_
Nfmk00M_N`800003Kg/0000000E_N`05001_NfmkKg/00008Kg/20005Kg/200000fmk00000002Kg/0
0`00Kg]_N`0<Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0FKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1000Kg]_N`000Vmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/03Fmk00<006mkKg/03fmk
000CKg/01000Kg]_N`001Vmk0P0000=_N`00Kg/05Vmk1@003fmk00<006mkKg/03fmk00@006mkKg/0
00]_N`05001_NfmkKg/00005Kg/01000Kg]_N`002Fmk00<006mkKg/01Vmk00@006mkKg/000I_N`03
001_Nfmk009_N`03001_Nfmk00=_N`D000i_N`80009_N`03001_N`0000Y_N`<000M_N`04001_Nfmk
0002Kg/00`00Kg]_N`020003Kg/01000Kg]_N`001Fmk00<006mkKg/00fmk0P000Vmk00<006mkKg/0
0fmk0P000Vmk00<006mkKg/00Vmk00<006mkKg/01fmk10001fmk00D006mkKg]_N`0000Q_N`8000M_
N`80009_N`03001_Nfmk00e_N`03001_Nfmk00e_N`03001_Nfmk01E_N`03001_Nfmk00=_N`03001_
Nfmk00=_N`04001_Nfmk0002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00
Kg]_N`0@Kg/001=_N`04001_Nfmk0006Kg/3000>Kg/:0005Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0A
Kg/01000Kg]_N`002Fmk00D006mkKg]_N`0000M_N`03001_N`0000Q_N`03001_Nfmk00M_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk000016mk0`0016mk200026mk0P0000A_N`00Kg/000E_N`D00003
Kg/00000008000A_N`03001_N`0000=_N`03001_Nfmk009_N`04001_Nfmk0002Kg/01000Kg]_Nfmk
0P0000=_N`00Kg/00fmk0P000Vmk00<006mkKg/01Fmk0P0000E_N`00Kg]_N`0000E_N`D00003Kg/0
000000Q_N`03001_Nfmk009_N`03001_Nfmk00E_N`8000M_N`05001_N`00Kg/0000@Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`0DKg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01000Kg]_N`000Vmk00<006mk
Kg/01Vmk00D006mkKg]_N`0000i_N`03001_Nfmk011_N`0056mk00<006mk00001Vmk0`0016mk2P00
3fmk00<006mkKg/02Vmk00<006mkKg/04Vmk00@006mkKg/000Q_N`03001_Nfmk009_N`03001_Nfmk
00E_N`03001_N`0000M_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk009_N`05001_Nfmk
Kg/00002Kg/20002Kg/00`00Kg]_N`0:Kg/900000fmk0000000200000fmk000000020004Kg/00`00
Kg/00003Kg/400000fmk00000003Kg/00`00Kg]_N`03Kg/20003Kg/02000Kg/00000Kg/006mk0004
Kg/01@00Kg/006mk00002Fmk0P0000=_N`00Kg/01@001Vmk00<006mk00001fmk00<006mkKg/00fmk
00<006mkKg/016mk00<006mk00001Vmk00@006mk0000015_N`03001_Nfmk00]_N`03001_Nfmk01A_
N`03001_Nfmk00A_N`03001_Nfmk00=_N`04001_Nfmk0002Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0@Kg/001A_N`04001_Nfmk0004Kg/00`00Kg/00005000JKg/0
0`00Kg]_N`08Kg/00`00Kg]_N`0DKg/01000Kg]_N`001Vmk00<006mkKg/00Vmk00<006mkKg/01fmk
0P001Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00@006mkKg/000=_N`04001_Nfmk0004Kg/00`00
Kg]_N`0CKg/60007Kg/01@00Kg]_Nfmk00001Vmk0P0016mk00<006mkKg/016mk1P000Vmk00D006mk
Kg]_N`0000=_N`05001_N`00Kg/0000;Kg/3000:Kg/01000Kg]_N`001fmk00<006mkKg/016mk00<0
06mkKg/00fmk00<006mk00001Fmk00D006mkKg]_N`00015_N`03001_Nfmk00]_N`03001_Nfmk01=_
N`03001_Nfmk00A_N`03001_Nfmk00A_N`04001_Nfmk0002Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk
00003Fmk00<006mkKg/046mk000DKg/01000Kg]_N`0016mk00<006mk00000Vmk1@006Fmk00<006mk
Kg/01Vmk00<006mkKg/05Fmk00@006mkKg/000A_N`8000E_N`03001_Nfmk00M_N`8000E_N`03001_
Nfmk00]_N`03001_Nfmk009_N`04001_Nfmk0002Kg/01000Kg/000001Fmk00<006mkKg/03Vmk1P00
0Vmk0`001Vmk00<006mkKg/00Vmk00<006mkKg/00fmk1@000Vmk00<006mkKg/00Vmk0P0000E_N`00
Kg]_N`0000=_N`05001_NfmkKg/00003Kg/01@00Kg/006mk00002Fmk0`0036mk00@006mkKg/000I_
N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_N`0000E_N`06001_Nfmk001_N`004Fmk00<006mk
Kg/02Vmk00<006mkKg/04Vmk00<006mkKg/01Fmk00<006mkKg/016mk00@006mkKg/0009_N`03001_
Nfmk00M_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0@Kg/001A_N`04001_Nfmk0004Kg/20008Kg/6
000CKg/00`00Kg]_N`05Kg/00`00Kg]_N`0FKg/01@00Kg]_Nfmk00000Vmk00<006mkKg/016mk00<0
06mkKg/026mk0P0016mk00<006mkKg/03Fmk00<006mkKg/00Vmk00@006mk001_N`<000M_N`03001_
Nfmk00M_N`L000M_N`04001_N`000005Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00000fmk00<006mk
00000Vmk00@006mkKg/000=_N`03001_Nfmk00800003Kg/006mk00A_N`04001_Nfmk0002Kg/20007
Kg/20003Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/01@00
Kg]_Nfmk00000Vmk00D006mkKg]_N`00009_N`80009_N`03001_Nfmk00i_N`03001_Nfmk00Y_N`03
001_Nfmk015_N`03001_Nfmk00E_N`03001_Nfmk00E_N`04001_Nfmk0002Kg/00`00Kg]_N`08Kg/0
1@00Kg]_Nfmk000036mk00<006mkKg/046mk000DKg/01000Kg]_N`0016mk0P003Vmk1@003fmk00<0
06mkKg/016mk00<006mkKg/05fmk00H006mkKg/006mk0006Kg/00`00Kg]_N`0:Kg/20003Kg/00`00
Kg]_N`0=Kg/00`00Kg]_N`03Kg/40009Kg/01000Kg]_Nfmk1P003Fmk00@006mkKg]_N`8000A_N`03
001_Nfmk00A_N`04001_N`000004Kg/00`00Kg]_N`050005Kg/01P00Kg/00000Kg/000I_N`03001_
N`00009_N`8000I_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk00=_
N`03001_Nfmk00Q_N`04001_Nfmk0002Kg/01000Kg]_N`000Vmk0P0016mk00<006mkKg/03Vmk00<0
06mkKg/02Fmk00<006mkKg/046mk00<006mkKg/01Fmk00<006mkKg/01Vmk00H006mkKg/006mk000;
Kg/01@00Kg]_Nfmk000036mk00<006mkKg/046mk000EKg/00`00Kg/00003Kg/00`00Kg/0000CKg/5
000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0DKg/90007Kg/00`00Kg]_N`0:Kg/20002Kg/00`00Kg]_
N`0>Kg/00`00Kg]_N`04Kg/@000CKg/01000Kg]_Nfmk0P000fmk00<006mkKg/01Fmk3`001Vmk00@0
06mk001_N`8000I_N`03001_N`00009_N`8000A_N`8000I_N`03001_Nfmk00M_N`03001_Nfmk00=_
N`03001_Nfmk00=_N`03001_Nfmk00Q_N`04001_Nfmk0002Kg/00`00Kg]_N`0300000fmk001_N`04
Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06
Kg/01P00Kg]_N`00Kg/000a_N`04001_Nfmk000;Kg/00`00Kg]_N`0AKg/001E_N`03001_N`0000=_
N`8001U_N`H000I_N`04001_Nfmk000=Kg/:0003Kg/200000fmk000000030004Kg/00`00Kg]_N`0;
Kg/200000fmk001_N`0AKg/00`00Kg]_N`02Kg/20009Kg/5000CKg/00`00Kg]_N`02Kg/01@00Kg/0
06mk000016mk100000=_N`00Kg/01Fmk00D006mk001_N`00009_N`<000A_N`<0009_N`<000A_N`80
009_N`80009_N`8000U_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk
00U_N`03001_N`00009_N`04001_N`000002Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/01P00Kg]_N`00Kg/000a_N`05
001_NfmkKg/0000:Kg/00`00Kg]_N`0AKg/001E_N`03001_N`0000=_N`8001m_N`D00004Kg/006mk
0004Kg/:000<Kg/00`00Kg/00004Kg/40002Kg/00`00Kg]_N`0<Kg/2000CKg/00`00Kg]_N`02Kg/2
0007Kg/20002Kg/01000Kg]_N`004Fmk00<006mkKg/00fmk00@006mk001_N`D000E_N`03001_Nfmk
00=_N`06001_Nfmk001_N`001Fmk1`001Fmk1P000fmk0`002fmk00<006mkKg/01Fmk00<006mkKg/0
1Fmk00<006mkKg/00Vmk00<006mkKg/02Vmk0P000fmk0P000fmk00<006mkKg/01Vmk0P003Fmk00<0
06mkKg/01fmk00<006mkKg/03Fmk0P002Fmk00<006mkKg/01fmk00<006mk00000Vmk00<006mkKg/0
2fmk00@006mkKg/000Y_N`03001_Nfmk015_N`005Fmk00<006mk00000fmk0P0096mk20005Fmk00@0
06mkKg/000Q_Na@0019_N`07001_NfmkKg/006mk00001Vmk00<006mkKg/00Vmk00D006mkKg]_N`00
00m_N`03001_Nfmk00A_N`03001_Nfmk008000U_N`03001_Nfmk009_N`04001_NfmkKg/O000<Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`07Kg/01000Kg]_N`003Fmk1P000fmk00<006mkKg/02Fmk00<006mk
Kg/02Vmk00<006mkKg/01fmk00<006mkKg/036mk00<006mkKg/026mk00<006mkKg/026mk00D006mk
001_N`0000i_N`04001_Nfmk000:Kg/00`00Kg]_N`0AKg/001I_N`80009_N`80029_N`@00003Kg/0
000001Q_N`05001_NfmkKg/00009Kg/4000:Kg/200000fmk001_N`06000=Kg/01P00Kg]_N`00Kg/0
00A_N`8000E_N`03001_Nfmk009_N`8000a_N`03001_Nfmk00E_N`05001_N`00001_N`030006Kg/0
0`00Kg]_N`020002Kg/200000fmk001_N`09Kg/3000:Kg/01P00Kg]_Nfmk001_N`8000]_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`04001_Nfmk000;Kg/300001Fmk000006mk00000fmk00<006mkKg/0
2Vmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mkKg/0
26mk00D006mk001_N`0000m_N`04001_Nfmk0009Kg/00`00Kg]_N`0AKg/001I_N`80009_N`8001i_
N`@000E_N`03001_N`0001I_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_N`00009_N`<000I_
N`04001_NfmkKg/30005Kg/60007Kg/00`00Kg/00002Kg/00`00Kg]_N`020007Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/30004Kg/20004Kg/01000Kg/006mk0`000fmk00<006mk
Kg/026mk0P0000=_N`00Kg/026mk00@006mkKg/000A_N`<000Q_N`03001_Nfmk009_N`03001_Nfmk
00Q_N`04001_Nfmk0009Kg/20002Kg/02@00Kg]_Nfmk001_N`00Kg/0000>Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/00`00Kg]_N`09Kg/01@00Kg/006mk0000
3fmk00@006mkKg/000U_N`03001_Nfmk015_N`005Vmk0P000Vmk0P006Vmk10002Vmk00<006mk0000
56mk00<006mkKg/00fmk00<006mkKg/01Vmk00@006mkKg/000A_N`80009_N`8000E_N`03001_N`00
00Y_N`H0009_N`80009_N`<000U_N`03001_Nfmk00E_N`8000M_N`03001_Nfmk00Q_N`03001_N`00
00I_N`<00003Kg/00000008000I_N`03001_Nfmk00M_N`8000=_N`03001_Nfmk00I_N`04001_Nfmk
0007Kg/20007Kg/01000Kg]_N`0036mk00<006mk00001fmk0P000fmk00<006mkKg/00fmk0P0000=_
N`00Kg/03Vmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/02Fmk00<0
06mkKg/02Vmk00D006mk001_N`00011_N`04001_Nfmk0008Kg/00`00Kg]_N`0AKg/001I_N`80009_
N`03001_Nfmk01E_N`@000i_N`03001_N`0001=_N`03001_Nfmk00A_N`03001_Nfmk00E_N`05001_
NfmkKg/00006Kg/20007Kg/01000Kg]_N`003fmk5@001fmk00<006mkKg/016mk00<006mkKg/01Vmk
0`0000=_N`00Kg/026mk0`0026mk00<006mkKg/01fmk0P000fmk00<006mkKg/01Vmk00@006mkKg/0
00U_N`8000E_N`04001_Nfmk000<Kg/00`00Kg/00004Kg/30005Kg/00`00Kg]_N`04Kg/3000@Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/0
1@00Kg/006mk000046mk00@006mkKg/000M_N`03001_Nfmk019_N`005fmk10004fmk10004Vmk00@0
06mkKg/0015_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`03
001_N`0000M_N`04001_Nfmk000?Kg/01@00Kg/006mk00001Vmk10000Vmk0P0000=_N`0000000P00
16mk00<006mkKg/00Vmk00<006mkKg/00fmk100000=_N`00Kg/00P001Fmk100000=_N`00000026mk
00<006mkKg/01Vmk00<006mk000016mk00<006mkKg/01Fmk00@006mkKg/000]_N`<0009_N`03001_
N`0000e_N`8000=_N`8000M_N`03001_Nfmk009_N`<00003Kg/006mk008000m_N`03001_Nfmk00M_
N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00Y_N`03001_Nfmk00]_N`04001_N`00000B
Kg/00`00Kg/00007Kg/00`00Kg]_N`0BKg/001M_N`@000m_N`@001I_N`05001_NfmkKg/0000>Kg/2
0008Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg]_N`001fmk00@006mk
Kg/000i_N`06001_N`00Kg/006mk1@001fmk0P0016mk1`0000=_N`00Kg/01@0016mk00<006mkKg/0
0P0000=_N`0000000P001Fmk0P0026mk00<006mkKg/01Vmk00<006mk00001Fmk00<006mkKg/016mk
00<006mk00003fmk0P0000=_N`0000003Vmk00@006mk000000U_N`D000A_N`04001_NfmkKg/2000>
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0;
Kg/200000fmk001_N`0AKg/01000Kg]_N`001Vmk00<006mkKg/04Vmk000GKg/3000<Kg/4000JKg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/0
1@00Kg]_Nfmk000016mk00<006mkKg/016mk00@006mkKg]_N`8000]_N`04001_NfmkKg/3000<Kg/0
0`00Kg/00008Kg/50008Kg/00`00Kg]_N`02Kg/20009Kg/00`00Kg/00007Kg/00`00Kg]_N`05Kg/0
0`00Kg/00007Kg/00`00Kg]_N`03Kg/00`00Kg/0000AKg/O0007Kg/00`00Kg]_N`04Kg/3000<Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/2
00000fmk001_N`0BKg/00`00Kg/00006Kg/00`00Kg]_N`0BKg/001M_N`<000Q_N`@001i_N`03001_
Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00U_N`03001_Nfmk00A_N`03001_Nfmk00A_N`05001_
NfmkKg/00005Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04000<Kg/01000
Kg]_N`0026mk00<006mk000026mk00@006mkKg]_N`800003Kg/006mk00Q_N`03001_N`0000M_N`03
001_Nfmk00A_N`04001_Nfmk0008Kg/00`00Kg]_N`02Kg/00`00Kg/0000>Kg/6000=Kg/40007Kg/2
00000fmk001_N`06Kg/00`00Kg]_N`07Kg/2000;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0<Kg/200000fmk001_N`0BKg/00`00Kg/00006Kg/0
0`00Kg]_N`0BKg/001Q_N`8000A_N`@002=_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk
00Y_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_N`0000Q_N`03001_Nfmk00=_N`03001_Nfmk
009_N`03001_Nfmk00I_N`03001_Nfmk008000=_N`03001_Nfmk00Y_N`04001_Nfmk0007Kg/00`00
Kg/00007Kg/00`00Kg]_N`02000016mk001_N`0026mk00D006mk001_N`0000I_N`03001_Nfmk00A_
N`04001_Nfmk0009Kg/01000Kg]_Nfmk0P0036mk1P0000=_N`00000036mk00<006mk00000Vmk00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/02Fmk0P002Vmk00<006mkKg/0
16mk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/036mk00<006mkKg/03Fmk0`005Fmk00<0
06mk00001Fmk00<006mkKg/04Vmk000HKg/00`00Kg/00003000WKg/00`00Kg]_N`04Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg/00009Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/01P00Kg]_N`00Kg/000A_N`03001_Nfmk00U_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00@006mkKg/0009_N`05001_NfmkKg/00007Kg/0
0`00Kg/00002Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00002Vmk00<006mkKg/0
0P002Fmk0`0000A_N`00000000A_N`8000Y_N`04001_Nfmk0003Kg/200000fmk00000006Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`0;Kg/30008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0>Kg/3000EKg/00`00Kg/00005Kg/00`00Kg]_N`0BKg/001Q_
Nbl000E_N`03001_Nfmk00=_N`03001_Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk00M_N`8000Y_
N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00=_N`<0009_N`03001_Nfmk00=_N`8000U_
N`03001_Nfmk009_N`03001_Nfmk009_N`05001_NfmkKg/00004Kg/01000Kg/000000fmk00<006mk
Kg/00Vmk00<006mkKg/016mk00<006mk00000Vmk00<006mkKg/00fmk00<006mkKg/00fmk00@006mk
Kg/000]_N`03001_Nfmk008000I_N`<000=_N`03001_N`0000E_N`8000U_N`05001_NfmkKg/00005
Kg/30007Kg/20003Kg/00`00Kg]_N`0>Kg/20007Kg/00`00Kg]_N`03Kg/01000Kg]_N`001Vmk00<0
06mkKg/03Fmk00<006mkKg/03Vmk0`005Vmk0P0016mk00<006mkKg/04fmk000HKg/3000ZKg/00`00
Kg/000020003Kg/01@00Kg]_Nfmk00003fmk00<006mkKg/00Vmk00<006mkKg/01fmk1@002Fmk00D0
06mkKg]_N`0000I_N`80009_N`8000A_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03001_Nfmk009_
N`04001_Nfmk0005Kg/00`00Kg]_N`030004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg/0
0003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk000036mk00@006mk000000=_N`<0
00A_N`800003Kg/006mk00E_N`03001_N`0000M_N`05001_NfmkKg/00005Kg/01000Kg]_Nfmk1000
1Fmk00<006mk00004fmk0`001Fmk0P000fmk00@006mkKg/000A_N`8000m_N`03001_Nfmk00m_N`<0
01I_N`03001_N`0000=_N`03001_Nfmk01=_N`006Fmk00<006mk0000:6mk00<006mkKg/00fmk1@00
00=_N`00Kg/03fmk00<006mkKg/00Vmk00<006mkKg/01Vmk00H006mk001_N`00Kg/20008Kg/01@00
Kg]_Nfmk00001fmk00<006mk000016mk00<006mkKg/01fmk0P001fmk00<006mkKg/00fmk00<006mk
00001Fmk00@006mk000000I_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_N`0000=_N`03001_
Nfmk009_N`03001_Nfmk009_N`05001_NfmkKg/0000=Kg/2000016mk000000001Fmk0P000Vmk00<0
06mkKg/01Fmk00<006mk00001fmk00D006mkKg]_N`0000E_N`03001_Nfmk00E_N`D00003Kg/00000
01I_N`8000E_N`04001_Nfmk0002Kg/01@00Kg]_Nfmk00004Fmk00<006mkKg/03fmk0`005fmk0P00
0fmk00<006mkKg/04fmk000IKg/01000Kg]_N`009fmk00<006mkKg/01fmk0P004Fmk00D006mkKg]_
N`0000Q_N`06001_Nfmk001_N`000fmk0`001Vmk00D006mkKg]_N`0000M_N`03001_Nfmk00=_N`03
001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00=_N`T000M_N`03001_Nfmk00E_N`03001_Nfmk
00=_N`03001_N`0000A_N`05001_NfmkKg/00003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/20007
Kg/00`00Kg]_N`020008Kg/01000Kg]_N`001Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mk
Kg/02fmk1`0056mk0P0016mk00H006mkKg/006mk0002Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0?Kg/3
000HKg/20003Kg/00`00Kg]_N`0CKg/001U_N`04001_NfmkKg/2000TKg/00`00Kg]_N`08Kg/4000?
Kg/01@00Kg]_Nfmk00001Vmk0P000fmk00@006mkKg/000E_N`8000E_N`04001_Nfmk0006Kg/00`00
Kg/00004Kg/00`00Kg]_N`0:Kg/20005Kg/00`00Kg]_N`02Kg/40004Kg/01000Kg/000001Fmk00<0
06mkKg/01Vmk00<006mkKg/00Vmk00<006mk000016mk00D006mkKg]_N`00009_N`03001_Nfmk009_
N`03001_Nfmk00]_N`<000I_N`80009_N`03001_Nfmk00Q_N`04001_Nfmk0004Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/40003Kg/9000=Kg/30002Kg/01`00Kg/006mk001_N`00
019_N`03001_Nfmk00m_N`<001U_N`80009_N`03001_Nfmk01=_N`006Fmk00<006mkKg/00fmk00<0
06mkKg/08Fmk00<006mkKg/01fmk00<006mk00000Vmk0P003Fmk00D006mkKg]_N`0000E_N`03001_
Nfmk00=_N`05001_NfmkKg/00006Kg/20004Kg/01000Kg]_N`001Fmk00<006mk00000fmk00<006mk
Kg/03Fmk00<006mkKg/00Vmk00<006mkKg/00Vmk0`0000=_N`00Kg/00Vmk00D006mkKg]_N`0000=_
N`03001_Nfmk00Q_N`07001_NfmkKg/006mk00001Fmk00@006mkKg/0009_N`03001_Nfmk009_N`03
001_Nfmk00U_N`8000=_N`04001_NfmkKg/20003Kg/00`00Kg]_N`0:Kg/01000Kg]_N`000Vmk00<0
06mkKg/016mk00D006mkKg]_N`0000a_N`8000=_N`03001_Nfmk00Y_N`P000Q_N`800006Kg/00000
001_N`004Vmk00<006mkKg/046mk0`006Fmk0P000Vmk00<006mkKg/04fmk000JKg/00`00Kg]_N`03
Kg/2000PKg/00`00Kg]_N`07Kg/01000Kg]_N`0016mk00<006mkKg/02Vmk00@006mkKg/000E_N`03
001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00E_N`8000=_N`800003Kg/006mk009_N`05001_
NfmkKg/00002Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`02Kg/02@00Kg]_N`00Kg/006mk001_N`030005
Kg/200000fmk001_N`09Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mk001_N`0000E_N`03
001_Nfmk00Q_N`03001_Nfmk00=_N`04001_N`000004Kg/00`00Kg]_N`0;Kg/01P00Kg]_N`00Kg/0
00M_N`05001_NfmkKg/0000:Kg/20005Kg/2000CKg/900000fmk00000003000CKg/00`00Kg]_N`0@
Kg/3000JKg/200000fmk001_N`0DKg/001Y_N`03001_Nfmk00E_N`03001_Nfmk01e_N`03001_Nfmk
00I_N`05001_NfmkKg/00005Kg/2000:Kg/01000Kg]_N`0016mk00<006mkKg/01Fmk00<006mkKg/0
0fmk00<006mkKg/01Vmk0`000Vmk0P000fmk00D006mkKg]_N`00009_N`03001_Nfmk00m_N`80009_
N`08001_Nfmk001_N`00Kg/000=_N`/000Y_N`03001_N`0000=_N`03001_Nfmk00=_N`05001_N`00
Kg/00005Kg/00`00Kg]_N`06Kg/20006Kg/20005Kg/00`00Kg]_N`09Kg/80008Kg/01000Kg]_N`00
2Fmk0P001fmk0P0076mk1P004Vmk00<006mkKg/04Fmk0`006Vmk0`005Vmk000JKg/00`00Kg]_N`06
Kg/2000LKg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00
Kg/00004Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/200001Fmk000006mk0000
1Fmk00<006mk00004fmk00D006mk001_N`00009_N`06001_Nfmk001_N`0016mk0`0000A_N`00001_
N`D000I_N`8000=_N`03001_Nfmk00A_N`<000E_N`03001_Nfmk00I_N`03001_Nfmk00=_N`<0009_
N`03001_Nfmk008000I_N`H0009_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk0P002Vmk
0P007Fmk0`0000=_N`0000003fmk00<006mkKg/04Vmk0P0076mk0P005Vmk000KKg/00`00Kg]_N`07
Kg/00`00Kg]_N`0IKg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/20007Kg/00`00
Kg/00003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/300000fmk001_N`04Kg/2
000EKg/40002Kg/01@00Kg]_N`00Kg/01@0016mk0`001Fmk1@0000=_N`0000000fmk00<006mkKg/0
16mk0`001Fmk00<006mkKg/016mk0P000fmk0`001Fmk00<006mk00000Vmk1P0026mk00@006mkKg/0
00=_N`03001_Nfmk00A_N`03001_N`0000I_N`8000a_N`8001]_N`800003Kg/006mk00=_N`8000e_
N`03001_Nfmk019_N`8001a_N`8001I_N`006fmk00<006mkKg/026mk00<006mkKg/05fmk00<006mk
Kg/01Fmk00<006mkKg/016mk00<006mkKg/026mk0P001Fmk00<006mk00000Vmk00<006mkKg/026mk
00<006mkKg/01Fmk00<006mkKg/02fmk:`001fmk00D006mk001_N`0000U_N`l000I_N`03001_Nfmk
009_N`8000=_N`8000M_N`H000e_N`04001_Nfmk0005Kg/00`00Kg]_N`02Kg/00`00Kg/00005Kg/2
000>Kg/00`00Kg/0000HKg/20003Kg/00`00Kg]_N`04Kg/2000:Kg/00`00Kg]_N`0CKg/2000JKg/4
000FKg/001]_N`03001_Nfmk00U_N`8001M_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk
00Y_N`03001_Nfmk009_N`800003Kg/0000000]_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`04001_
N`000004Kg/2000EKg/30003Kg/01@00Kg]_Nfmk000026mk00<006mk00000Vmk00<006mkKg/01fmk
00@006mkKg]_N`@000A_N`04001_N`000004Kg/01@00Kg]_Nfmk00000Vmk0`000fmk1P0000=_N`00
00000P003Fmk00@006mkKg/000M_N`80009_N`03001_N`0000=_N`80015_N`8001I_N`8000A_N`03
001_Nfmk00M_N`<000M_N`03001_Nfmk01=_N`80019_N`P0009_N`03001_Nfmk01E_N`006fmk00<0
06mkKg/02fmk00<006mkKg/04fmk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/02fmk0P00
0Vmk0`003Fmk00<006mkKg/01fmk00<006mkKg/01fmk0P000Vmk00<006mk00000fmk0P004fmk0P00
0Vmk00D006mkKg]_N`00009_N`03001_N`0000M_N`04001_Nfmk0002Kg/20007Kg/00`00Kg]_N`02
0003Kg/01@00Kg]_Nfmk00000fmk00@006mkKg/0009_N`D00003Kg/0000000<000I_N`800003Kg/0
06mk008000Y_N`04001_N`00000:Kg/01000Kg/000000Vmk0P004fmk00<006mk000056mk00<006mk
Kg/016mk00<006mkKg/02Vmk0P0016mk00<006mkKg/056mk00<006mkKg/02Fmk20002Fmk00<006mk
Kg/05Vmk000LKg/00`00Kg]_N`0;Kg/2000CKg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`0=Kg/4000>Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg/000020002
Kg/00`00Kg]_N`0>Kg/20004Kg/01@00Kg]_Nfmk00000Vmk00<006mk00001fmk00@006mkKg/000A_
N`03001_Nfmk00=_N`06001_Nfmk001_N`0016mk0`001Fmk2`002Vmk00D006mk001_N`0000=_N`03
001_Nfmk00M_N`8000e_N`D001E_N`04001_Nfmk000AKg/20007Kg/00`00Kg]_N`0<Kg/20002Kg/0
0`00Kg]_N`0DKg/01000Kg]_Nfmk200046mk0P0066mk000LKg/00`00Kg]_N`0=Kg/00`00Kg]_N`0@
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/2000>Kg/00`00Kg]_N`09Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/036mk0P001Vmk00D006mk
Kg]_N`00009_N`03001_N`0000M_N`04001_Nfmk0005Kg/00`00Kg]_N`02Kg/30002Kg/00`00Kg]_
N`04Kg/;000>Kg/20002Kg/00`00Kg/00004Kg/20006Kg/2000<Kg/5000HKg/00`00Kg/0000?Kg/2
0008Kg/00`00Kg]_N`0?Kg/M000GKg/2000IKg/001a_N`03001_Nfmk00i_N`03001_Nfmk00i_N`03
001_Nfmk009_N`03001_Nfmk00U_N`03001_Nfmk00i_N`800003Kg/0000000a_N`03001_Nfmk00U_
N`04001_NfmkKg/20008Kg/01`00Kg/006mk001_N`0000a_N`8000U_N`03001_N`00009_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`020004Kg/00`00Kg]_N`03
Kg/30006Kg/2000>Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/016mk0P000fmk0P001fmk1P0000E_
N`00000006mk00@001A_N`04001_Nfmk000<Kg/2000:Kg/00`00Kg]_N`0>Kg/4000EKg/2000JKg/0
0`00Kg]_N`0HKg/001e_N`03001_Nfmk00i_N`8000i_N`05001_NfmkKg/0000<Kg/00`00Kg]_N`0=
Kg/01000Kg]_N`000Vmk0P002Vmk00<006mkKg/02Vmk00<006mk00002Vmk00L006mk001_N`00Kg/0
000:Kg/2000;Kg/00`00Kg/00002Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
16mk00<006mk000016mk00<006mkKg/00fmk00D006mk001_N`0000E_N`8000e_N`03001_Nfmk009_
N`05001_NfmkKg/00007Kg/2000016mk001_Nfmk1P001Vmk00@006mkKg/000E_N`@0011_N`04001_
Nfmk000;Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/20002Kg/2000EKg/2000IKg/00`00Kg]_N`0I
Kg/001e_N`03001_Nfmk011_N`03001_Nfmk00Y_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0=Kg/0
1000Kg]_N`0016mk0P0026mk00<006mkKg/02Vmk3`000fmk0P0026mk0P003Fmk00<006mk00000Vmk
00D006mkKg]_N`0000E_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk
009_N`07001_NfmkKg/006mk000016mk00<006mk00002fmk00<006mkKg/00fmk00D006mkKg]_N`00
00U_N`@000]_N`05001_NfmkKg/00009Kg/4000=Kg/01000Kg]_N`0026mk0P0036mk00<006mkKg/0
36mk00<006mkKg/00Vmk00<006mk00004fmk00@006mkKg/001M_N`03001_Nfmk01Y_N`007Fmk00<0
06mkKg/04Fmk0P002Vmk00@006mkKg/000i_N`03001_Nfmk00a_N`05001_NfmkKg/00006Kg/30005
Kg/00`00Kg]_N`06Kg/400000fmk0000000;Kg/300000fmk00000006Kg/2000?Kg/01@00Kg/006mk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mk000016mk00D006mk
Kg]_N`0000A_N`03001_Nfmk0080009_N`03001_N`0000Y_N`03001_Nfmk00=_N`03001_Nfmk009_
N`03001_Nfmk00I_N`03001_N`0000]_N`8000A_N`03001_Nfmk00]_N`@000U_N`04001_Nfmk0006
Kg/2000>Kg/00`00Kg]_N`0:Kg/20005Kg/00`00Kg/0000CKg/01000Kg]_N`005Vmk0P0076mk000M
Kg/00`00Kg]_N`0CKg/00`00Kg]_N`06Kg/01000Kg]_N`003fmk00<006mkKg/02fmk00<006mkKg/0
0Vmk00<006mkKg/01fmk0P000fmk00<006mkKg/00fmk0`0016mk00@006mkKg/000Y_N`05001_Nfmk
001_N`020003Kg/2000AKg/01@00Kg/006mk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<0
06mkKg/00fmk00<006mk00000fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_N`00009_
N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00A_N`04001_Nfmk000:
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0?Kg/40005Kg/01@00Kg]_Nfmk00000fmk0P003fmk00<006mk
Kg/02Fmk0P001fmk00@006mkKg/0015_N`05001_NfmkKg/0000EKg/2000MKg/001i_N`03001_Nfmk
01=_N`8000I_N`03001_N`00011_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`80
0003Kg/006mk00@000M_N`05001_NfmkKg/00008Kg/00`00Kg]_N`02Kg/300000fmk0000000CKg/0
1@00Kg/006mk00001Fmk00<006mkKg/00Vmk00<006mkKg/016mk00D006mkKg]_N`0000=_N`04001_
Nfmk0002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/20003Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/20007Kg/00`00
Kg]_N`0CKg/40002Kg/01@00Kg]_N`00Kg/00P004Fmk00<006mkKg/01fmk0P002Fmk00@006mkKg/0
015_N`05001_NfmkKg/0000DKg/2000NKg/001i_N`03001_Nfmk01E_N`03001_Nfmk009_N`03001_
N`00015_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`<000]_N`03001_Nfmk009_
N`03001_Nfmk00E_N`03001_Nfmk00A_N`8001E_N`04001_N`000007Kg/01000Kg]_N`001fmk00@0
06mkKg/000A_N`06001_Nfmk001_N`001fmk00<006mkKg/016mk00D006mkKg]_N`0000A_N`8000M_
N`03001_Nfmk00A_N`04001_NfmkKg/20006Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/T000BKg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0:Kg/01000Kg]_N`003fmk00<006mkKg/00fmk00<006mkKg/046mk
0P007fmk000NKg/00`00Kg]_N`0FKg/01000Kg]_Nfmk0P004Vmk00<006mkKg/02Fmk00<006mkKg/0
1Fmk00<006mkKg/02Fmk0P0000=_N`00Kg/02Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mk
Kg/00fmk00<006mk000010004Fmk00@006mk000000M_N`04001_Nfmk0007Kg/00`00Kg/00006Kg/0
1000Kg/000002Fmk00@006mkKg]_N`D0009_N`04001_Nfmk0009Kg/00`00Kg]_N`04Kg/01000Kg]_
N`002Fmk00D006mkKg]_N`0000A_N`@00004Kg/006mkKg/4000EKg/01P00Kg]_Nfmk001_N`<000m_
N`03001_Nfmk00E_N`8000e_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0?Kg/2
000PKg/001m_N`03001_Nfmk01I_N`@001=_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk
00I_N`8000A_N`03001_Nfmk00M_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk009_N`05
001_NfmkKg/00003Kg/3000>Kg/01000Kg/000001fmk00@006mkKg/000Q_N`8000I_N`<000Y_N`04
001_N`000002Kg/00`00Kg]_N`0300000fmk001_N`09Kg/00`00Kg]_N`05Kg/2000:Kg/00`00Kg/0
00060005Kg/00`00Kg]_N`04Kg/3000BKg/01000Kg]_N`000fmk00<006mk00000P0036mk00<006mk
Kg/00fmk0P003fmk00D006mkKg]_N`0000e_N`03001_Nfmk00A_N`03001_Nfmk00i_N`80025_N`00
7fmk00<006mkKg/05Fmk100056mk00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/01Fmk00<0
06mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/01Vmk00<006mkKg/00Vmk00D006mkKg]_N`0000E_
N`03001_Nfmk00=_N`<000a_N`8000U_N`03001_N`0000M_NaP000E_N`04001_NfmkKg/30009Kg/0
0`00Kg]_N`05Kg/A0009Kg/00`00Kg]_N`08Kg/3000>Kg/01000Kg]_N`001Fmk00@006mkKg]_N`80
00Y_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk009_N`03001_Nfmk00U_N`03001_Nfmk
00E_N`03001_Nfmk00e_N`03001_N`00025_N`007fmk00<006mkKg/03fmk1P000Vmk10004Vmk00<0
06mkKg/01fmk00<006mkKg/026mk00<006mkKg/00fmk0P002Fmk00<006mkKg/01Fmk00<006mkKg/0
1fmk00H006mkKg]_N`00Kg/20006Kg/00`00Kg]_N`06Kg/40008Kg/20009Kg/00`00Kg/00005Kg/2
000016mk000000001Fmk00<006mk00002Fmk00<006mk00001Fmk00H006mkKg]_N`00Kg/30007Kg/0
0`00Kg]_N`03Kg/30008Kg/500000fmk001_N`09Kg/00`00Kg]_N`0;Kg/4000:Kg/30007Kg/00`00
Kg]_N`02Kg/20007Kg/01000Kg]_Nfmk0P004Vmk00<006mkKg/00Vmk00<006mkKg/02Fmk00<006mk
Kg/01Vmk00<006mkKg/036mk0P008Vmk000OKg/00`00Kg]_N`08Kg/70007Kg/01P00Kg/00000Kg/0
015_N`03001_Nfmk00I_N`03001_Nfmk00U_N`04001_NfmkKg/2000<Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`09Kg/01@00Kg/006mk00002Fmk00<006mkKg/02Fmk0`001Fmk0P002Fmk0P000fmk0`000fmk
00<006mkKg/00P000fmk00<006mk000026mk00D006mkKg]_N`0000A_N`05001_NfmkKg/00003Kg/4
0004Kg/00`00Kg]_N`030002Kg/00`00Kg]_N`02Kg/40003Kg/01@00Kg]_Nfmk000026mk00<006mk
Kg/046mk0`001Vmk0P002Vmk00<006mkKg/00fmk0`0016mk00@006mk000001A_N`03001_Nfmk00=_
N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00]_N`8002=_N`0086mk00@006mkKg]_N`H0
00e_N`05001_N`00Kg/00002Kg/2000?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/3000?Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0:Kg/3000;Kg/00`00Kg]_N`0;Kg/400000fmk001_N`0:Kg/01000Kg/0
00001Vmk00<006mkKg/00Vmk0`000fmk00<006mkKg/016mk00<006mkKg/00fmk00D006mkKg]_N`00
009_N`03001_Nfmk00=_N`800006Kg/00000Kg/006mk0P0016mk00<006mk00000`001Vmk00<006mk
Kg/00fmk00<006mkKg/016mk00<006mkKg/056mk10000Vmk00<006mkKg/02Vmk00<006mkKg/01Fmk
0P0000A_N`00000001I_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk
00Y_N`8002A_N`0086mk10004Fmk0P000Vmk00<006mk000016mk00<006mkKg/036mk00<006mkKg/0
16mk00<006mkKg/02fmk1@003fmk00D006mkKg]_N`0000]_N`@000a_N`03001_Nfmk00i_N`l000Q_
N`03001_Nfmk00=_N`8000=_N`03001_Nfmk009_N`8000M_N`800005Kg/006mkKg/00006Kg/?0009
Kg/00`00Kg]_N`05Kg/20004Kg/00`00Kg]_N`0EKg/7000<Kg/00`00Kg]_N`06Kg/3000GKg/00`00
Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/2000UKg/0025_N`P000]_
N`03001_Nfmk009_N`04001_Nfmk0004Kg/2000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/50002
Kg/70009Kg/01000Kg]_N`001Vmk1@000Vmk00<006mk00000P002Vmk00<006mkKg/036mk0`002Fmk
0`0000A_N`00000000E_N`04001_NfmkKg/20002Kg/20002Kg/01000Kg]_N`002fmk00@006mk0000
00A_N`<0009_N`80009_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`04001_Nfmk
000>Kg/:0003Kg/20002Kg/60007Kg/00`00Kg]_N`03Kg/200000fmk001_N`02000EKg/00`00Kg]_
N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00Kg/0000UKg/0029_N`03
001_N`0000X000A_N`03001_Nfmk00=_N`04001_Nfmk0006Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`08Kg/20002Kg/200000fmk001_N`07Kg/80002Kg/20002Kg/50007Kg/00`00Kg]_
N`02Kg/30008Kg/00`00Kg]_N`09Kg/200000fmk00000007Kg/300000fmk001_N`03Kg/400000fmk
001_N`020004Kg/00`00Kg/0000200000fmk001_N`0<Kg/70007Kg/01000Kg]_N`001Fmk00<006mk
Kg/01Vmk00<006mkKg/02Vmk00<006mk000016mk2P003Fmk0P0026mk1P000Vmk00<006mkKg/00P00
0Vmk00<006mkKg/00Vmk0`004Vmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/02Vmk00<0
06mkKg/01Vmk00<006mk00009Vmk000RKg/01000Kg]_Nfmk0P0000A_N`00000000=_N`@000I_N`04
001_Nfmk0007Kg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/20003Kg/01@00Kg/006mk0000
46mk1P0036mk00<006mkKg/01Fmk0P001fmk00<006mkKg/01fmk00H006mkKg/006mk0006Kg/00`00
Kg/00002Kg/00`00Kg]_N`06Kg/30007Kg/00`00Kg]_N`0C000<Kg/01000Kg]_N`001Fmk00<006mk
Kg/016mk00<006mkKg/02fmk1`005Vmk00<006mk00003Vmk1@0016mk00<006mkKg/01Fmk0`003fmk
00<006mkKg/01Vmk00D006mkKg]_N`0000e_N`03001_Nfmk00E_N`03001_N`0002M_N`008fmk00<0
06mkKg/00Vmk0`0000=_N`0000000P000fmk0P0016mk00D006mkKg]_N`0000Q_N`03001_Nfmk00I_
N`05001_NfmkKg/00008Kg/20005Kg/00`00Kg/00002Kg/00`00Kg]_N`0?Kg/4000<Kg/00`00Kg]_
N`07Kg/30004Kg/00`00Kg]_N`05Kg/20003Kg/00`00Kg/00004Kg/200000fmk001_N`02Kg/00`00
Kg]_N`06Kg/00`00Kg/000030004Kg/01000Kg]_N`002Vmk10000Vmk00<006mk00000`002Fmk0P00
00=_N`00Kg/00fmk00<006mkKg/016mk00<006mkKg/026mk100000=_N`00Kg/06Fmk00<006mk0000
46mk0P0016mk0P002Vmk0P003Fmk00<006mkKg/01Vmk00D006mkKg]_N`0000e_N`03001_Nfmk00A_
N`03001_N`0002Q_N`0096mk00<006mkKg/016mk0P000fmk0`000Vmk00@006mkKg/000A_N`03001_
Nfmk00M_N`8000I_N`05001_NfmkKg/00005Kg/30006Kg/00`00Kg/00004Kg/00`00Kg]_N`0>Kg/0
1@00Kg/006mk00002fmk00<006mkKg/02Vmk0`000Vmk00<006mkKg/00Vmk0P0016mk00@006mkKg/0
009_N`80009_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_N`0000=_N`8000=_N`03001_N`00
00E_N`D000I_N`03001_Nfmk00=_N`<000Q_N`03001_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk
00I_N`<0009_N`05001_NfmkKg/0000HKg/01@00Kg]_Nfmk00003Vmk00<006mk000016mk00<006mk
Kg/02fmk0`002fmk00<006mkKg/01Vmk00<006mk00003fmk00<006mkKg/00Vmk00<006mk0000:Fmk
000UKg/00`00Kg]_N`05Kg/20004Kg/60004Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/01000Kg]_
N`0016mk0P0026mk00@006mkKg/000E_N`03001_Nfmk00a_N`04001_Nfmk0002Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`0=Kg/400000fmk00000005Kg/01000Kg]_Nfmk0`000fmk00<006mkKg/00fmk00<0
06mkKg/01Fmk00D006mkKg]_N`0000A_N`D0009_N`@000Y_N`03001_Nfmk00M_N`<000I_N`<0009_
N`03001_Nfmk009_N`03001_Nfmk00A_N`<000A_N`03001_Nfmk00=_N`03001_Nfmk01E_N`05001_
NfmkKg/0000=Kg/00`00Kg/00004Kg/2000@Kg/20009Kg/00`00Kg]_N`06Kg/00`00Kg/0000?Kg/0
0`00Kg]_N`02Kg/00`00Kg/0000YKg/002E_N`03001_Nfmk00M_N`<000E_N`8000E_N`03001_Nfmk
00U_N`8000=_N`03001_N`0000=_N`8000Y_N`04001_Nfmk0006Kg/00`00Kg]_N`0;Kg/01000Kg]_
N`000fmk0P0026mk00<006mkKg/046mk0P001fmk00D006mkKg]_N`0000A_N`03001_Nfmk00A_N`03
001_Nfmk00E_N`05001_NfmkKg/00007Kg/4000>Kg/00`00Kg]_N`0:Kg/40004Kg/200000fmk001_
N`02Kg/00`00Kg]_N`02Kg/30007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0CKg/00`00Kg]_N`02Kg/0
0`00Kg]_N`09Kg/20002Kg/00`00Kg]_N`02Kg/2000BKg/30006Kg/00`00Kg]_N`06Kg/4000>Kg/0
1`00Kg]_Nfmk001_N`0002Y_N`009Vmk00<006mkKg/02Fmk0P001Fmk00<006mkKg/00Vmk00<006mk
Kg/02fmk00<006mkKg/00P000Vmk0P002fmk00D006mkKg]_N`0000M_N`03001_Nfmk00U_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk00e_N`<00004Kg/000000004Kg/0
0`00Kg]_N`0200001Fmk001_Nfmk00001fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/0
1Fmk0P003fmk00<006mkKg/03Vmk0`000Vmk0P0000A_N`00Kg/0009_N`<000U_N`03001_Nfmk00I_
N`03001_Nfmk015_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk009_N`04001_NfmkKg/2
000FKg/30003Kg/00`00Kg]_N`03Kg/30002Kg/00`00Kg/000050008Kg/01P00Kg]_N`00Kg/002]_
N`009fmk00<006mkKg/02Vmk0P0016mk00D006mkKg]_N`0000i_N`H000e_N`05001_NfmkKg/00007
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:
Kg/30004Kg/00`00Kg]_N`020002Kg/30003Kg/00`00Kg/00008Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`04Kg/00`00Kg/0000>Kg/00`00Kg]_N`0AKg/:000;Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`0@Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/01000Kg]_Nfmk0P00
6Fmk0P0000=_N`00Kg/010001Fmk00<006mkKg/01Fmk1P000fmk0P0000=_N`00Kg/0:fmk000XKg/0
0`00Kg]_N`0;Kg/20003Kg/01@00Kg]_Nfmk00003Vmk4P0016mk00<006mkKg/01Vmk00<006mkKg/0
1fmk00<006mkKg/00fmk00<006mkKg/016mk0P0016mk00<006mkKg/026mk0P001fmk00<006mkKg/0
0Vmk2P002Fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mk00003Vmk00<0
06mkKg/05Fmk0`003Fmk00<006mkKg/02Vmk00<006mkKg/03Vmk00<006mkKg/016mk00<006mkKg/0
1Vmk00<006mkKg/016mk00H006mkKg/006mk000KKg/3000:Kg/00`00Kg]_N`0:Kg/400000fmk001_
N`0/Kg/002U_N`03001_Nfmk00a_N`<00005Kg/00000Kg/0000:Kg/400000fmk001_N`0=Kg/30003
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk
00001fmk0`002Fmk00@006mkKg]_N`<000I_N`03001_N`0000Q_N`03001_Nfmk00=_N`03001_Nfmk
00I_N`03001_Nfmk00=_N`04001_Nfmk000<Kg/00`00Kg]_N`0EKg/4000<Kg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/01000Kg]_Nfmk0P00
6fmk0`0000=_N`0000000P001Vmk00<006mkKg/026mk1@0000=_N`00Kg/0;Fmk000YKg/00`00Kg]_
N`0?Kg/200000fmk00000006Kg/40006Kg/00`00Kg]_N`0:Kg/200000fmk001_N`02Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/01000Kg]_N`0016mk0`0036mk
00@006mkKg/0009_N`03001_Nfmk00A_N`04001_Nfmk0007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00002fmk00<006mkKg/04fmk0P000Vmk0P002fmk00<006mk
Kg/03Vmk00<006mkKg/02fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/01Fmk00H006mk
Kg/006mk000IKg/20002Kg/00`00Kg]_N`03Kg/30004Kg/00`00Kg]_N`04Kg/30003Kg/01000Kg]_
N`00;Vmk000ZKg/00`00Kg]_N`0@Kg/400000fmk00000002000:Kg/00`00Kg]_N`09Kg/00`00Kg/0
0002Kg/00`00Kg/0000<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/3000016mk
000000003fmk0`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/016mk00D006mkKg]_
N`0000]_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk015_N`8000A_
N`03001_N`0000Y_N`03001_Nfmk00m_N`03001_Nfmk00Y_N`03001_Nfmk00I_N`03001_Nfmk009_
N`03001_Nfmk00I_N`06001_Nfmk001_N`005fmk0P001Fmk00<006mkKg/01Fmk1@000Vmk10001Fmk
0P0000=_N`00Kg/0;Vmk000[Kg/00`00Kg]_N`0AKg/3000>Kg/00`00Kg]_N`09Kg/00`00Kg/00002
Kg/00`00Kg/0000=Kg/01@00Kg]_Nfmk00002Fmk00<006mkKg/026mk5@001Fmk00<006mkKg/00fmk
00<006mkKg/00fmk00<006mkKg/00fmk00D006mkKg]_N`0000a_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`0?Kg/20006Kg/00`00Kg/00009Kg/00`00Kg]_N`0AKg/00`00Kg]_N`08
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`020009Kg/00`00Kg]_N`02000FKg/20007Kg/00`00Kg]_N`09
Kg/30008Kg/200000fmk001_N`0_Kg/002a_N`03001_Nfmk015_N`<000e_N`03001_Nfmk00Q_N`04
001_Nfmk0003Kg/2000=Kg/01000Kg]_N`002Vmk00<006mkKg/01fmk00<006mk00003fmk0P0000=_
N`00Kg/00fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/00Vmk00@006mkKg/000e_N`05
001_NfmkKg/00006Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/20008Kg/01000Kg]_N`001fmk00<0
06mkKg/04fmk00<006mkKg/01Vmk00<006mkKg/026mk00<006mk00002fmk00D006mk001_N`0001A_
N`8000U_N`03001_Nfmk00U_N`03001_Nfmk00M_N`800003Kg/006mk031_N`00;Fmk00<006mkKg/0
4Fmk100036mk00<006mkKg/01Vmk00@006mkKg/000A_N`8000i_N`03001_N`0000Y_N`03001_Nfmk
00E_N`80009_N`03001_Nfmk00]_N`8000A_N`05001_NfmkKg/00005Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`02Kg/01000Kg]_N`003Vmk00@006mkKg/000I_N`03001_Nfmk00I_N`03001_Nfmk00]_N`80
00Y_N`04001_Nfmk0006Kg/00`00Kg]_N`0EKg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/2000<Kg/0
1@00Kg/006mk00004Vmk0P002fmk00<006mkKg/02Fmk00<006mkKg/01Fmk0`0000=_N`00Kg/0<Fmk
000]Kg/00`00Kg]_N`0AKg/300000fmk0000000:Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00001Fmk
4P002fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/026mk0P001Vmk00D006mkKg]_N`00
00A_N`03001_Nfmk00M_N`07001_NfmkKg/006mk000046mk00<006mk00001fmk00<006mkKg/016mk
00<006mkKg/02Vmk0P0036mk00D006mkKg]_N`0000A_N`03001_Nfmk01M_N`03001_Nfmk00=_N`03
001_Nfmk00Q_N`8000a_N`03001_N`00009_N`03001_Nfmk00i_N`8000e_N`03001_Nfmk00Q_N`03
001_Nfmk00E_N`06001_Nfmk001_N`00<Vmk000^Kg/00`00Kg]_N`0@Kg/2000016mk001_Nfmk0P00
26mk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/00Vmk10002Vmk0P0000=_N`00Kg/01000
1fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/01Fmk0`0026mk00D006mkKg]_N`0000A_
N`03001_Nfmk00Q_N`06001_Nfmk001_N`0046mk00<006mk000026mk00<006mkKg/00fmk00<006mk
Kg/026mk0P003Vmk00D006mkKg]_N`0000=_N`03001_Nfmk01U_N`03001_Nfmk009_N`03001_Nfmk
00A_N`@0009_N`8000Y_N`05001_N`00Kg/0000?Kg/2000?Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04
Kg/01P00Kg]_N`00Kg/003=_N`00;fmk00<006mkKg/046mk0P0000=_N`00Kg/00Vmk0P001fmk00<0
06mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mk00000Vmk00<006mkKg/016mk0`00
0fmk00<006mkKg/00fmk0`0016mk00<006mkKg/00P0026mk00<006mkKg/00Vmk0P002fmk00D006mk
Kg]_N`0000=_N`03001_Nfmk00Y_N`04001_N`00000BKg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`06Kg/2000@Kg/00`00Kg]_N`02Kg/01000Kg]_N`0076mk00@006mkKg/000A_N`<000I_N`04001_
N`000008Kg/20002Kg/00`00Kg]_N`0;Kg/2000BKg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/01P00
Kg]_N`00Kg/003A_N`00<6mk00<006mkKg/03fmk00D006mk001_N`0000A_N`8000E_N`05001_Nfmk
Kg/00005Kg/01`00Kg]_Nfmk001_N`0000A_N`80009_N`8000I_N`03001_Nfmk00I_N`@00003Kg/0
000000Y_N`03001_Nfmk008000i_N`04001_Nfmk0002Kg/00`00Kg]_N`0<Kg/3000BKg/2000:Kg/0
1@00Kg]_Nfmk00001Vmk0P004Vmk00<006mkKg/00Vmk00<006mk00007Vmk00<006mk000010002Vmk
00@006mkKg/000M_N`80009_N`03001_Nfmk00U_N`8001A_N`03001_Nfmk00I_N`03001_Nfmk00=_
N`06001_Nfmk001_N`00=Fmk000`Kg/00`00Kg]_N`0?Kg/01@00Kg/006mk00001Vmk0P000fmk00D0
06mkKg]_N`0000E_N`04001_N`000002Kg/00`00Kg]_N`04Kg/20009Kg/00`00Kg]_N`09Kg/@000@
Kg/01000Kg]_N`000Vmk00<006mkKg/036mk6@002Fmk00@006mkKg/000A_N`8001A_N`03001_Nfmk
00=_Nb<000i_N`04001_NfmkKg/20005Kg/01000Kg]_N`002Vmk0P005Vmk00<006mkKg/01Fmk00<0
06mkKg/00fmk00@006mkKg]_N`8003I_N`00<Fmk00<006mkKg/03fmk00D006mk001_N`0000M_N`80
0005Kg/006mkKg/00006Kg/20004Kg/00`00Kg]_N`03Kg/00`00Kg/00009Kg/00`00Kg]_N`0:Kg/3
000:Kg/00`00Kg/00002000=Kg/01P00Kg]_N`00Kg/000a_N`@00003Kg/006mk00U_N`H0009_N`04
001_N`00Kg/40005Kg/00`00Kg/00003Kg/2000FKg/01000Kg]_Nfmk10007fmk0P003fmk00<006mk
Kg/00Vmk0P000Vmk0P000Vmk00<006mkKg/01Vmk0P0066mk00<006mkKg/01Fmk00<006mkKg/00Vmk
00L006mkKg]_N`00Kg/0000fKg/0039_N`03001_Nfmk00i_N`03001_N`00009_N`03001_Nfmk00I_
N`@000I_N`8000E_N`03001_Nfmk009_N`04001_Nfmk0009Kg/00`00Kg]_N`09Kg/20002Kg/20008
Kg/00`00Kg]_N`02Kg/3000;Kg/01@00Kg/006mk00002Fmk0`000fmk00<006mk000016mk1P0026mk
00<006mk00001Fmk1@0000A_N`00001_N`8001Q_N`04001_N`000002Kg/00`00Kg/0000NKg/01000
Kg/000003Fmk00<006mkKg/016mk0`000fmk00<006mkKg/016mk0P006Vmk00<006mkKg/016mk00<0
06mkKg/00Vmk00L006mkKg]_N`00Kg/0000gKg/003=_N`03001_Nfmk00e_N`04001_Nfmk0002Kg/0
0`00Kg]_N`07Kg/90006Kg/01@00Kg]_Nfmk000016mk00<006mkKg/01Vmk00<006mkKg/02Fmk00<0
06mk00000fmk0P001Vmk00<006mkKg/01Fmk0P002Fmk0P0000=_N`00Kg/01fmk0P001Fmk00@006mk
Kg]_N`@000e_N`04001_NfmkKg/Z0004Kg/01000Kg]_N`007Fmk00D006mkKg]_N`0000e_N`03001_
Nfmk00E_N`04001_Nfmk0005Kg/2000MKg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01`00Kg]_Nfmk
001_N`0003Q_N`00=6mk00<006mkKg/03Fmk00@006mkKg/0009_N`03001_Nfmk00I_N`04001_N`00
0004Kg/30004Kg/01000Kg/000001Fmk00<006mkKg/01Vmk00<006mkKg/026mk00@006mkKg/000E_
N`8000A_N`03001_Nfmk00M_N`<000I_N`800003Kg/006mk00A_N`<000M_N`05001_Nfmk001_N`02
000>Kg/01P00Kg]_N`00Kg/000U_N`8001Y_N`8000E_N`05001_NfmkKg/0000LKg/00`00Kg]_N`02
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk0P007fmk00<006mkKg/00Vmk00D0
06mkKg]_N`0000=_N`03001_N`0003U_N`00=6mk00<006mkKg/03Fmk00@006mkKg/000=_N`03001_
Nfmk00I_N`03001_Nfmk00<0009_N`03001_N`00009_N`03001_N`0000Q_N`03001_Nfmk00E_N`03
001_Nfmk00Q_N`04001_Nfmk0007Kg/20002Kg/00`00Kg]_N`0:Kg/30003Kg/30003Kg/30009Kg/0
1000Kg]_N`000Vmk00@006mk000000]_N`04001_Nfmk0002Kg/00`00Kg]_N`07Kg/00`00Kg/0000I
Kg/00`00Kg/00004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0IKg/00`00Kg]_N`03Kg/2000;Kg/00`00
Kg]_N`04Kg/200000fmk001_N`02000QKg/01@00Kg]_Nfmk00000fmk00<006mkKg/00Vmk0P00>Vmk
000eKg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/01Fmk00<006mkKg/00fmk0`00
0Vmk10002Fmk00<006mkKg/01Fmk00<006mkKg/026mk00@006mkKg/000U_N`<000m_N`<00003Kg/0
000000<000a_N`03001_N`0000A_N`04001_Nfmk000:Kg/00`00Kg/00004Kg/00`00Kg]_N`05Kg/0
1000Kg]_N`0066mk00@006mkKg/000A_N`03001_Nfmk00=_N`03001_Nfmk01Q_N`03001_Nfmk00E_
N`03001_Nfmk00U_N`03001_Nfmk00=_N`D002=_N`06001_NfmkKg/006mk0P0016mk0P00>fmk000f
Kg/00`00Kg]_N`0<Kg/01000Kg]_N`0016mk00<006mkKg/016mk00<006mkKg/01Fmk1P002fmk00<0
06mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/026mk5P003Vmk00<006mk0000
1Fmk00@006mkKg]_N`8000M_N`03001_N`0000E_N`03001_Nfmk00E_N`04001_Nfmk000HKg/01000
Kg]_N`0016mk00<006mkKg/016mk00<006mkKg/05fmk00<006mkKg/01Vmk00<006mkKg/026mk00<0
06mkKg/00fmk00<006mk000010008Fmk00H006mkKg/006mk0005Kg/00`00Kg/0000kKg/003M_N`03
001_Nfmk00]_N`05001_NfmkKg/00004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/01000Kg]_Nfmk
0`002Vmk00<006mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mk
000010003fmk0P0036mk00<006mk00001fmk00<006mkKg/00Vmk00<006mkKg/016mk0P001fmk00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/056mk00D006mkKg]_N`0000A_N`03001_Nfmk00E_
N`03001_Nfmk01E_N`03001_Nfmk00Q_N`8000U_N`03001_Nfmk00=_N`8000A_N`X001M_N`03001_
Nfmk008000E_N`03001_N`0003a_N`00=fmk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00<006mkKg/016mk00L006mkKg/006mk001_N`020009Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg/00004Kg/3000<Kg/01000
Kg/000002Vmk00<006mk00001fmk00<006mkKg/00fmk0P000fmk0P0026mk00<006mkKg/00fmk00<0
06mkKg/00Vmk00<006mkKg/056mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<0
06mkKg/056mk00<006mkKg/02Vmk00<006mkKg/01Vmk00<006mkKg/00fmk0`003Fmk2P003Vmk0`00
1Vmk0P00?Fmk000hKg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00@006mkKg/0009_N`05001_NfmkKg/00009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00001Vmk0`002Vmk00@006mkKg/000Q_N`03
001_N`0000U_N`03001_Nfmk00A_N`800003Kg/006mk00U_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`0CKg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0CKg/00`00Kg]_
N`0;Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/3000GKg/:0004Kg/20006Kg/2000nKg/003U_N`03
001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/00003
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/40006Kg/01000Kg]_Nfmk0P001Vmk
0P002Vmk00<006mkKg/01Fmk10002Fmk00D006mkKg]_N`0000E_N`03001_Nfmk019_N`03001_Nfmk
00A_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk019_N`03001_Nfmk00a_N`8000I_N`03
001_Nfmk009_N`800003Kg/006mk01m_N`D000I_N`8003m_N`00>Vmk00<006mkKg/02Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000A_N`03001_N`0000A_N`03001_Nfmk00=_N`03
001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03
001_Nfmk00A_N`03001_Nfmk00U_N`<000A_N`03001_Nfmk009_N`8000=_N`8000a_N`03001_Nfmk
009_N`800004Kg/006mkKg/40006Kg/00`00Kg/00007Kg/00`00Kg]_N`0AKg/00`00Kg]_N`04Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0>Kg/00`00Kg]_N`04Kg/0
1000Kg]_Nfmk0P0000=_N`00Kg/08Fmk0P001Vmk00<006mk0000?fmk000kKg/00`00Kg]_N`09Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000fmk00<006mk000016mk00<006mkKg/0
16mk00<006mkKg/01Fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/0
16mk00<006mkKg/016mk00<006mkKg/036mk1@001Vmk0P0000=_N`00Kg/036mk00<006mkKg/00P00
0fmk00<006mkKg/016mk1@0000A_N`00Kg/000M_N`03001_Nfmk011_N`03001_Nfmk00I_N`05001_
NfmkKg/0000;Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`020002
Kg/00`00Kg]_N`0MKg/40005Kg/00`00Kg/00010Kg/003]_N`03001_Nfmk00U_N`03001_Nfmk00=_
N`03001_Nfmk00=_N`04001_Nfmk0002Kg/00`00Kg/00004Kg/00`00Kg]_N`06Kg/20006Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/03fmk
6`0016mk00<006mk00002Vmk0`0026mk00<006mkKg/046mk00<006mkKg/01Vmk00D006mkKg]_N`00
00a_N`03001_Nfmk00m_N`03001_Nfmk011_N`8000A_N`03001_Nfmk0080009_N`03001_Nfmk01]_
N`800003Kg/0000000I_N`80045_N`00?6mk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/0
16mk00<006mk00000Vmk0P001Fmk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/00Vmk00<0
06mkKg/00Vmk00<006mkKg/01fmk00D006mkKg]_N`0000Y_N`03001_Nfmk00m_N`<000A_N`03001_
Nfmk00Q_N`@000=_N`03001_Nfmk009_N`03001_N`0000Y_N`@000Q_N`03001_Nfmk00i_N`03001_
Nfmk00M_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0BKg/00`00Kg]_N`02Kg/0
1000Kg/000000Vmk00<006mkKg/06Vmk00H006mk000006mk0005Kg/20012Kg/003e_N`03001_Nfmk
00M_N`03001_Nfmk00A_N`03001_Nfmk00A_N`800003Kg/0000000I_N`03001_Nfmk00U_N`03001_
Nfmk00=_N`05001_NfmkKg/00004Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk00002Vmk00<006mkKg/0
3Vmk0P000Vmk00D006mkKg]_N`0000E_N`D000M_N`03001_Nfmk009_N`03001_N`0000Q_N`800005
Kg/006mkKg/00007Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`08Kg/01000Kg]_N`003Fmk00<006mkKg/0
3Vmk00<006mkKg/04fmk00H006mkKg]_N`00Kg/20003Kg/00`00Kg]_N`0GKg/200001Fmk001_Nfmk
00001Fmk0P00@fmk000nKg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/30007Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/01000Kg]_N`000fmk00<006mkKg/026mk00@006mkKg/000a_
N`03001_Nfmk00e_N`8000=_N`<0009_N`@000e_N`07001_NfmkKg/006mk00001fmk00D006mkKg]_
N`00009_N`03001_Nfmk00E_N`03001_Nfmk00e_N`03001_Nfmk00U_N`04001_Nfmk000>Kg/00`00
Kg]_N`0=Kg/00`00Kg]_N`0DKg/20002Kg/00`00Kg/00003Kg/00`00Kg]_N`0EKg/20002Kg/01@00
Kg]_Nfmk000016mk00<006mk0000@fmk000oKg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/20003Kg/01000Kg]_N`000fmk00<006mkKg/026mk
00@006mkKg/000e_N`03001_Nfmk00a_N`8000E_N`@0015_N`06001_Nfmk001_N`001Fmk0P0016mk
00D006mkKg]_N`0000M_N`03001_Nfmk00a_N`03001_Nfmk00U_N`04001_Nfmk000?Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`0FKg/01@00Kg/006mk000016mk00<006mkKg/04Vmk0P000fmk00D006mkKg]_
N`0000E_N`8004A_N`00?fmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/016mk0P001fmk
00<006mkKg/03Fmk00L006mkKg]_N`00Kg/00002Kg/00`00Kg]_N`0:Kg/2000?Kg/00`00Kg]_N`0:
Kg/20005Kg/30002Kg/8000:Kg/20003Kg/00`00Kg]_N`020005Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0:Kg/01000Kg]_N`0046mk00<006mkKg/02fmk00<006mk
Kg/05fmk00@006mk000000A_N`03001_Nfmk015_N`03001_Nfmk009_N`05001_NfmkKg/00005Kg/2
0015Kg/0041_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk00A_N`8000M_N`03001_Nfmk
00i_N`06001_Nfmk001_N`000Vmk00<006mkKg/02Vmk0P003fmk00<006mkKg/02Vmk0P001Fmk0`00
2Vmk20000Vmk0P000fmk0`001fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/02Vmk00<0
06mkKg/036mk00<006mk00004Fmk00<006mkKg/02Vmk00<006mkKg/066mk0`001Fmk00<006mkKg/0
3Vmk0P0016mk00<006mkKg/00Vmk00<006mkKg/00Vmk0P00AVmk0011Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`02Kg/01000Kg]_N`001Vmk00<006mkKg/03fmk00<006mkKg/00P000Vmk
00<006mkKg/02Fmk0`0046mk00<006mkKg/02Fmk0P0016mk0P000Vmk00<006mkKg/03fmk20002Fmk
00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/02Fmk00<006mkKg/036mk00<006mk00004Vmk
00<006mkKg/02Fmk00<006mkKg/06Fmk0P001Fmk00<006mkKg/036mk0P001Fmk00<006mkKg/00Vmk
00<006mkKg/00Vmk0P00Afmk0012Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/0
1000Kg]_N`001Vmk00<006mkKg/046mk00@006mk001_N`8000Q_N`H00003Kg/0000000m_N`03001_
Nfmk00M_N`03001_N`0000A_N`80009_N`03001_Nfmk015_N`03001_N`0000=_N`03001_Nfmk00E_
N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00e_N`03001_N`0001=_
N`03001_Nfmk00Q_N`03001_Nfmk01I_N`@00003Kg/006mk00=_N`03001_Nfmk00Y_N`8000E_N`80
00E_N`03001_Nfmk009_N`03001_Nfmk04I_N`00@Vmk00<006mkKg/01Fmk00<006mkKg/01Fmk00D0
06mkKg]_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk015_N`D000A_N`@000A_N`8000=_N`8000i_
N`03001_Nfmk00I_N`03001_N`0000=_N`03001_N`0000=_N`03001_Nfmk011_N`04001_Nfmk0002
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0>
Kg/2000DKg/00`00Kg]_N`07Kg/00`00Kg]_N`0DKg/20003Kg/00`00Kg]_N`020003Kg/00`00Kg]_
N`07Kg/20006Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/20018Kg/004=_N`03001_Nfmk00A_N`03
001_Nfmk00I_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0CKg/200000fmk00000002
0007Kg/00`00Kg/00005Kg/3000;Kg/00`00Kg]_N`06Kg/00`00Kg/00003Kg/00`00Kg/00003Kg/0
0`00Kg]_N`0?Kg/00`00Kg]_N`02Kg/01000Kg]_N`001Vmk00<006mkKg/026mk00<006mkKg/00Vmk
00<006mkKg/01Vmk00<006mkKg/03fmk0P005Fmk00<006mkKg/01Fmk00<006mkKg/04Vmk0`0016mk
00<006mkKg/00fmk00@006mkKg/000Q_N`03001_Nfmk00E_N`03001_Nfmk00E_N`04001_NfmkKg/2
0019Kg/004A_N`03001_Nfmk00=_N`03001_Nfmk00I_N`04001_Nfmk0004Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0CKg/3000;Kg/00`00Kg/00008Kg/2000:Kg/00`00Kg]_N`04Kg/01000Kg]_N`000Vmk
00@006mkKg/000A_N`03001_Nfmk00i_N`03001_Nfmk00=_N`03001_N`0000E_N`03001_Nfmk00U_
N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_Nfmk00m_N`03001_N`0001E_N`03001_Nfmk00A_
N`03001_Nfmk00m_N`<000M_N`03001_Nfmk00A_N`04001_Nfmk0005Kg/20007Kg/00`00Kg]_N`05
Kg/01000Kg]_Nfmk0P00BVmk0015Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/20006Kg/01000Kg]_
N`004Vmk100000=_N`00Kg/02Vmk00@006mkKg/000Y_N`8000U_N`03001_Nfmk00=_N`06001_Nfmk
001_N`000Vmk00<006mkKg/016mk00<006mkKg/036mk00<006mkKg/01Fmk00<006mk000016mk00<0
06mkKg/02Vmk00D006mkKg]_N`0000M_N`03001_Nfmk011_N`03001_N`0001I_N`03001_Nfmk00=_
N`03001_Nfmk00e_N`8000U_N`03001_Nfmk00I_N`<000=_N`8000Q_N`03001_Nfmk00E_N`04001_
NfmkKg/2001;Kg/004I_N`03001_Nfmk009_N`03001_Nfmk00I_N`8000I_N`04001_Nfmk000?Kg/3
0005Kg/00`00Kg]_N`08Kg/01@00Kg]_Nfmk000036mk0`001Vmk00<006mkKg/00fmk00H006mkKg/0
06mk0002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`06Kg/00`00Kg/00004Kg/00`00
Kg]_N`0;Kg/01000Kg]_N`001Vmk00<006mkKg/04Vmk0P005fmk00<006mkKg/00Vmk00<006mkKg/0
2Vmk0`002fmk00<006mkKg/026mk10002Fmk00<006mkKg/01Vmk00D006mkKg]_N`0004a_N`00AVmk
00<006mkKg/00Vmk00<006mkKg/01fmk0P001Vmk00<006mk000036mk0`0026mk00<006mkKg/026mk
00@006mkKg/0011_N`8000E_N`05001_NfmkKg/00002Kg/00`00Kg/00003Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00Kg/00002Kg/00`00Kg]_N`0=Kg/01000Kg]_N`001Fmk
00<006mkKg/04Vmk0P0066mk00D006mkKg]_N`0000U_N`<000e_N`03001_Nfmk00Y_N`03001_Nfmk
00Q_N`03001_Nfmk00I_N`04001_NfmkKg/2001<Kg/004M_N`03001_Nfmk009_N`03001_Nfmk00E_
N`03001_N`00008000A_N`03001_N`0000Q_N`@000]_N`03001_Nfmk00M_N`05001_NfmkKg/0000B
Kg/30003Kg/01000Kg]_N`000Vmk00<006mk00000fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<0
06mkKg/02Fmk0P000Vmk00<006mkKg/03Fmk00@006mkKg/000A_N`03001_Nfmk01=_N`8001U_N`04
001_Nfmk0006Kg/3000?Kg/00`00Kg]_N`09Kg/200000fmk00000006Kg/20009Kg/00`00Kg]_N`02
001=Kg/004Q_N`05001_NfmkKg/00007Kg/01@00Kg]_N`00Kg/00`000Vmk0P001Fmk0`0046mk00<0
06mkKg/01Fmk00<006mkKg/00Vmk00<006mkKg/04fmk0P000Vmk00<006mk00000Vmk0P0016mk00<0
06mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/02fmk0P0000=_N`00Kg/03fmk00<006mk000016mk
00<006mkKg/04fmk0P006Vmk00<006mk000016mk0P004Vmk00<006mkKg/026mk00L006mkKg]_N`00
Kg/00004Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02001>Kg/004U_N`04001_Nfmk0006Kg/00`00Kg]_
N`02Kg/01000Kg]_Nfmk100000=_N`0000000P004fmk00<006mkKg/01Fmk00<006mkKg/00Vmk00<0
06mkKg/05Fmk10000fmk0P0016mk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/036mk0P00
4Vmk00<006mk00000Vmk00<006mkKg/05Fmk00<006mkKg/06Fmk0P0000A_N`00000001=_N`03001_
Nfmk00M_N`8000E_N`06001_N`00001_N`002fmk00@006mkKg/004m_N`00BVmk00@006mkKg/000E_
N`03001_Nfmk00=_N`03001_Nfmk009_N`<001M_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_
Nfmk01M_N`H000A_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk00e_N`D0011_N`80009_
N`03001_Nfmk015_Nb<001I_N`03001_Nfmk00I_N`03001_Nfmk00E_N`05001_NfmkKg/0000;Kg/0
1000Kg]_N`00D6mk001:Kg/01000Kg]_N`0016mk00<006mkKg/01Fmk00<006mkKg/00Vmk00@006mk
000001E_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk01I_N`800003Kg/006mk009_N`05
001_NfmkKg/0000;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/4000016mk000006mk1`002Fmk0P00
00=_N`00Kg/02fmk20000Vmk0`006Vmk1@0056mk00<006mkKg/01Fmk0P002Fmk00@006mkKg/000Y_
N`03001_Nfmk0080051_N`00Bfmk00<006mk000016mk00<006mkKg/01Fmk00<006mkKg/00Vmk00@0
06mkKg]_N`<0019_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk01A_N`8000A_N`04001_
Nfmk0003Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/30003Kg/01000Kg]_Nfmk
0P001Vmk20000Vmk0`000fmk2@0026mk0P000fmk00<006mkKg/05Fmk0P000Vmk00<006mkKg/00P00
4Vmk00<006mkKg/016mk00<006mkKg/02Fmk00D006mkKg]_N`0000U_N`04001_N`00001AKg/004a_
N`03001_N`00009_N`03001_Nfmk00M_N`05001_NfmkKg/00006Kg/3000?Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0BKg/20007Kg/01000Kg]_N`000Vmk00<006mkKg/02Vmk00D006mk
Kg]_N`0000Q_N`<000E_N`03001_Nfmk00A_N`8000a_N`P000m_N`8000E_N`03001_Nfmk01A_N`05
001_NfmkKg/00005Kg/2000?Kg/00`00Kg]_N`03Kg/2000=Kg/01000Kg]_N`0026mk00@006mk0000
059_N`00CFmk0P000Vmk00<006mkKg/026mk00@006mkKg/000U_N`8000e_N`03001_Nfmk009_N`03
001_Nfmk00E_N`03001_Nfmk011_N`8000Y_N`<0009_N`03001_Nfmk00Y_N`05001_NfmkKg/00005
Kg/30008Kg/00`00Kg]_N`06Kg/2000<Kg/00`00Kg/0000@Kg/20007Kg/00`00Kg]_N`0BKg/20004
Kg/00`00Kg]_N`05Kg/2000<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/01000Kg]_N`0026mk00<0
06mk0000Dfmk001=Kg/200000fmk001_N`0;Kg/00`00Kg/0000;Kg/3000:Kg/01@00Kg]_Nfmk0000
26mk00<006mkKg/03Vmk0P003Vmk0`003Vmk00<006mk00000fmk0`002Vmk00<006mkKg/02Fmk00<0
06mkKg/02Fmk00@006mkKg/000i_N`03001_Nfmk00Q_N`03001_Nfmk00m_N`8000I_N`03001_Nfmk
00M_N`03001_Nfmk00U_N`04001_NfmkKg/2000AKg/00`00Kg/00007Kg/00`00Kg/0001DKg/004i_
N`<000e_N`8000i_N`8000U_N`03001_N`0000U_N`03001_Nfmk00a_N`80015_N`8000i_N`03001_
N`0000<000e_N`03001_Nfmk00Y_N`8000Q_N`03001_Nfmk009_N`03001_Nfmk00U_N`8000]_N`03
001_Nfmk00e_N`8000Q_N`03001_Nfmk00Q_N`8000Q_N`05001_NfmkKg/0000DKg/00`00Kg/00006
Kg/2001EKg/004m_NaD000a_N`<000I_N`03001_N`0000U_N`03001_Nfmk00Y_N`80019_Na@000m_
N`03001_Nfmk00e_N`8000I_N`03001_Nfmk00=_N`8000M_N`8000e_N`03001_Nfmk00a_N`03001_
Nfmk00Q_N`03001_Nfmk00Y_N`8000I_N`04001_N`00000EKg/00`00Kg/00005Kg/3001EKg/0051_
N`03001_Nfmk00a_N`03001_Nfmk009_N`P000M_N`<000=_N`8000U_N`03001_Nfmk00U_N`8000m_
N`D0009_N`8000i_N`<000e_N`03001_Nfmk011_N`8000=_N`03001_Nfmk00I_N`03001_Nfmk009_
N`80011_N`03001_Nfmk00U_N`8000Y_N`03001_Nfmk00e_N`8000=_N`03001_N`0001Q_N`8000A_
N`03001_N`0005I_N`00DFmk00<006mkKg/036mk00<006mkKg/02Fmk2@0000A_N`00001_N`8000U_
N`03001_Nfmk00M_N`8000a_N`D000I_N`03001_Nfmk008000e_N`04001_N`00000;Kg/00`00Kg]_
N`0BKg/200000fmk001_N`08Kg/01000Kg/000004Vmk00<006mkKg/01fmk0P0036mk00<006mkKg/0
3fmk0P0000=_N`0000006Fmk00<006mk00000fmk0P00Efmk001BKg/00`00Kg]_N`0;Kg/00`00Kg]_
N`0BKg/60009Kg/00`00Kg]_N`05Kg/20009Kg/5000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/0
1000Kg]_Nfmk0P0026mk00<006mkKg/04Vmk4P004fmk00<006mkKg/01Fmk00<006mkKg/036mk00<0
06mkKg/04Fmk10006Fmk0P000Vmk0P00F6mk001CKg/2000<Kg/00`00Kg]_N`0DKg/00`00Kg/00003
0006Kg/00`00Kg]_N`03Kg/20005Kg/6000@Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`03Kg/20006Kg/00`00Kg]_N`0<Kg/60003Kg/2000:Kg/00`00Kg]_N`06000=Kg/00`00Kg]_N`03
Kg/2000?Kg/00`00Kg]_N`0?Kg/20004Kg/8000AKg/20002Kg/00`00Kg]_N`1GKg/005E_N`03001_
Nfmk00U_N`03001_Nfmk01=_N`04001_Nfmk0003Kg/20004Kg/01000Kg]_Nfmk0P000Vmk1@005Vmk
00<006mkKg/016mk0P002Vmk00<006mkKg/016mk0P000fmk00<006mkKg/01Vmk1`002Fmk0P002Vmk
00<006mkKg/01Vmk1P001fmk00@006mkKg]_N`80015_N`03001_Nfmk00e_N`800003Kg/006mk00]_
N`P000Y_N`04001_N`00001IKg/005I_N`03001_Nfmk00Q_N`03001_Nfmk019_N`03001_Nfmk009_
N`03001_Nfmk009_N`<00003Kg/006mk00H001Y_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_
Nfmk00I_N`800004Kg/006mkKg/6000@Kg/00`00Kg/00009Kg/00`00Kg]_N`0<Kg/60002Kg/3000C
Kg/00`00Kg]_N`0;Kg/20002Kg/00`00Kg]_N`0CKg/80002Kg/3001JKg/005M_N`03001_Nfmk00Q_
N`03001_Nfmk011_N`03001_Nfmk00=_N`03001_Nfmk00E_N`@001m_N`03001_Nfmk00Q_N`03001_
Nfmk00I_N`03001_Nfmk00Q_N`@001I_N`03001_N`0000U_N`03001_Nfmk019_N`@001=_N`03001_
Nfmk00Y_N`8000=_N`03001_Nfmk01a_N`@005]_N`00F6mk00<006mkKg/01fmk00<006mkKg/03fmk
00<006mkKg/01Fmk00<006mkKg/016mk00<006mk000086mk00<006mkKg/02Fmk00<006mkKg/01Vmk
00<006mkKg/01Vmk00<006mk000066mk00@006mkKg/000Q_N`03001_Nfmk019_N`800003Kg/00000
0080011_N`03001_Nfmk00Q_N`8000A_N`03001_Nfmk01e_N`8005e_N`00FFmk00<006mkKg/01Vmk
00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mk00007fmk00<006mkKg/02fmk
0P001Vmk00<006mkKg/01Vmk00<006mk000066mk00@006mkKg/000Q_N`03001_Nfmk015_N`03001_
N`00009_N`03001_Nfmk00<000e_N`03001_Nfmk00I_N`8000I_N`03001_Nfmk01]_N`8005m_N`00
FVmk00<006mkKg/01Vmk00<006mkKg/036mk00<006mkKg/026mk00<006mkKg/00Vmk00D006mkKg]_
N`0001i_N`03001_Nfmk00e_N`03001_Nfmk00A_N`03001_Nfmk00A_N`05001_NfmkKg/0000GKg/0
1@00Kg]_Nfmk00001fmk00<006mkKg/046mk00<006mk000016mk00<006mkKg/00Vmk0P002fmk00<0
06mkKg/016mk0P001fmk00<006mkKg/06Vmk0P00HFmk001KKg/20006Kg/00`00Kg]_N`0;Kg/00`00
Kg]_N`09Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/06fmk00<006mkKg/03Vmk00<006mkKg/00fmk
00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/056mk00<006mkKg/00Vmk00<006mkKg/016mk
00<006mkKg/03Vmk0P000Vmk00<006mkKg/00fmk00<006mkKg/00fmk0`0026mk00<006mkKg/00Vmk
0P0026mk00<006mkKg/06Fmk0P00Hfmk001MKg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`0;Kg/00`00Kg/00006Kg/00`00Kg]_N`0KKg/00`00Kg]_N`0?Kg/20003Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0DKg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/0
1@00Kg]_Nfmk00001fmk00<006mkKg/01Fmk0`0016mk00@006mkKg]_N`8000Y_N`03001_Nfmk01M_
N`8006E_N`00GVmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/036mk00<006mk00001fmk
00<006mkKg/06Fmk00<006mkKg/04Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00E_N`03001_Nfmk
019_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00a_N`05001_NfmkKg/00008Kg/00`00
Kg]_N`08Kg/300000fmk001_N`02000;Kg/00`00Kg]_N`0FKg/2001WKg/005m_N`03001_Nfmk009_
N`03001_Nfmk00M_N`03001_Nfmk00e_N`8000U_N`03001_Nfmk01Q_N`03001_Nfmk01=_N`04001_
Nfmk0002Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0AKg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0:Kg/20004Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/3000<Kg/00`00Kg]_N`0EKg/2001Y
Kg/0061_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`@0009_N`03001_Nfmk00I_
N`03001_Nfmk01Q_N`03001_Nfmk01A_N`<00003Kg/006mk00U_N`03001_Nfmk015_N`03001_Nfmk
00E_N`03001_Nfmk009_N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk
00Y_N`03001_Nfmk00Y_N`03001_Nfmk01=_N`<006]_N`00HFmk00D006mkKg]_N`0000I_N`03001_
Nfmk00Q_N`<000M_N`03001_Nfmk00I_N`03001_Nfmk01I_N`03001_Nfmk01M_N`<000]_N`03001_
Nfmk011_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`03001_
Nfmk00]_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`03001_Nfmk015_N`8006i_N`00HVmk00@006mk
Kg/000E_N`03001_Nfmk00I_N`<000]_N`03001_Nfmk00I_N`03001_Nfmk01E_N`03001_Nfmk01Q_
N`03001_Nfmk00]_N`03001_Nfmk00m_N`03001_Nfmk00I_N`05001_NfmkKg/00008Kg/20006Kg/0
0`00Kg]_N`0<Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0@Kg/2001`Kg/006=_N`80
0003Kg/006mk009_N`03001_Nfmk00=_N`@000m_N`03001_Nfmk00I_N`03001_Nfmk01A_N`03001_
Nfmk01I_N`@000e_N`03001_Nfmk00i_N`03001_Nfmk00M_N`04001_Nfmk0007Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/2001bKg/006E_
N`80009_N`04001_NfmkKg/3000DKg/00`00Kg]_N`05Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0EKg/0
1000Kg]_Nfmk0`002fmk00<006mkKg/03Vmk00<006mkKg/01fmk00@006mkKg/000I_N`03001_Nfmk
00I_N`03001_Nfmk00m_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00e_N`8007A_N`00
IVmk1`0066mk00<006mkKg/01Fmk00<006mkKg/04Vmk00<006mkKg/05Fmk00<006mkKg/00Vmk00@0
06mkKg/000]_N`03001_Nfmk00e_N`03001_Nfmk00Q_N`03001_N`0000A_N`8000Q_N`03001_Nfmk
015_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00a_N`8007I_N`00Ifmk0P007Fmk00<0
06mkKg/01Fmk00<006mkKg/04Fmk00<006mkKg/04fmk0P001Fmk00D006mkKg]_N`0000]_N`03001_
Nfmk00a_N`03001_Nfmk00Q_N`03001_N`0000=_N`03001_Nfmk00M_N`03001_Nfmk01=_N`03001_
Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00]_N`8007Q_N`00JFmk0P0076mk00<006mkKg/016mk
00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/01Vmk00D006mkKg]_N`0000Y_N`03001_Nfmk
00a_N`03001_Nfmk00U_N`80009_N`03001_Nfmk00Q_N`03001_Nfmk01A_N`03001_Nfmk00A_N`03
001_Nfmk00A_N`03001_Nfmk00Y_N`8007Y_N`00Jfmk0`006Vmk00<006mkKg/016mk00<006mkKg/0
3fmk00<006mkKg/04Vmk00<006mkKg/01fmk00<006mkKg/00Vmk0P002Fmk00<006mkKg/02fmk00<0
06mkKg/02Fmk10002Vmk00<006mkKg/05Vmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/0
1fmk0`00O6mk001^Kg/2000IKg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0@Kg/2000;
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`0GKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/2001oKg/0071_
N`<001M_N`03001_Nfmk00=_N`03001_Nfmk00i_N`03001_Nfmk00m_N`03001_Nfmk00]_N`03001_
Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`03001_Nfmk00U_N`8000]_N`03001_Nfmk01Q_
N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00E_N`80085_N`00Lfmk0P005Vmk00<006mk
Kg/00fmk00<006mkKg/03Fmk00<006mkKg/03Vmk00<006mkKg/036mk00<006mkKg/01Fmk00<006mk
Kg/01Vmk00<006mkKg/02Fmk00<006mkKg/026mk00@006mk000000U_N`03001_Nfmk01Y_N`05001_
NfmkKg/00004Kg/00`00Kg]_N`03Kg/20023Kg/007E_N`<001A_N`03001_Nfmk00=_N`03001_Nfmk
00]_N`03001_Nfmk00e_N`80011_N`03001_Nfmk00E_N`8000M_N`03001_Nfmk00Q_N`03001_Nfmk
00Q_N`04001_N`000009Kg/00`00Kg]_N`0KKg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00Vmk0P00
QFmk001hKg/2000CKg/20003Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0@Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`020008Kg/0
0`00Kg]_N`0MKg/01P00Kg]_N`00Kg/000=_N`8008M_N`00NVmk0`004Vmk00D006mkKg]_N`0000a_
N`03001_Nfmk00]_N`03001_Nfmk015_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00M_
N`03001_Nfmk00I_N`04001_NfmkKg/20008Kg/00`00Kg]_N`0NKg/01000Kg/000000Vmk0P00RFmk
001mKg/2000AKg/01@00Kg]_Nfmk00002Vmk00<006mkKg/02Vmk0P005Fmk00<006mkKg/026mk00<0
06mkKg/016mk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/00Vmk00<006mk00001Vmk00<0
06mkKg/086mk1@00Rfmk001oKg/3000?Kg/01000Kg]_N`002Vmk00<006mkKg/02Fmk00<006mkKg/0
5Fmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/0
0Vmk00<006mk00001Fmk00<006mkKg/086mk1000SFmk0022Kg/3000=Kg/01000Kg]_N`002Fmk00<0
06mkKg/01fmk0P006Fmk00<006mkKg/02Fmk0P0016mk00<006mkKg/01Fmk00<006mkKg/016mk00<0
06mkKg/00Vmk00@006mk000000E_N`03001_Nfmk01Y_N`L0091_N`00QFmk0P0036mk00@006mkKg/0
00Q_N`03001_Nfmk00I_N`03001_Nfmk01U_N`03001_Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk
00=_N`03001_Nfmk00A_N`04001_NfmkKg/20002Kg/00`00Kg/00003Kg/00`00Kg]_N`0EKg/60003
Kg/2002BKg/008M_N`<000Y_N`04001_Nfmk0006Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0JKg/00`00
Kg]_N`0<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
0P000Vmk00<006mkKg/046mk1P001fmk0P00U6mk002:Kg/20009Kg/00`00Kg/00006Kg/00`00Kg]_
N`04Kg/2000NKg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00Vmk00D006mkKg]_
N`0000I_N`80009_N`03001_Nfmk00Y_N`H000]_N`8009I_N`00S6mk0`001fmk00<006mk00001Fmk
00<006mkKg/00fmk00<006mkKg/07Vmk00<006mkKg/03Fmk0P000Vmk00D006mkKg]_N`0000A_N`04
001_Nfmk0008Kg/00`00Kg/00007Kg/6000?Kg/2002HKg/008m_N`8000I_N`03001_N`0000=_N`03
001_Nfmk00=_N`03001_Nfmk01m_N`03001_Nfmk00m_N`04001_Nfmk0002Kg/01P00Kg]_Nfmk001_
N`8000U_N`<00003Kg/0000000@0019_N`<009Y_N`00TFmk0`0016mk0P000fmk00@006mkKg]_N`80
02=_N`03001_Nfmk00m_N`03001_N`00009_N`06001_Nfmk001_N`002Vmk1@005Vmk0P00WFmk002D
Kg/20003Kg/20002Kg/01000Kg]_N`009Fmk00<006mkKg/046mk00T006mk001_N`00Kg/006mk0000
1fmk1@0000=_N`00Kg/05Fmk0P00Wfmk002FKg/300001fmk000006mk001_N`0002M_N`03001_Nfmk
011_N`@00003Kg/0000000=_N`D00003Kg/0000000=_N`03001_Nfmk019_N`800:5_N`00VFmk1P00
:6mk00<006mkKg/04Vmk0`0000=_N`0000000P0016mk0P001Vmk00<006mkKg/03fmk0P00Xfmk002K
Kg/4000XKg/00`00Kg]_N`0CKg/30005Kg/30008Kg/00`00Kg]_N`0=Kg/2002UKg/009m_N`D002A_
N`03001_Nfmk011_N`@000A_N`8000]_N`03001_Nfmk00Y_N`<00:M_N`00Y6mk100086mk00<006mk
Kg/03Vmk0P000Vmk0P000Vmk0P003Fmk00<006mkKg/026mk0P00ZVmk002XKg/5000KKg/00`00Kg]_
N`0<Kg/20004Kg/00`00Kg/00002000>Kg/00`00Kg]_N`06Kg/2002/Kg/00:e_N`D001M_N`03001_
Nfmk00U_N`8000I_N`8000=_N`@000Y_N`03001_Nfmk00A_N`800:i_N`00/Vmk10004fmk00<006mk
Kg/026mk00<006mkKg/01Vmk0P001fmk1@001Vmk00@006mkKg]_N`800;1_N`00]Vmk1@003fmk00<0
06mkKg/01Fmk0P002Fmk00<006mkKg/02fmk10000Vmk00@006mk00000;9_N`00^fmk1@002Vmk00<0
06mkKg/00fmk0P002Fmk6000]6mk0030Kg/40006Kg/01000Kg]_Nfmk0P001Fmk1P0016mk3000_6mk
0034Kg/50002Kg/300000fmk0000000>0038Kg/00<U_N`T00=E_N`00ofmkZ6mk003oKg^XKg/00?m_
NjQ_N`00ofmkZ6mk003oKg^XKg/00?m_NjQ_N`00ofmkZ6mk003oKg^XKg/00?m_NjQ_N`00ofmkZ6mk
0000\
\>"],
  ImageRangeCache->{{{0, 422.563}, {421.313, 0}} -> {-5.19858, -5.13732, \
0.0369076, 0.0369076}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["\<\
As mentioned earlier, the distance function is used again to select meshbars \
that are interior to the defined region. For example, the following distance \
function defines a rectangle with a hole in the middle.\
\>", "Text"],

Cell[BoxData[
    \(d[{x_, y_}] := 
      ddiff[drectangle[{x, y}, {\(-2\), \(-0.8\), 2, 0.8}], \ 
        dcircle[{x, y}, \ {0, 0, 0.5}]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((p2 = selectMeshpoints[d, {\(-2\), \(-1\), \ 2, 1}, 0.1])\) // 
      ListPlot[#, AspectRatio \[Rule] Automatic, \ 
          PlotStyle -> PointSize[0.01]] &\)], "Input",
  CellLabel->"In[37]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.2442 0.189743 0.2442 [
[.0116 .17724 -6 -9 ]
[.0116 .17724 6 0 ]
[.2558 .17724 -6 -9 ]
[.2558 .17724 6 0 ]
[.7442 .17724 -3 -9 ]
[.7442 .17724 3 0 ]
[.9884 .17724 -3 -9 ]
[.9884 .17724 3 0 ]
[.4875 .04322 -24 -4.5 ]
[.4875 .04322 0 4.5 ]
[.4875 .09206 -24 -4.5 ]
[.4875 .09206 0 4.5 ]
[.4875 .1409 -24 -4.5 ]
[.4875 .1409 0 4.5 ]
[.4875 .23858 -18 -4.5 ]
[.4875 .23858 0 4.5 ]
[.4875 .28742 -18 -4.5 ]
[.4875 .28742 0 4.5 ]
[.4875 .33626 -18 -4.5 ]
[.4875 .33626 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .3775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0116 .18974 m
.0116 .19599 L
s
[(-2)] .0116 .17724 0 1 Mshowa
.2558 .18974 m
.2558 .19599 L
s
[(-1)] .2558 .17724 0 1 Mshowa
.7442 .18974 m
.7442 .19599 L
s
[(1)] .7442 .17724 0 1 Mshowa
.9884 .18974 m
.9884 .19599 L
s
[(2)] .9884 .17724 0 1 Mshowa
.125 Mabswid
.06044 .18974 m
.06044 .19349 L
s
.10928 .18974 m
.10928 .19349 L
s
.15812 .18974 m
.15812 .19349 L
s
.20696 .18974 m
.20696 .19349 L
s
.30464 .18974 m
.30464 .19349 L
s
.35348 .18974 m
.35348 .19349 L
s
.40232 .18974 m
.40232 .19349 L
s
.45116 .18974 m
.45116 .19349 L
s
.54884 .18974 m
.54884 .19349 L
s
.59768 .18974 m
.59768 .19349 L
s
.64652 .18974 m
.64652 .19349 L
s
.69536 .18974 m
.69536 .19349 L
s
.79304 .18974 m
.79304 .19349 L
s
.84188 .18974 m
.84188 .19349 L
s
.89072 .18974 m
.89072 .19349 L
s
.93956 .18974 m
.93956 .19349 L
s
.25 Mabswid
0 .18974 m
1 .18974 L
s
.5 .04322 m
.50625 .04322 L
s
[(-0.6)] .4875 .04322 1 0 Mshowa
.5 .09206 m
.50625 .09206 L
s
[(-0.4)] .4875 .09206 1 0 Mshowa
.5 .1409 m
.50625 .1409 L
s
[(-0.2)] .4875 .1409 1 0 Mshowa
.5 .23858 m
.50625 .23858 L
s
[(0.2)] .4875 .23858 1 0 Mshowa
.5 .28742 m
.50625 .28742 L
s
[(0.4)] .4875 .28742 1 0 Mshowa
.5 .33626 m
.50625 .33626 L
s
[(0.6)] .4875 .33626 1 0 Mshowa
.125 Mabswid
.5 .05543 m
.50375 .05543 L
s
.5 .06764 m
.50375 .06764 L
s
.5 .07985 m
.50375 .07985 L
s
.5 .10427 m
.50375 .10427 L
s
.5 .11648 m
.50375 .11648 L
s
.5 .12869 m
.50375 .12869 L
s
.5 .15311 m
.50375 .15311 L
s
.5 .16532 m
.50375 .16532 L
s
.5 .17753 m
.50375 .17753 L
s
.5 .20195 m
.50375 .20195 L
s
.5 .21416 m
.50375 .21416 L
s
.5 .22637 m
.50375 .22637 L
s
.5 .25079 m
.50375 .25079 L
s
.5 .263 m
.50375 .263 L
s
.5 .27521 m
.50375 .27521 L
s
.5 .29963 m
.50375 .29963 L
s
.5 .31184 m
.50375 .31184 L
s
.5 .32405 m
.50375 .32405 L
s
.5 .03101 m
.50375 .03101 L
s
.5 .0188 m
.50375 .0188 L
s
.5 .00659 m
.50375 .00659 L
s
.5 .34847 m
.50375 .34847 L
s
.5 .36068 m
.50375 .36068 L
s
.5 .37289 m
.50375 .37289 L
s
.25 Mabswid
.5 0 m
.5 .3775 L
s
0 0 m
1 0 L
1 .3775 L
0 .3775 L
closepath
clip
newpath
.01 w
.02381 .00899 Mdot
.04823 .00899 Mdot
.07265 .00899 Mdot
.09707 .00899 Mdot
.12149 .00899 Mdot
.14591 .00899 Mdot
.17033 .00899 Mdot
.19475 .00899 Mdot
.21917 .00899 Mdot
.24359 .00899 Mdot
.26801 .00899 Mdot
.29243 .00899 Mdot
.31685 .00899 Mdot
.34127 .00899 Mdot
.36569 .00899 Mdot
.39011 .00899 Mdot
.41453 .00899 Mdot
.43895 .00899 Mdot
.46337 .00899 Mdot
.48779 .00899 Mdot
.51221 .00899 Mdot
.53663 .00899 Mdot
.56105 .00899 Mdot
.58547 .00899 Mdot
.60989 .00899 Mdot
.63431 .00899 Mdot
.65873 .00899 Mdot
.68315 .00899 Mdot
.70757 .00899 Mdot
.73199 .00899 Mdot
.75641 .00899 Mdot
.78083 .00899 Mdot
.80525 .00899 Mdot
.82967 .00899 Mdot
.85409 .00899 Mdot
.87851 .00899 Mdot
.90293 .00899 Mdot
.92735 .00899 Mdot
.95177 .00899 Mdot
.97619 .00899 Mdot
.03602 .03014 Mdot
.06044 .03014 Mdot
.08486 .03014 Mdot
.10928 .03014 Mdot
.1337 .03014 Mdot
.15812 .03014 Mdot
.18254 .03014 Mdot
.20696 .03014 Mdot
.23138 .03014 Mdot
.2558 .03014 Mdot
.28022 .03014 Mdot
.30464 .03014 Mdot
.32906 .03014 Mdot
.35348 .03014 Mdot
.3779 .03014 Mdot
.40232 .03014 Mdot
.42674 .03014 Mdot
.45116 .03014 Mdot
.47558 .03014 Mdot
.5 .03014 Mdot
.52442 .03014 Mdot
.54884 .03014 Mdot
.57326 .03014 Mdot
.59768 .03014 Mdot
.6221 .03014 Mdot
.64652 .03014 Mdot
.67094 .03014 Mdot
.69536 .03014 Mdot
.71978 .03014 Mdot
.7442 .03014 Mdot
.76862 .03014 Mdot
.79304 .03014 Mdot
.81746 .03014 Mdot
.84188 .03014 Mdot
.8663 .03014 Mdot
.89072 .03014 Mdot
.91514 .03014 Mdot
.93956 .03014 Mdot
.96398 .03014 Mdot
.02381 .05128 Mdot
.04823 .05128 Mdot
.07265 .05128 Mdot
.09707 .05128 Mdot
.12149 .05128 Mdot
.14591 .05128 Mdot
.17033 .05128 Mdot
.19475 .05128 Mdot
.21917 .05128 Mdot
.24359 .05128 Mdot
.26801 .05128 Mdot
.29243 .05128 Mdot
.31685 .05128 Mdot
.34127 .05128 Mdot
.36569 .05128 Mdot
.39011 .05128 Mdot
.41453 .05128 Mdot
.43895 .05128 Mdot
.46337 .05128 Mdot
.48779 .05128 Mdot
.51221 .05128 Mdot
.53663 .05128 Mdot
.56105 .05128 Mdot
.58547 .05128 Mdot
.60989 .05128 Mdot
.63431 .05128 Mdot
.65873 .05128 Mdot
.68315 .05128 Mdot
.70757 .05128 Mdot
.73199 .05128 Mdot
.75641 .05128 Mdot
.78083 .05128 Mdot
.80525 .05128 Mdot
.82967 .05128 Mdot
.85409 .05128 Mdot
.87851 .05128 Mdot
.90293 .05128 Mdot
.92735 .05128 Mdot
.95177 .05128 Mdot
.97619 .05128 Mdot
.03602 .07243 Mdot
.06044 .07243 Mdot
.08486 .07243 Mdot
.10928 .07243 Mdot
.1337 .07243 Mdot
.15812 .07243 Mdot
.18254 .07243 Mdot
.20696 .07243 Mdot
.23138 .07243 Mdot
.2558 .07243 Mdot
.28022 .07243 Mdot
.30464 .07243 Mdot
.32906 .07243 Mdot
.35348 .07243 Mdot
.3779 .07243 Mdot
.40232 .07243 Mdot
.42674 .07243 Mdot
.45116 .07243 Mdot
.54884 .07243 Mdot
.57326 .07243 Mdot
.59768 .07243 Mdot
.6221 .07243 Mdot
.64652 .07243 Mdot
.67094 .07243 Mdot
.69536 .07243 Mdot
.71978 .07243 Mdot
.7442 .07243 Mdot
.76862 .07243 Mdot
.79304 .07243 Mdot
.81746 .07243 Mdot
.84188 .07243 Mdot
.8663 .07243 Mdot
.89072 .07243 Mdot
.91514 .07243 Mdot
.93956 .07243 Mdot
.96398 .07243 Mdot
.02381 .09358 Mdot
.04823 .09358 Mdot
.07265 .09358 Mdot
.09707 .09358 Mdot
.12149 .09358 Mdot
.14591 .09358 Mdot
.17033 .09358 Mdot
.19475 .09358 Mdot
.21917 .09358 Mdot
.24359 .09358 Mdot
.26801 .09358 Mdot
.29243 .09358 Mdot
.31685 .09358 Mdot
.34127 .09358 Mdot
.36569 .09358 Mdot
.39011 .09358 Mdot
.41453 .09358 Mdot
.58547 .09358 Mdot
.60989 .09358 Mdot
.63431 .09358 Mdot
.65873 .09358 Mdot
.68315 .09358 Mdot
.70757 .09358 Mdot
.73199 .09358 Mdot
.75641 .09358 Mdot
.78083 .09358 Mdot
.80525 .09358 Mdot
.82967 .09358 Mdot
.85409 .09358 Mdot
.87851 .09358 Mdot
.90293 .09358 Mdot
.92735 .09358 Mdot
.95177 .09358 Mdot
.97619 .09358 Mdot
.03602 .11473 Mdot
.06044 .11473 Mdot
.08486 .11473 Mdot
.10928 .11473 Mdot
.1337 .11473 Mdot
.15812 .11473 Mdot
.18254 .11473 Mdot
.20696 .11473 Mdot
.23138 .11473 Mdot
.2558 .11473 Mdot
.28022 .11473 Mdot
.30464 .11473 Mdot
.32906 .11473 Mdot
.35348 .11473 Mdot
.3779 .11473 Mdot
.40232 .11473 Mdot
.59768 .11473 Mdot
.6221 .11473 Mdot
.64652 .11473 Mdot
.67094 .11473 Mdot
.69536 .11473 Mdot
.71978 .11473 Mdot
.7442 .11473 Mdot
.76862 .11473 Mdot
.79304 .11473 Mdot
.81746 .11473 Mdot
.84188 .11473 Mdot
.8663 .11473 Mdot
.89072 .11473 Mdot
.91514 .11473 Mdot
.93956 .11473 Mdot
.96398 .11473 Mdot
.02381 .13588 Mdot
.04823 .13588 Mdot
.07265 .13588 Mdot
.09707 .13588 Mdot
.12149 .13588 Mdot
.14591 .13588 Mdot
.17033 .13588 Mdot
.19475 .13588 Mdot
.21917 .13588 Mdot
.24359 .13588 Mdot
.26801 .13588 Mdot
.29243 .13588 Mdot
.31685 .13588 Mdot
.34127 .13588 Mdot
.36569 .13588 Mdot
.39011 .13588 Mdot
.60989 .13588 Mdot
.63431 .13588 Mdot
.65873 .13588 Mdot
.68315 .13588 Mdot
.70757 .13588 Mdot
.73199 .13588 Mdot
.75641 .13588 Mdot
.78083 .13588 Mdot
.80525 .13588 Mdot
.82967 .13588 Mdot
.85409 .13588 Mdot
.87851 .13588 Mdot
.90293 .13588 Mdot
.92735 .13588 Mdot
.95177 .13588 Mdot
.97619 .13588 Mdot
.03602 .15703 Mdot
.06044 .15703 Mdot
.08486 .15703 Mdot
.10928 .15703 Mdot
.1337 .15703 Mdot
.15812 .15703 Mdot
.18254 .15703 Mdot
.20696 .15703 Mdot
.23138 .15703 Mdot
.2558 .15703 Mdot
.28022 .15703 Mdot
.30464 .15703 Mdot
.32906 .15703 Mdot
.35348 .15703 Mdot
.3779 .15703 Mdot
.6221 .15703 Mdot
.64652 .15703 Mdot
.67094 .15703 Mdot
.69536 .15703 Mdot
.71978 .15703 Mdot
.7442 .15703 Mdot
.76862 .15703 Mdot
.79304 .15703 Mdot
.81746 .15703 Mdot
.84188 .15703 Mdot
.8663 .15703 Mdot
.89072 .15703 Mdot
.91514 .15703 Mdot
.93956 .15703 Mdot
.96398 .15703 Mdot
.02381 .17817 Mdot
.04823 .17817 Mdot
.07265 .17817 Mdot
.09707 .17817 Mdot
.12149 .17817 Mdot
.14591 .17817 Mdot
.17033 .17817 Mdot
.19475 .17817 Mdot
.21917 .17817 Mdot
.24359 .17817 Mdot
.26801 .17817 Mdot
.29243 .17817 Mdot
.31685 .17817 Mdot
.34127 .17817 Mdot
.36569 .17817 Mdot
.63431 .17817 Mdot
.65873 .17817 Mdot
.68315 .17817 Mdot
.70757 .17817 Mdot
.73199 .17817 Mdot
.75641 .17817 Mdot
.78083 .17817 Mdot
.80525 .17817 Mdot
.82967 .17817 Mdot
.85409 .17817 Mdot
.87851 .17817 Mdot
.90293 .17817 Mdot
.92735 .17817 Mdot
.95177 .17817 Mdot
.97619 .17817 Mdot
.03602 .19932 Mdot
.06044 .19932 Mdot
.08486 .19932 Mdot
.10928 .19932 Mdot
.1337 .19932 Mdot
.15812 .19932 Mdot
.18254 .19932 Mdot
.20696 .19932 Mdot
.23138 .19932 Mdot
.2558 .19932 Mdot
.28022 .19932 Mdot
.30464 .19932 Mdot
.32906 .19932 Mdot
.35348 .19932 Mdot
.3779 .19932 Mdot
.6221 .19932 Mdot
.64652 .19932 Mdot
.67094 .19932 Mdot
.69536 .19932 Mdot
.71978 .19932 Mdot
.7442 .19932 Mdot
.76862 .19932 Mdot
.79304 .19932 Mdot
.81746 .19932 Mdot
.84188 .19932 Mdot
.8663 .19932 Mdot
.89072 .19932 Mdot
.91514 .19932 Mdot
.93956 .19932 Mdot
.96398 .19932 Mdot
.02381 .22047 Mdot
.04823 .22047 Mdot
.07265 .22047 Mdot
.09707 .22047 Mdot
.12149 .22047 Mdot
.14591 .22047 Mdot
.17033 .22047 Mdot
.19475 .22047 Mdot
.21917 .22047 Mdot
.24359 .22047 Mdot
.26801 .22047 Mdot
.29243 .22047 Mdot
.31685 .22047 Mdot
.34127 .22047 Mdot
.36569 .22047 Mdot
.63431 .22047 Mdot
.65873 .22047 Mdot
.68315 .22047 Mdot
.70757 .22047 Mdot
.73199 .22047 Mdot
.75641 .22047 Mdot
.78083 .22047 Mdot
.80525 .22047 Mdot
.82967 .22047 Mdot
.85409 .22047 Mdot
.87851 .22047 Mdot
.90293 .22047 Mdot
.92735 .22047 Mdot
.95177 .22047 Mdot
.97619 .22047 Mdot
.03602 .24162 Mdot
.06044 .24162 Mdot
.08486 .24162 Mdot
.10928 .24162 Mdot
.1337 .24162 Mdot
.15812 .24162 Mdot
.18254 .24162 Mdot
.20696 .24162 Mdot
.23138 .24162 Mdot
.2558 .24162 Mdot
.28022 .24162 Mdot
.30464 .24162 Mdot
.32906 .24162 Mdot
.35348 .24162 Mdot
.3779 .24162 Mdot
.6221 .24162 Mdot
.64652 .24162 Mdot
.67094 .24162 Mdot
.69536 .24162 Mdot
.71978 .24162 Mdot
.7442 .24162 Mdot
.76862 .24162 Mdot
.79304 .24162 Mdot
.81746 .24162 Mdot
.84188 .24162 Mdot
.8663 .24162 Mdot
.89072 .24162 Mdot
.91514 .24162 Mdot
.93956 .24162 Mdot
.96398 .24162 Mdot
.02381 .26277 Mdot
.04823 .26277 Mdot
.07265 .26277 Mdot
.09707 .26277 Mdot
.12149 .26277 Mdot
.14591 .26277 Mdot
.17033 .26277 Mdot
.19475 .26277 Mdot
.21917 .26277 Mdot
.24359 .26277 Mdot
.26801 .26277 Mdot
.29243 .26277 Mdot
.31685 .26277 Mdot
.34127 .26277 Mdot
.36569 .26277 Mdot
.39011 .26277 Mdot
.60989 .26277 Mdot
.63431 .26277 Mdot
.65873 .26277 Mdot
.68315 .26277 Mdot
.70757 .26277 Mdot
.73199 .26277 Mdot
.75641 .26277 Mdot
.78083 .26277 Mdot
.80525 .26277 Mdot
.82967 .26277 Mdot
.85409 .26277 Mdot
.87851 .26277 Mdot
.90293 .26277 Mdot
.92735 .26277 Mdot
.95177 .26277 Mdot
.97619 .26277 Mdot
.03602 .28392 Mdot
.06044 .28392 Mdot
.08486 .28392 Mdot
.10928 .28392 Mdot
.1337 .28392 Mdot
.15812 .28392 Mdot
.18254 .28392 Mdot
.20696 .28392 Mdot
.23138 .28392 Mdot
.2558 .28392 Mdot
.28022 .28392 Mdot
.30464 .28392 Mdot
.32906 .28392 Mdot
.35348 .28392 Mdot
.3779 .28392 Mdot
.40232 .28392 Mdot
.59768 .28392 Mdot
.6221 .28392 Mdot
.64652 .28392 Mdot
.67094 .28392 Mdot
.69536 .28392 Mdot
.71978 .28392 Mdot
.7442 .28392 Mdot
.76862 .28392 Mdot
.79304 .28392 Mdot
.81746 .28392 Mdot
.84188 .28392 Mdot
.8663 .28392 Mdot
.89072 .28392 Mdot
.91514 .28392 Mdot
.93956 .28392 Mdot
.96398 .28392 Mdot
.02381 .30507 Mdot
.04823 .30507 Mdot
.07265 .30507 Mdot
.09707 .30507 Mdot
.12149 .30507 Mdot
.14591 .30507 Mdot
.17033 .30507 Mdot
.19475 .30507 Mdot
.21917 .30507 Mdot
.24359 .30507 Mdot
.26801 .30507 Mdot
.29243 .30507 Mdot
.31685 .30507 Mdot
.34127 .30507 Mdot
.36569 .30507 Mdot
.39011 .30507 Mdot
.41453 .30507 Mdot
.43895 .30507 Mdot
.56105 .30507 Mdot
.58547 .30507 Mdot
.60989 .30507 Mdot
.63431 .30507 Mdot
.65873 .30507 Mdot
.68315 .30507 Mdot
.70757 .30507 Mdot
.73199 .30507 Mdot
.75641 .30507 Mdot
.78083 .30507 Mdot
.80525 .30507 Mdot
.82967 .30507 Mdot
.85409 .30507 Mdot
.87851 .30507 Mdot
.90293 .30507 Mdot
.92735 .30507 Mdot
.95177 .30507 Mdot
.97619 .30507 Mdot
.03602 .32621 Mdot
.06044 .32621 Mdot
.08486 .32621 Mdot
.10928 .32621 Mdot
.1337 .32621 Mdot
.15812 .32621 Mdot
.18254 .32621 Mdot
.20696 .32621 Mdot
.23138 .32621 Mdot
.2558 .32621 Mdot
.28022 .32621 Mdot
.30464 .32621 Mdot
.32906 .32621 Mdot
.35348 .32621 Mdot
.3779 .32621 Mdot
.40232 .32621 Mdot
.42674 .32621 Mdot
.45116 .32621 Mdot
.47558 .32621 Mdot
.5 .32621 Mdot
.52442 .32621 Mdot
.54884 .32621 Mdot
.57326 .32621 Mdot
.59768 .32621 Mdot
.6221 .32621 Mdot
.64652 .32621 Mdot
.67094 .32621 Mdot
.69536 .32621 Mdot
.71978 .32621 Mdot
.7442 .32621 Mdot
.76862 .32621 Mdot
.79304 .32621 Mdot
.81746 .32621 Mdot
.84188 .32621 Mdot
.8663 .32621 Mdot
.89072 .32621 Mdot
.91514 .32621 Mdot
.93956 .32621 Mdot
.96398 .32621 Mdot
.02381 .34736 Mdot
.04823 .34736 Mdot
.07265 .34736 Mdot
.09707 .34736 Mdot
.12149 .34736 Mdot
.14591 .34736 Mdot
.17033 .34736 Mdot
.19475 .34736 Mdot
.21917 .34736 Mdot
.24359 .34736 Mdot
.26801 .34736 Mdot
.29243 .34736 Mdot
.31685 .34736 Mdot
.34127 .34736 Mdot
.36569 .34736 Mdot
.39011 .34736 Mdot
.41453 .34736 Mdot
.43895 .34736 Mdot
.46337 .34736 Mdot
.48779 .34736 Mdot
.51221 .34736 Mdot
.53663 .34736 Mdot
.56105 .34736 Mdot
.58547 .34736 Mdot
.60989 .34736 Mdot
.63431 .34736 Mdot
.65873 .34736 Mdot
.68315 .34736 Mdot
.70757 .34736 Mdot
.73199 .34736 Mdot
.75641 .34736 Mdot
.78083 .34736 Mdot
.80525 .34736 Mdot
.82967 .34736 Mdot
.85409 .34736 Mdot
.87851 .34736 Mdot
.90293 .34736 Mdot
.92735 .34736 Mdot
.95177 .34736 Mdot
.97619 .34736 Mdot
.03602 .36851 Mdot
.06044 .36851 Mdot
.08486 .36851 Mdot
.10928 .36851 Mdot
.1337 .36851 Mdot
.15812 .36851 Mdot
.18254 .36851 Mdot
.20696 .36851 Mdot
.23138 .36851 Mdot
.2558 .36851 Mdot
.28022 .36851 Mdot
.30464 .36851 Mdot
.32906 .36851 Mdot
.35348 .36851 Mdot
.3779 .36851 Mdot
.40232 .36851 Mdot
.42674 .36851 Mdot
.45116 .36851 Mdot
.47558 .36851 Mdot
.5 .36851 Mdot
.52442 .36851 Mdot
.54884 .36851 Mdot
.57326 .36851 Mdot
.59768 .36851 Mdot
.6221 .36851 Mdot
.64652 .36851 Mdot
.67094 .36851 Mdot
.69536 .36851 Mdot
.71978 .36851 Mdot
.7442 .36851 Mdot
.76862 .36851 Mdot
.79304 .36851 Mdot
.81746 .36851 Mdot
.84188 .36851 Mdot
.8663 .36851 Mdot
.89072 .36851 Mdot
.91514 .36851 Mdot
.93956 .36851 Mdot
.96398 .36851 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[37]:=",
  ImageSize->{288, 108.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000Xa000`40O003h00Oofmk/Fmk003IKg/0
0`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`003Fmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0016mk00<006mkKg/00Vmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P002Vmk000<Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40003Kg/300000fmk0000
00020006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40009
Kg/000a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000=_N`04001_NfmkKg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40009Kg/000e_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000A_N`03001_Nfmk009_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Y_N`00fFmk00<006mkKg/0e6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`<00=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/0019_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80011_N`004Fmk1000
1fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10003fmk000AKg/40007
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/50006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000?Kg/0019_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80011_N`00^fmk10001Vmk
0P001fmk10001fmk00<006mkKg/0e6mk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20006Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`3DKg/00;Y_N`03001_Nfmk009_N`03001_Nfmk
00]_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk0=A_N`00^Vmk00<006mkKg/00Vmk00<0
06mkKg/02fmk0P000fmk00<006mkKg/016mk1000dfmk002aKg/60003Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0;Kg/00`00Kg/000020007Kg/00`00Kg]_N`3DKg/000e_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000A_N`04001_NfmkKg/20009Kg/20002Kg/00`00Kg]_N`03Kg/20004
Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/2000:Kg/000a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000=_
N`03001_Nfmk00@000M_N`@0009_N`04001_NfmkKg/40003Kg/01000Kg]_Nfmk10001Vmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Fmk000<Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40003Kg/00`00Kg]_N`040007Kg/40003Kg/00`00
Kg]_N`040003Kg/01000Kg]_Nfmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001fmk10002Fmk000=Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20005Kg/50009Kg/20005Kg/50004Kg/00`00Kg]_N`02Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:Kg/00=U_N`<00=A_N`00fFmk00<006mk
Kg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk000B
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000CKg/3000AKg/20009
Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000@Kg/0015_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@0019_N`03001_Nfmk011_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000m_N`004Fmk10001fmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001fmk10004Vmk00<006mkKg/046mk10001fmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10003fmk000BKg/20009Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/20008Kg/20009Kg/2000CKg/00`00Kg]_N`0AKg/20009Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/2000@Kg/00=U_N`03001_Nfmk0=A_N`00fFmk0`00e6mk003IKg/00`00
Kg]_N`3DKg/00;]_N`@000I_N`8000M_N`@000M_N`03001_Nfmk0=A_N`00^Vmk00<006mkKg/00Vmk
00<006mkKg/00fmk0P002Fmk00<006mkKg/01Vmk00<006mkKg/0e6mk000=Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`0QKg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:Kg/0
00a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000=_N`03001_Nfmk009_N`03
001_Nfmk00Y_N`H000M_N`@001m_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00U_N`0036mk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001Fmk1P000fmk00<006mkKg/0
0Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03001_Nfmk021_N`@000I_N`@000M_N`@000I_N`@0
00M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000U_N`003Fmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0016mk00<006mkKg/00Vmk00<006mkKg/02fmk00@006mkKg/000Q_N`03001_Nfmk025_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Y_N`00^Vmk00<006mkKg/00Vmk00<0
06mkKg/036mk00<006mk000026mk00<006mkKg/0e6mk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<
Kg/00`00Kg/00008Kg/00`00Kg]_N`3DKg/00;]_N`@0011_N`8000Q_N`<00=A_N`00fFmk00<006mk
Kg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`004Vmk0P002Fmk0P0026mk0P00
2Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P00:6mk00<006mkKg/09Vmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P00
26mk0P0046mk000AKg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4000WKg/00`00Kg]_N`0U
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000?Kg/0015_N`@000M_N`@000I_N`@000M_
N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_
N`@000I_N`@000M_N`@002M_N`<002E_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_
N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000m_
N`004Vmk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00:6mk00<006mkKg/09Vmk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P002Fmk0P0026mk0P0026mk0P0046mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk
0=A_N`00fFmk00<006mkKg/0e6mk003IKg/3003DKg/00=U_N`03001_Nfmk0=A_N`003Fmk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk
0P0026mk0P002Fmk0P0026mk0P0026mk0P0046mk10001Vmk0P001Fmk1P001fmk00<006mkKg/0:fmk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P002Vmk000<Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/4000>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0ZKg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40009Kg/0
00a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000i_N`03001_Nfmk009_N`03001_Nfmk
00]_N`03001_Nfmk00U_N`03001_Nfmk02Y_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00U_N`003Fmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00
26mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P003fmk00<006mkKg/00Vmk00<0
06mkKg/036mk00<006mkKg/026mk1000:Vmk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00
2Vmk002aKg/60003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`07Kg/00`00Kg]_N`3D
Kg/00;Y_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk0=A_N`00^Vmk
00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0e6mk
000:Kg/6001RKg/70011Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`1RKg/7001QKg/60004Kg/000Y_N`03001_Nfmk009_N`03001_Nfmk06=_N`03
001_Nfmk04=_N`@000i_N`@000Q_N`<006E_N`03001_Nfmk069_N`03001_Nfmk009_N`03001_Nfmk
009_N`002fmk00<006mkKg/016mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P00
26mk0P002Fmk0P0026mk0P000fmk00<006mkKg/00fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P00
<fmk00<006mkKg/0<Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P00
26mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P001fmk00<006mkKg/01Vmk000<
Kg/00`00Kg]_N`02Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40002Kg/00`00Kg]_N`02Kg/40006Kg/40006Kg/40007Kg/40006Kg/4000bKg/00`00
Kg]_N`0`Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/00`00Kg]_N`05Kg/00003Kg/00000
00@000I_N`04001_NfmkKg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4
0007Kg/>0002Kg/00`00Kg]_N`02Kg/40006Kg/40006Kg/40007Kg/40006Kg/4000bKg/00`00Kg]_
N`0`Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40008Kg/00`00Kg]_N`04Kg/000i_N`04001_Nfmk
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20003
Kg/00`00Kg]_N`03Kg/20008Kg/20008Kg/20009Kg/20008Kg/2000cKg/00`00Kg]_N`0aKg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20008Kg/2000:Kg/00`00Kg]_N`03Kg/000Y_N`03001_Nfmk009_N`03001_
Nfmk06=_N`03001_Nfmk065_N`<006E_N`03001_Nfmk069_N`03001_Nfmk009_N`03001_Nfmk009_
N`002Vmk00<006mkKg/00Vmk00<006mkKg/0HFmk0`00Hfmk00<006mkKg/0Hfmk0`00I6mk00<006mk
Kg/00Vmk00<006mkKg/00Vmk000;Kg/4001VKg/00`00Kg]_N`1QKg/00`00Kg]_N`1UKg/00`00Kg]_
N`1SKg/40005Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk000=Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/2000hKg/00`00Kg]_N`0fKg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:
Kg/000a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@003M_N`<003E_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000U_N`0036mk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000=fmk00<006mkKg/0=Fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk10002Fmk000=Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/2
000hKg/00`00Kg]_N`0fKg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:Kg/00=U_N`03001_Nfmk
0=A_N`00fFmk00<006mkKg/0e6mk0004Kg_o002/0001Kg/000U_N`03001_Nfmk015_N`03001_Nfmk
019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk
015_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk
019_N`03001_Nfmk019_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk
019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk019_N`03001_Nfmk00=_N`002Fmk00<0
06mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<0
06mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<0
06mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/04Vmk00<0
06mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<0
06mkKg/00fmk0009Kg/00`00Kg]_N`06Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2000cKg/00`00
Kg]_N`0aKg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000:Kg/00`00Kg]_N`03Kg/0015_N`@000M_
N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@0039_N`03001_Nfmk031_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000m_N`004Fmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk1000<Vmk0`00<6mk10001Vmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001Vmk10003fmk000BKg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2000cKg/00`00Kg]_
N`0aKg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000@Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`<00=A_N`00fFmk00<006mkKg/0e6mk000=Kg/2
0009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20009Kg/20008Kg/2000hKg/00`00Kg]_N`0fKg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
0009Kg/2000:Kg/000a_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@003M_N`03001_Nfmk03E_N`@0
00I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@0
00I_N`@000M_N`@000I_N`@000M_N`@000U_N`0036mk10001fmk10001Vmk10001Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
=fmk00<006mkKg/0=Fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Fmk000=Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/2000hKg/00`00Kg]_N`0fKg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:
Kg/00=U_N`<00=A_N`00^fmk10001Vmk0P001Fmk1P001fmk00<006mkKg/0e6mk002jKg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`3DKg/0
0;Y_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00U_N`03001_Nfmk0=A_N`00^Vmk00<0
06mkKg/00Vmk00<006mkKg/036mk00<006mkKg/026mk00<006mkKg/0e6mk000BKg/20009Kg/20008
Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008
Kg/20009Kg/20008Kg/2000DKg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`07Kg/4000`
Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009
Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000@Kg/0015_N`@000M_N`@000I_N`@000M_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@001=_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk031_N`@000I_
N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000m_N`004Fmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10004fmk
00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0<6mk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10003fmk000BKg/20009Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/2
000DKg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`0aKg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2
0009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000@Kg/00;]_N`@000i_N`@000Q_N`03001_Nfmk
0=A_N`00fFmk0`00e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mk
Kg/0e6mk000=Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000^Kg/00`00Kg]_N`0[Kg/2
0009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:Kg/000a_N`@000M_N`@000I_N`@000I_N`@0
00M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@0
00I_N`@000I_N`@002e_N`<002Y_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@0
00I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000U_N`00
36mk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000;Fmk00<006mkKg/0:Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1Vmk10001fmk10001Vmk10001fmk10002Fmk000=Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008
Kg/2000^Kg/00`00Kg]_N`0[Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/2000:Kg/00=U_
N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/3003DKg/00=U_N`03001_Nfmk0=A_N`00
^fmk10001Vmk0P001fmk10001fmk00<006mkKg/0e6mk000BKg/20009Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008
Kg/20009Kg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20009Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`0VKg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008
Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20008Kg/2000@Kg/0015_N`@000M_N`@000I_
N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_
N`@000M_N`@000I_N`@000M_N`@000Q_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk00I_
N`03001_Nfmk02E_N`@000M_N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000M_
N`@000I_N`@000I_N`@000M_N`@000I_N`@000M_N`@000I_N`@000I_N`@000m_N`004Fmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk100026mk00<006mkKg/00Vmk00<006mkKg/02Vmk1P001fmk
00<006mkKg/09Fmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10003fmk000BKg/20009Kg/2
0008Kg/20009Kg/20008Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/01000Kg]_
N`0026mk10009Fmk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P0046mk002jKg/00`00Kg]_
N`02Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0026mk00<006mkKg/0e6mk002jKg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0<Kg/00`00Kg/00008Kg/00`00Kg]_N`3DKg/00;Y_N`03001_Nfmk009_N`03001_Nfmk
00a_N`03001_N`0000Q_N`03001_Nfmk0=A_N`00^fmk100046mk0P0026mk00<006mkKg/0e6mk003I
Kg/3003DKg/000e_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8001U_
N`03001_Nfmk01I_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Y_
N`0036mk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk100066mk00<006mk
Kg/05Fmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Fmk000<Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/4000HKg/00`00Kg]_N`0EKg/4
0007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40009Kg/000e_N`8000U_N`80
00Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8001U_N`03001_Nfmk01I_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Y_N`00fFmk0`00e6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/0
019_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`@0
00M_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80011_N`00
4Fmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk1000
1fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk1000
1Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10003fmk000A
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/70004Kg/40006Kg/50005Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006
Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000?Kg/0019_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000A_N`03001_Nfmk009_N`<000I_
N`<0009_N`03001_Nfmk00=_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`80011_N`00^Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/00Vmk
00<006mkKg/016mk00<006mkKg/0e6mk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/20003Kg/0
0`00Kg]_N`04Kg/4003CKg/00;Y_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_N`00008000M_
N`03001_Nfmk0=A_N`00^Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mk
Kg/0e6mk002jKg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`08Kg/00`00Kg]_N`3DKg/0
00e_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000A_N`04001_NfmkKg/20009
Kg/20004Kg/01000Kg]_Nfmk0P0016mk00<006mkKg/00Vmk0P0026mk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk
0P0026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P002Vmk000<Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40006Kg/40007Kg/40004Kg/60007Kg/40004Kg/60003Kg/01000Kg]_Nfmk10001Vmk1000
1Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk1000
1fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10002Fmk000<Kg/40007
Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007
Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40003Kg/30000
0fmk000000020006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006
Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007
Kg/40009Kg/000e_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000A_N`03001_Nfmk009_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Y_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/0
0=U_N`03001_Nfmk0=A_N`00fFmk0`00e6mk003IKg/00`00Kg]_N`3DKg/0019_N`8000U_N`8000Q_
N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_
N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80011_N`004Fmk10001fmk10001Vmk
10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk
10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk
10001Vmk10001fmk10001Vmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001fmk10001Vmk
10001Vmk10001fmk10001Vmk10001fmk10001Vmk10001Vmk10003fmk000AKg/40007Kg/40006Kg/4
0007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4
0007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/4
0006Kg/40007Kg/40006Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40007Kg/40006Kg/4
0006Kg/40007Kg/40006Kg/40007Kg/40006Kg/40006Kg/4000?Kg/0019_N`8000U_N`8000Q_N`80
00U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80
00U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`@000M_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`80011_N`00fFmk00<006mkKg/0e6mk003I
Kg/00`00Kg]_N`3DKg/00001\
\>"],
  ImageRangeCache->{{{0, 431}, {162, 0}} -> {-2.08634, -0.780964, 0.014387, \
0.014387}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(bars2 = meshbar[DelaunayTriangulation[p2]]; 
    meshbarPlot[p2, bars2]\)], "Input",
  CellLabel->"In[38]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.2442 0.189743 0.2442 [
[ 0 0 0 0 ]
[ 1 .3775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3775 L
0 .3775 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00899 m
.04823 .00899 L
s
.02381 .00899 m
.03602 .03014 L
s
.02381 .00899 m
.02381 .05128 L
s
.04823 .00899 m
.07265 .00899 L
s
.04823 .00899 m
.03602 .03014 L
s
.04823 .00899 m
.06044 .03014 L
s
.07265 .00899 m
.09707 .00899 L
s
.07265 .00899 m
.06044 .03014 L
s
.07265 .00899 m
.08486 .03014 L
s
.09707 .00899 m
.12149 .00899 L
s
.09707 .00899 m
.08486 .03014 L
s
.09707 .00899 m
.10928 .03014 L
s
.12149 .00899 m
.14591 .00899 L
s
.12149 .00899 m
.10928 .03014 L
s
.12149 .00899 m
.1337 .03014 L
s
.14591 .00899 m
.17033 .00899 L
s
.14591 .00899 m
.1337 .03014 L
s
.14591 .00899 m
.15812 .03014 L
s
.17033 .00899 m
.19475 .00899 L
s
.17033 .00899 m
.15812 .03014 L
s
.17033 .00899 m
.18254 .03014 L
s
.19475 .00899 m
.21917 .00899 L
s
.19475 .00899 m
.18254 .03014 L
s
.19475 .00899 m
.20696 .03014 L
s
.21917 .00899 m
.24359 .00899 L
s
.21917 .00899 m
.20696 .03014 L
s
.21917 .00899 m
.23138 .03014 L
s
.24359 .00899 m
.26801 .00899 L
s
.24359 .00899 m
.23138 .03014 L
s
.24359 .00899 m
.2558 .03014 L
s
.26801 .00899 m
.29243 .00899 L
s
.26801 .00899 m
.2558 .03014 L
s
.26801 .00899 m
.28022 .03014 L
s
.29243 .00899 m
.31685 .00899 L
s
.29243 .00899 m
.28022 .03014 L
s
.29243 .00899 m
.30464 .03014 L
s
.31685 .00899 m
.34127 .00899 L
s
.31685 .00899 m
.30464 .03014 L
s
.31685 .00899 m
.32906 .03014 L
s
.34127 .00899 m
.36569 .00899 L
s
.34127 .00899 m
.32906 .03014 L
s
.34127 .00899 m
.35348 .03014 L
s
.36569 .00899 m
.39011 .00899 L
s
.36569 .00899 m
.35348 .03014 L
s
.36569 .00899 m
.3779 .03014 L
s
.39011 .00899 m
.41453 .00899 L
s
.39011 .00899 m
.3779 .03014 L
s
.39011 .00899 m
.40232 .03014 L
s
.41453 .00899 m
.43895 .00899 L
s
.41453 .00899 m
.40232 .03014 L
s
.41453 .00899 m
.42674 .03014 L
s
.43895 .00899 m
.46337 .00899 L
s
.43895 .00899 m
.42674 .03014 L
s
.43895 .00899 m
.45116 .03014 L
s
.46337 .00899 m
.48779 .00899 L
s
.46337 .00899 m
.45116 .03014 L
s
.46337 .00899 m
.47558 .03014 L
s
.48779 .00899 m
.51221 .00899 L
s
.48779 .00899 m
.47558 .03014 L
s
.48779 .00899 m
.5 .03014 L
s
.51221 .00899 m
.53663 .00899 L
s
.51221 .00899 m
.5 .03014 L
s
.51221 .00899 m
.52442 .03014 L
s
.53663 .00899 m
.56105 .00899 L
s
.53663 .00899 m
.52442 .03014 L
s
.53663 .00899 m
.54884 .03014 L
s
.56105 .00899 m
.58547 .00899 L
s
.56105 .00899 m
.54884 .03014 L
s
.56105 .00899 m
.57326 .03014 L
s
.58547 .00899 m
.60989 .00899 L
s
.58547 .00899 m
.57326 .03014 L
s
.58547 .00899 m
.59768 .03014 L
s
.60989 .00899 m
.63431 .00899 L
s
.60989 .00899 m
.59768 .03014 L
s
.60989 .00899 m
.6221 .03014 L
s
.63431 .00899 m
.65873 .00899 L
s
.63431 .00899 m
.6221 .03014 L
s
.63431 .00899 m
.64652 .03014 L
s
.65873 .00899 m
.68315 .00899 L
s
.65873 .00899 m
.64652 .03014 L
s
.65873 .00899 m
.67094 .03014 L
s
.68315 .00899 m
.70757 .00899 L
s
.68315 .00899 m
.67094 .03014 L
s
.68315 .00899 m
.69536 .03014 L
s
.70757 .00899 m
.73199 .00899 L
s
.70757 .00899 m
.69536 .03014 L
s
.70757 .00899 m
.71978 .03014 L
s
.73199 .00899 m
.75641 .00899 L
s
.73199 .00899 m
.71978 .03014 L
s
.73199 .00899 m
.7442 .03014 L
s
.75641 .00899 m
.78083 .00899 L
s
.75641 .00899 m
.7442 .03014 L
s
.75641 .00899 m
.76862 .03014 L
s
.78083 .00899 m
.80525 .00899 L
s
.78083 .00899 m
.76862 .03014 L
s
.78083 .00899 m
.79304 .03014 L
s
.80525 .00899 m
.82967 .00899 L
s
.80525 .00899 m
.79304 .03014 L
s
.80525 .00899 m
.81746 .03014 L
s
.82967 .00899 m
.85409 .00899 L
s
.82967 .00899 m
.81746 .03014 L
s
.82967 .00899 m
.84188 .03014 L
s
.85409 .00899 m
.87851 .00899 L
s
.85409 .00899 m
.84188 .03014 L
s
.85409 .00899 m
.8663 .03014 L
s
.87851 .00899 m
.90293 .00899 L
s
.87851 .00899 m
.8663 .03014 L
s
.87851 .00899 m
.89072 .03014 L
s
.90293 .00899 m
.92735 .00899 L
s
.90293 .00899 m
.89072 .03014 L
s
.90293 .00899 m
.91514 .03014 L
s
.92735 .00899 m
.95177 .00899 L
s
.92735 .00899 m
.91514 .03014 L
s
.92735 .00899 m
.93956 .03014 L
s
.95177 .00899 m
.97619 .00899 L
s
.95177 .00899 m
.93956 .03014 L
s
.95177 .00899 m
.96398 .03014 L
s
.97619 .00899 m
.96398 .03014 L
s
.97619 .00899 m
.97619 .05128 L
s
.03602 .03014 m
.06044 .03014 L
s
.03602 .03014 m
.02381 .05128 L
s
.03602 .03014 m
.04823 .05128 L
s
.06044 .03014 m
.08486 .03014 L
s
.06044 .03014 m
.04823 .05128 L
s
.06044 .03014 m
.07265 .05128 L
s
.08486 .03014 m
.10928 .03014 L
s
.08486 .03014 m
.07265 .05128 L
s
.08486 .03014 m
.09707 .05128 L
s
.10928 .03014 m
.1337 .03014 L
s
.10928 .03014 m
.09707 .05128 L
s
.10928 .03014 m
.12149 .05128 L
s
.1337 .03014 m
.15812 .03014 L
s
.1337 .03014 m
.12149 .05128 L
s
.1337 .03014 m
.14591 .05128 L
s
.15812 .03014 m
.18254 .03014 L
s
.15812 .03014 m
.14591 .05128 L
s
.15812 .03014 m
.17033 .05128 L
s
.18254 .03014 m
.20696 .03014 L
s
.18254 .03014 m
.17033 .05128 L
s
.18254 .03014 m
.19475 .05128 L
s
.20696 .03014 m
.23138 .03014 L
s
.20696 .03014 m
.19475 .05128 L
s
.20696 .03014 m
.21917 .05128 L
s
.23138 .03014 m
.2558 .03014 L
s
.23138 .03014 m
.21917 .05128 L
s
.23138 .03014 m
.24359 .05128 L
s
.2558 .03014 m
.28022 .03014 L
s
.2558 .03014 m
.24359 .05128 L
s
.2558 .03014 m
.26801 .05128 L
s
.28022 .03014 m
.30464 .03014 L
s
.28022 .03014 m
.26801 .05128 L
s
.28022 .03014 m
.29243 .05128 L
s
.30464 .03014 m
.32906 .03014 L
s
.30464 .03014 m
.29243 .05128 L
s
.30464 .03014 m
.31685 .05128 L
s
.32906 .03014 m
.35348 .03014 L
s
.32906 .03014 m
.31685 .05128 L
s
.32906 .03014 m
.34127 .05128 L
s
.35348 .03014 m
.3779 .03014 L
s
.35348 .03014 m
.34127 .05128 L
s
.35348 .03014 m
.36569 .05128 L
s
.3779 .03014 m
.40232 .03014 L
s
.3779 .03014 m
.36569 .05128 L
s
.3779 .03014 m
.39011 .05128 L
s
.40232 .03014 m
.42674 .03014 L
s
.40232 .03014 m
.39011 .05128 L
s
.40232 .03014 m
.41453 .05128 L
s
.42674 .03014 m
.45116 .03014 L
s
.42674 .03014 m
.41453 .05128 L
s
.42674 .03014 m
.43895 .05128 L
s
.45116 .03014 m
.47558 .03014 L
s
.45116 .03014 m
.43895 .05128 L
s
.45116 .03014 m
.46337 .05128 L
s
.47558 .03014 m
.5 .03014 L
s
.47558 .03014 m
.46337 .05128 L
s
.47558 .03014 m
.48779 .05128 L
s
.5 .03014 m
.52442 .03014 L
s
.5 .03014 m
.48779 .05128 L
s
.5 .03014 m
.51221 .05128 L
s
.52442 .03014 m
.54884 .03014 L
s
.52442 .03014 m
.51221 .05128 L
s
.52442 .03014 m
.53663 .05128 L
s
.54884 .03014 m
.57326 .03014 L
s
.54884 .03014 m
.53663 .05128 L
s
.54884 .03014 m
.56105 .05128 L
s
.57326 .03014 m
.59768 .03014 L
s
.57326 .03014 m
.56105 .05128 L
s
.57326 .03014 m
.58547 .05128 L
s
.59768 .03014 m
.6221 .03014 L
s
.59768 .03014 m
.58547 .05128 L
s
.59768 .03014 m
.60989 .05128 L
s
.6221 .03014 m
.64652 .03014 L
s
.6221 .03014 m
.60989 .05128 L
s
.6221 .03014 m
.63431 .05128 L
s
.64652 .03014 m
.67094 .03014 L
s
.64652 .03014 m
.63431 .05128 L
s
.64652 .03014 m
.65873 .05128 L
s
.67094 .03014 m
.69536 .03014 L
s
.67094 .03014 m
.65873 .05128 L
s
.67094 .03014 m
.68315 .05128 L
s
.69536 .03014 m
.71978 .03014 L
s
.69536 .03014 m
.68315 .05128 L
s
.69536 .03014 m
.70757 .05128 L
s
.71978 .03014 m
.7442 .03014 L
s
.71978 .03014 m
.70757 .05128 L
s
.71978 .03014 m
.73199 .05128 L
s
.7442 .03014 m
.76862 .03014 L
s
.7442 .03014 m
.73199 .05128 L
s
.7442 .03014 m
.75641 .05128 L
s
.76862 .03014 m
.79304 .03014 L
s
.76862 .03014 m
.75641 .05128 L
s
.76862 .03014 m
.78083 .05128 L
s
.79304 .03014 m
.81746 .03014 L
s
.79304 .03014 m
.78083 .05128 L
s
.79304 .03014 m
.80525 .05128 L
s
.81746 .03014 m
.84188 .03014 L
s
.81746 .03014 m
.80525 .05128 L
s
.81746 .03014 m
.82967 .05128 L
s
.84188 .03014 m
.8663 .03014 L
s
.84188 .03014 m
.82967 .05128 L
s
.84188 .03014 m
.85409 .05128 L
s
.8663 .03014 m
.89072 .03014 L
s
.8663 .03014 m
.85409 .05128 L
s
.8663 .03014 m
.87851 .05128 L
s
.89072 .03014 m
.91514 .03014 L
s
.89072 .03014 m
.87851 .05128 L
s
.89072 .03014 m
.90293 .05128 L
s
.91514 .03014 m
.93956 .03014 L
s
.91514 .03014 m
.90293 .05128 L
s
.91514 .03014 m
.92735 .05128 L
s
.93956 .03014 m
.96398 .03014 L
s
.93956 .03014 m
.92735 .05128 L
s
.93956 .03014 m
.95177 .05128 L
s
.96398 .03014 m
.95177 .05128 L
s
.96398 .03014 m
.97619 .05128 L
s
.02381 .05128 m
.04823 .05128 L
s
.02381 .05128 m
.03602 .07243 L
s
.02381 .05128 m
.02381 .09358 L
s
.04823 .05128 m
.07265 .05128 L
s
.04823 .05128 m
.03602 .07243 L
s
.04823 .05128 m
.06044 .07243 L
s
.07265 .05128 m
.09707 .05128 L
s
.07265 .05128 m
.06044 .07243 L
s
.07265 .05128 m
.08486 .07243 L
s
.09707 .05128 m
.12149 .05128 L
s
.09707 .05128 m
.08486 .07243 L
s
.09707 .05128 m
.10928 .07243 L
s
.12149 .05128 m
.14591 .05128 L
s
.12149 .05128 m
.10928 .07243 L
s
.12149 .05128 m
.1337 .07243 L
s
.14591 .05128 m
.17033 .05128 L
s
.14591 .05128 m
.1337 .07243 L
s
.14591 .05128 m
.15812 .07243 L
s
.17033 .05128 m
.19475 .05128 L
s
.17033 .05128 m
.15812 .07243 L
s
.17033 .05128 m
.18254 .07243 L
s
.19475 .05128 m
.21917 .05128 L
s
.19475 .05128 m
.18254 .07243 L
s
.19475 .05128 m
.20696 .07243 L
s
.21917 .05128 m
.24359 .05128 L
s
.21917 .05128 m
.20696 .07243 L
s
.21917 .05128 m
.23138 .07243 L
s
.24359 .05128 m
.26801 .05128 L
s
.24359 .05128 m
.23138 .07243 L
s
.24359 .05128 m
.2558 .07243 L
s
.26801 .05128 m
.29243 .05128 L
s
.26801 .05128 m
.2558 .07243 L
s
.26801 .05128 m
.28022 .07243 L
s
.29243 .05128 m
.31685 .05128 L
s
.29243 .05128 m
.28022 .07243 L
s
.29243 .05128 m
.30464 .07243 L
s
.31685 .05128 m
.34127 .05128 L
s
.31685 .05128 m
.30464 .07243 L
s
.31685 .05128 m
.32906 .07243 L
s
.34127 .05128 m
.36569 .05128 L
s
.34127 .05128 m
.32906 .07243 L
s
.34127 .05128 m
.35348 .07243 L
s
.36569 .05128 m
.39011 .05128 L
s
.36569 .05128 m
.35348 .07243 L
s
.36569 .05128 m
.3779 .07243 L
s
.39011 .05128 m
.41453 .05128 L
s
.39011 .05128 m
.3779 .07243 L
s
.39011 .05128 m
.40232 .07243 L
s
.41453 .05128 m
.43895 .05128 L
s
.41453 .05128 m
.40232 .07243 L
s
.41453 .05128 m
.42674 .07243 L
s
.43895 .05128 m
.46337 .05128 L
s
.43895 .05128 m
.42674 .07243 L
s
.43895 .05128 m
.45116 .07243 L
s
.46337 .05128 m
.48779 .05128 L
s
.46337 .05128 m
.45116 .07243 L
s
.48779 .05128 m
.51221 .05128 L
s
.48779 .05128 m
.45116 .07243 L
s
.48779 .05128 m
.54884 .07243 L
s
.51221 .05128 m
.53663 .05128 L
s
.51221 .05128 m
.54884 .07243 L
s
.53663 .05128 m
.56105 .05128 L
s
.53663 .05128 m
.54884 .07243 L
s
.56105 .05128 m
.58547 .05128 L
s
.56105 .05128 m
.54884 .07243 L
s
.56105 .05128 m
.57326 .07243 L
s
.58547 .05128 m
.60989 .05128 L
s
.58547 .05128 m
.57326 .07243 L
s
.58547 .05128 m
.59768 .07243 L
s
.60989 .05128 m
.63431 .05128 L
s
.60989 .05128 m
.59768 .07243 L
s
.60989 .05128 m
.6221 .07243 L
s
.63431 .05128 m
.65873 .05128 L
s
.63431 .05128 m
.6221 .07243 L
s
.63431 .05128 m
.64652 .07243 L
s
.65873 .05128 m
.68315 .05128 L
s
.65873 .05128 m
.64652 .07243 L
s
.65873 .05128 m
.67094 .07243 L
s
.68315 .05128 m
.70757 .05128 L
s
.68315 .05128 m
.67094 .07243 L
s
.68315 .05128 m
.69536 .07243 L
s
.70757 .05128 m
.73199 .05128 L
s
.70757 .05128 m
.69536 .07243 L
s
.70757 .05128 m
.71978 .07243 L
s
.73199 .05128 m
.75641 .05128 L
s
.73199 .05128 m
.71978 .07243 L
s
.73199 .05128 m
.7442 .07243 L
s
.75641 .05128 m
.78083 .05128 L
s
.75641 .05128 m
.7442 .07243 L
s
.75641 .05128 m
.76862 .07243 L
s
.78083 .05128 m
.80525 .05128 L
s
.78083 .05128 m
.76862 .07243 L
s
.78083 .05128 m
.79304 .07243 L
s
.80525 .05128 m
.82967 .05128 L
s
.80525 .05128 m
.79304 .07243 L
s
.80525 .05128 m
.81746 .07243 L
s
.82967 .05128 m
.85409 .05128 L
s
.82967 .05128 m
.81746 .07243 L
s
.82967 .05128 m
.84188 .07243 L
s
.85409 .05128 m
.87851 .05128 L
s
.85409 .05128 m
.84188 .07243 L
s
.85409 .05128 m
.8663 .07243 L
s
.87851 .05128 m
.90293 .05128 L
s
.87851 .05128 m
.8663 .07243 L
s
.87851 .05128 m
.89072 .07243 L
s
.90293 .05128 m
.92735 .05128 L
s
.90293 .05128 m
.89072 .07243 L
s
.90293 .05128 m
.91514 .07243 L
s
.92735 .05128 m
.95177 .05128 L
s
.92735 .05128 m
.91514 .07243 L
s
.92735 .05128 m
.93956 .07243 L
s
.95177 .05128 m
.97619 .05128 L
s
.95177 .05128 m
.93956 .07243 L
s
.95177 .05128 m
.96398 .07243 L
s
.97619 .05128 m
.96398 .07243 L
s
.97619 .05128 m
.97619 .09358 L
s
.03602 .07243 m
.06044 .07243 L
s
.03602 .07243 m
.02381 .09358 L
s
.03602 .07243 m
.04823 .09358 L
s
.06044 .07243 m
.08486 .07243 L
s
.06044 .07243 m
.04823 .09358 L
s
.06044 .07243 m
.07265 .09358 L
s
.08486 .07243 m
.10928 .07243 L
s
.08486 .07243 m
.07265 .09358 L
s
.08486 .07243 m
.09707 .09358 L
s
.10928 .07243 m
.1337 .07243 L
s
.10928 .07243 m
.09707 .09358 L
s
.10928 .07243 m
.12149 .09358 L
s
.1337 .07243 m
.15812 .07243 L
s
.1337 .07243 m
.12149 .09358 L
s
.1337 .07243 m
.14591 .09358 L
s
.15812 .07243 m
.18254 .07243 L
s
.15812 .07243 m
.14591 .09358 L
s
.15812 .07243 m
.17033 .09358 L
s
.18254 .07243 m
.20696 .07243 L
s
.18254 .07243 m
.17033 .09358 L
s
.18254 .07243 m
.19475 .09358 L
s
.20696 .07243 m
.23138 .07243 L
s
.20696 .07243 m
.19475 .09358 L
s
.20696 .07243 m
.21917 .09358 L
s
.23138 .07243 m
.2558 .07243 L
s
.23138 .07243 m
.21917 .09358 L
s
.23138 .07243 m
.24359 .09358 L
s
.2558 .07243 m
.28022 .07243 L
s
.2558 .07243 m
.24359 .09358 L
s
.2558 .07243 m
.26801 .09358 L
s
.28022 .07243 m
.30464 .07243 L
s
.28022 .07243 m
.26801 .09358 L
s
.28022 .07243 m
.29243 .09358 L
s
.30464 .07243 m
.32906 .07243 L
s
.30464 .07243 m
.29243 .09358 L
s
.30464 .07243 m
.31685 .09358 L
s
.32906 .07243 m
.35348 .07243 L
s
.32906 .07243 m
.31685 .09358 L
s
.32906 .07243 m
.34127 .09358 L
s
.35348 .07243 m
.3779 .07243 L
s
.35348 .07243 m
.34127 .09358 L
s
.35348 .07243 m
.36569 .09358 L
s
.3779 .07243 m
.40232 .07243 L
s
.3779 .07243 m
.36569 .09358 L
s
.3779 .07243 m
.39011 .09358 L
s
.40232 .07243 m
.42674 .07243 L
s
.40232 .07243 m
.39011 .09358 L
s
.40232 .07243 m
.41453 .09358 L
s
.42674 .07243 m
.45116 .07243 L
s
.42674 .07243 m
.41453 .09358 L
s
.45116 .07243 m
.54884 .07243 L
s
.45116 .07243 m
.41453 .09358 L
s
.45116 .07243 m
.40232 .11473 L
s
.45116 .07243 m
.59768 .11473 L
s
.54884 .07243 m
.57326 .07243 L
s
.54884 .07243 m
.58547 .09358 L
s
.54884 .07243 m
.59768 .11473 L
s
.57326 .07243 m
.59768 .07243 L
s
.57326 .07243 m
.58547 .09358 L
s
.59768 .07243 m
.6221 .07243 L
s
.59768 .07243 m
.58547 .09358 L
s
.59768 .07243 m
.60989 .09358 L
s
.6221 .07243 m
.64652 .07243 L
s
.6221 .07243 m
.60989 .09358 L
s
.6221 .07243 m
.63431 .09358 L
s
.64652 .07243 m
.67094 .07243 L
s
.64652 .07243 m
.63431 .09358 L
s
.64652 .07243 m
.65873 .09358 L
s
.67094 .07243 m
.69536 .07243 L
s
.67094 .07243 m
.65873 .09358 L
s
.67094 .07243 m
.68315 .09358 L
s
.69536 .07243 m
.71978 .07243 L
s
.69536 .07243 m
.68315 .09358 L
s
.69536 .07243 m
.70757 .09358 L
s
.71978 .07243 m
.7442 .07243 L
s
.71978 .07243 m
.70757 .09358 L
s
.71978 .07243 m
.73199 .09358 L
s
.7442 .07243 m
.76862 .07243 L
s
.7442 .07243 m
.73199 .09358 L
s
.7442 .07243 m
.75641 .09358 L
s
.76862 .07243 m
.79304 .07243 L
s
.76862 .07243 m
.75641 .09358 L
s
.76862 .07243 m
.78083 .09358 L
s
.79304 .07243 m
.81746 .07243 L
s
.79304 .07243 m
.78083 .09358 L
s
.79304 .07243 m
.80525 .09358 L
s
.81746 .07243 m
.84188 .07243 L
s
.81746 .07243 m
.80525 .09358 L
s
.81746 .07243 m
.82967 .09358 L
s
.84188 .07243 m
.8663 .07243 L
s
.84188 .07243 m
.82967 .09358 L
s
.84188 .07243 m
.85409 .09358 L
s
.8663 .07243 m
.89072 .07243 L
s
.8663 .07243 m
.85409 .09358 L
s
.8663 .07243 m
.87851 .09358 L
s
.89072 .07243 m
.91514 .07243 L
s
.89072 .07243 m
.87851 .09358 L
s
.89072 .07243 m
.90293 .09358 L
s
.91514 .07243 m
.93956 .07243 L
s
.91514 .07243 m
.90293 .09358 L
s
.91514 .07243 m
.92735 .09358 L
s
.93956 .07243 m
.96398 .07243 L
s
.93956 .07243 m
.92735 .09358 L
s
.93956 .07243 m
.95177 .09358 L
s
.96398 .07243 m
.95177 .09358 L
s
.96398 .07243 m
.97619 .09358 L
s
.02381 .09358 m
.04823 .09358 L
s
.02381 .09358 m
.03602 .11473 L
s
.02381 .09358 m
.02381 .13588 L
s
.04823 .09358 m
.07265 .09358 L
s
.04823 .09358 m
.03602 .11473 L
s
.04823 .09358 m
.06044 .11473 L
s
.07265 .09358 m
.09707 .09358 L
s
.07265 .09358 m
.06044 .11473 L
s
.07265 .09358 m
.08486 .11473 L
s
.09707 .09358 m
.12149 .09358 L
s
.09707 .09358 m
.08486 .11473 L
s
.09707 .09358 m
.10928 .11473 L
s
.12149 .09358 m
.14591 .09358 L
s
.12149 .09358 m
.10928 .11473 L
s
.12149 .09358 m
.1337 .11473 L
s
.14591 .09358 m
.17033 .09358 L
s
.14591 .09358 m
.1337 .11473 L
s
.14591 .09358 m
.15812 .11473 L
s
.17033 .09358 m
.19475 .09358 L
s
.17033 .09358 m
.15812 .11473 L
s
.17033 .09358 m
.18254 .11473 L
s
.19475 .09358 m
.21917 .09358 L
s
.19475 .09358 m
.18254 .11473 L
s
.19475 .09358 m
.20696 .11473 L
s
.21917 .09358 m
.24359 .09358 L
s
.21917 .09358 m
.20696 .11473 L
s
.21917 .09358 m
.23138 .11473 L
s
.24359 .09358 m
.26801 .09358 L
s
.24359 .09358 m
.23138 .11473 L
s
.24359 .09358 m
.2558 .11473 L
s
.26801 .09358 m
.29243 .09358 L
s
.26801 .09358 m
.2558 .11473 L
s
.26801 .09358 m
.28022 .11473 L
s
.29243 .09358 m
.31685 .09358 L
s
.29243 .09358 m
.28022 .11473 L
s
.29243 .09358 m
.30464 .11473 L
s
.31685 .09358 m
.34127 .09358 L
s
.31685 .09358 m
.30464 .11473 L
s
.31685 .09358 m
.32906 .11473 L
s
.34127 .09358 m
.36569 .09358 L
s
.34127 .09358 m
.32906 .11473 L
s
.34127 .09358 m
.35348 .11473 L
s
.36569 .09358 m
.39011 .09358 L
s
.36569 .09358 m
.35348 .11473 L
s
.36569 .09358 m
.3779 .11473 L
s
.39011 .09358 m
.41453 .09358 L
s
.39011 .09358 m
.3779 .11473 L
s
.39011 .09358 m
.40232 .11473 L
s
.41453 .09358 m
.40232 .11473 L
s
.58547 .09358 m
.60989 .09358 L
s
.58547 .09358 m
.59768 .11473 L
s
.60989 .09358 m
.63431 .09358 L
s
.60989 .09358 m
.59768 .11473 L
s
.60989 .09358 m
.6221 .11473 L
s
.63431 .09358 m
.65873 .09358 L
s
.63431 .09358 m
.6221 .11473 L
s
.63431 .09358 m
.64652 .11473 L
s
.65873 .09358 m
.68315 .09358 L
s
.65873 .09358 m
.64652 .11473 L
s
.65873 .09358 m
.67094 .11473 L
s
.68315 .09358 m
.70757 .09358 L
s
.68315 .09358 m
.67094 .11473 L
s
.68315 .09358 m
.69536 .11473 L
s
.70757 .09358 m
.73199 .09358 L
s
.70757 .09358 m
.69536 .11473 L
s
.70757 .09358 m
.71978 .11473 L
s
.73199 .09358 m
.75641 .09358 L
s
.73199 .09358 m
.71978 .11473 L
s
.73199 .09358 m
.7442 .11473 L
s
.75641 .09358 m
.78083 .09358 L
s
.75641 .09358 m
.7442 .11473 L
s
.75641 .09358 m
.76862 .11473 L
s
.78083 .09358 m
.80525 .09358 L
s
.78083 .09358 m
.76862 .11473 L
s
.78083 .09358 m
.79304 .11473 L
s
.80525 .09358 m
.82967 .09358 L
s
.80525 .09358 m
.79304 .11473 L
s
.80525 .09358 m
.81746 .11473 L
s
.82967 .09358 m
.85409 .09358 L
s
.82967 .09358 m
.81746 .11473 L
s
.82967 .09358 m
.84188 .11473 L
s
.85409 .09358 m
.87851 .09358 L
s
.85409 .09358 m
.84188 .11473 L
s
.85409 .09358 m
.8663 .11473 L
s
.87851 .09358 m
.90293 .09358 L
s
.87851 .09358 m
.8663 .11473 L
s
.87851 .09358 m
.89072 .11473 L
s
.90293 .09358 m
.92735 .09358 L
s
.90293 .09358 m
.89072 .11473 L
s
.90293 .09358 m
.91514 .11473 L
s
.92735 .09358 m
.95177 .09358 L
s
.92735 .09358 m
.91514 .11473 L
s
.92735 .09358 m
.93956 .11473 L
s
.95177 .09358 m
.97619 .09358 L
s
.95177 .09358 m
.93956 .11473 L
s
.95177 .09358 m
.96398 .11473 L
s
.97619 .09358 m
.96398 .11473 L
s
.97619 .09358 m
.97619 .13588 L
s
.03602 .11473 m
.06044 .11473 L
s
.03602 .11473 m
.02381 .13588 L
s
.03602 .11473 m
.04823 .13588 L
s
.06044 .11473 m
.08486 .11473 L
s
.06044 .11473 m
.04823 .13588 L
s
.06044 .11473 m
.07265 .13588 L
s
.08486 .11473 m
.10928 .11473 L
s
.08486 .11473 m
.07265 .13588 L
s
.08486 .11473 m
.09707 .13588 L
s
.10928 .11473 m
.1337 .11473 L
s
.10928 .11473 m
.09707 .13588 L
s
.10928 .11473 m
.12149 .13588 L
s
.1337 .11473 m
.15812 .11473 L
s
.1337 .11473 m
.12149 .13588 L
s
.1337 .11473 m
.14591 .13588 L
s
.15812 .11473 m
.18254 .11473 L
s
.15812 .11473 m
.14591 .13588 L
s
.15812 .11473 m
.17033 .13588 L
s
.18254 .11473 m
.20696 .11473 L
s
.18254 .11473 m
.17033 .13588 L
s
.18254 .11473 m
.19475 .13588 L
s
.20696 .11473 m
.23138 .11473 L
s
.20696 .11473 m
.19475 .13588 L
s
.20696 .11473 m
.21917 .13588 L
s
.23138 .11473 m
.2558 .11473 L
s
.23138 .11473 m
.21917 .13588 L
s
.23138 .11473 m
.24359 .13588 L
s
.2558 .11473 m
.28022 .11473 L
s
.2558 .11473 m
.24359 .13588 L
s
.2558 .11473 m
.26801 .13588 L
s
.28022 .11473 m
.30464 .11473 L
s
.28022 .11473 m
.26801 .13588 L
s
.28022 .11473 m
.29243 .13588 L
s
.30464 .11473 m
.32906 .11473 L
s
.30464 .11473 m
.29243 .13588 L
s
.30464 .11473 m
.31685 .13588 L
s
.32906 .11473 m
.35348 .11473 L
s
.32906 .11473 m
.31685 .13588 L
s
.32906 .11473 m
.34127 .13588 L
s
.35348 .11473 m
.3779 .11473 L
s
.35348 .11473 m
.34127 .13588 L
s
.35348 .11473 m
.36569 .13588 L
s
.3779 .11473 m
.40232 .11473 L
s
.3779 .11473 m
.36569 .13588 L
s
.3779 .11473 m
.39011 .13588 L
s
.40232 .11473 m
.59768 .11473 L
s
.40232 .11473 m
.39011 .13588 L
s
.40232 .11473 m
.60989 .13588 L
s
.59768 .11473 m
.6221 .11473 L
s
.59768 .11473 m
.60989 .13588 L
s
.6221 .11473 m
.64652 .11473 L
s
.6221 .11473 m
.60989 .13588 L
s
.6221 .11473 m
.63431 .13588 L
s
.64652 .11473 m
.67094 .11473 L
s
.64652 .11473 m
.63431 .13588 L
s
.64652 .11473 m
.65873 .13588 L
s
.67094 .11473 m
.69536 .11473 L
s
.67094 .11473 m
.65873 .13588 L
s
.67094 .11473 m
.68315 .13588 L
s
.69536 .11473 m
.71978 .11473 L
s
.69536 .11473 m
.68315 .13588 L
s
.69536 .11473 m
.70757 .13588 L
s
.71978 .11473 m
.7442 .11473 L
s
.71978 .11473 m
.70757 .13588 L
s
.71978 .11473 m
.73199 .13588 L
s
.7442 .11473 m
.76862 .11473 L
s
.7442 .11473 m
.73199 .13588 L
s
.7442 .11473 m
.75641 .13588 L
s
.76862 .11473 m
.79304 .11473 L
s
.76862 .11473 m
.75641 .13588 L
s
.76862 .11473 m
.78083 .13588 L
s
.79304 .11473 m
.81746 .11473 L
s
.79304 .11473 m
.78083 .13588 L
s
.79304 .11473 m
.80525 .13588 L
s
.81746 .11473 m
.84188 .11473 L
s
.81746 .11473 m
.80525 .13588 L
s
.81746 .11473 m
.82967 .13588 L
s
.84188 .11473 m
.8663 .11473 L
s
.84188 .11473 m
.82967 .13588 L
s
.84188 .11473 m
.85409 .13588 L
s
.8663 .11473 m
.89072 .11473 L
s
.8663 .11473 m
.85409 .13588 L
s
.8663 .11473 m
.87851 .13588 L
s
.89072 .11473 m
.91514 .11473 L
s
.89072 .11473 m
.87851 .13588 L
s
.89072 .11473 m
.90293 .13588 L
s
.91514 .11473 m
.93956 .11473 L
s
.91514 .11473 m
.90293 .13588 L
s
.91514 .11473 m
.92735 .13588 L
s
.93956 .11473 m
.96398 .11473 L
s
.93956 .11473 m
.92735 .13588 L
s
.93956 .11473 m
.95177 .13588 L
s
.96398 .11473 m
.95177 .13588 L
s
.96398 .11473 m
.97619 .13588 L
s
.02381 .13588 m
.04823 .13588 L
s
.02381 .13588 m
.03602 .15703 L
s
.02381 .13588 m
.02381 .17817 L
s
.04823 .13588 m
.07265 .13588 L
s
.04823 .13588 m
.03602 .15703 L
s
.04823 .13588 m
.06044 .15703 L
s
.07265 .13588 m
.09707 .13588 L
s
.07265 .13588 m
.06044 .15703 L
s
.07265 .13588 m
.08486 .15703 L
s
.09707 .13588 m
.12149 .13588 L
s
.09707 .13588 m
.08486 .15703 L
s
.09707 .13588 m
.10928 .15703 L
s
.12149 .13588 m
.14591 .13588 L
s
.12149 .13588 m
.10928 .15703 L
s
.12149 .13588 m
.1337 .15703 L
s
.14591 .13588 m
.17033 .13588 L
s
.14591 .13588 m
.1337 .15703 L
s
.14591 .13588 m
.15812 .15703 L
s
.17033 .13588 m
.19475 .13588 L
s
.17033 .13588 m
.15812 .15703 L
s
.17033 .13588 m
.18254 .15703 L
s
.19475 .13588 m
.21917 .13588 L
s
.19475 .13588 m
.18254 .15703 L
s
.19475 .13588 m
.20696 .15703 L
s
.21917 .13588 m
.24359 .13588 L
s
.21917 .13588 m
.20696 .15703 L
s
.21917 .13588 m
.23138 .15703 L
s
.24359 .13588 m
.26801 .13588 L
s
.24359 .13588 m
.23138 .15703 L
s
.24359 .13588 m
.2558 .15703 L
s
.26801 .13588 m
.29243 .13588 L
s
.26801 .13588 m
.2558 .15703 L
s
.26801 .13588 m
.28022 .15703 L
s
.29243 .13588 m
.31685 .13588 L
s
.29243 .13588 m
.28022 .15703 L
s
.29243 .13588 m
.30464 .15703 L
s
.31685 .13588 m
.34127 .13588 L
s
.31685 .13588 m
.30464 .15703 L
s
.31685 .13588 m
.32906 .15703 L
s
.34127 .13588 m
.36569 .13588 L
s
.34127 .13588 m
.32906 .15703 L
s
.34127 .13588 m
.35348 .15703 L
s
.36569 .13588 m
.39011 .13588 L
s
.36569 .13588 m
.35348 .15703 L
s
.36569 .13588 m
.3779 .15703 L
s
.39011 .13588 m
.60989 .13588 L
s
.39011 .13588 m
.3779 .15703 L
s
.39011 .13588 m
.3779 .19932 L
s
.60989 .13588 m
.63431 .13588 L
s
.60989 .13588 m
.6221 .15703 L
s
.60989 .13588 m
.3779 .19932 L
s
.60989 .13588 m
.6221 .19932 L
s
.63431 .13588 m
.65873 .13588 L
s
.63431 .13588 m
.6221 .15703 L
s
.63431 .13588 m
.64652 .15703 L
s
.65873 .13588 m
.68315 .13588 L
s
.65873 .13588 m
.64652 .15703 L
s
.65873 .13588 m
.67094 .15703 L
s
.68315 .13588 m
.70757 .13588 L
s
.68315 .13588 m
.67094 .15703 L
s
.68315 .13588 m
.69536 .15703 L
s
.70757 .13588 m
.73199 .13588 L
s
.70757 .13588 m
.69536 .15703 L
s
.70757 .13588 m
.71978 .15703 L
s
.73199 .13588 m
.75641 .13588 L
s
.73199 .13588 m
.71978 .15703 L
s
.73199 .13588 m
.7442 .15703 L
s
.75641 .13588 m
.78083 .13588 L
s
.75641 .13588 m
.7442 .15703 L
s
.75641 .13588 m
.76862 .15703 L
s
.78083 .13588 m
.80525 .13588 L
s
.78083 .13588 m
.76862 .15703 L
s
.78083 .13588 m
.79304 .15703 L
s
.80525 .13588 m
.82967 .13588 L
s
.80525 .13588 m
.79304 .15703 L
s
.80525 .13588 m
.81746 .15703 L
s
.82967 .13588 m
.85409 .13588 L
s
.82967 .13588 m
.81746 .15703 L
s
.82967 .13588 m
.84188 .15703 L
s
.85409 .13588 m
.87851 .13588 L
s
.85409 .13588 m
.84188 .15703 L
s
.85409 .13588 m
.8663 .15703 L
s
.87851 .13588 m
.90293 .13588 L
s
.87851 .13588 m
.8663 .15703 L
s
.87851 .13588 m
.89072 .15703 L
s
.90293 .13588 m
.92735 .13588 L
s
.90293 .13588 m
.89072 .15703 L
s
.90293 .13588 m
.91514 .15703 L
s
.92735 .13588 m
.95177 .13588 L
s
.92735 .13588 m
.91514 .15703 L
s
.92735 .13588 m
.93956 .15703 L
s
.95177 .13588 m
.97619 .13588 L
s
.95177 .13588 m
.93956 .15703 L
s
.95177 .13588 m
.96398 .15703 L
s
.97619 .13588 m
.96398 .15703 L
s
.97619 .13588 m
.97619 .17817 L
s
.03602 .15703 m
.06044 .15703 L
s
.03602 .15703 m
.02381 .17817 L
s
.03602 .15703 m
.04823 .17817 L
s
.06044 .15703 m
.08486 .15703 L
s
.06044 .15703 m
.04823 .17817 L
s
.06044 .15703 m
.07265 .17817 L
s
.08486 .15703 m
.10928 .15703 L
s
.08486 .15703 m
.07265 .17817 L
s
.08486 .15703 m
.09707 .17817 L
s
.10928 .15703 m
.1337 .15703 L
s
.10928 .15703 m
.09707 .17817 L
s
.10928 .15703 m
.12149 .17817 L
s
.1337 .15703 m
.15812 .15703 L
s
.1337 .15703 m
.12149 .17817 L
s
.1337 .15703 m
.14591 .17817 L
s
.15812 .15703 m
.18254 .15703 L
s
.15812 .15703 m
.14591 .17817 L
s
.15812 .15703 m
.17033 .17817 L
s
.18254 .15703 m
.20696 .15703 L
s
.18254 .15703 m
.17033 .17817 L
s
.18254 .15703 m
.19475 .17817 L
s
.20696 .15703 m
.23138 .15703 L
s
.20696 .15703 m
.19475 .17817 L
s
.20696 .15703 m
.21917 .17817 L
s
.23138 .15703 m
.2558 .15703 L
s
.23138 .15703 m
.21917 .17817 L
s
.23138 .15703 m
.24359 .17817 L
s
.2558 .15703 m
.28022 .15703 L
s
.2558 .15703 m
.24359 .17817 L
s
.2558 .15703 m
.26801 .17817 L
s
.28022 .15703 m
.30464 .15703 L
s
.28022 .15703 m
.26801 .17817 L
s
.28022 .15703 m
.29243 .17817 L
s
.30464 .15703 m
.32906 .15703 L
s
.30464 .15703 m
.29243 .17817 L
s
.30464 .15703 m
.31685 .17817 L
s
.32906 .15703 m
.35348 .15703 L
s
.32906 .15703 m
.31685 .17817 L
s
.32906 .15703 m
.34127 .17817 L
s
.35348 .15703 m
.3779 .15703 L
s
.35348 .15703 m
.34127 .17817 L
s
.35348 .15703 m
.36569 .17817 L
s
.3779 .15703 m
.36569 .17817 L
s
.3779 .15703 m
.3779 .19932 L
s
.6221 .15703 m
.64652 .15703 L
s
.6221 .15703 m
.63431 .17817 L
s
.6221 .15703 m
.6221 .19932 L
s
.64652 .15703 m
.67094 .15703 L
s
.64652 .15703 m
.63431 .17817 L
s
.64652 .15703 m
.65873 .17817 L
s
.67094 .15703 m
.69536 .15703 L
s
.67094 .15703 m
.65873 .17817 L
s
.67094 .15703 m
.68315 .17817 L
s
.69536 .15703 m
.71978 .15703 L
s
.69536 .15703 m
.68315 .17817 L
s
.69536 .15703 m
.70757 .17817 L
s
.71978 .15703 m
.7442 .15703 L
s
.71978 .15703 m
.70757 .17817 L
s
.71978 .15703 m
.73199 .17817 L
s
.7442 .15703 m
.76862 .15703 L
s
.7442 .15703 m
.73199 .17817 L
s
.7442 .15703 m
.75641 .17817 L
s
.76862 .15703 m
.79304 .15703 L
s
.76862 .15703 m
.75641 .17817 L
s
.76862 .15703 m
.78083 .17817 L
s
.79304 .15703 m
.81746 .15703 L
s
.79304 .15703 m
.78083 .17817 L
s
.79304 .15703 m
.80525 .17817 L
s
.81746 .15703 m
.84188 .15703 L
s
.81746 .15703 m
.80525 .17817 L
s
.81746 .15703 m
.82967 .17817 L
s
.84188 .15703 m
.8663 .15703 L
s
.84188 .15703 m
.82967 .17817 L
s
.84188 .15703 m
.85409 .17817 L
s
.8663 .15703 m
.89072 .15703 L
s
.8663 .15703 m
.85409 .17817 L
s
.8663 .15703 m
.87851 .17817 L
s
.89072 .15703 m
.91514 .15703 L
s
.89072 .15703 m
.87851 .17817 L
s
.89072 .15703 m
.90293 .17817 L
s
.91514 .15703 m
.93956 .15703 L
s
.91514 .15703 m
.90293 .17817 L
s
.91514 .15703 m
.92735 .17817 L
s
.93956 .15703 m
.96398 .15703 L
s
.93956 .15703 m
.92735 .17817 L
s
.93956 .15703 m
.95177 .17817 L
s
.96398 .15703 m
.95177 .17817 L
s
.96398 .15703 m
.97619 .17817 L
s
.02381 .17817 m
.04823 .17817 L
s
.02381 .17817 m
.03602 .19932 L
s
.02381 .17817 m
.02381 .22047 L
s
.04823 .17817 m
.07265 .17817 L
s
.04823 .17817 m
.03602 .19932 L
s
.04823 .17817 m
.06044 .19932 L
s
.07265 .17817 m
.09707 .17817 L
s
.07265 .17817 m
.06044 .19932 L
s
.07265 .17817 m
.08486 .19932 L
s
.09707 .17817 m
.12149 .17817 L
s
.09707 .17817 m
.08486 .19932 L
s
.09707 .17817 m
.10928 .19932 L
s
.12149 .17817 m
.14591 .17817 L
s
.12149 .17817 m
.10928 .19932 L
s
.12149 .17817 m
.1337 .19932 L
s
.14591 .17817 m
.17033 .17817 L
s
.14591 .17817 m
.1337 .19932 L
s
.14591 .17817 m
.15812 .19932 L
s
.17033 .17817 m
.19475 .17817 L
s
.17033 .17817 m
.15812 .19932 L
s
.17033 .17817 m
.18254 .19932 L
s
.19475 .17817 m
.21917 .17817 L
s
.19475 .17817 m
.18254 .19932 L
s
.19475 .17817 m
.20696 .19932 L
s
.21917 .17817 m
.24359 .17817 L
s
.21917 .17817 m
.20696 .19932 L
s
.21917 .17817 m
.23138 .19932 L
s
.24359 .17817 m
.26801 .17817 L
s
.24359 .17817 m
.23138 .19932 L
s
.24359 .17817 m
.2558 .19932 L
s
.26801 .17817 m
.29243 .17817 L
s
.26801 .17817 m
.2558 .19932 L
s
.26801 .17817 m
.28022 .19932 L
s
.29243 .17817 m
.31685 .17817 L
s
.29243 .17817 m
.28022 .19932 L
s
.29243 .17817 m
.30464 .19932 L
s
.31685 .17817 m
.34127 .17817 L
s
.31685 .17817 m
.30464 .19932 L
s
.31685 .17817 m
.32906 .19932 L
s
.34127 .17817 m
.36569 .17817 L
s
.34127 .17817 m
.32906 .19932 L
s
.34127 .17817 m
.35348 .19932 L
s
.36569 .17817 m
.35348 .19932 L
s
.36569 .17817 m
.3779 .19932 L
s
.63431 .17817 m
.65873 .17817 L
s
.63431 .17817 m
.6221 .19932 L
s
.63431 .17817 m
.64652 .19932 L
s
.65873 .17817 m
.68315 .17817 L
s
.65873 .17817 m
.64652 .19932 L
s
.65873 .17817 m
.67094 .19932 L
s
.68315 .17817 m
.70757 .17817 L
s
.68315 .17817 m
.67094 .19932 L
s
.68315 .17817 m
.69536 .19932 L
s
.70757 .17817 m
.73199 .17817 L
s
.70757 .17817 m
.69536 .19932 L
s
.70757 .17817 m
.71978 .19932 L
s
.73199 .17817 m
.75641 .17817 L
s
.73199 .17817 m
.71978 .19932 L
s
.73199 .17817 m
.7442 .19932 L
s
.75641 .17817 m
.78083 .17817 L
s
.75641 .17817 m
.7442 .19932 L
s
.75641 .17817 m
.76862 .19932 L
s
.78083 .17817 m
.80525 .17817 L
s
.78083 .17817 m
.76862 .19932 L
s
.78083 .17817 m
.79304 .19932 L
s
.80525 .17817 m
.82967 .17817 L
s
.80525 .17817 m
.79304 .19932 L
s
.80525 .17817 m
.81746 .19932 L
s
.82967 .17817 m
.85409 .17817 L
s
.82967 .17817 m
.81746 .19932 L
s
.82967 .17817 m
.84188 .19932 L
s
.85409 .17817 m
.87851 .17817 L
s
.85409 .17817 m
.84188 .19932 L
s
.85409 .17817 m
.8663 .19932 L
s
.87851 .17817 m
.90293 .17817 L
s
.87851 .17817 m
.8663 .19932 L
s
.87851 .17817 m
.89072 .19932 L
s
.90293 .17817 m
.92735 .17817 L
s
.90293 .17817 m
.89072 .19932 L
s
.90293 .17817 m
.91514 .19932 L
s
.92735 .17817 m
.95177 .17817 L
s
.92735 .17817 m
.91514 .19932 L
s
.92735 .17817 m
.93956 .19932 L
s
.95177 .17817 m
.97619 .17817 L
s
.95177 .17817 m
.93956 .19932 L
s
.95177 .17817 m
.96398 .19932 L
s
.97619 .17817 m
.96398 .19932 L
s
.97619 .17817 m
.97619 .22047 L
s
.03602 .19932 m
.06044 .19932 L
s
.03602 .19932 m
.02381 .22047 L
s
.03602 .19932 m
.04823 .22047 L
s
.06044 .19932 m
.08486 .19932 L
s
.06044 .19932 m
.04823 .22047 L
s
.06044 .19932 m
.07265 .22047 L
s
.08486 .19932 m
.10928 .19932 L
s
.08486 .19932 m
.07265 .22047 L
s
.08486 .19932 m
.09707 .22047 L
s
.10928 .19932 m
.1337 .19932 L
s
.10928 .19932 m
.09707 .22047 L
s
.10928 .19932 m
.12149 .22047 L
s
.1337 .19932 m
.15812 .19932 L
s
.1337 .19932 m
.12149 .22047 L
s
.1337 .19932 m
.14591 .22047 L
s
.15812 .19932 m
.18254 .19932 L
s
.15812 .19932 m
.14591 .22047 L
s
.15812 .19932 m
.17033 .22047 L
s
.18254 .19932 m
.20696 .19932 L
s
.18254 .19932 m
.17033 .22047 L
s
.18254 .19932 m
.19475 .22047 L
s
.20696 .19932 m
.23138 .19932 L
s
.20696 .19932 m
.19475 .22047 L
s
.20696 .19932 m
.21917 .22047 L
s
.23138 .19932 m
.2558 .19932 L
s
.23138 .19932 m
.21917 .22047 L
s
.23138 .19932 m
.24359 .22047 L
s
.2558 .19932 m
.28022 .19932 L
s
.2558 .19932 m
.24359 .22047 L
s
.2558 .19932 m
.26801 .22047 L
s
.28022 .19932 m
.30464 .19932 L
s
.28022 .19932 m
.26801 .22047 L
s
.28022 .19932 m
.29243 .22047 L
s
.30464 .19932 m
.32906 .19932 L
s
.30464 .19932 m
.29243 .22047 L
s
.30464 .19932 m
.31685 .22047 L
s
.32906 .19932 m
.35348 .19932 L
s
.32906 .19932 m
.31685 .22047 L
s
.32906 .19932 m
.34127 .22047 L
s
.35348 .19932 m
.3779 .19932 L
s
.35348 .19932 m
.34127 .22047 L
s
.35348 .19932 m
.36569 .22047 L
s
.3779 .19932 m
.6221 .19932 L
s
.3779 .19932 m
.36569 .22047 L
s
.3779 .19932 m
.3779 .24162 L
s
.3779 .19932 m
.39011 .26277 L
s
.3779 .19932 m
.43895 .30507 L
s
.6221 .19932 m
.64652 .19932 L
s
.6221 .19932 m
.63431 .22047 L
s
.6221 .19932 m
.6221 .24162 L
s
.6221 .19932 m
.60989 .26277 L
s
.6221 .19932 m
.43895 .30507 L
s
.6221 .19932 m
.56105 .30507 L
s
.64652 .19932 m
.67094 .19932 L
s
.64652 .19932 m
.63431 .22047 L
s
.64652 .19932 m
.65873 .22047 L
s
.67094 .19932 m
.69536 .19932 L
s
.67094 .19932 m
.65873 .22047 L
s
.67094 .19932 m
.68315 .22047 L
s
.69536 .19932 m
.71978 .19932 L
s
.69536 .19932 m
.68315 .22047 L
s
.69536 .19932 m
.70757 .22047 L
s
.71978 .19932 m
.7442 .19932 L
s
.71978 .19932 m
.70757 .22047 L
s
.71978 .19932 m
.73199 .22047 L
s
.7442 .19932 m
.76862 .19932 L
s
.7442 .19932 m
.73199 .22047 L
s
.7442 .19932 m
.75641 .22047 L
s
.76862 .19932 m
.79304 .19932 L
s
.76862 .19932 m
.75641 .22047 L
s
.76862 .19932 m
.78083 .22047 L
s
.79304 .19932 m
.81746 .19932 L
s
.79304 .19932 m
.78083 .22047 L
s
.79304 .19932 m
.80525 .22047 L
s
.81746 .19932 m
.84188 .19932 L
s
.81746 .19932 m
.80525 .22047 L
s
.81746 .19932 m
.82967 .22047 L
s
.84188 .19932 m
.8663 .19932 L
s
.84188 .19932 m
.82967 .22047 L
s
.84188 .19932 m
.85409 .22047 L
s
.8663 .19932 m
.89072 .19932 L
s
.8663 .19932 m
.85409 .22047 L
s
.8663 .19932 m
.87851 .22047 L
s
.89072 .19932 m
.91514 .19932 L
s
.89072 .19932 m
.87851 .22047 L
s
.89072 .19932 m
.90293 .22047 L
s
.91514 .19932 m
.93956 .19932 L
s
.91514 .19932 m
.90293 .22047 L
s
.91514 .19932 m
.92735 .22047 L
s
.93956 .19932 m
.96398 .19932 L
s
.93956 .19932 m
.92735 .22047 L
s
.93956 .19932 m
.95177 .22047 L
s
.96398 .19932 m
.95177 .22047 L
s
.96398 .19932 m
.97619 .22047 L
s
.02381 .22047 m
.04823 .22047 L
s
.02381 .22047 m
.03602 .24162 L
s
.02381 .22047 m
.02381 .26277 L
s
.04823 .22047 m
.07265 .22047 L
s
.04823 .22047 m
.03602 .24162 L
s
.04823 .22047 m
.06044 .24162 L
s
.07265 .22047 m
.09707 .22047 L
s
.07265 .22047 m
.06044 .24162 L
s
.07265 .22047 m
.08486 .24162 L
s
.09707 .22047 m
.12149 .22047 L
s
.09707 .22047 m
.08486 .24162 L
s
.09707 .22047 m
.10928 .24162 L
s
.12149 .22047 m
.14591 .22047 L
s
.12149 .22047 m
.10928 .24162 L
s
.12149 .22047 m
.1337 .24162 L
s
.14591 .22047 m
.17033 .22047 L
s
.14591 .22047 m
.1337 .24162 L
s
.14591 .22047 m
.15812 .24162 L
s
.17033 .22047 m
.19475 .22047 L
s
.17033 .22047 m
.15812 .24162 L
s
.17033 .22047 m
.18254 .24162 L
s
.19475 .22047 m
.21917 .22047 L
s
.19475 .22047 m
.18254 .24162 L
s
.19475 .22047 m
.20696 .24162 L
s
.21917 .22047 m
.24359 .22047 L
s
.21917 .22047 m
.20696 .24162 L
s
.21917 .22047 m
.23138 .24162 L
s
.24359 .22047 m
.26801 .22047 L
s
.24359 .22047 m
.23138 .24162 L
s
.24359 .22047 m
.2558 .24162 L
s
.26801 .22047 m
.29243 .22047 L
s
.26801 .22047 m
.2558 .24162 L
s
.26801 .22047 m
.28022 .24162 L
s
.29243 .22047 m
.31685 .22047 L
s
.29243 .22047 m
.28022 .24162 L
s
.29243 .22047 m
.30464 .24162 L
s
.31685 .22047 m
.34127 .22047 L
s
.31685 .22047 m
.30464 .24162 L
s
.31685 .22047 m
.32906 .24162 L
s
.34127 .22047 m
.36569 .22047 L
s
.34127 .22047 m
.32906 .24162 L
s
.34127 .22047 m
.35348 .24162 L
s
.36569 .22047 m
.35348 .24162 L
s
.36569 .22047 m
.3779 .24162 L
s
.63431 .22047 m
.65873 .22047 L
s
.63431 .22047 m
.6221 .24162 L
s
.63431 .22047 m
.64652 .24162 L
s
.65873 .22047 m
.68315 .22047 L
s
.65873 .22047 m
.64652 .24162 L
s
.65873 .22047 m
.67094 .24162 L
s
.68315 .22047 m
.70757 .22047 L
s
.68315 .22047 m
.67094 .24162 L
s
.68315 .22047 m
.69536 .24162 L
s
.70757 .22047 m
.73199 .22047 L
s
.70757 .22047 m
.69536 .24162 L
s
.70757 .22047 m
.71978 .24162 L
s
.73199 .22047 m
.75641 .22047 L
s
.73199 .22047 m
.71978 .24162 L
s
.73199 .22047 m
.7442 .24162 L
s
.75641 .22047 m
.78083 .22047 L
s
.75641 .22047 m
.7442 .24162 L
s
.75641 .22047 m
.76862 .24162 L
s
.78083 .22047 m
.80525 .22047 L
s
.78083 .22047 m
.76862 .24162 L
s
.78083 .22047 m
.79304 .24162 L
s
.80525 .22047 m
.82967 .22047 L
s
.80525 .22047 m
.79304 .24162 L
s
.80525 .22047 m
.81746 .24162 L
s
.82967 .22047 m
.85409 .22047 L
s
.82967 .22047 m
.81746 .24162 L
s
.82967 .22047 m
.84188 .24162 L
s
.85409 .22047 m
.87851 .22047 L
s
.85409 .22047 m
.84188 .24162 L
s
.85409 .22047 m
.8663 .24162 L
s
.87851 .22047 m
.90293 .22047 L
s
.87851 .22047 m
.8663 .24162 L
s
.87851 .22047 m
.89072 .24162 L
s
.90293 .22047 m
.92735 .22047 L
s
.90293 .22047 m
.89072 .24162 L
s
.90293 .22047 m
.91514 .24162 L
s
.92735 .22047 m
.95177 .22047 L
s
.92735 .22047 m
.91514 .24162 L
s
.92735 .22047 m
.93956 .24162 L
s
.95177 .22047 m
.97619 .22047 L
s
.95177 .22047 m
.93956 .24162 L
s
.95177 .22047 m
.96398 .24162 L
s
.97619 .22047 m
.96398 .24162 L
s
.97619 .22047 m
.97619 .26277 L
s
.03602 .24162 m
.06044 .24162 L
s
.03602 .24162 m
.02381 .26277 L
s
.03602 .24162 m
.04823 .26277 L
s
.06044 .24162 m
.08486 .24162 L
s
.06044 .24162 m
.04823 .26277 L
s
.06044 .24162 m
.07265 .26277 L
s
.08486 .24162 m
.10928 .24162 L
s
.08486 .24162 m
.07265 .26277 L
s
.08486 .24162 m
.09707 .26277 L
s
.10928 .24162 m
.1337 .24162 L
s
.10928 .24162 m
.09707 .26277 L
s
.10928 .24162 m
.12149 .26277 L
s
.1337 .24162 m
.15812 .24162 L
s
.1337 .24162 m
.12149 .26277 L
s
.1337 .24162 m
.14591 .26277 L
s
.15812 .24162 m
.18254 .24162 L
s
.15812 .24162 m
.14591 .26277 L
s
.15812 .24162 m
.17033 .26277 L
s
.18254 .24162 m
.20696 .24162 L
s
.18254 .24162 m
.17033 .26277 L
s
.18254 .24162 m
.19475 .26277 L
s
.20696 .24162 m
.23138 .24162 L
s
.20696 .24162 m
.19475 .26277 L
s
.20696 .24162 m
.21917 .26277 L
s
.23138 .24162 m
.2558 .24162 L
s
.23138 .24162 m
.21917 .26277 L
s
.23138 .24162 m
.24359 .26277 L
s
.2558 .24162 m
.28022 .24162 L
s
.2558 .24162 m
.24359 .26277 L
s
.2558 .24162 m
.26801 .26277 L
s
.28022 .24162 m
.30464 .24162 L
s
.28022 .24162 m
.26801 .26277 L
s
.28022 .24162 m
.29243 .26277 L
s
.30464 .24162 m
.32906 .24162 L
s
.30464 .24162 m
.29243 .26277 L
s
.30464 .24162 m
.31685 .26277 L
s
.32906 .24162 m
.35348 .24162 L
s
.32906 .24162 m
.31685 .26277 L
s
.32906 .24162 m
.34127 .26277 L
s
.35348 .24162 m
.3779 .24162 L
s
.35348 .24162 m
.34127 .26277 L
s
.35348 .24162 m
.36569 .26277 L
s
.3779 .24162 m
.36569 .26277 L
s
.3779 .24162 m
.39011 .26277 L
s
.6221 .24162 m
.64652 .24162 L
s
.6221 .24162 m
.60989 .26277 L
s
.6221 .24162 m
.63431 .26277 L
s
.64652 .24162 m
.67094 .24162 L
s
.64652 .24162 m
.63431 .26277 L
s
.64652 .24162 m
.65873 .26277 L
s
.67094 .24162 m
.69536 .24162 L
s
.67094 .24162 m
.65873 .26277 L
s
.67094 .24162 m
.68315 .26277 L
s
.69536 .24162 m
.71978 .24162 L
s
.69536 .24162 m
.68315 .26277 L
s
.69536 .24162 m
.70757 .26277 L
s
.71978 .24162 m
.7442 .24162 L
s
.71978 .24162 m
.70757 .26277 L
s
.71978 .24162 m
.73199 .26277 L
s
.7442 .24162 m
.76862 .24162 L
s
.7442 .24162 m
.73199 .26277 L
s
.7442 .24162 m
.75641 .26277 L
s
.76862 .24162 m
.79304 .24162 L
s
.76862 .24162 m
.75641 .26277 L
s
.76862 .24162 m
.78083 .26277 L
s
.79304 .24162 m
.81746 .24162 L
s
.79304 .24162 m
.78083 .26277 L
s
.79304 .24162 m
.80525 .26277 L
s
.81746 .24162 m
.84188 .24162 L
s
.81746 .24162 m
.80525 .26277 L
s
.81746 .24162 m
.82967 .26277 L
s
.84188 .24162 m
.8663 .24162 L
s
.84188 .24162 m
.82967 .26277 L
s
.84188 .24162 m
.85409 .26277 L
s
.8663 .24162 m
.89072 .24162 L
s
.8663 .24162 m
.85409 .26277 L
s
.8663 .24162 m
.87851 .26277 L
s
.89072 .24162 m
.91514 .24162 L
s
.89072 .24162 m
.87851 .26277 L
s
.89072 .24162 m
.90293 .26277 L
s
.91514 .24162 m
.93956 .24162 L
s
.91514 .24162 m
.90293 .26277 L
s
.91514 .24162 m
.92735 .26277 L
s
.93956 .24162 m
.96398 .24162 L
s
.93956 .24162 m
.92735 .26277 L
s
.93956 .24162 m
.95177 .26277 L
s
.96398 .24162 m
.95177 .26277 L
s
.96398 .24162 m
.97619 .26277 L
s
.02381 .26277 m
.04823 .26277 L
s
.02381 .26277 m
.03602 .28392 L
s
.02381 .26277 m
.02381 .30507 L
s
.04823 .26277 m
.07265 .26277 L
s
.04823 .26277 m
.03602 .28392 L
s
.04823 .26277 m
.06044 .28392 L
s
.07265 .26277 m
.09707 .26277 L
s
.07265 .26277 m
.06044 .28392 L
s
.07265 .26277 m
.08486 .28392 L
s
.09707 .26277 m
.12149 .26277 L
s
.09707 .26277 m
.08486 .28392 L
s
.09707 .26277 m
.10928 .28392 L
s
.12149 .26277 m
.14591 .26277 L
s
.12149 .26277 m
.10928 .28392 L
s
.12149 .26277 m
.1337 .28392 L
s
.14591 .26277 m
.17033 .26277 L
s
.14591 .26277 m
.1337 .28392 L
s
.14591 .26277 m
.15812 .28392 L
s
.17033 .26277 m
.19475 .26277 L
s
.17033 .26277 m
.15812 .28392 L
s
.17033 .26277 m
.18254 .28392 L
s
.19475 .26277 m
.21917 .26277 L
s
.19475 .26277 m
.18254 .28392 L
s
.19475 .26277 m
.20696 .28392 L
s
.21917 .26277 m
.24359 .26277 L
s
.21917 .26277 m
.20696 .28392 L
s
.21917 .26277 m
.23138 .28392 L
s
.24359 .26277 m
.26801 .26277 L
s
.24359 .26277 m
.23138 .28392 L
s
.24359 .26277 m
.2558 .28392 L
s
.26801 .26277 m
.29243 .26277 L
s
.26801 .26277 m
.2558 .28392 L
s
.26801 .26277 m
.28022 .28392 L
s
.29243 .26277 m
.31685 .26277 L
s
.29243 .26277 m
.28022 .28392 L
s
.29243 .26277 m
.30464 .28392 L
s
.31685 .26277 m
.34127 .26277 L
s
.31685 .26277 m
.30464 .28392 L
s
.31685 .26277 m
.32906 .28392 L
s
.34127 .26277 m
.36569 .26277 L
s
.34127 .26277 m
.32906 .28392 L
s
.34127 .26277 m
.35348 .28392 L
s
.36569 .26277 m
.39011 .26277 L
s
.36569 .26277 m
.35348 .28392 L
s
.36569 .26277 m
.3779 .28392 L
s
.39011 .26277 m
.3779 .28392 L
s
.39011 .26277 m
.40232 .28392 L
s
.39011 .26277 m
.43895 .30507 L
s
.60989 .26277 m
.63431 .26277 L
s
.60989 .26277 m
.59768 .28392 L
s
.60989 .26277 m
.6221 .28392 L
s
.60989 .26277 m
.56105 .30507 L
s
.63431 .26277 m
.65873 .26277 L
s
.63431 .26277 m
.6221 .28392 L
s
.63431 .26277 m
.64652 .28392 L
s
.65873 .26277 m
.68315 .26277 L
s
.65873 .26277 m
.64652 .28392 L
s
.65873 .26277 m
.67094 .28392 L
s
.68315 .26277 m
.70757 .26277 L
s
.68315 .26277 m
.67094 .28392 L
s
.68315 .26277 m
.69536 .28392 L
s
.70757 .26277 m
.73199 .26277 L
s
.70757 .26277 m
.69536 .28392 L
s
.70757 .26277 m
.71978 .28392 L
s
.73199 .26277 m
.75641 .26277 L
s
.73199 .26277 m
.71978 .28392 L
s
.73199 .26277 m
.7442 .28392 L
s
.75641 .26277 m
.78083 .26277 L
s
.75641 .26277 m
.7442 .28392 L
s
.75641 .26277 m
.76862 .28392 L
s
.78083 .26277 m
.80525 .26277 L
s
.78083 .26277 m
.76862 .28392 L
s
.78083 .26277 m
.79304 .28392 L
s
.80525 .26277 m
.82967 .26277 L
s
.80525 .26277 m
.79304 .28392 L
s
.80525 .26277 m
.81746 .28392 L
s
.82967 .26277 m
.85409 .26277 L
s
.82967 .26277 m
.81746 .28392 L
s
.82967 .26277 m
.84188 .28392 L
s
.85409 .26277 m
.87851 .26277 L
s
.85409 .26277 m
.84188 .28392 L
s
.85409 .26277 m
.8663 .28392 L
s
.87851 .26277 m
.90293 .26277 L
s
.87851 .26277 m
.8663 .28392 L
s
.87851 .26277 m
.89072 .28392 L
s
.90293 .26277 m
.92735 .26277 L
s
.90293 .26277 m
.89072 .28392 L
s
.90293 .26277 m
.91514 .28392 L
s
.92735 .26277 m
.95177 .26277 L
s
.92735 .26277 m
.91514 .28392 L
s
.92735 .26277 m
.93956 .28392 L
s
.95177 .26277 m
.97619 .26277 L
s
.95177 .26277 m
.93956 .28392 L
s
.95177 .26277 m
.96398 .28392 L
s
.97619 .26277 m
.96398 .28392 L
s
.97619 .26277 m
.97619 .30507 L
s
.03602 .28392 m
.06044 .28392 L
s
.03602 .28392 m
.02381 .30507 L
s
.03602 .28392 m
.04823 .30507 L
s
.06044 .28392 m
.08486 .28392 L
s
.06044 .28392 m
.04823 .30507 L
s
.06044 .28392 m
.07265 .30507 L
s
.08486 .28392 m
.10928 .28392 L
s
.08486 .28392 m
.07265 .30507 L
s
.08486 .28392 m
.09707 .30507 L
s
.10928 .28392 m
.1337 .28392 L
s
.10928 .28392 m
.09707 .30507 L
s
.10928 .28392 m
.12149 .30507 L
s
.1337 .28392 m
.15812 .28392 L
s
.1337 .28392 m
.12149 .30507 L
s
.1337 .28392 m
.14591 .30507 L
s
.15812 .28392 m
.18254 .28392 L
s
.15812 .28392 m
.14591 .30507 L
s
.15812 .28392 m
.17033 .30507 L
s
.18254 .28392 m
.20696 .28392 L
s
.18254 .28392 m
.17033 .30507 L
s
.18254 .28392 m
.19475 .30507 L
s
.20696 .28392 m
.23138 .28392 L
s
.20696 .28392 m
.19475 .30507 L
s
.20696 .28392 m
.21917 .30507 L
s
.23138 .28392 m
.2558 .28392 L
s
.23138 .28392 m
.21917 .30507 L
s
.23138 .28392 m
.24359 .30507 L
s
.2558 .28392 m
.28022 .28392 L
s
.2558 .28392 m
.24359 .30507 L
s
.2558 .28392 m
.26801 .30507 L
s
.28022 .28392 m
.30464 .28392 L
s
.28022 .28392 m
.26801 .30507 L
s
.28022 .28392 m
.29243 .30507 L
s
.30464 .28392 m
.32906 .28392 L
s
.30464 .28392 m
.29243 .30507 L
s
.30464 .28392 m
.31685 .30507 L
s
.32906 .28392 m
.35348 .28392 L
s
.32906 .28392 m
.31685 .30507 L
s
.32906 .28392 m
.34127 .30507 L
s
.35348 .28392 m
.3779 .28392 L
s
.35348 .28392 m
.34127 .30507 L
s
.35348 .28392 m
.36569 .30507 L
s
.3779 .28392 m
.40232 .28392 L
s
.3779 .28392 m
.36569 .30507 L
s
.3779 .28392 m
.39011 .30507 L
s
.40232 .28392 m
.39011 .30507 L
s
.40232 .28392 m
.41453 .30507 L
s
.40232 .28392 m
.43895 .30507 L
s
.59768 .28392 m
.6221 .28392 L
s
.59768 .28392 m
.56105 .30507 L
s
.59768 .28392 m
.58547 .30507 L
s
.59768 .28392 m
.60989 .30507 L
s
.6221 .28392 m
.64652 .28392 L
s
.6221 .28392 m
.60989 .30507 L
s
.6221 .28392 m
.63431 .30507 L
s
.64652 .28392 m
.67094 .28392 L
s
.64652 .28392 m
.63431 .30507 L
s
.64652 .28392 m
.65873 .30507 L
s
.67094 .28392 m
.69536 .28392 L
s
.67094 .28392 m
.65873 .30507 L
s
.67094 .28392 m
.68315 .30507 L
s
.69536 .28392 m
.71978 .28392 L
s
.69536 .28392 m
.68315 .30507 L
s
.69536 .28392 m
.70757 .30507 L
s
.71978 .28392 m
.7442 .28392 L
s
.71978 .28392 m
.70757 .30507 L
s
.71978 .28392 m
.73199 .30507 L
s
.7442 .28392 m
.76862 .28392 L
s
.7442 .28392 m
.73199 .30507 L
s
.7442 .28392 m
.75641 .30507 L
s
.76862 .28392 m
.79304 .28392 L
s
.76862 .28392 m
.75641 .30507 L
s
.76862 .28392 m
.78083 .30507 L
s
.79304 .28392 m
.81746 .28392 L
s
.79304 .28392 m
.78083 .30507 L
s
.79304 .28392 m
.80525 .30507 L
s
.81746 .28392 m
.84188 .28392 L
s
.81746 .28392 m
.80525 .30507 L
s
.81746 .28392 m
.82967 .30507 L
s
.84188 .28392 m
.8663 .28392 L
s
.84188 .28392 m
.82967 .30507 L
s
.84188 .28392 m
.85409 .30507 L
s
.8663 .28392 m
.89072 .28392 L
s
.8663 .28392 m
.85409 .30507 L
s
.8663 .28392 m
.87851 .30507 L
s
.89072 .28392 m
.91514 .28392 L
s
.89072 .28392 m
.87851 .30507 L
s
.89072 .28392 m
.90293 .30507 L
s
.91514 .28392 m
.93956 .28392 L
s
.91514 .28392 m
.90293 .30507 L
s
.91514 .28392 m
.92735 .30507 L
s
.93956 .28392 m
.96398 .28392 L
s
.93956 .28392 m
.92735 .30507 L
s
.93956 .28392 m
.95177 .30507 L
s
.96398 .28392 m
.95177 .30507 L
s
.96398 .28392 m
.97619 .30507 L
s
.02381 .30507 m
.04823 .30507 L
s
.02381 .30507 m
.03602 .32621 L
s
.02381 .30507 m
.02381 .34736 L
s
.04823 .30507 m
.07265 .30507 L
s
.04823 .30507 m
.03602 .32621 L
s
.04823 .30507 m
.06044 .32621 L
s
.07265 .30507 m
.09707 .30507 L
s
.07265 .30507 m
.06044 .32621 L
s
.07265 .30507 m
.08486 .32621 L
s
.09707 .30507 m
.12149 .30507 L
s
.09707 .30507 m
.08486 .32621 L
s
.09707 .30507 m
.10928 .32621 L
s
.12149 .30507 m
.14591 .30507 L
s
.12149 .30507 m
.10928 .32621 L
s
.12149 .30507 m
.1337 .32621 L
s
.14591 .30507 m
.17033 .30507 L
s
.14591 .30507 m
.1337 .32621 L
s
.14591 .30507 m
.15812 .32621 L
s
.17033 .30507 m
.19475 .30507 L
s
.17033 .30507 m
.15812 .32621 L
s
.17033 .30507 m
.18254 .32621 L
s
.19475 .30507 m
.21917 .30507 L
s
.19475 .30507 m
.18254 .32621 L
s
.19475 .30507 m
.20696 .32621 L
s
.21917 .30507 m
.24359 .30507 L
s
.21917 .30507 m
.20696 .32621 L
s
.21917 .30507 m
.23138 .32621 L
s
.24359 .30507 m
.26801 .30507 L
s
.24359 .30507 m
.23138 .32621 L
s
.24359 .30507 m
.2558 .32621 L
s
.26801 .30507 m
.29243 .30507 L
s
.26801 .30507 m
.2558 .32621 L
s
.26801 .30507 m
.28022 .32621 L
s
.29243 .30507 m
.31685 .30507 L
s
.29243 .30507 m
.28022 .32621 L
s
.29243 .30507 m
.30464 .32621 L
s
.31685 .30507 m
.34127 .30507 L
s
.31685 .30507 m
.30464 .32621 L
s
.31685 .30507 m
.32906 .32621 L
s
.34127 .30507 m
.36569 .30507 L
s
.34127 .30507 m
.32906 .32621 L
s
.34127 .30507 m
.35348 .32621 L
s
.36569 .30507 m
.39011 .30507 L
s
.36569 .30507 m
.35348 .32621 L
s
.36569 .30507 m
.3779 .32621 L
s
.39011 .30507 m
.41453 .30507 L
s
.39011 .30507 m
.3779 .32621 L
s
.39011 .30507 m
.40232 .32621 L
s
.41453 .30507 m
.43895 .30507 L
s
.41453 .30507 m
.40232 .32621 L
s
.41453 .30507 m
.42674 .32621 L
s
.43895 .30507 m
.56105 .30507 L
s
.43895 .30507 m
.42674 .32621 L
s
.43895 .30507 m
.45116 .32621 L
s
.43895 .30507 m
.47558 .32621 L
s
.43895 .30507 m
.5 .32621 L
s
.56105 .30507 m
.58547 .30507 L
s
.56105 .30507 m
.5 .32621 L
s
.56105 .30507 m
.52442 .32621 L
s
.56105 .30507 m
.54884 .32621 L
s
.56105 .30507 m
.57326 .32621 L
s
.58547 .30507 m
.60989 .30507 L
s
.58547 .30507 m
.57326 .32621 L
s
.58547 .30507 m
.59768 .32621 L
s
.60989 .30507 m
.63431 .30507 L
s
.60989 .30507 m
.59768 .32621 L
s
.60989 .30507 m
.6221 .32621 L
s
.63431 .30507 m
.65873 .30507 L
s
.63431 .30507 m
.6221 .32621 L
s
.63431 .30507 m
.64652 .32621 L
s
.65873 .30507 m
.68315 .30507 L
s
.65873 .30507 m
.64652 .32621 L
s
.65873 .30507 m
.67094 .32621 L
s
.68315 .30507 m
.70757 .30507 L
s
.68315 .30507 m
.67094 .32621 L
s
.68315 .30507 m
.69536 .32621 L
s
.70757 .30507 m
.73199 .30507 L
s
.70757 .30507 m
.69536 .32621 L
s
.70757 .30507 m
.71978 .32621 L
s
.73199 .30507 m
.75641 .30507 L
s
.73199 .30507 m
.71978 .32621 L
s
.73199 .30507 m
.7442 .32621 L
s
.75641 .30507 m
.78083 .30507 L
s
.75641 .30507 m
.7442 .32621 L
s
.75641 .30507 m
.76862 .32621 L
s
.78083 .30507 m
.80525 .30507 L
s
.78083 .30507 m
.76862 .32621 L
s
.78083 .30507 m
.79304 .32621 L
s
.80525 .30507 m
.82967 .30507 L
s
.80525 .30507 m
.79304 .32621 L
s
.80525 .30507 m
.81746 .32621 L
s
.82967 .30507 m
.85409 .30507 L
s
.82967 .30507 m
.81746 .32621 L
s
.82967 .30507 m
.84188 .32621 L
s
.85409 .30507 m
.87851 .30507 L
s
.85409 .30507 m
.84188 .32621 L
s
.85409 .30507 m
.8663 .32621 L
s
.87851 .30507 m
.90293 .30507 L
s
.87851 .30507 m
.8663 .32621 L
s
.87851 .30507 m
.89072 .32621 L
s
.90293 .30507 m
.92735 .30507 L
s
.90293 .30507 m
.89072 .32621 L
s
.90293 .30507 m
.91514 .32621 L
s
.92735 .30507 m
.95177 .30507 L
s
.92735 .30507 m
.91514 .32621 L
s
.92735 .30507 m
.93956 .32621 L
s
.95177 .30507 m
.97619 .30507 L
s
.95177 .30507 m
.93956 .32621 L
s
.95177 .30507 m
.96398 .32621 L
s
.97619 .30507 m
.96398 .32621 L
s
.97619 .30507 m
.97619 .34736 L
s
.03602 .32621 m
.06044 .32621 L
s
.03602 .32621 m
.02381 .34736 L
s
.03602 .32621 m
.04823 .34736 L
s
.06044 .32621 m
.08486 .32621 L
s
.06044 .32621 m
.04823 .34736 L
s
.06044 .32621 m
.07265 .34736 L
s
.08486 .32621 m
.10928 .32621 L
s
.08486 .32621 m
.07265 .34736 L
s
.08486 .32621 m
.09707 .34736 L
s
.10928 .32621 m
.1337 .32621 L
s
.10928 .32621 m
.09707 .34736 L
s
.10928 .32621 m
.12149 .34736 L
s
.1337 .32621 m
.15812 .32621 L
s
.1337 .32621 m
.12149 .34736 L
s
.1337 .32621 m
.14591 .34736 L
s
.15812 .32621 m
.18254 .32621 L
s
.15812 .32621 m
.14591 .34736 L
s
.15812 .32621 m
.17033 .34736 L
s
.18254 .32621 m
.20696 .32621 L
s
.18254 .32621 m
.17033 .34736 L
s
.18254 .32621 m
.19475 .34736 L
s
.20696 .32621 m
.23138 .32621 L
s
.20696 .32621 m
.19475 .34736 L
s
.20696 .32621 m
.21917 .34736 L
s
.23138 .32621 m
.2558 .32621 L
s
.23138 .32621 m
.21917 .34736 L
s
.23138 .32621 m
.24359 .34736 L
s
.2558 .32621 m
.28022 .32621 L
s
.2558 .32621 m
.24359 .34736 L
s
.2558 .32621 m
.26801 .34736 L
s
.28022 .32621 m
.30464 .32621 L
s
.28022 .32621 m
.26801 .34736 L
s
.28022 .32621 m
.29243 .34736 L
s
.30464 .32621 m
.32906 .32621 L
s
.30464 .32621 m
.29243 .34736 L
s
.30464 .32621 m
.31685 .34736 L
s
.32906 .32621 m
.35348 .32621 L
s
.32906 .32621 m
.31685 .34736 L
s
.32906 .32621 m
.34127 .34736 L
s
.35348 .32621 m
.3779 .32621 L
s
.35348 .32621 m
.34127 .34736 L
s
.35348 .32621 m
.36569 .34736 L
s
.3779 .32621 m
.40232 .32621 L
s
.3779 .32621 m
.36569 .34736 L
s
.3779 .32621 m
.39011 .34736 L
s
.40232 .32621 m
.42674 .32621 L
s
.40232 .32621 m
.39011 .34736 L
s
.40232 .32621 m
.41453 .34736 L
s
.42674 .32621 m
.45116 .32621 L
s
.42674 .32621 m
.41453 .34736 L
s
.42674 .32621 m
.43895 .34736 L
s
.45116 .32621 m
.47558 .32621 L
s
.45116 .32621 m
.43895 .34736 L
s
.45116 .32621 m
.46337 .34736 L
s
.47558 .32621 m
.5 .32621 L
s
.47558 .32621 m
.46337 .34736 L
s
.47558 .32621 m
.48779 .34736 L
s
.5 .32621 m
.52442 .32621 L
s
.5 .32621 m
.48779 .34736 L
s
.5 .32621 m
.51221 .34736 L
s
.52442 .32621 m
.54884 .32621 L
s
.52442 .32621 m
.51221 .34736 L
s
.52442 .32621 m
.53663 .34736 L
s
.54884 .32621 m
.57326 .32621 L
s
.54884 .32621 m
.53663 .34736 L
s
.54884 .32621 m
.56105 .34736 L
s
.57326 .32621 m
.59768 .32621 L
s
.57326 .32621 m
.56105 .34736 L
s
.57326 .32621 m
.58547 .34736 L
s
.59768 .32621 m
.6221 .32621 L
s
.59768 .32621 m
.58547 .34736 L
s
.59768 .32621 m
.60989 .34736 L
s
.6221 .32621 m
.64652 .32621 L
s
.6221 .32621 m
.60989 .34736 L
s
.6221 .32621 m
.63431 .34736 L
s
.64652 .32621 m
.67094 .32621 L
s
.64652 .32621 m
.63431 .34736 L
s
.64652 .32621 m
.65873 .34736 L
s
.67094 .32621 m
.69536 .32621 L
s
.67094 .32621 m
.65873 .34736 L
s
.67094 .32621 m
.68315 .34736 L
s
.69536 .32621 m
.71978 .32621 L
s
.69536 .32621 m
.68315 .34736 L
s
.69536 .32621 m
.70757 .34736 L
s
.71978 .32621 m
.7442 .32621 L
s
.71978 .32621 m
.70757 .34736 L
s
.71978 .32621 m
.73199 .34736 L
s
.7442 .32621 m
.76862 .32621 L
s
.7442 .32621 m
.73199 .34736 L
s
.7442 .32621 m
.75641 .34736 L
s
.76862 .32621 m
.79304 .32621 L
s
.76862 .32621 m
.75641 .34736 L
s
.76862 .32621 m
.78083 .34736 L
s
.79304 .32621 m
.81746 .32621 L
s
.79304 .32621 m
.78083 .34736 L
s
.79304 .32621 m
.80525 .34736 L
s
.81746 .32621 m
.84188 .32621 L
s
.81746 .32621 m
.80525 .34736 L
s
.81746 .32621 m
.82967 .34736 L
s
.84188 .32621 m
.8663 .32621 L
s
.84188 .32621 m
.82967 .34736 L
s
.84188 .32621 m
.85409 .34736 L
s
.8663 .32621 m
.89072 .32621 L
s
.8663 .32621 m
.85409 .34736 L
s
.8663 .32621 m
.87851 .34736 L
s
.89072 .32621 m
.91514 .32621 L
s
.89072 .32621 m
.87851 .34736 L
s
.89072 .32621 m
.90293 .34736 L
s
.91514 .32621 m
.93956 .32621 L
s
.91514 .32621 m
.90293 .34736 L
s
.91514 .32621 m
.92735 .34736 L
s
.93956 .32621 m
.96398 .32621 L
s
.93956 .32621 m
.92735 .34736 L
s
.93956 .32621 m
.95177 .34736 L
s
.96398 .32621 m
.95177 .34736 L
s
.96398 .32621 m
.97619 .34736 L
s
.02381 .34736 m
.04823 .34736 L
s
.02381 .34736 m
.03602 .36851 L
s
.04823 .34736 m
.07265 .34736 L
s
.04823 .34736 m
.03602 .36851 L
s
.04823 .34736 m
.06044 .36851 L
s
.07265 .34736 m
.09707 .34736 L
s
.07265 .34736 m
.06044 .36851 L
s
.07265 .34736 m
.08486 .36851 L
s
.09707 .34736 m
.12149 .34736 L
s
.09707 .34736 m
.08486 .36851 L
s
.09707 .34736 m
.10928 .36851 L
s
.12149 .34736 m
.14591 .34736 L
s
.12149 .34736 m
.10928 .36851 L
s
.12149 .34736 m
.1337 .36851 L
s
.14591 .34736 m
.17033 .34736 L
s
.14591 .34736 m
.1337 .36851 L
s
.14591 .34736 m
.15812 .36851 L
s
.17033 .34736 m
.19475 .34736 L
s
.17033 .34736 m
.15812 .36851 L
s
.17033 .34736 m
.18254 .36851 L
s
.19475 .34736 m
.21917 .34736 L
s
.19475 .34736 m
.18254 .36851 L
s
.19475 .34736 m
.20696 .36851 L
s
.21917 .34736 m
.24359 .34736 L
s
.21917 .34736 m
.20696 .36851 L
s
.21917 .34736 m
.23138 .36851 L
s
.24359 .34736 m
.26801 .34736 L
s
.24359 .34736 m
.23138 .36851 L
s
.24359 .34736 m
.2558 .36851 L
s
.26801 .34736 m
.29243 .34736 L
s
.26801 .34736 m
.2558 .36851 L
s
.26801 .34736 m
.28022 .36851 L
s
.29243 .34736 m
.31685 .34736 L
s
.29243 .34736 m
.28022 .36851 L
s
.29243 .34736 m
.30464 .36851 L
s
.31685 .34736 m
.34127 .34736 L
s
.31685 .34736 m
.30464 .36851 L
s
.31685 .34736 m
.32906 .36851 L
s
.34127 .34736 m
.36569 .34736 L
s
.34127 .34736 m
.32906 .36851 L
s
.34127 .34736 m
.35348 .36851 L
s
.36569 .34736 m
.39011 .34736 L
s
.36569 .34736 m
.35348 .36851 L
s
.36569 .34736 m
.3779 .36851 L
s
.39011 .34736 m
.41453 .34736 L
s
.39011 .34736 m
.3779 .36851 L
s
.39011 .34736 m
.40232 .36851 L
s
.41453 .34736 m
.43895 .34736 L
s
.41453 .34736 m
.40232 .36851 L
s
.41453 .34736 m
.42674 .36851 L
s
.43895 .34736 m
.46337 .34736 L
s
.43895 .34736 m
.42674 .36851 L
s
.43895 .34736 m
.45116 .36851 L
s
.46337 .34736 m
.48779 .34736 L
s
.46337 .34736 m
.45116 .36851 L
s
.46337 .34736 m
.47558 .36851 L
s
.48779 .34736 m
.51221 .34736 L
s
.48779 .34736 m
.47558 .36851 L
s
.48779 .34736 m
.5 .36851 L
s
.51221 .34736 m
.53663 .34736 L
s
.51221 .34736 m
.5 .36851 L
s
.51221 .34736 m
.52442 .36851 L
s
.53663 .34736 m
.56105 .34736 L
s
.53663 .34736 m
.52442 .36851 L
s
.53663 .34736 m
.54884 .36851 L
s
.56105 .34736 m
.58547 .34736 L
s
.56105 .34736 m
.54884 .36851 L
s
.56105 .34736 m
.57326 .36851 L
s
.58547 .34736 m
.60989 .34736 L
s
.58547 .34736 m
.57326 .36851 L
s
.58547 .34736 m
.59768 .36851 L
s
.60989 .34736 m
.63431 .34736 L
s
.60989 .34736 m
.59768 .36851 L
s
.60989 .34736 m
.6221 .36851 L
s
.63431 .34736 m
.65873 .34736 L
s
.63431 .34736 m
.6221 .36851 L
s
.63431 .34736 m
.64652 .36851 L
s
.65873 .34736 m
.68315 .34736 L
s
.65873 .34736 m
.64652 .36851 L
s
.65873 .34736 m
.67094 .36851 L
s
.68315 .34736 m
.70757 .34736 L
s
.68315 .34736 m
.67094 .36851 L
s
.68315 .34736 m
.69536 .36851 L
s
.70757 .34736 m
.73199 .34736 L
s
.70757 .34736 m
.69536 .36851 L
s
.70757 .34736 m
.71978 .36851 L
s
.73199 .34736 m
.75641 .34736 L
s
.73199 .34736 m
.71978 .36851 L
s
.73199 .34736 m
.7442 .36851 L
s
.75641 .34736 m
.78083 .34736 L
s
.75641 .34736 m
.7442 .36851 L
s
.75641 .34736 m
.76862 .36851 L
s
.78083 .34736 m
.80525 .34736 L
s
.78083 .34736 m
.76862 .36851 L
s
.78083 .34736 m
.79304 .36851 L
s
.80525 .34736 m
.82967 .34736 L
s
.80525 .34736 m
.79304 .36851 L
s
.80525 .34736 m
.81746 .36851 L
s
.82967 .34736 m
.85409 .34736 L
s
.82967 .34736 m
.81746 .36851 L
s
.82967 .34736 m
.84188 .36851 L
s
.85409 .34736 m
.87851 .34736 L
s
.85409 .34736 m
.84188 .36851 L
s
.85409 .34736 m
.8663 .36851 L
s
.87851 .34736 m
.90293 .34736 L
s
.87851 .34736 m
.8663 .36851 L
s
.87851 .34736 m
.89072 .36851 L
s
.90293 .34736 m
.92735 .34736 L
s
.90293 .34736 m
.89072 .36851 L
s
.90293 .34736 m
.91514 .36851 L
s
.92735 .34736 m
.95177 .34736 L
s
.92735 .34736 m
.91514 .36851 L
s
.92735 .34736 m
.93956 .36851 L
s
.95177 .34736 m
.97619 .34736 L
s
.95177 .34736 m
.93956 .36851 L
s
.95177 .34736 m
.96398 .36851 L
s
.97619 .34736 m
.96398 .36851 L
s
.03602 .36851 m
.06044 .36851 L
s
.06044 .36851 m
.08486 .36851 L
s
.08486 .36851 m
.10928 .36851 L
s
.10928 .36851 m
.1337 .36851 L
s
.1337 .36851 m
.15812 .36851 L
s
.15812 .36851 m
.18254 .36851 L
s
.18254 .36851 m
.20696 .36851 L
s
.20696 .36851 m
.23138 .36851 L
s
.23138 .36851 m
.2558 .36851 L
s
.2558 .36851 m
.28022 .36851 L
s
.28022 .36851 m
.30464 .36851 L
s
.30464 .36851 m
.32906 .36851 L
s
.32906 .36851 m
.35348 .36851 L
s
.35348 .36851 m
.3779 .36851 L
s
.3779 .36851 m
.40232 .36851 L
s
.40232 .36851 m
.42674 .36851 L
s
.42674 .36851 m
.45116 .36851 L
s
.45116 .36851 m
.47558 .36851 L
s
.47558 .36851 m
.5 .36851 L
s
.5 .36851 m
.52442 .36851 L
s
.52442 .36851 m
.54884 .36851 L
s
.54884 .36851 m
.57326 .36851 L
s
.57326 .36851 m
.59768 .36851 L
s
.59768 .36851 m
.6221 .36851 L
s
.6221 .36851 m
.64652 .36851 L
s
.64652 .36851 m
.67094 .36851 L
s
.67094 .36851 m
.69536 .36851 L
s
.69536 .36851 m
.71978 .36851 L
s
.71978 .36851 m
.7442 .36851 L
s
.7442 .36851 m
.76862 .36851 L
s
.76862 .36851 m
.79304 .36851 L
s
.79304 .36851 m
.81746 .36851 L
s
.81746 .36851 m
.84188 .36851 L
s
.84188 .36851 m
.8663 .36851 L
s
.8663 .36851 m
.89072 .36851 L
s
.89072 .36851 m
.91514 .36851 L
s
.91514 .36851 m
.93956 .36851 L
s
.93956 .36851 m
.96398 .36851 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 108.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000Xa000`40O003h00Oofmk/Fmk003oKg^a
Kg/00?m_Nk5_N`00ofmk/Fmk000;Kg_o002J000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk
00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_
N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03
001_Nfmk00Y_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk
000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_
N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Nol0090000A_N`03001_Nfmk
00Y_N`002fmk00@006mkKg]_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_
N`03001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_
N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_
N`8000Q_N`03001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0002Kg/00`00Kg]_N`04
Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk
00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_
Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk
00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk
0006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk0000
1Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_
N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/0
1000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/0
00I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000=_N`03001_Nfmk00Y_N`002fmk
00@006mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00004
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/01000Kg]_N`0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`00
00a_N`002fmk0P001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mk
Kg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006
Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk
00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04
001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_
N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04
001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`00
1fmk00@006mkKg/000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05
001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/00`00
Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_
N`002fmk00<006mkKg/01Vmk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk
00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk
000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk
0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk
0P0036mk000;Kg_o002J000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
Nfmk00M_N`80009_N`<000I_N`8000U_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mkKg/01Fmk0P001fmk
0`001Fmk0P001fmk00<006mkKg/01Fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/0
0`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00A_N`8000a_
N`<000A_N`8000I_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<0
06mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0?Kg/20004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`04001_Nfmk0003
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00004Kg/2000DKg/30002
Kg/20004Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk
00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00002Kg/2000IKg/300000fmk00000002Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00@006mk001_N`8001i_N`D00004Kg/006mk0007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00@0
06mk000002=_N`@00003Kg/006mk00I_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00<006mkKg/00Vmko`00T00016mk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_Nfmk00I_N`80009_N`@002E_N`8000Q_N`03001_Nfmk00I_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03
001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg]_N`04Kg/30007Kg/3000SKg/3
0006Kg/00`00Kg]_N`06Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/00`00Kg]_N`03Kg/4000;Kg/4000PKg/40005Kg/00`00Kg]_N`04Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`03Kg/0
0`00Kg/0000AKg/3000OKg/00`00Kg/00005Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00Kg]_
N`0:Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00@006mkKg]_N`800003Kg/006mk01A_N`@001a_
N`04001_N`000003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`00009_N`80009_N`03001_Nfmk01Q_N`<001Y_N`03001_Nfmk0080009_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`04001_N`00Kg/20003Kg/00`00Kg]_
N`0LKg/4000GKg/01000Kg]_Nfmk0P0000A_N`00Kg/000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00@006mk
000000A_N`03001_Nfmk025_N`<001E_N`03001_Nfmk009_N`800003Kg/006mk00I_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`00
2fmkZ00016mk0P009fmk10004Vmk0P0016mkZ00036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0[Kg/3000AKg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`8000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`05001_
NfmkKg/0000aKg/4000>Kg/01@00Kg]_Nfmk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk0000=Vmk0`0036mk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk0000
1Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
1000Kg]_N`00>Vmk10002Fmk00@006mkKg/000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/01000Kg]_N`000fmk00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`0mKg/30007Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_
N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`04001_NfmkKg/30013Kg/40004Kg/30003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:
Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00@006mk000004U_N`<000=_N`800003Kg/006mk00I_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/0001=Kg/500000fmk001_N`06Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03
001_Nfmk009_Nol0090000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg]_N`03Kg/:0016
Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mkKg/03Fmk2P00?6mk00<0
06mkKg/01Fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk00000fmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0HKg/:000cKg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/08Vmk2P00:Fmk00<006mkKg/00fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00Kg]_
N`0:Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk0000;fmk2P0086mk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0003U_N`X001I_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_
N`0000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk0000A6mk2P003Fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0001>Kg/:0003Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_Nol0
09X000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk0P00F6mk100000=_N`00000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/2001DKg/40005Kg/20008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk0P00DVmk0`002Vmk0P001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`03001_N`00
00E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/2001>Kg/4000=Kg/20005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/0
1000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_N`00
04Y_N`@0015_N`03001_N`0000A_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`07001_NfmkKg/006mk0000Afmk0`005Fmk00<006mk00000fmk00<006mk
Kg/016mk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:
Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00000Vmk00<006mkKg/0@Fmk100066mk00H006mkKg/006mk0008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_
NfmkKg/006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
0Vmk00<006mkKg/0?Fmk100076mk00H006mkKg/006mk0008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Ni@0009_
N`03001_Nfmk03]_N`<0025_N`03001_Nfmk09@000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_
N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/20002Kg/00`00Kg]_
N`0gKg/4000TKg/00`00Kg]_N`020008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk0P000Vmk00<006mkKg/0<fmk1000:6mk00<006mkKg/0
0P0026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00000fmk00<006mk
Kg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`03001_N`00009_N`03001_Nfmk031_N`<002a_N`06001_Nfmk001_N`001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk
0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00@006mkKg/0009_N`03001_Nfmk02a_N`@0
02m_N`04001_Nfmk0002Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_
N`03001_Nfmk00Y_N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`06
001_Nfmk001_N`00:fmk1000=6mk00<006mk00000Vmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00003Kg/00`00Kg/0000XKg/3000hKg/00`00Kg/00003Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk0P00
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000016mk00<006mk0000
96mk1000>fmk00<006mk000016mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00004Kg/00`00Kg/0000PKg/4000oKg/00`00Kg/00004Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_Ni<000E_N`03001_N`0001e_
N`<004=_N`03001_N`0000E_Ni<000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000016mk0P006Vmk1000Afmk0P0016mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00004Kg/2000FKg/4001;Kg/20004Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`03001_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000fmk0P004fmk0`00Cfmk
0P000fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/00`00Kg/0000<
Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02000?
Kg/4001BKg/20002Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
000036mk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
008000]_N`@005I_N`80009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
0Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`04001_N`000008Kg/3001JKg/200000fmk001_N`05Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00009_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/20005Kg/4001NKg/20008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:
Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk0P0000=_N`0000000P00HVmk0P0026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/00`00Kg]_N`02Kg_o002@0004Kg/00`00Kg]_
N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk0`00I6mk100026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`<0069_N`800004Kg/000000008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00<006mk00000P00Gfmk0P000Vmk
0`0000=_N`00Kg/01Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/0
0`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00`00GVmk00<006mkKg/00Vmk0`000Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0200000fmk001_N`1JKg/20004Kg/01000Kg/000000Vmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00003Kg/200000fmk001_N`1H
Kg/20006Kg/01000Kg/000000fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/00`00Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000A_N`80009_N`03001_Nfmk05E_N`03001_Nfmk00E_N`03001_Nfmk008000A_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk
0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000016mk0P000fmk
00<006mkKg/0DVmk0P001fmk00@006mkKg]_N`8000A_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmkT`001Fmk00<006mk00000Vmk00<006mkKg/0
D6mk0P002Fmk00H006mkKg/006mk0005Kg^C000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000A_N`03001_N`0000=_N`03001_Nfmk04e_N`8000Y_
N`07001_NfmkKg/006mk000016mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00004Kg/00`00Kg/00003Kg/00`00Kg]_N`1<Kg/00`00Kg]_N`0:Kg/01`00Kg]_Nfmk
001_N`0000A_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`80
00a_N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0003Kg/00`00Kg/00004Kg/00`00Kg]_N`19Kg/2000<Kg/00`00Kg]_N`02Kg/00`00Kg/00003Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk
00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`06001_Nfmk001_N`001Fmk00<0
06mkKg/0AVmk0P003Fmk00<006mkKg/00fmk00<006mk00000Vmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/01000Kg]_N`000Vmk00<006mkKg/00Vmk00<006mkKg/0A6mk0P003fmk
00<006mkKg/00Vmk00@006mkKg/0009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`03001_N`00009_N`03001_Nfmk00=_N`03001_Nfmk049_N`03001_
Nfmk00i_N`03001_Nfmk00=_N`06001_Nfmk001_N`001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk0P000Vmk00<006mkKg/00fmk00<006mkKg/0
@6mk0P004Fmk00<006mkKg/00fmk00<006mkKg/00P0026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`80009_N`03001_Nfmk00A_N`03001_
Nfmk03e_N`80019_N`03001_Nfmk00A_N`03001_Nfmk008000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00<006mkKg/00VmkU000
0Vmk00<006mkKg/016mk00<006mkKg/0>fmk0P0056mk00<006mkKg/016mk00<006mkKg/0U00016mk
00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`00009_N`03001_Nfmk00A_N`03001_Nfmk03U_N`03001_Nfmk01=_
N`03001_Nfmk00A_N`06001_Nfmk001_N`0026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00009_N`03001_Nfmk00E_N`03001_
Nfmk03I_N`8001E_N`03001_Nfmk00E_N`06001_Nfmk001_N`0026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk
00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`07001_NfmkKg/006mk00001fmk
00<006mkKg/0=6mk0P005fmk00<006mkKg/01Fmk00<006mk00000fmk00<006mkKg/016mk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`04001_
Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk000026mk
00<006mkKg/0<Vmk00<006mkKg/05Vmk00<006mkKg/01Vmk00<006mk000016mk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`03001_N`0000E_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/20008Kg/00`00Kg]_N`0`Kg/2
000IKg/00`00Kg]_N`06Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`8000U_N`03001_Nfmk02e_N`8001Y_N`03001_Nfmk00M_N`8000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/2
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/20008Kg/0
0`00Kg]_N`0[Kg/2000LKg/00`00Kg]_N`06Kg/20008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`8000U_N`03001_Nfmk02U_N`03001_Nfmk01]_N`03
001_Nfmk00M_N`8000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`8000a_N`002fmkWP002Vmk00<006mkKg/09Vmk0P007Fmk00<006mkKg/026mkWP0036mk000;
Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00009Kg/00`00Kg]_N`0TKg/2000OKg/00`00Kg]_N`07Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`8000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`04001_N`000009Kg/00`00
Kg]_N`0QKg/2000PKg/00`00Kg]_N`07Kg/200000fmk001_N`07Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`03001_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg]_N`<000M_N`03001_Nfmk
021_N`03001_Nfmk021_N`03001_Nfmk00E_N`<000=_N`03001_Nfmk00A_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/00`00Kg/00005Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03001_
Nfmk00E_N`03001_Nfmk01e_N`80029_N`03001_Nfmk00E_N`04001_Nfmk0003Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/0
1000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`04001_Nfmk0006Kg/00`00Kg]_N`0KKg/2000TKg/00`00Kg]_N`04Kg/01000Kg]_N`001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00
Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/00`00Kg]_N`0HKg/2000UKg/00`00
Kg]_N`04Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`05001_NfmkKg/0
0006Kg/00`00Kg]_N`0FKg/00`00Kg]_N`0TKg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00000fmk00<0
06mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk01A_N`80
02M_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00<0
06mkKg/00VmkWP0016mk0P0016mk00<006mkKg/04Fmk0P00:6mk00<006mkKg/00Vmk0P0016mkWP00
16mk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`04001_N`000004Kg/01@00Kg]_Nfmk00004Vmk00<0
06mkKg/0:6mk00D006mkKg]_N`0000A_N`800003Kg/006mk00I_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00L0
06mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/01000Kg/006mk0P000fmk00D006mkKg]_N`0000m_N`8002Y_N`05001_NfmkKg/00003Kg/2
000016mk001_N`001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk0P00
0Vmk00D006mkKg]_N`0000a_N`8002]_N`05001_NfmkKg/00002Kg/20002Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
0Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00004Kg/01000Kg]_N`000Vmk00<006mk
Kg/026mk0P00;Fmk00@006mkKg/0009_N`03001_Nfmk009_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03001_Nfmk00Y_
N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/200001Fmk001_Nfmk000026mk00<006mkKg/0;6mk00D0
06mkKg/006mk008000A_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`04Kg/50006Kg/2000_Kg/50006Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`8000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_Nfmk00E_N`@000=_N`80031_N`@000M_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mkKg/01fmk0P0000=_N`000000<Vmk0P002Fmk00<006mkKg/01Fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg_o002J000<
Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000<002]_N`@00003Kg/006mk00M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00@006mk001_N`D002E_N`D00004Kg/0
06mk0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00000Vmk0P0000A_N`00000001m_N`<00003Kg/00000009_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00004Kg/01000Kg]_Nfmk0P006fmk0P000fmk00<006mkKg/00Vmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/01000Kg]_N`00
0fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/20003Kg/3000EKg/3
0003Kg/20004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/0
0`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/016mk0P0016mk0`003fmk0`0016mk0P001Vmk00<006mkKg/00fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mkKg/01Fmk0P001Fmk0`002Fmk0`001Fmk0P001fmk00<006mkKg/01Fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_Nfmk00M_N`8000I_N`<000=_N`<000I_N`8000U_N`03001_Nfmk00E_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00<006mkKg/00Vmko`00T00016mk00<0
06mkKg/02Vmk000;Kg/01000Kg]_Nfmk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk
0P0026mk00<006mk000026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk00<006mk000026mk0P0026mk
00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk
000026mk0P0026mk00<006mk000026mk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk
0P0026mk0P0016mk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00@006mkKg/0009_N`03001_
Nfmk00A_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk
0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk
00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_Nfmk
0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@0
06mkKg/000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_Nfmk
Kg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk
00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`00
00I_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000
Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`000fmk00<006mkKg/02Vmk
000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`03001_
N`0000A_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_
Nfmk009_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk009_N`03001_Nfmk009_N`04001_Nfmk000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<0
06mk000036mk000;Kg/20006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_Nfmk0007Kg/0
1000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001Vmk00D006mkKg]_
N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/0
0006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk0000
1Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04
001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`00
1Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_
Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`00
1Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_
N`03001_N`0000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
0P0036mk000;Kg/00`00Kg]_N`06Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/2
0008Kg/00`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/0
0`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/20009Kg/2
0008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/20008Kg/20009Kg/2
0008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/20008Kg/00`00Kg/00008Kg/2
0008Kg/2000<Kg/000]_Nol009X000a_N`0036mk00<006mkKg/01Fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mkKg/02fmk000<Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg]_N`0;Kg/000e_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/036mk000=Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk00a_N`003Vmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00003fmk000>Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0000?Kg/000m_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`00011_N`003fmk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000046mk000@Kg_o002@000AKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {162, 0}} -> {-2.0564, -0.777006, 0.0143137, \
0.0143137}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell["\<\
Obviously, these meshbars across the hole in the center need to be removed. \
Here we use a \"middle point\" approach that is different from the original \
MATLAB code. However the idea is the same; that is, using distance function \
to identify meshbars that lie out of the defined region.\
\>", "Text"],

Cell[BoxData[
    \(middlepoint[p_, {a_, b_}] := \(p[\([a]\)] + p[\([b]\)]\)\/2\)], "Input",\

  CellLabel->"In[33]:="],

Cell["It selects only the meshbars interior to the region.", "Text"],

Cell[BoxData[
    \(\(bars2 = Select[bars2, d[middlepoint[p2, #]] < 0 &];\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(meshbarPlot[p2, bars2]\)], "Input",
  CellLabel->"In[40]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3775 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.2442 0.189743 0.2442 [
[ 0 0 0 0 ]
[ 1 .3775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .3775 L
0 .3775 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.02381 .00899 m
.04823 .00899 L
s
.02381 .00899 m
.03602 .03014 L
s
.02381 .00899 m
.02381 .05128 L
s
.04823 .00899 m
.07265 .00899 L
s
.04823 .00899 m
.03602 .03014 L
s
.04823 .00899 m
.06044 .03014 L
s
.07265 .00899 m
.09707 .00899 L
s
.07265 .00899 m
.06044 .03014 L
s
.07265 .00899 m
.08486 .03014 L
s
.09707 .00899 m
.12149 .00899 L
s
.09707 .00899 m
.08486 .03014 L
s
.09707 .00899 m
.10928 .03014 L
s
.12149 .00899 m
.14591 .00899 L
s
.12149 .00899 m
.10928 .03014 L
s
.12149 .00899 m
.1337 .03014 L
s
.14591 .00899 m
.17033 .00899 L
s
.14591 .00899 m
.1337 .03014 L
s
.14591 .00899 m
.15812 .03014 L
s
.17033 .00899 m
.19475 .00899 L
s
.17033 .00899 m
.15812 .03014 L
s
.17033 .00899 m
.18254 .03014 L
s
.19475 .00899 m
.21917 .00899 L
s
.19475 .00899 m
.18254 .03014 L
s
.19475 .00899 m
.20696 .03014 L
s
.21917 .00899 m
.24359 .00899 L
s
.21917 .00899 m
.20696 .03014 L
s
.21917 .00899 m
.23138 .03014 L
s
.24359 .00899 m
.26801 .00899 L
s
.24359 .00899 m
.23138 .03014 L
s
.24359 .00899 m
.2558 .03014 L
s
.26801 .00899 m
.29243 .00899 L
s
.26801 .00899 m
.2558 .03014 L
s
.26801 .00899 m
.28022 .03014 L
s
.29243 .00899 m
.31685 .00899 L
s
.29243 .00899 m
.28022 .03014 L
s
.29243 .00899 m
.30464 .03014 L
s
.31685 .00899 m
.34127 .00899 L
s
.31685 .00899 m
.30464 .03014 L
s
.31685 .00899 m
.32906 .03014 L
s
.34127 .00899 m
.36569 .00899 L
s
.34127 .00899 m
.32906 .03014 L
s
.34127 .00899 m
.35348 .03014 L
s
.36569 .00899 m
.39011 .00899 L
s
.36569 .00899 m
.35348 .03014 L
s
.36569 .00899 m
.3779 .03014 L
s
.39011 .00899 m
.41453 .00899 L
s
.39011 .00899 m
.3779 .03014 L
s
.39011 .00899 m
.40232 .03014 L
s
.41453 .00899 m
.43895 .00899 L
s
.41453 .00899 m
.40232 .03014 L
s
.41453 .00899 m
.42674 .03014 L
s
.43895 .00899 m
.46337 .00899 L
s
.43895 .00899 m
.42674 .03014 L
s
.43895 .00899 m
.45116 .03014 L
s
.46337 .00899 m
.48779 .00899 L
s
.46337 .00899 m
.45116 .03014 L
s
.46337 .00899 m
.47558 .03014 L
s
.48779 .00899 m
.51221 .00899 L
s
.48779 .00899 m
.47558 .03014 L
s
.48779 .00899 m
.5 .03014 L
s
.51221 .00899 m
.53663 .00899 L
s
.51221 .00899 m
.5 .03014 L
s
.51221 .00899 m
.52442 .03014 L
s
.53663 .00899 m
.56105 .00899 L
s
.53663 .00899 m
.52442 .03014 L
s
.53663 .00899 m
.54884 .03014 L
s
.56105 .00899 m
.58547 .00899 L
s
.56105 .00899 m
.54884 .03014 L
s
.56105 .00899 m
.57326 .03014 L
s
.58547 .00899 m
.60989 .00899 L
s
.58547 .00899 m
.57326 .03014 L
s
.58547 .00899 m
.59768 .03014 L
s
.60989 .00899 m
.63431 .00899 L
s
.60989 .00899 m
.59768 .03014 L
s
.60989 .00899 m
.6221 .03014 L
s
.63431 .00899 m
.65873 .00899 L
s
.63431 .00899 m
.6221 .03014 L
s
.63431 .00899 m
.64652 .03014 L
s
.65873 .00899 m
.68315 .00899 L
s
.65873 .00899 m
.64652 .03014 L
s
.65873 .00899 m
.67094 .03014 L
s
.68315 .00899 m
.70757 .00899 L
s
.68315 .00899 m
.67094 .03014 L
s
.68315 .00899 m
.69536 .03014 L
s
.70757 .00899 m
.73199 .00899 L
s
.70757 .00899 m
.69536 .03014 L
s
.70757 .00899 m
.71978 .03014 L
s
.73199 .00899 m
.75641 .00899 L
s
.73199 .00899 m
.71978 .03014 L
s
.73199 .00899 m
.7442 .03014 L
s
.75641 .00899 m
.78083 .00899 L
s
.75641 .00899 m
.7442 .03014 L
s
.75641 .00899 m
.76862 .03014 L
s
.78083 .00899 m
.80525 .00899 L
s
.78083 .00899 m
.76862 .03014 L
s
.78083 .00899 m
.79304 .03014 L
s
.80525 .00899 m
.82967 .00899 L
s
.80525 .00899 m
.79304 .03014 L
s
.80525 .00899 m
.81746 .03014 L
s
.82967 .00899 m
.85409 .00899 L
s
.82967 .00899 m
.81746 .03014 L
s
.82967 .00899 m
.84188 .03014 L
s
.85409 .00899 m
.87851 .00899 L
s
.85409 .00899 m
.84188 .03014 L
s
.85409 .00899 m
.8663 .03014 L
s
.87851 .00899 m
.90293 .00899 L
s
.87851 .00899 m
.8663 .03014 L
s
.87851 .00899 m
.89072 .03014 L
s
.90293 .00899 m
.92735 .00899 L
s
.90293 .00899 m
.89072 .03014 L
s
.90293 .00899 m
.91514 .03014 L
s
.92735 .00899 m
.95177 .00899 L
s
.92735 .00899 m
.91514 .03014 L
s
.92735 .00899 m
.93956 .03014 L
s
.95177 .00899 m
.97619 .00899 L
s
.95177 .00899 m
.93956 .03014 L
s
.95177 .00899 m
.96398 .03014 L
s
.97619 .00899 m
.96398 .03014 L
s
.97619 .00899 m
.97619 .05128 L
s
.03602 .03014 m
.06044 .03014 L
s
.03602 .03014 m
.02381 .05128 L
s
.03602 .03014 m
.04823 .05128 L
s
.06044 .03014 m
.08486 .03014 L
s
.06044 .03014 m
.04823 .05128 L
s
.06044 .03014 m
.07265 .05128 L
s
.08486 .03014 m
.10928 .03014 L
s
.08486 .03014 m
.07265 .05128 L
s
.08486 .03014 m
.09707 .05128 L
s
.10928 .03014 m
.1337 .03014 L
s
.10928 .03014 m
.09707 .05128 L
s
.10928 .03014 m
.12149 .05128 L
s
.1337 .03014 m
.15812 .03014 L
s
.1337 .03014 m
.12149 .05128 L
s
.1337 .03014 m
.14591 .05128 L
s
.15812 .03014 m
.18254 .03014 L
s
.15812 .03014 m
.14591 .05128 L
s
.15812 .03014 m
.17033 .05128 L
s
.18254 .03014 m
.20696 .03014 L
s
.18254 .03014 m
.17033 .05128 L
s
.18254 .03014 m
.19475 .05128 L
s
.20696 .03014 m
.23138 .03014 L
s
.20696 .03014 m
.19475 .05128 L
s
.20696 .03014 m
.21917 .05128 L
s
.23138 .03014 m
.2558 .03014 L
s
.23138 .03014 m
.21917 .05128 L
s
.23138 .03014 m
.24359 .05128 L
s
.2558 .03014 m
.28022 .03014 L
s
.2558 .03014 m
.24359 .05128 L
s
.2558 .03014 m
.26801 .05128 L
s
.28022 .03014 m
.30464 .03014 L
s
.28022 .03014 m
.26801 .05128 L
s
.28022 .03014 m
.29243 .05128 L
s
.30464 .03014 m
.32906 .03014 L
s
.30464 .03014 m
.29243 .05128 L
s
.30464 .03014 m
.31685 .05128 L
s
.32906 .03014 m
.35348 .03014 L
s
.32906 .03014 m
.31685 .05128 L
s
.32906 .03014 m
.34127 .05128 L
s
.35348 .03014 m
.3779 .03014 L
s
.35348 .03014 m
.34127 .05128 L
s
.35348 .03014 m
.36569 .05128 L
s
.3779 .03014 m
.40232 .03014 L
s
.3779 .03014 m
.36569 .05128 L
s
.3779 .03014 m
.39011 .05128 L
s
.40232 .03014 m
.42674 .03014 L
s
.40232 .03014 m
.39011 .05128 L
s
.40232 .03014 m
.41453 .05128 L
s
.42674 .03014 m
.45116 .03014 L
s
.42674 .03014 m
.41453 .05128 L
s
.42674 .03014 m
.43895 .05128 L
s
.45116 .03014 m
.47558 .03014 L
s
.45116 .03014 m
.43895 .05128 L
s
.45116 .03014 m
.46337 .05128 L
s
.47558 .03014 m
.5 .03014 L
s
.47558 .03014 m
.46337 .05128 L
s
.47558 .03014 m
.48779 .05128 L
s
.5 .03014 m
.52442 .03014 L
s
.5 .03014 m
.48779 .05128 L
s
.5 .03014 m
.51221 .05128 L
s
.52442 .03014 m
.54884 .03014 L
s
.52442 .03014 m
.51221 .05128 L
s
.52442 .03014 m
.53663 .05128 L
s
.54884 .03014 m
.57326 .03014 L
s
.54884 .03014 m
.53663 .05128 L
s
.54884 .03014 m
.56105 .05128 L
s
.57326 .03014 m
.59768 .03014 L
s
.57326 .03014 m
.56105 .05128 L
s
.57326 .03014 m
.58547 .05128 L
s
.59768 .03014 m
.6221 .03014 L
s
.59768 .03014 m
.58547 .05128 L
s
.59768 .03014 m
.60989 .05128 L
s
.6221 .03014 m
.64652 .03014 L
s
.6221 .03014 m
.60989 .05128 L
s
.6221 .03014 m
.63431 .05128 L
s
.64652 .03014 m
.67094 .03014 L
s
.64652 .03014 m
.63431 .05128 L
s
.64652 .03014 m
.65873 .05128 L
s
.67094 .03014 m
.69536 .03014 L
s
.67094 .03014 m
.65873 .05128 L
s
.67094 .03014 m
.68315 .05128 L
s
.69536 .03014 m
.71978 .03014 L
s
.69536 .03014 m
.68315 .05128 L
s
.69536 .03014 m
.70757 .05128 L
s
.71978 .03014 m
.7442 .03014 L
s
.71978 .03014 m
.70757 .05128 L
s
.71978 .03014 m
.73199 .05128 L
s
.7442 .03014 m
.76862 .03014 L
s
.7442 .03014 m
.73199 .05128 L
s
.7442 .03014 m
.75641 .05128 L
s
.76862 .03014 m
.79304 .03014 L
s
.76862 .03014 m
.75641 .05128 L
s
.76862 .03014 m
.78083 .05128 L
s
.79304 .03014 m
.81746 .03014 L
s
.79304 .03014 m
.78083 .05128 L
s
.79304 .03014 m
.80525 .05128 L
s
.81746 .03014 m
.84188 .03014 L
s
.81746 .03014 m
.80525 .05128 L
s
.81746 .03014 m
.82967 .05128 L
s
.84188 .03014 m
.8663 .03014 L
s
.84188 .03014 m
.82967 .05128 L
s
.84188 .03014 m
.85409 .05128 L
s
.8663 .03014 m
.89072 .03014 L
s
.8663 .03014 m
.85409 .05128 L
s
.8663 .03014 m
.87851 .05128 L
s
.89072 .03014 m
.91514 .03014 L
s
.89072 .03014 m
.87851 .05128 L
s
.89072 .03014 m
.90293 .05128 L
s
.91514 .03014 m
.93956 .03014 L
s
.91514 .03014 m
.90293 .05128 L
s
.91514 .03014 m
.92735 .05128 L
s
.93956 .03014 m
.96398 .03014 L
s
.93956 .03014 m
.92735 .05128 L
s
.93956 .03014 m
.95177 .05128 L
s
.96398 .03014 m
.95177 .05128 L
s
.96398 .03014 m
.97619 .05128 L
s
.02381 .05128 m
.04823 .05128 L
s
.02381 .05128 m
.03602 .07243 L
s
.02381 .05128 m
.02381 .09358 L
s
.04823 .05128 m
.07265 .05128 L
s
.04823 .05128 m
.03602 .07243 L
s
.04823 .05128 m
.06044 .07243 L
s
.07265 .05128 m
.09707 .05128 L
s
.07265 .05128 m
.06044 .07243 L
s
.07265 .05128 m
.08486 .07243 L
s
.09707 .05128 m
.12149 .05128 L
s
.09707 .05128 m
.08486 .07243 L
s
.09707 .05128 m
.10928 .07243 L
s
.12149 .05128 m
.14591 .05128 L
s
.12149 .05128 m
.10928 .07243 L
s
.12149 .05128 m
.1337 .07243 L
s
.14591 .05128 m
.17033 .05128 L
s
.14591 .05128 m
.1337 .07243 L
s
.14591 .05128 m
.15812 .07243 L
s
.17033 .05128 m
.19475 .05128 L
s
.17033 .05128 m
.15812 .07243 L
s
.17033 .05128 m
.18254 .07243 L
s
.19475 .05128 m
.21917 .05128 L
s
.19475 .05128 m
.18254 .07243 L
s
.19475 .05128 m
.20696 .07243 L
s
.21917 .05128 m
.24359 .05128 L
s
.21917 .05128 m
.20696 .07243 L
s
.21917 .05128 m
.23138 .07243 L
s
.24359 .05128 m
.26801 .05128 L
s
.24359 .05128 m
.23138 .07243 L
s
.24359 .05128 m
.2558 .07243 L
s
.26801 .05128 m
.29243 .05128 L
s
.26801 .05128 m
.2558 .07243 L
s
.26801 .05128 m
.28022 .07243 L
s
.29243 .05128 m
.31685 .05128 L
s
.29243 .05128 m
.28022 .07243 L
s
.29243 .05128 m
.30464 .07243 L
s
.31685 .05128 m
.34127 .05128 L
s
.31685 .05128 m
.30464 .07243 L
s
.31685 .05128 m
.32906 .07243 L
s
.34127 .05128 m
.36569 .05128 L
s
.34127 .05128 m
.32906 .07243 L
s
.34127 .05128 m
.35348 .07243 L
s
.36569 .05128 m
.39011 .05128 L
s
.36569 .05128 m
.35348 .07243 L
s
.36569 .05128 m
.3779 .07243 L
s
.39011 .05128 m
.41453 .05128 L
s
.39011 .05128 m
.3779 .07243 L
s
.39011 .05128 m
.40232 .07243 L
s
.41453 .05128 m
.43895 .05128 L
s
.41453 .05128 m
.40232 .07243 L
s
.41453 .05128 m
.42674 .07243 L
s
.43895 .05128 m
.46337 .05128 L
s
.43895 .05128 m
.42674 .07243 L
s
.43895 .05128 m
.45116 .07243 L
s
.46337 .05128 m
.48779 .05128 L
s
.46337 .05128 m
.45116 .07243 L
s
.48779 .05128 m
.51221 .05128 L
s
.48779 .05128 m
.45116 .07243 L
s
.48779 .05128 m
.54884 .07243 L
s
.51221 .05128 m
.53663 .05128 L
s
.51221 .05128 m
.54884 .07243 L
s
.53663 .05128 m
.56105 .05128 L
s
.53663 .05128 m
.54884 .07243 L
s
.56105 .05128 m
.58547 .05128 L
s
.56105 .05128 m
.54884 .07243 L
s
.56105 .05128 m
.57326 .07243 L
s
.58547 .05128 m
.60989 .05128 L
s
.58547 .05128 m
.57326 .07243 L
s
.58547 .05128 m
.59768 .07243 L
s
.60989 .05128 m
.63431 .05128 L
s
.60989 .05128 m
.59768 .07243 L
s
.60989 .05128 m
.6221 .07243 L
s
.63431 .05128 m
.65873 .05128 L
s
.63431 .05128 m
.6221 .07243 L
s
.63431 .05128 m
.64652 .07243 L
s
.65873 .05128 m
.68315 .05128 L
s
.65873 .05128 m
.64652 .07243 L
s
.65873 .05128 m
.67094 .07243 L
s
.68315 .05128 m
.70757 .05128 L
s
.68315 .05128 m
.67094 .07243 L
s
.68315 .05128 m
.69536 .07243 L
s
.70757 .05128 m
.73199 .05128 L
s
.70757 .05128 m
.69536 .07243 L
s
.70757 .05128 m
.71978 .07243 L
s
.73199 .05128 m
.75641 .05128 L
s
.73199 .05128 m
.71978 .07243 L
s
.73199 .05128 m
.7442 .07243 L
s
.75641 .05128 m
.78083 .05128 L
s
.75641 .05128 m
.7442 .07243 L
s
.75641 .05128 m
.76862 .07243 L
s
.78083 .05128 m
.80525 .05128 L
s
.78083 .05128 m
.76862 .07243 L
s
.78083 .05128 m
.79304 .07243 L
s
.80525 .05128 m
.82967 .05128 L
s
.80525 .05128 m
.79304 .07243 L
s
.80525 .05128 m
.81746 .07243 L
s
.82967 .05128 m
.85409 .05128 L
s
.82967 .05128 m
.81746 .07243 L
s
.82967 .05128 m
.84188 .07243 L
s
.85409 .05128 m
.87851 .05128 L
s
.85409 .05128 m
.84188 .07243 L
s
.85409 .05128 m
.8663 .07243 L
s
.87851 .05128 m
.90293 .05128 L
s
.87851 .05128 m
.8663 .07243 L
s
.87851 .05128 m
.89072 .07243 L
s
.90293 .05128 m
.92735 .05128 L
s
.90293 .05128 m
.89072 .07243 L
s
.90293 .05128 m
.91514 .07243 L
s
.92735 .05128 m
.95177 .05128 L
s
.92735 .05128 m
.91514 .07243 L
s
.92735 .05128 m
.93956 .07243 L
s
.95177 .05128 m
.97619 .05128 L
s
.95177 .05128 m
.93956 .07243 L
s
.95177 .05128 m
.96398 .07243 L
s
.97619 .05128 m
.96398 .07243 L
s
.97619 .05128 m
.97619 .09358 L
s
.03602 .07243 m
.06044 .07243 L
s
.03602 .07243 m
.02381 .09358 L
s
.03602 .07243 m
.04823 .09358 L
s
.06044 .07243 m
.08486 .07243 L
s
.06044 .07243 m
.04823 .09358 L
s
.06044 .07243 m
.07265 .09358 L
s
.08486 .07243 m
.10928 .07243 L
s
.08486 .07243 m
.07265 .09358 L
s
.08486 .07243 m
.09707 .09358 L
s
.10928 .07243 m
.1337 .07243 L
s
.10928 .07243 m
.09707 .09358 L
s
.10928 .07243 m
.12149 .09358 L
s
.1337 .07243 m
.15812 .07243 L
s
.1337 .07243 m
.12149 .09358 L
s
.1337 .07243 m
.14591 .09358 L
s
.15812 .07243 m
.18254 .07243 L
s
.15812 .07243 m
.14591 .09358 L
s
.15812 .07243 m
.17033 .09358 L
s
.18254 .07243 m
.20696 .07243 L
s
.18254 .07243 m
.17033 .09358 L
s
.18254 .07243 m
.19475 .09358 L
s
.20696 .07243 m
.23138 .07243 L
s
.20696 .07243 m
.19475 .09358 L
s
.20696 .07243 m
.21917 .09358 L
s
.23138 .07243 m
.2558 .07243 L
s
.23138 .07243 m
.21917 .09358 L
s
.23138 .07243 m
.24359 .09358 L
s
.2558 .07243 m
.28022 .07243 L
s
.2558 .07243 m
.24359 .09358 L
s
.2558 .07243 m
.26801 .09358 L
s
.28022 .07243 m
.30464 .07243 L
s
.28022 .07243 m
.26801 .09358 L
s
.28022 .07243 m
.29243 .09358 L
s
.30464 .07243 m
.32906 .07243 L
s
.30464 .07243 m
.29243 .09358 L
s
.30464 .07243 m
.31685 .09358 L
s
.32906 .07243 m
.35348 .07243 L
s
.32906 .07243 m
.31685 .09358 L
s
.32906 .07243 m
.34127 .09358 L
s
.35348 .07243 m
.3779 .07243 L
s
.35348 .07243 m
.34127 .09358 L
s
.35348 .07243 m
.36569 .09358 L
s
.3779 .07243 m
.40232 .07243 L
s
.3779 .07243 m
.36569 .09358 L
s
.3779 .07243 m
.39011 .09358 L
s
.40232 .07243 m
.42674 .07243 L
s
.40232 .07243 m
.39011 .09358 L
s
.40232 .07243 m
.41453 .09358 L
s
.42674 .07243 m
.45116 .07243 L
s
.42674 .07243 m
.41453 .09358 L
s
.45116 .07243 m
.41453 .09358 L
s
.54884 .07243 m
.57326 .07243 L
s
.54884 .07243 m
.58547 .09358 L
s
.57326 .07243 m
.59768 .07243 L
s
.57326 .07243 m
.58547 .09358 L
s
.59768 .07243 m
.6221 .07243 L
s
.59768 .07243 m
.58547 .09358 L
s
.59768 .07243 m
.60989 .09358 L
s
.6221 .07243 m
.64652 .07243 L
s
.6221 .07243 m
.60989 .09358 L
s
.6221 .07243 m
.63431 .09358 L
s
.64652 .07243 m
.67094 .07243 L
s
.64652 .07243 m
.63431 .09358 L
s
.64652 .07243 m
.65873 .09358 L
s
.67094 .07243 m
.69536 .07243 L
s
.67094 .07243 m
.65873 .09358 L
s
.67094 .07243 m
.68315 .09358 L
s
.69536 .07243 m
.71978 .07243 L
s
.69536 .07243 m
.68315 .09358 L
s
.69536 .07243 m
.70757 .09358 L
s
.71978 .07243 m
.7442 .07243 L
s
.71978 .07243 m
.70757 .09358 L
s
.71978 .07243 m
.73199 .09358 L
s
.7442 .07243 m
.76862 .07243 L
s
.7442 .07243 m
.73199 .09358 L
s
.7442 .07243 m
.75641 .09358 L
s
.76862 .07243 m
.79304 .07243 L
s
.76862 .07243 m
.75641 .09358 L
s
.76862 .07243 m
.78083 .09358 L
s
.79304 .07243 m
.81746 .07243 L
s
.79304 .07243 m
.78083 .09358 L
s
.79304 .07243 m
.80525 .09358 L
s
.81746 .07243 m
.84188 .07243 L
s
.81746 .07243 m
.80525 .09358 L
s
.81746 .07243 m
.82967 .09358 L
s
.84188 .07243 m
.8663 .07243 L
s
.84188 .07243 m
.82967 .09358 L
s
.84188 .07243 m
.85409 .09358 L
s
.8663 .07243 m
.89072 .07243 L
s
.8663 .07243 m
.85409 .09358 L
s
.8663 .07243 m
.87851 .09358 L
s
.89072 .07243 m
.91514 .07243 L
s
.89072 .07243 m
.87851 .09358 L
s
.89072 .07243 m
.90293 .09358 L
s
.91514 .07243 m
.93956 .07243 L
s
.91514 .07243 m
.90293 .09358 L
s
.91514 .07243 m
.92735 .09358 L
s
.93956 .07243 m
.96398 .07243 L
s
.93956 .07243 m
.92735 .09358 L
s
.93956 .07243 m
.95177 .09358 L
s
.96398 .07243 m
.95177 .09358 L
s
.96398 .07243 m
.97619 .09358 L
s
.02381 .09358 m
.04823 .09358 L
s
.02381 .09358 m
.03602 .11473 L
s
.02381 .09358 m
.02381 .13588 L
s
.04823 .09358 m
.07265 .09358 L
s
.04823 .09358 m
.03602 .11473 L
s
.04823 .09358 m
.06044 .11473 L
s
.07265 .09358 m
.09707 .09358 L
s
.07265 .09358 m
.06044 .11473 L
s
.07265 .09358 m
.08486 .11473 L
s
.09707 .09358 m
.12149 .09358 L
s
.09707 .09358 m
.08486 .11473 L
s
.09707 .09358 m
.10928 .11473 L
s
.12149 .09358 m
.14591 .09358 L
s
.12149 .09358 m
.10928 .11473 L
s
.12149 .09358 m
.1337 .11473 L
s
.14591 .09358 m
.17033 .09358 L
s
.14591 .09358 m
.1337 .11473 L
s
.14591 .09358 m
.15812 .11473 L
s
.17033 .09358 m
.19475 .09358 L
s
.17033 .09358 m
.15812 .11473 L
s
.17033 .09358 m
.18254 .11473 L
s
.19475 .09358 m
.21917 .09358 L
s
.19475 .09358 m
.18254 .11473 L
s
.19475 .09358 m
.20696 .11473 L
s
.21917 .09358 m
.24359 .09358 L
s
.21917 .09358 m
.20696 .11473 L
s
.21917 .09358 m
.23138 .11473 L
s
.24359 .09358 m
.26801 .09358 L
s
.24359 .09358 m
.23138 .11473 L
s
.24359 .09358 m
.2558 .11473 L
s
.26801 .09358 m
.29243 .09358 L
s
.26801 .09358 m
.2558 .11473 L
s
.26801 .09358 m
.28022 .11473 L
s
.29243 .09358 m
.31685 .09358 L
s
.29243 .09358 m
.28022 .11473 L
s
.29243 .09358 m
.30464 .11473 L
s
.31685 .09358 m
.34127 .09358 L
s
.31685 .09358 m
.30464 .11473 L
s
.31685 .09358 m
.32906 .11473 L
s
.34127 .09358 m
.36569 .09358 L
s
.34127 .09358 m
.32906 .11473 L
s
.34127 .09358 m
.35348 .11473 L
s
.36569 .09358 m
.39011 .09358 L
s
.36569 .09358 m
.35348 .11473 L
s
.36569 .09358 m
.3779 .11473 L
s
.39011 .09358 m
.41453 .09358 L
s
.39011 .09358 m
.3779 .11473 L
s
.39011 .09358 m
.40232 .11473 L
s
.41453 .09358 m
.40232 .11473 L
s
.58547 .09358 m
.60989 .09358 L
s
.58547 .09358 m
.59768 .11473 L
s
.60989 .09358 m
.63431 .09358 L
s
.60989 .09358 m
.59768 .11473 L
s
.60989 .09358 m
.6221 .11473 L
s
.63431 .09358 m
.65873 .09358 L
s
.63431 .09358 m
.6221 .11473 L
s
.63431 .09358 m
.64652 .11473 L
s
.65873 .09358 m
.68315 .09358 L
s
.65873 .09358 m
.64652 .11473 L
s
.65873 .09358 m
.67094 .11473 L
s
.68315 .09358 m
.70757 .09358 L
s
.68315 .09358 m
.67094 .11473 L
s
.68315 .09358 m
.69536 .11473 L
s
.70757 .09358 m
.73199 .09358 L
s
.70757 .09358 m
.69536 .11473 L
s
.70757 .09358 m
.71978 .11473 L
s
.73199 .09358 m
.75641 .09358 L
s
.73199 .09358 m
.71978 .11473 L
s
.73199 .09358 m
.7442 .11473 L
s
.75641 .09358 m
.78083 .09358 L
s
.75641 .09358 m
.7442 .11473 L
s
.75641 .09358 m
.76862 .11473 L
s
.78083 .09358 m
.80525 .09358 L
s
.78083 .09358 m
.76862 .11473 L
s
.78083 .09358 m
.79304 .11473 L
s
.80525 .09358 m
.82967 .09358 L
s
.80525 .09358 m
.79304 .11473 L
s
.80525 .09358 m
.81746 .11473 L
s
.82967 .09358 m
.85409 .09358 L
s
.82967 .09358 m
.81746 .11473 L
s
.82967 .09358 m
.84188 .11473 L
s
.85409 .09358 m
.87851 .09358 L
s
.85409 .09358 m
.84188 .11473 L
s
.85409 .09358 m
.8663 .11473 L
s
.87851 .09358 m
.90293 .09358 L
s
.87851 .09358 m
.8663 .11473 L
s
.87851 .09358 m
.89072 .11473 L
s
.90293 .09358 m
.92735 .09358 L
s
.90293 .09358 m
.89072 .11473 L
s
.90293 .09358 m
.91514 .11473 L
s
.92735 .09358 m
.95177 .09358 L
s
.92735 .09358 m
.91514 .11473 L
s
.92735 .09358 m
.93956 .11473 L
s
.95177 .09358 m
.97619 .09358 L
s
.95177 .09358 m
.93956 .11473 L
s
.95177 .09358 m
.96398 .11473 L
s
.97619 .09358 m
.96398 .11473 L
s
.97619 .09358 m
.97619 .13588 L
s
.03602 .11473 m
.06044 .11473 L
s
.03602 .11473 m
.02381 .13588 L
s
.03602 .11473 m
.04823 .13588 L
s
.06044 .11473 m
.08486 .11473 L
s
.06044 .11473 m
.04823 .13588 L
s
.06044 .11473 m
.07265 .13588 L
s
.08486 .11473 m
.10928 .11473 L
s
.08486 .11473 m
.07265 .13588 L
s
.08486 .11473 m
.09707 .13588 L
s
.10928 .11473 m
.1337 .11473 L
s
.10928 .11473 m
.09707 .13588 L
s
.10928 .11473 m
.12149 .13588 L
s
.1337 .11473 m
.15812 .11473 L
s
.1337 .11473 m
.12149 .13588 L
s
.1337 .11473 m
.14591 .13588 L
s
.15812 .11473 m
.18254 .11473 L
s
.15812 .11473 m
.14591 .13588 L
s
.15812 .11473 m
.17033 .13588 L
s
.18254 .11473 m
.20696 .11473 L
s
.18254 .11473 m
.17033 .13588 L
s
.18254 .11473 m
.19475 .13588 L
s
.20696 .11473 m
.23138 .11473 L
s
.20696 .11473 m
.19475 .13588 L
s
.20696 .11473 m
.21917 .13588 L
s
.23138 .11473 m
.2558 .11473 L
s
.23138 .11473 m
.21917 .13588 L
s
.23138 .11473 m
.24359 .13588 L
s
.2558 .11473 m
.28022 .11473 L
s
.2558 .11473 m
.24359 .13588 L
s
.2558 .11473 m
.26801 .13588 L
s
.28022 .11473 m
.30464 .11473 L
s
.28022 .11473 m
.26801 .13588 L
s
.28022 .11473 m
.29243 .13588 L
s
.30464 .11473 m
.32906 .11473 L
s
.30464 .11473 m
.29243 .13588 L
s
.30464 .11473 m
.31685 .13588 L
s
.32906 .11473 m
.35348 .11473 L
s
.32906 .11473 m
.31685 .13588 L
s
.32906 .11473 m
.34127 .13588 L
s
.35348 .11473 m
.3779 .11473 L
s
.35348 .11473 m
.34127 .13588 L
s
.35348 .11473 m
.36569 .13588 L
s
.3779 .11473 m
.40232 .11473 L
s
.3779 .11473 m
.36569 .13588 L
s
.3779 .11473 m
.39011 .13588 L
s
.40232 .11473 m
.39011 .13588 L
s
.59768 .11473 m
.6221 .11473 L
s
.59768 .11473 m
.60989 .13588 L
s
.6221 .11473 m
.64652 .11473 L
s
.6221 .11473 m
.60989 .13588 L
s
.6221 .11473 m
.63431 .13588 L
s
.64652 .11473 m
.67094 .11473 L
s
.64652 .11473 m
.63431 .13588 L
s
.64652 .11473 m
.65873 .13588 L
s
.67094 .11473 m
.69536 .11473 L
s
.67094 .11473 m
.65873 .13588 L
s
.67094 .11473 m
.68315 .13588 L
s
.69536 .11473 m
.71978 .11473 L
s
.69536 .11473 m
.68315 .13588 L
s
.69536 .11473 m
.70757 .13588 L
s
.71978 .11473 m
.7442 .11473 L
s
.71978 .11473 m
.70757 .13588 L
s
.71978 .11473 m
.73199 .13588 L
s
.7442 .11473 m
.76862 .11473 L
s
.7442 .11473 m
.73199 .13588 L
s
.7442 .11473 m
.75641 .13588 L
s
.76862 .11473 m
.79304 .11473 L
s
.76862 .11473 m
.75641 .13588 L
s
.76862 .11473 m
.78083 .13588 L
s
.79304 .11473 m
.81746 .11473 L
s
.79304 .11473 m
.78083 .13588 L
s
.79304 .11473 m
.80525 .13588 L
s
.81746 .11473 m
.84188 .11473 L
s
.81746 .11473 m
.80525 .13588 L
s
.81746 .11473 m
.82967 .13588 L
s
.84188 .11473 m
.8663 .11473 L
s
.84188 .11473 m
.82967 .13588 L
s
.84188 .11473 m
.85409 .13588 L
s
.8663 .11473 m
.89072 .11473 L
s
.8663 .11473 m
.85409 .13588 L
s
.8663 .11473 m
.87851 .13588 L
s
.89072 .11473 m
.91514 .11473 L
s
.89072 .11473 m
.87851 .13588 L
s
.89072 .11473 m
.90293 .13588 L
s
.91514 .11473 m
.93956 .11473 L
s
.91514 .11473 m
.90293 .13588 L
s
.91514 .11473 m
.92735 .13588 L
s
.93956 .11473 m
.96398 .11473 L
s
.93956 .11473 m
.92735 .13588 L
s
.93956 .11473 m
.95177 .13588 L
s
.96398 .11473 m
.95177 .13588 L
s
.96398 .11473 m
.97619 .13588 L
s
.02381 .13588 m
.04823 .13588 L
s
.02381 .13588 m
.03602 .15703 L
s
.02381 .13588 m
.02381 .17817 L
s
.04823 .13588 m
.07265 .13588 L
s
.04823 .13588 m
.03602 .15703 L
s
.04823 .13588 m
.06044 .15703 L
s
.07265 .13588 m
.09707 .13588 L
s
.07265 .13588 m
.06044 .15703 L
s
.07265 .13588 m
.08486 .15703 L
s
.09707 .13588 m
.12149 .13588 L
s
.09707 .13588 m
.08486 .15703 L
s
.09707 .13588 m
.10928 .15703 L
s
.12149 .13588 m
.14591 .13588 L
s
.12149 .13588 m
.10928 .15703 L
s
.12149 .13588 m
.1337 .15703 L
s
.14591 .13588 m
.17033 .13588 L
s
.14591 .13588 m
.1337 .15703 L
s
.14591 .13588 m
.15812 .15703 L
s
.17033 .13588 m
.19475 .13588 L
s
.17033 .13588 m
.15812 .15703 L
s
.17033 .13588 m
.18254 .15703 L
s
.19475 .13588 m
.21917 .13588 L
s
.19475 .13588 m
.18254 .15703 L
s
.19475 .13588 m
.20696 .15703 L
s
.21917 .13588 m
.24359 .13588 L
s
.21917 .13588 m
.20696 .15703 L
s
.21917 .13588 m
.23138 .15703 L
s
.24359 .13588 m
.26801 .13588 L
s
.24359 .13588 m
.23138 .15703 L
s
.24359 .13588 m
.2558 .15703 L
s
.26801 .13588 m
.29243 .13588 L
s
.26801 .13588 m
.2558 .15703 L
s
.26801 .13588 m
.28022 .15703 L
s
.29243 .13588 m
.31685 .13588 L
s
.29243 .13588 m
.28022 .15703 L
s
.29243 .13588 m
.30464 .15703 L
s
.31685 .13588 m
.34127 .13588 L
s
.31685 .13588 m
.30464 .15703 L
s
.31685 .13588 m
.32906 .15703 L
s
.34127 .13588 m
.36569 .13588 L
s
.34127 .13588 m
.32906 .15703 L
s
.34127 .13588 m
.35348 .15703 L
s
.36569 .13588 m
.39011 .13588 L
s
.36569 .13588 m
.35348 .15703 L
s
.36569 .13588 m
.3779 .15703 L
s
.39011 .13588 m
.3779 .15703 L
s
.60989 .13588 m
.63431 .13588 L
s
.60989 .13588 m
.6221 .15703 L
s
.63431 .13588 m
.65873 .13588 L
s
.63431 .13588 m
.6221 .15703 L
s
.63431 .13588 m
.64652 .15703 L
s
.65873 .13588 m
.68315 .13588 L
s
.65873 .13588 m
.64652 .15703 L
s
.65873 .13588 m
.67094 .15703 L
s
.68315 .13588 m
.70757 .13588 L
s
.68315 .13588 m
.67094 .15703 L
s
.68315 .13588 m
.69536 .15703 L
s
.70757 .13588 m
.73199 .13588 L
s
.70757 .13588 m
.69536 .15703 L
s
.70757 .13588 m
.71978 .15703 L
s
.73199 .13588 m
.75641 .13588 L
s
.73199 .13588 m
.71978 .15703 L
s
.73199 .13588 m
.7442 .15703 L
s
.75641 .13588 m
.78083 .13588 L
s
.75641 .13588 m
.7442 .15703 L
s
.75641 .13588 m
.76862 .15703 L
s
.78083 .13588 m
.80525 .13588 L
s
.78083 .13588 m
.76862 .15703 L
s
.78083 .13588 m
.79304 .15703 L
s
.80525 .13588 m
.82967 .13588 L
s
.80525 .13588 m
.79304 .15703 L
s
.80525 .13588 m
.81746 .15703 L
s
.82967 .13588 m
.85409 .13588 L
s
.82967 .13588 m
.81746 .15703 L
s
.82967 .13588 m
.84188 .15703 L
s
.85409 .13588 m
.87851 .13588 L
s
.85409 .13588 m
.84188 .15703 L
s
.85409 .13588 m
.8663 .15703 L
s
.87851 .13588 m
.90293 .13588 L
s
.87851 .13588 m
.8663 .15703 L
s
.87851 .13588 m
.89072 .15703 L
s
.90293 .13588 m
.92735 .13588 L
s
.90293 .13588 m
.89072 .15703 L
s
.90293 .13588 m
.91514 .15703 L
s
.92735 .13588 m
.95177 .13588 L
s
.92735 .13588 m
.91514 .15703 L
s
.92735 .13588 m
.93956 .15703 L
s
.95177 .13588 m
.97619 .13588 L
s
.95177 .13588 m
.93956 .15703 L
s
.95177 .13588 m
.96398 .15703 L
s
.97619 .13588 m
.96398 .15703 L
s
.97619 .13588 m
.97619 .17817 L
s
.03602 .15703 m
.06044 .15703 L
s
.03602 .15703 m
.02381 .17817 L
s
.03602 .15703 m
.04823 .17817 L
s
.06044 .15703 m
.08486 .15703 L
s
.06044 .15703 m
.04823 .17817 L
s
.06044 .15703 m
.07265 .17817 L
s
.08486 .15703 m
.10928 .15703 L
s
.08486 .15703 m
.07265 .17817 L
s
.08486 .15703 m
.09707 .17817 L
s
.10928 .15703 m
.1337 .15703 L
s
.10928 .15703 m
.09707 .17817 L
s
.10928 .15703 m
.12149 .17817 L
s
.1337 .15703 m
.15812 .15703 L
s
.1337 .15703 m
.12149 .17817 L
s
.1337 .15703 m
.14591 .17817 L
s
.15812 .15703 m
.18254 .15703 L
s
.15812 .15703 m
.14591 .17817 L
s
.15812 .15703 m
.17033 .17817 L
s
.18254 .15703 m
.20696 .15703 L
s
.18254 .15703 m
.17033 .17817 L
s
.18254 .15703 m
.19475 .17817 L
s
.20696 .15703 m
.23138 .15703 L
s
.20696 .15703 m
.19475 .17817 L
s
.20696 .15703 m
.21917 .17817 L
s
.23138 .15703 m
.2558 .15703 L
s
.23138 .15703 m
.21917 .17817 L
s
.23138 .15703 m
.24359 .17817 L
s
.2558 .15703 m
.28022 .15703 L
s
.2558 .15703 m
.24359 .17817 L
s
.2558 .15703 m
.26801 .17817 L
s
.28022 .15703 m
.30464 .15703 L
s
.28022 .15703 m
.26801 .17817 L
s
.28022 .15703 m
.29243 .17817 L
s
.30464 .15703 m
.32906 .15703 L
s
.30464 .15703 m
.29243 .17817 L
s
.30464 .15703 m
.31685 .17817 L
s
.32906 .15703 m
.35348 .15703 L
s
.32906 .15703 m
.31685 .17817 L
s
.32906 .15703 m
.34127 .17817 L
s
.35348 .15703 m
.3779 .15703 L
s
.35348 .15703 m
.34127 .17817 L
s
.35348 .15703 m
.36569 .17817 L
s
.3779 .15703 m
.36569 .17817 L
s
.3779 .15703 m
.3779 .19932 L
s
.6221 .15703 m
.64652 .15703 L
s
.6221 .15703 m
.63431 .17817 L
s
.6221 .15703 m
.6221 .19932 L
s
.64652 .15703 m
.67094 .15703 L
s
.64652 .15703 m
.63431 .17817 L
s
.64652 .15703 m
.65873 .17817 L
s
.67094 .15703 m
.69536 .15703 L
s
.67094 .15703 m
.65873 .17817 L
s
.67094 .15703 m
.68315 .17817 L
s
.69536 .15703 m
.71978 .15703 L
s
.69536 .15703 m
.68315 .17817 L
s
.69536 .15703 m
.70757 .17817 L
s
.71978 .15703 m
.7442 .15703 L
s
.71978 .15703 m
.70757 .17817 L
s
.71978 .15703 m
.73199 .17817 L
s
.7442 .15703 m
.76862 .15703 L
s
.7442 .15703 m
.73199 .17817 L
s
.7442 .15703 m
.75641 .17817 L
s
.76862 .15703 m
.79304 .15703 L
s
.76862 .15703 m
.75641 .17817 L
s
.76862 .15703 m
.78083 .17817 L
s
.79304 .15703 m
.81746 .15703 L
s
.79304 .15703 m
.78083 .17817 L
s
.79304 .15703 m
.80525 .17817 L
s
.81746 .15703 m
.84188 .15703 L
s
.81746 .15703 m
.80525 .17817 L
s
.81746 .15703 m
.82967 .17817 L
s
.84188 .15703 m
.8663 .15703 L
s
.84188 .15703 m
.82967 .17817 L
s
.84188 .15703 m
.85409 .17817 L
s
.8663 .15703 m
.89072 .15703 L
s
.8663 .15703 m
.85409 .17817 L
s
.8663 .15703 m
.87851 .17817 L
s
.89072 .15703 m
.91514 .15703 L
s
.89072 .15703 m
.87851 .17817 L
s
.89072 .15703 m
.90293 .17817 L
s
.91514 .15703 m
.93956 .15703 L
s
.91514 .15703 m
.90293 .17817 L
s
.91514 .15703 m
.92735 .17817 L
s
.93956 .15703 m
.96398 .15703 L
s
.93956 .15703 m
.92735 .17817 L
s
.93956 .15703 m
.95177 .17817 L
s
.96398 .15703 m
.95177 .17817 L
s
.96398 .15703 m
.97619 .17817 L
s
.02381 .17817 m
.04823 .17817 L
s
.02381 .17817 m
.03602 .19932 L
s
.02381 .17817 m
.02381 .22047 L
s
.04823 .17817 m
.07265 .17817 L
s
.04823 .17817 m
.03602 .19932 L
s
.04823 .17817 m
.06044 .19932 L
s
.07265 .17817 m
.09707 .17817 L
s
.07265 .17817 m
.06044 .19932 L
s
.07265 .17817 m
.08486 .19932 L
s
.09707 .17817 m
.12149 .17817 L
s
.09707 .17817 m
.08486 .19932 L
s
.09707 .17817 m
.10928 .19932 L
s
.12149 .17817 m
.14591 .17817 L
s
.12149 .17817 m
.10928 .19932 L
s
.12149 .17817 m
.1337 .19932 L
s
.14591 .17817 m
.17033 .17817 L
s
.14591 .17817 m
.1337 .19932 L
s
.14591 .17817 m
.15812 .19932 L
s
.17033 .17817 m
.19475 .17817 L
s
.17033 .17817 m
.15812 .19932 L
s
.17033 .17817 m
.18254 .19932 L
s
.19475 .17817 m
.21917 .17817 L
s
.19475 .17817 m
.18254 .19932 L
s
.19475 .17817 m
.20696 .19932 L
s
.21917 .17817 m
.24359 .17817 L
s
.21917 .17817 m
.20696 .19932 L
s
.21917 .17817 m
.23138 .19932 L
s
.24359 .17817 m
.26801 .17817 L
s
.24359 .17817 m
.23138 .19932 L
s
.24359 .17817 m
.2558 .19932 L
s
.26801 .17817 m
.29243 .17817 L
s
.26801 .17817 m
.2558 .19932 L
s
.26801 .17817 m
.28022 .19932 L
s
.29243 .17817 m
.31685 .17817 L
s
.29243 .17817 m
.28022 .19932 L
s
.29243 .17817 m
.30464 .19932 L
s
.31685 .17817 m
.34127 .17817 L
s
.31685 .17817 m
.30464 .19932 L
s
.31685 .17817 m
.32906 .19932 L
s
.34127 .17817 m
.36569 .17817 L
s
.34127 .17817 m
.32906 .19932 L
s
.34127 .17817 m
.35348 .19932 L
s
.36569 .17817 m
.35348 .19932 L
s
.36569 .17817 m
.3779 .19932 L
s
.63431 .17817 m
.65873 .17817 L
s
.63431 .17817 m
.6221 .19932 L
s
.63431 .17817 m
.64652 .19932 L
s
.65873 .17817 m
.68315 .17817 L
s
.65873 .17817 m
.64652 .19932 L
s
.65873 .17817 m
.67094 .19932 L
s
.68315 .17817 m
.70757 .17817 L
s
.68315 .17817 m
.67094 .19932 L
s
.68315 .17817 m
.69536 .19932 L
s
.70757 .17817 m
.73199 .17817 L
s
.70757 .17817 m
.69536 .19932 L
s
.70757 .17817 m
.71978 .19932 L
s
.73199 .17817 m
.75641 .17817 L
s
.73199 .17817 m
.71978 .19932 L
s
.73199 .17817 m
.7442 .19932 L
s
.75641 .17817 m
.78083 .17817 L
s
.75641 .17817 m
.7442 .19932 L
s
.75641 .17817 m
.76862 .19932 L
s
.78083 .17817 m
.80525 .17817 L
s
.78083 .17817 m
.76862 .19932 L
s
.78083 .17817 m
.79304 .19932 L
s
.80525 .17817 m
.82967 .17817 L
s
.80525 .17817 m
.79304 .19932 L
s
.80525 .17817 m
.81746 .19932 L
s
.82967 .17817 m
.85409 .17817 L
s
.82967 .17817 m
.81746 .19932 L
s
.82967 .17817 m
.84188 .19932 L
s
.85409 .17817 m
.87851 .17817 L
s
.85409 .17817 m
.84188 .19932 L
s
.85409 .17817 m
.8663 .19932 L
s
.87851 .17817 m
.90293 .17817 L
s
.87851 .17817 m
.8663 .19932 L
s
.87851 .17817 m
.89072 .19932 L
s
.90293 .17817 m
.92735 .17817 L
s
.90293 .17817 m
.89072 .19932 L
s
.90293 .17817 m
.91514 .19932 L
s
.92735 .17817 m
.95177 .17817 L
s
.92735 .17817 m
.91514 .19932 L
s
.92735 .17817 m
.93956 .19932 L
s
.95177 .17817 m
.97619 .17817 L
s
.95177 .17817 m
.93956 .19932 L
s
.95177 .17817 m
.96398 .19932 L
s
.97619 .17817 m
.96398 .19932 L
s
.97619 .17817 m
.97619 .22047 L
s
.03602 .19932 m
.06044 .19932 L
s
.03602 .19932 m
.02381 .22047 L
s
.03602 .19932 m
.04823 .22047 L
s
.06044 .19932 m
.08486 .19932 L
s
.06044 .19932 m
.04823 .22047 L
s
.06044 .19932 m
.07265 .22047 L
s
.08486 .19932 m
.10928 .19932 L
s
.08486 .19932 m
.07265 .22047 L
s
.08486 .19932 m
.09707 .22047 L
s
.10928 .19932 m
.1337 .19932 L
s
.10928 .19932 m
.09707 .22047 L
s
.10928 .19932 m
.12149 .22047 L
s
.1337 .19932 m
.15812 .19932 L
s
.1337 .19932 m
.12149 .22047 L
s
.1337 .19932 m
.14591 .22047 L
s
.15812 .19932 m
.18254 .19932 L
s
.15812 .19932 m
.14591 .22047 L
s
.15812 .19932 m
.17033 .22047 L
s
.18254 .19932 m
.20696 .19932 L
s
.18254 .19932 m
.17033 .22047 L
s
.18254 .19932 m
.19475 .22047 L
s
.20696 .19932 m
.23138 .19932 L
s
.20696 .19932 m
.19475 .22047 L
s
.20696 .19932 m
.21917 .22047 L
s
.23138 .19932 m
.2558 .19932 L
s
.23138 .19932 m
.21917 .22047 L
s
.23138 .19932 m
.24359 .22047 L
s
.2558 .19932 m
.28022 .19932 L
s
.2558 .19932 m
.24359 .22047 L
s
.2558 .19932 m
.26801 .22047 L
s
.28022 .19932 m
.30464 .19932 L
s
.28022 .19932 m
.26801 .22047 L
s
.28022 .19932 m
.29243 .22047 L
s
.30464 .19932 m
.32906 .19932 L
s
.30464 .19932 m
.29243 .22047 L
s
.30464 .19932 m
.31685 .22047 L
s
.32906 .19932 m
.35348 .19932 L
s
.32906 .19932 m
.31685 .22047 L
s
.32906 .19932 m
.34127 .22047 L
s
.35348 .19932 m
.3779 .19932 L
s
.35348 .19932 m
.34127 .22047 L
s
.35348 .19932 m
.36569 .22047 L
s
.3779 .19932 m
.36569 .22047 L
s
.3779 .19932 m
.3779 .24162 L
s
.3779 .19932 m
.39011 .26277 L
s
.6221 .19932 m
.64652 .19932 L
s
.6221 .19932 m
.63431 .22047 L
s
.6221 .19932 m
.6221 .24162 L
s
.6221 .19932 m
.60989 .26277 L
s
.64652 .19932 m
.67094 .19932 L
s
.64652 .19932 m
.63431 .22047 L
s
.64652 .19932 m
.65873 .22047 L
s
.67094 .19932 m
.69536 .19932 L
s
.67094 .19932 m
.65873 .22047 L
s
.67094 .19932 m
.68315 .22047 L
s
.69536 .19932 m
.71978 .19932 L
s
.69536 .19932 m
.68315 .22047 L
s
.69536 .19932 m
.70757 .22047 L
s
.71978 .19932 m
.7442 .19932 L
s
.71978 .19932 m
.70757 .22047 L
s
.71978 .19932 m
.73199 .22047 L
s
.7442 .19932 m
.76862 .19932 L
s
.7442 .19932 m
.73199 .22047 L
s
.7442 .19932 m
.75641 .22047 L
s
.76862 .19932 m
.79304 .19932 L
s
.76862 .19932 m
.75641 .22047 L
s
.76862 .19932 m
.78083 .22047 L
s
.79304 .19932 m
.81746 .19932 L
s
.79304 .19932 m
.78083 .22047 L
s
.79304 .19932 m
.80525 .22047 L
s
.81746 .19932 m
.84188 .19932 L
s
.81746 .19932 m
.80525 .22047 L
s
.81746 .19932 m
.82967 .22047 L
s
.84188 .19932 m
.8663 .19932 L
s
.84188 .19932 m
.82967 .22047 L
s
.84188 .19932 m
.85409 .22047 L
s
.8663 .19932 m
.89072 .19932 L
s
.8663 .19932 m
.85409 .22047 L
s
.8663 .19932 m
.87851 .22047 L
s
.89072 .19932 m
.91514 .19932 L
s
.89072 .19932 m
.87851 .22047 L
s
.89072 .19932 m
.90293 .22047 L
s
.91514 .19932 m
.93956 .19932 L
s
.91514 .19932 m
.90293 .22047 L
s
.91514 .19932 m
.92735 .22047 L
s
.93956 .19932 m
.96398 .19932 L
s
.93956 .19932 m
.92735 .22047 L
s
.93956 .19932 m
.95177 .22047 L
s
.96398 .19932 m
.95177 .22047 L
s
.96398 .19932 m
.97619 .22047 L
s
.02381 .22047 m
.04823 .22047 L
s
.02381 .22047 m
.03602 .24162 L
s
.02381 .22047 m
.02381 .26277 L
s
.04823 .22047 m
.07265 .22047 L
s
.04823 .22047 m
.03602 .24162 L
s
.04823 .22047 m
.06044 .24162 L
s
.07265 .22047 m
.09707 .22047 L
s
.07265 .22047 m
.06044 .24162 L
s
.07265 .22047 m
.08486 .24162 L
s
.09707 .22047 m
.12149 .22047 L
s
.09707 .22047 m
.08486 .24162 L
s
.09707 .22047 m
.10928 .24162 L
s
.12149 .22047 m
.14591 .22047 L
s
.12149 .22047 m
.10928 .24162 L
s
.12149 .22047 m
.1337 .24162 L
s
.14591 .22047 m
.17033 .22047 L
s
.14591 .22047 m
.1337 .24162 L
s
.14591 .22047 m
.15812 .24162 L
s
.17033 .22047 m
.19475 .22047 L
s
.17033 .22047 m
.15812 .24162 L
s
.17033 .22047 m
.18254 .24162 L
s
.19475 .22047 m
.21917 .22047 L
s
.19475 .22047 m
.18254 .24162 L
s
.19475 .22047 m
.20696 .24162 L
s
.21917 .22047 m
.24359 .22047 L
s
.21917 .22047 m
.20696 .24162 L
s
.21917 .22047 m
.23138 .24162 L
s
.24359 .22047 m
.26801 .22047 L
s
.24359 .22047 m
.23138 .24162 L
s
.24359 .22047 m
.2558 .24162 L
s
.26801 .22047 m
.29243 .22047 L
s
.26801 .22047 m
.2558 .24162 L
s
.26801 .22047 m
.28022 .24162 L
s
.29243 .22047 m
.31685 .22047 L
s
.29243 .22047 m
.28022 .24162 L
s
.29243 .22047 m
.30464 .24162 L
s
.31685 .22047 m
.34127 .22047 L
s
.31685 .22047 m
.30464 .24162 L
s
.31685 .22047 m
.32906 .24162 L
s
.34127 .22047 m
.36569 .22047 L
s
.34127 .22047 m
.32906 .24162 L
s
.34127 .22047 m
.35348 .24162 L
s
.36569 .22047 m
.35348 .24162 L
s
.36569 .22047 m
.3779 .24162 L
s
.63431 .22047 m
.65873 .22047 L
s
.63431 .22047 m
.6221 .24162 L
s
.63431 .22047 m
.64652 .24162 L
s
.65873 .22047 m
.68315 .22047 L
s
.65873 .22047 m
.64652 .24162 L
s
.65873 .22047 m
.67094 .24162 L
s
.68315 .22047 m
.70757 .22047 L
s
.68315 .22047 m
.67094 .24162 L
s
.68315 .22047 m
.69536 .24162 L
s
.70757 .22047 m
.73199 .22047 L
s
.70757 .22047 m
.69536 .24162 L
s
.70757 .22047 m
.71978 .24162 L
s
.73199 .22047 m
.75641 .22047 L
s
.73199 .22047 m
.71978 .24162 L
s
.73199 .22047 m
.7442 .24162 L
s
.75641 .22047 m
.78083 .22047 L
s
.75641 .22047 m
.7442 .24162 L
s
.75641 .22047 m
.76862 .24162 L
s
.78083 .22047 m
.80525 .22047 L
s
.78083 .22047 m
.76862 .24162 L
s
.78083 .22047 m
.79304 .24162 L
s
.80525 .22047 m
.82967 .22047 L
s
.80525 .22047 m
.79304 .24162 L
s
.80525 .22047 m
.81746 .24162 L
s
.82967 .22047 m
.85409 .22047 L
s
.82967 .22047 m
.81746 .24162 L
s
.82967 .22047 m
.84188 .24162 L
s
.85409 .22047 m
.87851 .22047 L
s
.85409 .22047 m
.84188 .24162 L
s
.85409 .22047 m
.8663 .24162 L
s
.87851 .22047 m
.90293 .22047 L
s
.87851 .22047 m
.8663 .24162 L
s
.87851 .22047 m
.89072 .24162 L
s
.90293 .22047 m
.92735 .22047 L
s
.90293 .22047 m
.89072 .24162 L
s
.90293 .22047 m
.91514 .24162 L
s
.92735 .22047 m
.95177 .22047 L
s
.92735 .22047 m
.91514 .24162 L
s
.92735 .22047 m
.93956 .24162 L
s
.95177 .22047 m
.97619 .22047 L
s
.95177 .22047 m
.93956 .24162 L
s
.95177 .22047 m
.96398 .24162 L
s
.97619 .22047 m
.96398 .24162 L
s
.97619 .22047 m
.97619 .26277 L
s
.03602 .24162 m
.06044 .24162 L
s
.03602 .24162 m
.02381 .26277 L
s
.03602 .24162 m
.04823 .26277 L
s
.06044 .24162 m
.08486 .24162 L
s
.06044 .24162 m
.04823 .26277 L
s
.06044 .24162 m
.07265 .26277 L
s
.08486 .24162 m
.10928 .24162 L
s
.08486 .24162 m
.07265 .26277 L
s
.08486 .24162 m
.09707 .26277 L
s
.10928 .24162 m
.1337 .24162 L
s
.10928 .24162 m
.09707 .26277 L
s
.10928 .24162 m
.12149 .26277 L
s
.1337 .24162 m
.15812 .24162 L
s
.1337 .24162 m
.12149 .26277 L
s
.1337 .24162 m
.14591 .26277 L
s
.15812 .24162 m
.18254 .24162 L
s
.15812 .24162 m
.14591 .26277 L
s
.15812 .24162 m
.17033 .26277 L
s
.18254 .24162 m
.20696 .24162 L
s
.18254 .24162 m
.17033 .26277 L
s
.18254 .24162 m
.19475 .26277 L
s
.20696 .24162 m
.23138 .24162 L
s
.20696 .24162 m
.19475 .26277 L
s
.20696 .24162 m
.21917 .26277 L
s
.23138 .24162 m
.2558 .24162 L
s
.23138 .24162 m
.21917 .26277 L
s
.23138 .24162 m
.24359 .26277 L
s
.2558 .24162 m
.28022 .24162 L
s
.2558 .24162 m
.24359 .26277 L
s
.2558 .24162 m
.26801 .26277 L
s
.28022 .24162 m
.30464 .24162 L
s
.28022 .24162 m
.26801 .26277 L
s
.28022 .24162 m
.29243 .26277 L
s
.30464 .24162 m
.32906 .24162 L
s
.30464 .24162 m
.29243 .26277 L
s
.30464 .24162 m
.31685 .26277 L
s
.32906 .24162 m
.35348 .24162 L
s
.32906 .24162 m
.31685 .26277 L
s
.32906 .24162 m
.34127 .26277 L
s
.35348 .24162 m
.3779 .24162 L
s
.35348 .24162 m
.34127 .26277 L
s
.35348 .24162 m
.36569 .26277 L
s
.3779 .24162 m
.36569 .26277 L
s
.3779 .24162 m
.39011 .26277 L
s
.6221 .24162 m
.64652 .24162 L
s
.6221 .24162 m
.60989 .26277 L
s
.6221 .24162 m
.63431 .26277 L
s
.64652 .24162 m
.67094 .24162 L
s
.64652 .24162 m
.63431 .26277 L
s
.64652 .24162 m
.65873 .26277 L
s
.67094 .24162 m
.69536 .24162 L
s
.67094 .24162 m
.65873 .26277 L
s
.67094 .24162 m
.68315 .26277 L
s
.69536 .24162 m
.71978 .24162 L
s
.69536 .24162 m
.68315 .26277 L
s
.69536 .24162 m
.70757 .26277 L
s
.71978 .24162 m
.7442 .24162 L
s
.71978 .24162 m
.70757 .26277 L
s
.71978 .24162 m
.73199 .26277 L
s
.7442 .24162 m
.76862 .24162 L
s
.7442 .24162 m
.73199 .26277 L
s
.7442 .24162 m
.75641 .26277 L
s
.76862 .24162 m
.79304 .24162 L
s
.76862 .24162 m
.75641 .26277 L
s
.76862 .24162 m
.78083 .26277 L
s
.79304 .24162 m
.81746 .24162 L
s
.79304 .24162 m
.78083 .26277 L
s
.79304 .24162 m
.80525 .26277 L
s
.81746 .24162 m
.84188 .24162 L
s
.81746 .24162 m
.80525 .26277 L
s
.81746 .24162 m
.82967 .26277 L
s
.84188 .24162 m
.8663 .24162 L
s
.84188 .24162 m
.82967 .26277 L
s
.84188 .24162 m
.85409 .26277 L
s
.8663 .24162 m
.89072 .24162 L
s
.8663 .24162 m
.85409 .26277 L
s
.8663 .24162 m
.87851 .26277 L
s
.89072 .24162 m
.91514 .24162 L
s
.89072 .24162 m
.87851 .26277 L
s
.89072 .24162 m
.90293 .26277 L
s
.91514 .24162 m
.93956 .24162 L
s
.91514 .24162 m
.90293 .26277 L
s
.91514 .24162 m
.92735 .26277 L
s
.93956 .24162 m
.96398 .24162 L
s
.93956 .24162 m
.92735 .26277 L
s
.93956 .24162 m
.95177 .26277 L
s
.96398 .24162 m
.95177 .26277 L
s
.96398 .24162 m
.97619 .26277 L
s
.02381 .26277 m
.04823 .26277 L
s
.02381 .26277 m
.03602 .28392 L
s
.02381 .26277 m
.02381 .30507 L
s
.04823 .26277 m
.07265 .26277 L
s
.04823 .26277 m
.03602 .28392 L
s
.04823 .26277 m
.06044 .28392 L
s
.07265 .26277 m
.09707 .26277 L
s
.07265 .26277 m
.06044 .28392 L
s
.07265 .26277 m
.08486 .28392 L
s
.09707 .26277 m
.12149 .26277 L
s
.09707 .26277 m
.08486 .28392 L
s
.09707 .26277 m
.10928 .28392 L
s
.12149 .26277 m
.14591 .26277 L
s
.12149 .26277 m
.10928 .28392 L
s
.12149 .26277 m
.1337 .28392 L
s
.14591 .26277 m
.17033 .26277 L
s
.14591 .26277 m
.1337 .28392 L
s
.14591 .26277 m
.15812 .28392 L
s
.17033 .26277 m
.19475 .26277 L
s
.17033 .26277 m
.15812 .28392 L
s
.17033 .26277 m
.18254 .28392 L
s
.19475 .26277 m
.21917 .26277 L
s
.19475 .26277 m
.18254 .28392 L
s
.19475 .26277 m
.20696 .28392 L
s
.21917 .26277 m
.24359 .26277 L
s
.21917 .26277 m
.20696 .28392 L
s
.21917 .26277 m
.23138 .28392 L
s
.24359 .26277 m
.26801 .26277 L
s
.24359 .26277 m
.23138 .28392 L
s
.24359 .26277 m
.2558 .28392 L
s
.26801 .26277 m
.29243 .26277 L
s
.26801 .26277 m
.2558 .28392 L
s
.26801 .26277 m
.28022 .28392 L
s
.29243 .26277 m
.31685 .26277 L
s
.29243 .26277 m
.28022 .28392 L
s
.29243 .26277 m
.30464 .28392 L
s
.31685 .26277 m
.34127 .26277 L
s
.31685 .26277 m
.30464 .28392 L
s
.31685 .26277 m
.32906 .28392 L
s
.34127 .26277 m
.36569 .26277 L
s
.34127 .26277 m
.32906 .28392 L
s
.34127 .26277 m
.35348 .28392 L
s
.36569 .26277 m
.39011 .26277 L
s
.36569 .26277 m
.35348 .28392 L
s
.36569 .26277 m
.3779 .28392 L
s
.39011 .26277 m
.3779 .28392 L
s
.39011 .26277 m
.40232 .28392 L
s
.39011 .26277 m
.43895 .30507 L
s
.60989 .26277 m
.63431 .26277 L
s
.60989 .26277 m
.59768 .28392 L
s
.60989 .26277 m
.6221 .28392 L
s
.60989 .26277 m
.56105 .30507 L
s
.63431 .26277 m
.65873 .26277 L
s
.63431 .26277 m
.6221 .28392 L
s
.63431 .26277 m
.64652 .28392 L
s
.65873 .26277 m
.68315 .26277 L
s
.65873 .26277 m
.64652 .28392 L
s
.65873 .26277 m
.67094 .28392 L
s
.68315 .26277 m
.70757 .26277 L
s
.68315 .26277 m
.67094 .28392 L
s
.68315 .26277 m
.69536 .28392 L
s
.70757 .26277 m
.73199 .26277 L
s
.70757 .26277 m
.69536 .28392 L
s
.70757 .26277 m
.71978 .28392 L
s
.73199 .26277 m
.75641 .26277 L
s
.73199 .26277 m
.71978 .28392 L
s
.73199 .26277 m
.7442 .28392 L
s
.75641 .26277 m
.78083 .26277 L
s
.75641 .26277 m
.7442 .28392 L
s
.75641 .26277 m
.76862 .28392 L
s
.78083 .26277 m
.80525 .26277 L
s
.78083 .26277 m
.76862 .28392 L
s
.78083 .26277 m
.79304 .28392 L
s
.80525 .26277 m
.82967 .26277 L
s
.80525 .26277 m
.79304 .28392 L
s
.80525 .26277 m
.81746 .28392 L
s
.82967 .26277 m
.85409 .26277 L
s
.82967 .26277 m
.81746 .28392 L
s
.82967 .26277 m
.84188 .28392 L
s
.85409 .26277 m
.87851 .26277 L
s
.85409 .26277 m
.84188 .28392 L
s
.85409 .26277 m
.8663 .28392 L
s
.87851 .26277 m
.90293 .26277 L
s
.87851 .26277 m
.8663 .28392 L
s
.87851 .26277 m
.89072 .28392 L
s
.90293 .26277 m
.92735 .26277 L
s
.90293 .26277 m
.89072 .28392 L
s
.90293 .26277 m
.91514 .28392 L
s
.92735 .26277 m
.95177 .26277 L
s
.92735 .26277 m
.91514 .28392 L
s
.92735 .26277 m
.93956 .28392 L
s
.95177 .26277 m
.97619 .26277 L
s
.95177 .26277 m
.93956 .28392 L
s
.95177 .26277 m
.96398 .28392 L
s
.97619 .26277 m
.96398 .28392 L
s
.97619 .26277 m
.97619 .30507 L
s
.03602 .28392 m
.06044 .28392 L
s
.03602 .28392 m
.02381 .30507 L
s
.03602 .28392 m
.04823 .30507 L
s
.06044 .28392 m
.08486 .28392 L
s
.06044 .28392 m
.04823 .30507 L
s
.06044 .28392 m
.07265 .30507 L
s
.08486 .28392 m
.10928 .28392 L
s
.08486 .28392 m
.07265 .30507 L
s
.08486 .28392 m
.09707 .30507 L
s
.10928 .28392 m
.1337 .28392 L
s
.10928 .28392 m
.09707 .30507 L
s
.10928 .28392 m
.12149 .30507 L
s
.1337 .28392 m
.15812 .28392 L
s
.1337 .28392 m
.12149 .30507 L
s
.1337 .28392 m
.14591 .30507 L
s
.15812 .28392 m
.18254 .28392 L
s
.15812 .28392 m
.14591 .30507 L
s
.15812 .28392 m
.17033 .30507 L
s
.18254 .28392 m
.20696 .28392 L
s
.18254 .28392 m
.17033 .30507 L
s
.18254 .28392 m
.19475 .30507 L
s
.20696 .28392 m
.23138 .28392 L
s
.20696 .28392 m
.19475 .30507 L
s
.20696 .28392 m
.21917 .30507 L
s
.23138 .28392 m
.2558 .28392 L
s
.23138 .28392 m
.21917 .30507 L
s
.23138 .28392 m
.24359 .30507 L
s
.2558 .28392 m
.28022 .28392 L
s
.2558 .28392 m
.24359 .30507 L
s
.2558 .28392 m
.26801 .30507 L
s
.28022 .28392 m
.30464 .28392 L
s
.28022 .28392 m
.26801 .30507 L
s
.28022 .28392 m
.29243 .30507 L
s
.30464 .28392 m
.32906 .28392 L
s
.30464 .28392 m
.29243 .30507 L
s
.30464 .28392 m
.31685 .30507 L
s
.32906 .28392 m
.35348 .28392 L
s
.32906 .28392 m
.31685 .30507 L
s
.32906 .28392 m
.34127 .30507 L
s
.35348 .28392 m
.3779 .28392 L
s
.35348 .28392 m
.34127 .30507 L
s
.35348 .28392 m
.36569 .30507 L
s
.3779 .28392 m
.40232 .28392 L
s
.3779 .28392 m
.36569 .30507 L
s
.3779 .28392 m
.39011 .30507 L
s
.40232 .28392 m
.39011 .30507 L
s
.40232 .28392 m
.41453 .30507 L
s
.40232 .28392 m
.43895 .30507 L
s
.59768 .28392 m
.6221 .28392 L
s
.59768 .28392 m
.56105 .30507 L
s
.59768 .28392 m
.58547 .30507 L
s
.59768 .28392 m
.60989 .30507 L
s
.6221 .28392 m
.64652 .28392 L
s
.6221 .28392 m
.60989 .30507 L
s
.6221 .28392 m
.63431 .30507 L
s
.64652 .28392 m
.67094 .28392 L
s
.64652 .28392 m
.63431 .30507 L
s
.64652 .28392 m
.65873 .30507 L
s
.67094 .28392 m
.69536 .28392 L
s
.67094 .28392 m
.65873 .30507 L
s
.67094 .28392 m
.68315 .30507 L
s
.69536 .28392 m
.71978 .28392 L
s
.69536 .28392 m
.68315 .30507 L
s
.69536 .28392 m
.70757 .30507 L
s
.71978 .28392 m
.7442 .28392 L
s
.71978 .28392 m
.70757 .30507 L
s
.71978 .28392 m
.73199 .30507 L
s
.7442 .28392 m
.76862 .28392 L
s
.7442 .28392 m
.73199 .30507 L
s
.7442 .28392 m
.75641 .30507 L
s
.76862 .28392 m
.79304 .28392 L
s
.76862 .28392 m
.75641 .30507 L
s
.76862 .28392 m
.78083 .30507 L
s
.79304 .28392 m
.81746 .28392 L
s
.79304 .28392 m
.78083 .30507 L
s
.79304 .28392 m
.80525 .30507 L
s
.81746 .28392 m
.84188 .28392 L
s
.81746 .28392 m
.80525 .30507 L
s
.81746 .28392 m
.82967 .30507 L
s
.84188 .28392 m
.8663 .28392 L
s
.84188 .28392 m
.82967 .30507 L
s
.84188 .28392 m
.85409 .30507 L
s
.8663 .28392 m
.89072 .28392 L
s
.8663 .28392 m
.85409 .30507 L
s
.8663 .28392 m
.87851 .30507 L
s
.89072 .28392 m
.91514 .28392 L
s
.89072 .28392 m
.87851 .30507 L
s
.89072 .28392 m
.90293 .30507 L
s
.91514 .28392 m
.93956 .28392 L
s
.91514 .28392 m
.90293 .30507 L
s
.91514 .28392 m
.92735 .30507 L
s
.93956 .28392 m
.96398 .28392 L
s
.93956 .28392 m
.92735 .30507 L
s
.93956 .28392 m
.95177 .30507 L
s
.96398 .28392 m
.95177 .30507 L
s
.96398 .28392 m
.97619 .30507 L
s
.02381 .30507 m
.04823 .30507 L
s
.02381 .30507 m
.03602 .32621 L
s
.02381 .30507 m
.02381 .34736 L
s
.04823 .30507 m
.07265 .30507 L
s
.04823 .30507 m
.03602 .32621 L
s
.04823 .30507 m
.06044 .32621 L
s
.07265 .30507 m
.09707 .30507 L
s
.07265 .30507 m
.06044 .32621 L
s
.07265 .30507 m
.08486 .32621 L
s
.09707 .30507 m
.12149 .30507 L
s
.09707 .30507 m
.08486 .32621 L
s
.09707 .30507 m
.10928 .32621 L
s
.12149 .30507 m
.14591 .30507 L
s
.12149 .30507 m
.10928 .32621 L
s
.12149 .30507 m
.1337 .32621 L
s
.14591 .30507 m
.17033 .30507 L
s
.14591 .30507 m
.1337 .32621 L
s
.14591 .30507 m
.15812 .32621 L
s
.17033 .30507 m
.19475 .30507 L
s
.17033 .30507 m
.15812 .32621 L
s
.17033 .30507 m
.18254 .32621 L
s
.19475 .30507 m
.21917 .30507 L
s
.19475 .30507 m
.18254 .32621 L
s
.19475 .30507 m
.20696 .32621 L
s
.21917 .30507 m
.24359 .30507 L
s
.21917 .30507 m
.20696 .32621 L
s
.21917 .30507 m
.23138 .32621 L
s
.24359 .30507 m
.26801 .30507 L
s
.24359 .30507 m
.23138 .32621 L
s
.24359 .30507 m
.2558 .32621 L
s
.26801 .30507 m
.29243 .30507 L
s
.26801 .30507 m
.2558 .32621 L
s
.26801 .30507 m
.28022 .32621 L
s
.29243 .30507 m
.31685 .30507 L
s
.29243 .30507 m
.28022 .32621 L
s
.29243 .30507 m
.30464 .32621 L
s
.31685 .30507 m
.34127 .30507 L
s
.31685 .30507 m
.30464 .32621 L
s
.31685 .30507 m
.32906 .32621 L
s
.34127 .30507 m
.36569 .30507 L
s
.34127 .30507 m
.32906 .32621 L
s
.34127 .30507 m
.35348 .32621 L
s
.36569 .30507 m
.39011 .30507 L
s
.36569 .30507 m
.35348 .32621 L
s
.36569 .30507 m
.3779 .32621 L
s
.39011 .30507 m
.41453 .30507 L
s
.39011 .30507 m
.3779 .32621 L
s
.39011 .30507 m
.40232 .32621 L
s
.41453 .30507 m
.43895 .30507 L
s
.41453 .30507 m
.40232 .32621 L
s
.41453 .30507 m
.42674 .32621 L
s
.43895 .30507 m
.42674 .32621 L
s
.43895 .30507 m
.45116 .32621 L
s
.43895 .30507 m
.47558 .32621 L
s
.43895 .30507 m
.5 .32621 L
s
.56105 .30507 m
.58547 .30507 L
s
.56105 .30507 m
.5 .32621 L
s
.56105 .30507 m
.52442 .32621 L
s
.56105 .30507 m
.54884 .32621 L
s
.56105 .30507 m
.57326 .32621 L
s
.58547 .30507 m
.60989 .30507 L
s
.58547 .30507 m
.57326 .32621 L
s
.58547 .30507 m
.59768 .32621 L
s
.60989 .30507 m
.63431 .30507 L
s
.60989 .30507 m
.59768 .32621 L
s
.60989 .30507 m
.6221 .32621 L
s
.63431 .30507 m
.65873 .30507 L
s
.63431 .30507 m
.6221 .32621 L
s
.63431 .30507 m
.64652 .32621 L
s
.65873 .30507 m
.68315 .30507 L
s
.65873 .30507 m
.64652 .32621 L
s
.65873 .30507 m
.67094 .32621 L
s
.68315 .30507 m
.70757 .30507 L
s
.68315 .30507 m
.67094 .32621 L
s
.68315 .30507 m
.69536 .32621 L
s
.70757 .30507 m
.73199 .30507 L
s
.70757 .30507 m
.69536 .32621 L
s
.70757 .30507 m
.71978 .32621 L
s
.73199 .30507 m
.75641 .30507 L
s
.73199 .30507 m
.71978 .32621 L
s
.73199 .30507 m
.7442 .32621 L
s
.75641 .30507 m
.78083 .30507 L
s
.75641 .30507 m
.7442 .32621 L
s
.75641 .30507 m
.76862 .32621 L
s
.78083 .30507 m
.80525 .30507 L
s
.78083 .30507 m
.76862 .32621 L
s
.78083 .30507 m
.79304 .32621 L
s
.80525 .30507 m
.82967 .30507 L
s
.80525 .30507 m
.79304 .32621 L
s
.80525 .30507 m
.81746 .32621 L
s
.82967 .30507 m
.85409 .30507 L
s
.82967 .30507 m
.81746 .32621 L
s
.82967 .30507 m
.84188 .32621 L
s
.85409 .30507 m
.87851 .30507 L
s
.85409 .30507 m
.84188 .32621 L
s
.85409 .30507 m
.8663 .32621 L
s
.87851 .30507 m
.90293 .30507 L
s
.87851 .30507 m
.8663 .32621 L
s
.87851 .30507 m
.89072 .32621 L
s
.90293 .30507 m
.92735 .30507 L
s
.90293 .30507 m
.89072 .32621 L
s
.90293 .30507 m
.91514 .32621 L
s
.92735 .30507 m
.95177 .30507 L
s
.92735 .30507 m
.91514 .32621 L
s
.92735 .30507 m
.93956 .32621 L
s
.95177 .30507 m
.97619 .30507 L
s
.95177 .30507 m
.93956 .32621 L
s
.95177 .30507 m
.96398 .32621 L
s
.97619 .30507 m
.96398 .32621 L
s
.97619 .30507 m
.97619 .34736 L
s
.03602 .32621 m
.06044 .32621 L
s
.03602 .32621 m
.02381 .34736 L
s
.03602 .32621 m
.04823 .34736 L
s
.06044 .32621 m
.08486 .32621 L
s
.06044 .32621 m
.04823 .34736 L
s
.06044 .32621 m
.07265 .34736 L
s
.08486 .32621 m
.10928 .32621 L
s
.08486 .32621 m
.07265 .34736 L
s
.08486 .32621 m
.09707 .34736 L
s
.10928 .32621 m
.1337 .32621 L
s
.10928 .32621 m
.09707 .34736 L
s
.10928 .32621 m
.12149 .34736 L
s
.1337 .32621 m
.15812 .32621 L
s
.1337 .32621 m
.12149 .34736 L
s
.1337 .32621 m
.14591 .34736 L
s
.15812 .32621 m
.18254 .32621 L
s
.15812 .32621 m
.14591 .34736 L
s
.15812 .32621 m
.17033 .34736 L
s
.18254 .32621 m
.20696 .32621 L
s
.18254 .32621 m
.17033 .34736 L
s
.18254 .32621 m
.19475 .34736 L
s
.20696 .32621 m
.23138 .32621 L
s
.20696 .32621 m
.19475 .34736 L
s
.20696 .32621 m
.21917 .34736 L
s
.23138 .32621 m
.2558 .32621 L
s
.23138 .32621 m
.21917 .34736 L
s
.23138 .32621 m
.24359 .34736 L
s
.2558 .32621 m
.28022 .32621 L
s
.2558 .32621 m
.24359 .34736 L
s
.2558 .32621 m
.26801 .34736 L
s
.28022 .32621 m
.30464 .32621 L
s
.28022 .32621 m
.26801 .34736 L
s
.28022 .32621 m
.29243 .34736 L
s
.30464 .32621 m
.32906 .32621 L
s
.30464 .32621 m
.29243 .34736 L
s
.30464 .32621 m
.31685 .34736 L
s
.32906 .32621 m
.35348 .32621 L
s
.32906 .32621 m
.31685 .34736 L
s
.32906 .32621 m
.34127 .34736 L
s
.35348 .32621 m
.3779 .32621 L
s
.35348 .32621 m
.34127 .34736 L
s
.35348 .32621 m
.36569 .34736 L
s
.3779 .32621 m
.40232 .32621 L
s
.3779 .32621 m
.36569 .34736 L
s
.3779 .32621 m
.39011 .34736 L
s
.40232 .32621 m
.42674 .32621 L
s
.40232 .32621 m
.39011 .34736 L
s
.40232 .32621 m
.41453 .34736 L
s
.42674 .32621 m
.45116 .32621 L
s
.42674 .32621 m
.41453 .34736 L
s
.42674 .32621 m
.43895 .34736 L
s
.45116 .32621 m
.47558 .32621 L
s
.45116 .32621 m
.43895 .34736 L
s
.45116 .32621 m
.46337 .34736 L
s
.47558 .32621 m
.5 .32621 L
s
.47558 .32621 m
.46337 .34736 L
s
.47558 .32621 m
.48779 .34736 L
s
.5 .32621 m
.52442 .32621 L
s
.5 .32621 m
.48779 .34736 L
s
.5 .32621 m
.51221 .34736 L
s
.52442 .32621 m
.54884 .32621 L
s
.52442 .32621 m
.51221 .34736 L
s
.52442 .32621 m
.53663 .34736 L
s
.54884 .32621 m
.57326 .32621 L
s
.54884 .32621 m
.53663 .34736 L
s
.54884 .32621 m
.56105 .34736 L
s
.57326 .32621 m
.59768 .32621 L
s
.57326 .32621 m
.56105 .34736 L
s
.57326 .32621 m
.58547 .34736 L
s
.59768 .32621 m
.6221 .32621 L
s
.59768 .32621 m
.58547 .34736 L
s
.59768 .32621 m
.60989 .34736 L
s
.6221 .32621 m
.64652 .32621 L
s
.6221 .32621 m
.60989 .34736 L
s
.6221 .32621 m
.63431 .34736 L
s
.64652 .32621 m
.67094 .32621 L
s
.64652 .32621 m
.63431 .34736 L
s
.64652 .32621 m
.65873 .34736 L
s
.67094 .32621 m
.69536 .32621 L
s
.67094 .32621 m
.65873 .34736 L
s
.67094 .32621 m
.68315 .34736 L
s
.69536 .32621 m
.71978 .32621 L
s
.69536 .32621 m
.68315 .34736 L
s
.69536 .32621 m
.70757 .34736 L
s
.71978 .32621 m
.7442 .32621 L
s
.71978 .32621 m
.70757 .34736 L
s
.71978 .32621 m
.73199 .34736 L
s
.7442 .32621 m
.76862 .32621 L
s
.7442 .32621 m
.73199 .34736 L
s
.7442 .32621 m
.75641 .34736 L
s
.76862 .32621 m
.79304 .32621 L
s
.76862 .32621 m
.75641 .34736 L
s
.76862 .32621 m
.78083 .34736 L
s
.79304 .32621 m
.81746 .32621 L
s
.79304 .32621 m
.78083 .34736 L
s
.79304 .32621 m
.80525 .34736 L
s
.81746 .32621 m
.84188 .32621 L
s
.81746 .32621 m
.80525 .34736 L
s
.81746 .32621 m
.82967 .34736 L
s
.84188 .32621 m
.8663 .32621 L
s
.84188 .32621 m
.82967 .34736 L
s
.84188 .32621 m
.85409 .34736 L
s
.8663 .32621 m
.89072 .32621 L
s
.8663 .32621 m
.85409 .34736 L
s
.8663 .32621 m
.87851 .34736 L
s
.89072 .32621 m
.91514 .32621 L
s
.89072 .32621 m
.87851 .34736 L
s
.89072 .32621 m
.90293 .34736 L
s
.91514 .32621 m
.93956 .32621 L
s
.91514 .32621 m
.90293 .34736 L
s
.91514 .32621 m
.92735 .34736 L
s
.93956 .32621 m
.96398 .32621 L
s
.93956 .32621 m
.92735 .34736 L
s
.93956 .32621 m
.95177 .34736 L
s
.96398 .32621 m
.95177 .34736 L
s
.96398 .32621 m
.97619 .34736 L
s
.02381 .34736 m
.04823 .34736 L
s
.02381 .34736 m
.03602 .36851 L
s
.04823 .34736 m
.07265 .34736 L
s
.04823 .34736 m
.03602 .36851 L
s
.04823 .34736 m
.06044 .36851 L
s
.07265 .34736 m
.09707 .34736 L
s
.07265 .34736 m
.06044 .36851 L
s
.07265 .34736 m
.08486 .36851 L
s
.09707 .34736 m
.12149 .34736 L
s
.09707 .34736 m
.08486 .36851 L
s
.09707 .34736 m
.10928 .36851 L
s
.12149 .34736 m
.14591 .34736 L
s
.12149 .34736 m
.10928 .36851 L
s
.12149 .34736 m
.1337 .36851 L
s
.14591 .34736 m
.17033 .34736 L
s
.14591 .34736 m
.1337 .36851 L
s
.14591 .34736 m
.15812 .36851 L
s
.17033 .34736 m
.19475 .34736 L
s
.17033 .34736 m
.15812 .36851 L
s
.17033 .34736 m
.18254 .36851 L
s
.19475 .34736 m
.21917 .34736 L
s
.19475 .34736 m
.18254 .36851 L
s
.19475 .34736 m
.20696 .36851 L
s
.21917 .34736 m
.24359 .34736 L
s
.21917 .34736 m
.20696 .36851 L
s
.21917 .34736 m
.23138 .36851 L
s
.24359 .34736 m
.26801 .34736 L
s
.24359 .34736 m
.23138 .36851 L
s
.24359 .34736 m
.2558 .36851 L
s
.26801 .34736 m
.29243 .34736 L
s
.26801 .34736 m
.2558 .36851 L
s
.26801 .34736 m
.28022 .36851 L
s
.29243 .34736 m
.31685 .34736 L
s
.29243 .34736 m
.28022 .36851 L
s
.29243 .34736 m
.30464 .36851 L
s
.31685 .34736 m
.34127 .34736 L
s
.31685 .34736 m
.30464 .36851 L
s
.31685 .34736 m
.32906 .36851 L
s
.34127 .34736 m
.36569 .34736 L
s
.34127 .34736 m
.32906 .36851 L
s
.34127 .34736 m
.35348 .36851 L
s
.36569 .34736 m
.39011 .34736 L
s
.36569 .34736 m
.35348 .36851 L
s
.36569 .34736 m
.3779 .36851 L
s
.39011 .34736 m
.41453 .34736 L
s
.39011 .34736 m
.3779 .36851 L
s
.39011 .34736 m
.40232 .36851 L
s
.41453 .34736 m
.43895 .34736 L
s
.41453 .34736 m
.40232 .36851 L
s
.41453 .34736 m
.42674 .36851 L
s
.43895 .34736 m
.46337 .34736 L
s
.43895 .34736 m
.42674 .36851 L
s
.43895 .34736 m
.45116 .36851 L
s
.46337 .34736 m
.48779 .34736 L
s
.46337 .34736 m
.45116 .36851 L
s
.46337 .34736 m
.47558 .36851 L
s
.48779 .34736 m
.51221 .34736 L
s
.48779 .34736 m
.47558 .36851 L
s
.48779 .34736 m
.5 .36851 L
s
.51221 .34736 m
.53663 .34736 L
s
.51221 .34736 m
.5 .36851 L
s
.51221 .34736 m
.52442 .36851 L
s
.53663 .34736 m
.56105 .34736 L
s
.53663 .34736 m
.52442 .36851 L
s
.53663 .34736 m
.54884 .36851 L
s
.56105 .34736 m
.58547 .34736 L
s
.56105 .34736 m
.54884 .36851 L
s
.56105 .34736 m
.57326 .36851 L
s
.58547 .34736 m
.60989 .34736 L
s
.58547 .34736 m
.57326 .36851 L
s
.58547 .34736 m
.59768 .36851 L
s
.60989 .34736 m
.63431 .34736 L
s
.60989 .34736 m
.59768 .36851 L
s
.60989 .34736 m
.6221 .36851 L
s
.63431 .34736 m
.65873 .34736 L
s
.63431 .34736 m
.6221 .36851 L
s
.63431 .34736 m
.64652 .36851 L
s
.65873 .34736 m
.68315 .34736 L
s
.65873 .34736 m
.64652 .36851 L
s
.65873 .34736 m
.67094 .36851 L
s
.68315 .34736 m
.70757 .34736 L
s
.68315 .34736 m
.67094 .36851 L
s
.68315 .34736 m
.69536 .36851 L
s
.70757 .34736 m
.73199 .34736 L
s
.70757 .34736 m
.69536 .36851 L
s
.70757 .34736 m
.71978 .36851 L
s
.73199 .34736 m
.75641 .34736 L
s
.73199 .34736 m
.71978 .36851 L
s
.73199 .34736 m
.7442 .36851 L
s
.75641 .34736 m
.78083 .34736 L
s
.75641 .34736 m
.7442 .36851 L
s
.75641 .34736 m
.76862 .36851 L
s
.78083 .34736 m
.80525 .34736 L
s
.78083 .34736 m
.76862 .36851 L
s
.78083 .34736 m
.79304 .36851 L
s
.80525 .34736 m
.82967 .34736 L
s
.80525 .34736 m
.79304 .36851 L
s
.80525 .34736 m
.81746 .36851 L
s
.82967 .34736 m
.85409 .34736 L
s
.82967 .34736 m
.81746 .36851 L
s
.82967 .34736 m
.84188 .36851 L
s
.85409 .34736 m
.87851 .34736 L
s
.85409 .34736 m
.84188 .36851 L
s
.85409 .34736 m
.8663 .36851 L
s
.87851 .34736 m
.90293 .34736 L
s
.87851 .34736 m
.8663 .36851 L
s
.87851 .34736 m
.89072 .36851 L
s
.90293 .34736 m
.92735 .34736 L
s
.90293 .34736 m
.89072 .36851 L
s
.90293 .34736 m
.91514 .36851 L
s
.92735 .34736 m
.95177 .34736 L
s
.92735 .34736 m
.91514 .36851 L
s
.92735 .34736 m
.93956 .36851 L
s
.95177 .34736 m
.97619 .34736 L
s
.95177 .34736 m
.93956 .36851 L
s
.95177 .34736 m
.96398 .36851 L
s
.97619 .34736 m
.96398 .36851 L
s
.03602 .36851 m
.06044 .36851 L
s
.06044 .36851 m
.08486 .36851 L
s
.08486 .36851 m
.10928 .36851 L
s
.10928 .36851 m
.1337 .36851 L
s
.1337 .36851 m
.15812 .36851 L
s
.15812 .36851 m
.18254 .36851 L
s
.18254 .36851 m
.20696 .36851 L
s
.20696 .36851 m
.23138 .36851 L
s
.23138 .36851 m
.2558 .36851 L
s
.2558 .36851 m
.28022 .36851 L
s
.28022 .36851 m
.30464 .36851 L
s
.30464 .36851 m
.32906 .36851 L
s
.32906 .36851 m
.35348 .36851 L
s
.35348 .36851 m
.3779 .36851 L
s
.3779 .36851 m
.40232 .36851 L
s
.40232 .36851 m
.42674 .36851 L
s
.42674 .36851 m
.45116 .36851 L
s
.45116 .36851 m
.47558 .36851 L
s
.47558 .36851 m
.5 .36851 L
s
.5 .36851 m
.52442 .36851 L
s
.52442 .36851 m
.54884 .36851 L
s
.54884 .36851 m
.57326 .36851 L
s
.57326 .36851 m
.59768 .36851 L
s
.59768 .36851 m
.6221 .36851 L
s
.6221 .36851 m
.64652 .36851 L
s
.64652 .36851 m
.67094 .36851 L
s
.67094 .36851 m
.69536 .36851 L
s
.69536 .36851 m
.71978 .36851 L
s
.71978 .36851 m
.7442 .36851 L
s
.7442 .36851 m
.76862 .36851 L
s
.76862 .36851 m
.79304 .36851 L
s
.79304 .36851 m
.81746 .36851 L
s
.81746 .36851 m
.84188 .36851 L
s
.84188 .36851 m
.8663 .36851 L
s
.8663 .36851 m
.89072 .36851 L
s
.89072 .36851 m
.91514 .36851 L
s
.91514 .36851 m
.93956 .36851 L
s
.93956 .36851 m
.96398 .36851 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 108.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0000Xa000`40O003h00Oofmk/Fmk003oKg^a
Kg/00?m_Nk5_N`00ofmk/Fmk000;Kg_o002J000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk
00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_
N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03
001_Nfmk00Y_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk
000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_
N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Nol0090000A_N`03001_Nfmk
00Y_N`002fmk00@006mkKg]_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_
N`03001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_
N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_
N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_
N`8000Q_N`03001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_
N`8000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0002Kg/00`00Kg]_N`04
Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk
00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_
Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk
00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk
0006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk0000
1Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_
N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/0
1000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/0
00I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000=_N`03001_Nfmk00Y_N`002fmk
00@006mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00004
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/01000Kg]_N`0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`00
00a_N`002fmk0P001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mk
Kg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006
Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk
00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04
001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_
N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04
001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`00
1fmk00@006mkKg/000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05
001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/00`00
Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_
N`002fmk00<006mkKg/01Vmk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk
00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk
000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk0P002Fmk0P0026mk
0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk
0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk
0P0036mk000;Kg_o002J000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
Nfmk00M_N`80009_N`<000I_N`8000U_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mkKg/01Fmk0P001fmk
0`001Fmk0P001fmk00<006mkKg/01Fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/0
0`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00A_N`8000a_
N`<000A_N`8000I_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<0
06mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0?Kg/20004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`04001_Nfmk0003
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00004Kg/2000DKg/30002
Kg/20004Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk
00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00002Kg/2000IKg/300000fmk00000002Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00@006mk001_N`8001i_N`D00004Kg/006mk0007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00@0
06mk000002=_N`@00003Kg/006mk00I_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00<006mkKg/00Vmk/`00:6mk]00016mk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_Nfmk00I_N`8002]_N`8000Q_N`03001_Nfmk00I_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_
Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg]_N`04Kg/2000_Kg/20006Kg/00`00
Kg]_N`06Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/00`00Kg]_N`03Kg/2000cKg/20005Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mk
Kg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0eKg/00`00
Kg]_N`03Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`03001_N`0000E_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00@006mkKg]_N`8003U_N`8000=_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk0000
36mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk0P00?Fmk0P000Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`03001_N`0000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00@006mk001_N`80045_N`800004Kg/006mk0007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2
000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`04001_N`000015Kg/200000fmk001_N`06Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_NjP004U_
NjP000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mkKg/0BFmk00<006mkKg/01Fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg]_N`19Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk04]_N`03
001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`1;Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
N`0000a_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000Cfmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;
Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk0000Cfmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00009_N`03001_Nfmk00Y_N`002fmk
00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/0001AKg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk0000DFmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/00`00Kg]_N`02Kg^N001CKg^N0004
Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mkKg/0Dfmk00<006mkKg/01Fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00000fmk00<006mkKg/0
2Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_Nfmk05=_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00@0
06mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/0EFmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk
00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk
05E_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk
009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0005U_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/00`00Kg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0001I
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/00`00Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0005]_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000Ffmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg^N001MKg^N
000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_Nfmk05e_N`03001_Nfmk00I_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mkKg/0GFmk00<006mkKg/01Vmk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`03001_Nfmk05m_N`03001_Nfmk
00A_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk
000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<0
06mkKg/0Gfmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_N`0000a_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`1QKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`00009_N`03001_Nfmk00Y_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000Hfmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;
Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0006E_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000=_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0001UKg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk
009_Ni@006M_Ni@000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/2001WKg/20008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk0P00Ifmk0P0026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/0
1000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`03001_N`00
06M_N`03001_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk
00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`04
001_Nfmk001WKg/01000Kg]_N`001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00
Kg]_N`0:Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/01000Kg]_
N`00Ifmk00@006mkKg/000A_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/0
00]_N`03001_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000fmk
00<006mkKg/0IFmk00D006mkKg]_N`0000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/00`00Kg/0000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000A_N`03001_Nfmk06E_N`03001_Nfmk009_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000016mk00<006mkKg/0IFmk00<006mkKg/00Vmk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg^C
0005Kg/00`00Kg]_N`1UKg/00`00Kg]_N`03Kg^C000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000A_N`03001_Nfmk06E_N`03001_Nfmk009_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk0P00
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000016mk00<006mkKg/0
IFmk00<006mkKg/00Vmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000=_N`03001_Nfmk06E_N`05001_NfmkKg/00003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00@006mkKg/006M_N`04001_Nfmk0004Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mk000036mk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`04001_Nfmk001WKg/01000Kg]_N`001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00<006mk0000Ifmk00<006mk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/000]_N`07001_NfmkKg/006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk0P00Ifmk0P0026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_
Nfmk001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`8006M_N`8000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00<006mkKg/00VmkU000IfmkU00016mk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`8006M_N`8000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk
00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/2001W
Kg/20008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00003Kg/00`00
Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00@006mk000006E_N`800003Kg/006mk00E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk008006E_N`80009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00P00IFmk0P000Vmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00003Kg/2001UKg/20003Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`00
00E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk0P001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000016mk0P00IFmk0P0016mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00004Kg/2001UKg/20004Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_Ni<000E_
N`03001_N`0006=_N`03001_N`0000E_Ni<000a_N`002fmk0P001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000016mk00<006mk0000Hfmk00<006mk000016mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00004Kg/00`00Kg/0001SKg/0
0`00Kg/00004Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2
000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00000fmk00<006mk0000Hfmk00<006mk00000fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk
00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`03001_N`0000E_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`02Kg/01P00Kg]_N`00Kg/006=_N`03001_N`00009_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg/0000<Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00@006mkKg/0009_N`03001_Nfmk05m_N`04001_Nfmk0002Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk
00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03001_Nfmk00Y_N`002fmk00@0
06mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/00`00Kg/00002
Kg/00`00Kg]_N`1OKg/01P00Kg]_N`00Kg/000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`80009_N`03001_Nfmk05m_N`03001_Nfmk008000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/20002Kg/00`00Kg]_N`1OKg/00`00Kg]_N`020008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Ni@0009_N`03
001_Nfmk05m_N`03001_Nfmk09@000A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00002Kg/00`00Kg]_N`1M
Kg/01P00Kg]_N`00Kg/000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000=_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00002Kg/00`00Kg]_N`1MKg/01P00Kg]_N`00Kg/000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_
N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1`00Kg]_Nfmk001_N`0005m_N`03001_N`0000=_N`03001_Nfmk00A_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<0
06mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_N`0005m_N`03001_N`0000A_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_
Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_
N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;
Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk0P00Gfmk
0P001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`00
2fmk00<006mk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/2
001OKg/20006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_
N`0000a_N`002fmk0P001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk0P00GFmk0P0026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk0P0036mk000;Kg/20007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/2001MKg/20008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/2000<Kg/000]_Nih005e_Nih000a_N`002fmk0P001fmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000Ffmk00<006mk000026mk00<0
06mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<0
06mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk0P0036mk000;Kg/20007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/01000Kg/00000
FFmk0P0000=_N`00Kg/01fmk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk00<006mk
000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk
00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_
N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000I_N`04001_NfmkKg/3001EKg/30003Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk00001Fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk
00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00002Kg/00`00
Kg]_N`1AKg/01000Kg]_N`000fmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00@006mkKg/000=_N`03001_Nfmk00=_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg]_N`00DFmk00@006mkKg/000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk00<0
06mkKg/02Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000Cfmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00009_N`03001_
Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/01@00Kg]_Nfmk0000CFmk00D006mkKg]_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk
00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`19Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Nih000A_N`8004M_N`8000A_Nih000A_N`03
001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/01000Kg/0000016mk00<006mkKg/0@fmk00<006mkKg/00Vmk
0P0000=_N`00Kg/01Vmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk00000fmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`04001_N`00Kg/20003Kg/00`00
Kg]_N`11Kg/01000Kg]_Nfmk0P0000A_N`00Kg/000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000=_N`03001_Nfmk00Y_N`002fmk00@006mkKg/0
00=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`00009_N`80009_N`03001_Nfmk03m_N`03001_Nfmk0080009_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000A_N`04001_Nfmk000oKg/01000
Kg]_N`0016mk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_
N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`80
0003Kg/006mk03a_N`04001_N`000004Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mk
Kg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/016mk1000>Fmk10001Vmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00<006mk000036mk000;Kg/20007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg]_N`05Kg/3000gKg/30007Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/00`00Kg/00007
Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008
Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2000<Kg/000]_N`8000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
Nfmk00M_N`8003E_N`8000U_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`0000M_N`03001_
N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_
N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`002fmk]000<Fmk]00036mk000;Kg/2
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00003000[Kg/400000fmk001_N`07Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/2
000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`04001_N`00Kg/5000UKg/5000016mk001_N`0026mk
00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk00001fmk
00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk
00<006mk00001fmk0P0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`00009_N`800004Kg/00000000OKg/300000fmk00000002Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006
Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`03001_N`0000a_N`002fmk00<006mk00001Fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk000016mk00@006mkKg]_N`8001]_N`8000=_N`03001_Nfmk009_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/0
0005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00D006mkKg]_N`0000E_N`03001_N`0000a_N`002fmk00@006mkKg/000=_N`03001_
Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_
Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk0000
1Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/00Vmk0P000fmk0`005Fmk0`000fmk0P00
16mk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
1@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_
Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_
NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/0
2Vmk000;Kg/01000Kg]_N`000fmk00<006mkKg/00fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk00A_
N`8000A_N`<000m_N`<000A_N`8000I_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/01`00Kg]_Nfmk001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_Nfmk00E_N`8000E_N`<000U_N`<000E_N`8000M_N`03001_Nfmk00E_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000=_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg]_N`07Kg/20006Kg/30003Kg/30006Kg/20009Kg/00`00Kg]_N`05Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/0
0`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/0
0`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`03001_Nfmk009_Nol0090000A_N`03001_Nfmk00Y_
N`002fmk00@006mkKg]_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03
001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`80
00Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`00
00Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`8000Q_N`03001_N`0000Q_N`80
00Q_N`03001_N`0000Q_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`8000U_N`8000Q_N`80
00A_N`03001_Nfmk00Y_N`002fmk00L006mkKg]_N`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/0
0008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/0
0007Kg/00`00Kg/00003Kg/00`00Kg]_N`0:Kg/000]_N`04001_Nfmk0002Kg/00`00Kg]_N`04Kg/0
1@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D0
06mkKg]_N`0000I_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_Nfmk
0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@0
06mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006
Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk
00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04
001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/01000
Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_
N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000=_N`03001_Nfmk00Y_N`002fmk00@0
06mkKg/000=_N`03001_Nfmk00=_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mk
Kg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05
001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005
Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk
00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mk
Kg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05
001_NfmkKg/00005Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/02Vmk000;Kg/00`00Kg/00004Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`02Kg/01000Kg]_N`0036mk000;Kg/00`00Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/0
0005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_
Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/0
0006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_
Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D0
06mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_
N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_N`0000a_
N`002fmk0P001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/0
00I_N`04001_Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000I_N`05001_NfmkKg/00006Kg/0
1000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@0
06mkKg/000I_N`05001_NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_
Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`04001_Nfmk0007Kg/01000Kg]_N`00
1Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk00@006mkKg/000I_N`04001_
Nfmk0007Kg/01000Kg]_N`001Vmk00@006mkKg/000M_N`04001_Nfmk0006Kg/01000Kg]_N`001fmk
00@006mkKg/000I_N`04001_Nfmk0006Kg/01@00Kg]_Nfmk00001Vmk00@006mkKg/000I_N`05001_
NfmkKg/00006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`0000I_N`04001_Nfmk0006Kg/00`00Kg/0
000<Kg/000]_N`8000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`00
00Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`00
00M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`8000a_N`00
2fmk00<006mkKg/01Vmk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P0026mk00<0
06mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk0000
26mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk0P002Fmk0P0026mk0P00
2Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P002Fmk0P0026mk0P00
26mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk00<006mk000026mk0P0026mk0P00
36mk000;Kg_o002J000<Kg/000a_N`03001_Nfmk00E_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000M_N`03
001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03
001_N`0000M_N`03001_Nfmk00]_N`0036mk00<006mkKg/01Fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
1fmk00<006mk000026mk00<006mk00001fmk00<006mk000026mk00<006mk00001fmk00<006mk0000
26mk00<006mk00001fmk00<006mkKg/02fmk000=Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_Nfmk
Kg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00
Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_Nfmk
Kg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00
Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk
00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`00
00I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`03001_Nfmk
00a_N`003Fmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_
N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D0
06mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_
N`0<Kg/000i_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03
001_Nfmk00=_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000E_N`03
001_Nfmk009_N`03001_Nfmk00=_N`05001_NfmkKg/00005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mkKg]_N`0000m_N`00
3Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_
N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_
NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/0
1@00Kg]_Nfmk00001Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk0000
1Fmk00D006mkKg]_N`0000I_N`05001_NfmkKg/00005Kg/01@00Kg]_Nfmk00001Vmk00D006mkKg]_
N`0000E_N`05001_NfmkKg/00006Kg/01@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000I_N`05001_
NfmkKg/00005Kg/01@00Kg]_Nfmk00003fmk000?Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00
Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00Kg/00007Kg/00`00Kg/00008Kg/00`00
Kg/00007Kg/00`00Kg/0000@Kg/000m_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_
N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_N`03001_N`0000Q_N`03001_N`0000M_
N`03001_N`00011_N`0046mko`00T0004Fmk003oKg^aKg/00?m_Nk5_N`00ofmk/Fmk0000\
\>"],
  ImageRangeCache->{{{0, 431}, {162, 0}} -> {-2.0564, -0.777006, 0.0143137, \
0.0143137}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "Now you may notice that two upper corner points of the rectangle are \
missing. This is caused by the definition of its distance function. To remedy \
for this, we need to add these points to our list of meshpoints list ",
  StyleBox["p",
    FontFamily->"Courier"],
  ". Now the list is completely initialized after putting in these missing \
meshpoints (if there is any). They are called fixed meshpoints because they \
won't move at all during the force equilibrium process."
}], "Text"],

Cell["\<\
Since now we have the meshbars, they will start exerting force on the \
connecting meshpoints to achieve an equilibrium. Let the force be with \
them.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Force be with them", "Section"],

Cell[TextData[{
  "These meshbars act like a special kind of springs that have the following \
force vs. length relationship\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(l, \ l\_0)\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{"{", 
              StyleBox[GridBox[{
                    {\(\(\(k(l - l\_0)\)\ \ \ \ \ \ if\ l < l\_0\)\(,\)\)},
                    {\(0\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ if\ l \
\[GreaterEqual] \(\(l\_0\)\(\ \)\(.\)\)\)}
                    }],
                ShowAutoStyles->True]}],
            ShowAutoStyles->False],
          (#&)], TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  "The function ",
  StyleBox["barlength",
    FontFamily->"Courier"],
  " calculates ",
  Cell[BoxData[
      \(TraditionalForm\`l\)]],
  " (the actual meshbar length) in the above equation, given the two \
connecting meshpoints of a a meshbar."
}], "Text"],

Cell[BoxData[
    \(barlength[p_, {a_, b_}] := Norm[p[\([a]\)] - p[\([b]\)]]\)], "Input",
  CellLabel->"In[41]:="],

Cell[TextData[{
  "How about ",
  Cell[BoxData[
      \(TraditionalForm\`l\_0\)]],
  "? It looks like a desired length since ",
  Cell[BoxData[
      \(TraditionalForm\`l = l\_0\)]],
  " will certainly turn force ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " into 0. Guess who involves in the calculation of ",
  Cell[BoxData[
      \(TraditionalForm\`l\_0\)]],
  ", size function ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " again. It is the second yet most important appearance of this function. \
It is essentially the core of the algorithm\[LongDash]the desired mesh \
triangle size yields the desired meshbar length. So the iterative process to \
zero the force is really a process to adjust the meshbar length to be close \
to ",
  Cell[BoxData[
      \(TraditionalForm\`l\_0\)]],
  ", which inevitably and implicitly adjusts the mesh triangles to the size \
and distribution as ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  ". The clever part is that still ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " gives a relative measure, so a scaling process with scaling factor ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(\[Sum]\ l\_i\^2\)\/\(\[Sum]\ \(h(x\_i, \ \
y\_i)\)\^2\))\)\^\(1/2\)\)]],
  " is used. "
}], "Text"],

Cell[BoxData[
    \(scale[
        a_List, \ {p_, \ 
          bars_}] := \ \@\(Plus @@ Map[barlength[p, #]\^2 &, bars]\/Plus @@ \
\(a\^2\)\)\[Times]a\)], "Input",
  CellLabel->"In[46]:="],

Cell[TextData[{
  "The parameter ",
  StyleBox["Fscale=1.2",
    FontFamily->"Courier"],
  " blows ",
  Cell[BoxData[
      \(TraditionalForm\`l\_0\)]],
  " a little bit. Now let's return to our disk example. To find the desired \
length ",
  Cell[BoxData[
      \(TraditionalForm\`l\_0\)]],
  " for each meshbar, we use the middle point of each meshbar as input to ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\)]],
  " and then scale the output."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(l0 = 
        With[{Fscale = 1.2}, 
          Fscale\ \[Times]\ 
            scale[\(h[middlepoint[p, #]] &\) /@ bars, \ {p, 
                bars}]];\)\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(Fscale\\)\\\" is similar to existing symbol \
\\\"\\!\\(scale\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message",
  CellLabel->"From In[47]:="]
}, Open  ]],

Cell[TextData[{
  "Now assuming ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  ", the force can be calculated according to the \"spring\" relationship."
}], "Text"],

Cell[BoxData[
    \(\(F = \(Max[#, 
              0] &\) /@ \((l0 - \((\(barlength[p, #] &\) /@ 
                  bars)\))\);\)\)], "Input",
  CellLabel->"In[48]:="],

Cell["\<\
Now the force needs to be dissected into vectors of x-axis and y-axis \
components at each meshpoint so that they can be summed in these two \
independent directions.\
\>", "Text"],

Cell[BoxData[
    \(\(Fvec = 
        F \((\(Subtract @@ p[\([#]\)]\/barlength[p, #] &\) /@ 
              bars)\);\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[TextData[{
  "The MATLAB code (",
  StyleBox["step 6",
    FontSlant->"Italic"],
  ") uses sparse matrix to sum forces (both x- and y-component) at each \
meshpoint. Here we try the same way by defining a sparse array in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The sparse array is a square matrix of ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Times]n\)]],
  " dimensions, with n = number of meshpoints. Each row stores the forces for \
one meshpoint and the columns are forces (x- and y-component) exerted on it \
by neighboring meshpoints through connecting meshbars. Since one meshpoint \
only connects with a small fraction of the total number of meshpoints, the \
matrix is very sparse (i.e., many zeros in the matrix). A little trick (",
  StyleBox["Hold",
    FontFamily->"Courier"],
  ") is used to store ",
  Cell[BoxData[
      \(TraditionalForm\`\((F\_x, F\_y)\)\)]],
  " at position ",
  Cell[BoxData[
      \(TraditionalForm\`\((a, \ b)\)\)]],
  " in the sparse array."
}], "Text"],

Cell[BoxData[
    \(ForceRule[{a_, b_}, {Fx_, Fy_}] := {{a, b} \[Rule] 
          Hold[{Fx, Fy}], \[IndentingNewLine] (*\ 
          Newton' s\ Third\ Law\ *) \[IndentingNewLine]\ {b, a} \[Rule] 
          Hold[{\(-Fx\), \(-Fy\)}]}\)], "Input",
  CellLabel->"In[50]:="],

Cell[TextData[{
  "A sparse array, ",
  StyleBox["forcematrix",
    FontFamily->"Courier"],
  " is built from these rules"
}], "Text"],

Cell[BoxData[
    \(\(forcematrix = \(SparseArray[#, {Length[p], 
                Length[p]}] &\)@\((MapThread[ForceRule, {bars, Fvec}] // 
              Flatten[#, 1] &)\);\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[TextData[{
  "Then the movements of the meshpoints are induced by the force acting on it \
(Aristotle-ly) according to the formula\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold"], \(n + 1\)], "=", 
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold"], "n"], "+", 
            RowBox[{"\[CapitalDelta]t", " ", 
              RowBox[{
                StyleBox["F",
                  FontWeight->"Bold"], "(", 
                SubscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold"], "n"], ")"}]}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "We calculate the second term on the right hand side (with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 0.2\)]],
  ") by summing all forces on each row of the sparse array."
}], "Text"],

Cell[BoxData[
    \(\(dp = 
        With[{deltat = 0.2}, 
          deltat\ \[Times]\ 
            Table[Plus @@ \((ReleaseHold /@ forcematrix[\([i]\)])\), {i, 
                Length[p]}]];\)\)], "Input",
  CellLabel->"In[52]:="],

Cell["So the movement of meshpoints", "Text"],

Cell[BoxData[
    \(\(pp = p + dp;\)\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
As shown below, the meshpoints moves from the initial location\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[p, AspectRatio \[Rule] Automatic, 
      PlotStyle \[Rule] PointSize[0.01]]\)], "Input",
  CellLabel->"In[57]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99724 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0962001 0.494206 0.0962001 [
[.1152 .48171 -6 -9 ]
[.1152 .48171 6 0 ]
[.3076 .48171 -6 -9 ]
[.3076 .48171 6 0 ]
[.6924 .48171 -3 -9 ]
[.6924 .48171 3 0 ]
[.8848 .48171 -3 -9 ]
[.8848 .48171 3 0 ]
[.4875 .10941 -12 -4.5 ]
[.4875 .10941 0 4.5 ]
[.4875 .30181 -12 -4.5 ]
[.4875 .30181 0 4.5 ]
[.4875 .68661 -6 -4.5 ]
[.4875 .68661 0 4.5 ]
[.4875 .87901 -6 -4.5 ]
[.4875 .87901 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99724 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1152 .49421 m
.1152 .50046 L
s
[(-4)] .1152 .48171 0 1 Mshowa
.3076 .49421 m
.3076 .50046 L
s
[(-2)] .3076 .48171 0 1 Mshowa
.6924 .49421 m
.6924 .50046 L
s
[(2)] .6924 .48171 0 1 Mshowa
.8848 .49421 m
.8848 .50046 L
s
[(4)] .8848 .48171 0 1 Mshowa
.125 Mabswid
.1633 .49421 m
.1633 .49796 L
s
.2114 .49421 m
.2114 .49796 L
s
.2595 .49421 m
.2595 .49796 L
s
.3557 .49421 m
.3557 .49796 L
s
.4038 .49421 m
.4038 .49796 L
s
.4519 .49421 m
.4519 .49796 L
s
.5481 .49421 m
.5481 .49796 L
s
.5962 .49421 m
.5962 .49796 L
s
.6443 .49421 m
.6443 .49796 L
s
.7405 .49421 m
.7405 .49796 L
s
.7886 .49421 m
.7886 .49796 L
s
.8367 .49421 m
.8367 .49796 L
s
.0671 .49421 m
.0671 .49796 L
s
.019 .49421 m
.019 .49796 L
s
.9329 .49421 m
.9329 .49796 L
s
.981 .49421 m
.981 .49796 L
s
.25 Mabswid
0 .49421 m
1 .49421 L
s
.5 .10941 m
.50625 .10941 L
s
[(-4)] .4875 .10941 1 0 Mshowa
.5 .30181 m
.50625 .30181 L
s
[(-2)] .4875 .30181 1 0 Mshowa
.5 .68661 m
.50625 .68661 L
s
[(2)] .4875 .68661 1 0 Mshowa
.5 .87901 m
.50625 .87901 L
s
[(4)] .4875 .87901 1 0 Mshowa
.125 Mabswid
.5 .15751 m
.50375 .15751 L
s
.5 .20561 m
.50375 .20561 L
s
.5 .25371 m
.50375 .25371 L
s
.5 .34991 m
.50375 .34991 L
s
.5 .39801 m
.50375 .39801 L
s
.5 .44611 m
.50375 .44611 L
s
.5 .54231 m
.50375 .54231 L
s
.5 .59041 m
.50375 .59041 L
s
.5 .63851 m
.50375 .63851 L
s
.5 .73471 m
.50375 .73471 L
s
.5 .78281 m
.50375 .78281 L
s
.5 .83091 m
.50375 .83091 L
s
.5 .06131 m
.50375 .06131 L
s
.5 .01321 m
.50375 .01321 L
s
.5 .92711 m
.50375 .92711 L
s
.5 .97521 m
.50375 .97521 L
s
.25 Mabswid
.5 0 m
.5 .99724 L
s
0 0 m
1 0 L
1 .99724 L
0 .99724 L
closepath
clip
newpath
.01 w
.47114 .02374 Mdot
.46152 .04041 Mdot
.52886 .04041 Mdot
.56253 .04874 Mdot
.4519 .05707 Mdot
.52405 .0654 Mdot
.47114 .07373 Mdot
.28355 .08206 Mdot
.31241 .08206 Mdot
.37013 .08206 Mdot
.63949 .08206 Mdot
.72607 .08206 Mdot
.5 .09039 Mdot
.42785 .09872 Mdot
.58177 .09872 Mdot
.3557 .10706 Mdot
.5 .10706 Mdot
.5962 .10706 Mdot
.66354 .10706 Mdot
.27393 .11539 Mdot
.31241 .11539 Mdot
.55291 .11539 Mdot
.62025 .11539 Mdot
.77417 .11539 Mdot
.79822 .12372 Mdot
.48557 .14871 Mdot
.49519 .14871 Mdot
.50481 .14871 Mdot
.58177 .14871 Mdot
.24988 .15704 Mdot
.50962 .15704 Mdot
.60582 .15704 Mdot
.44709 .16537 Mdot
.45671 .16537 Mdot
.80784 .1737 Mdot
.36051 .18204 Mdot
.39899 .18204 Mdot
.42785 .18204 Mdot
.44709 .18204 Mdot
.45671 .18204 Mdot
.48557 .18204 Mdot
.49519 .18204 Mdot
.64911 .18204 Mdot
.23064 .19037 Mdot
.27874 .19037 Mdot
.3076 .19037 Mdot
.61544 .19037 Mdot
.42785 .1987 Mdot
.44709 .1987 Mdot
.46633 .1987 Mdot
.51443 .1987 Mdot
.24988 .20703 Mdot
.3076 .20703 Mdot
.70202 .20703 Mdot
.29317 .21536 Mdot
.57215 .21536 Mdot
.61063 .21536 Mdot
.70683 .21536 Mdot
.81265 .21536 Mdot
.39418 .22369 Mdot
.4038 .22369 Mdot
.49038 .22369 Mdot
.67316 .22369 Mdot
.7405 .22369 Mdot
.79822 .22369 Mdot
.50481 .23202 Mdot
.63949 .23202 Mdot
.65873 .23202 Mdot
.73569 .23202 Mdot
.18254 .24035 Mdot
.36532 .24035 Mdot
.39418 .24035 Mdot
.44228 .24035 Mdot
.5481 .24035 Mdot
.12001 .24869 Mdot
.17773 .24869 Mdot
.69721 .24869 Mdot
.72607 .24869 Mdot
.82227 .24869 Mdot
.3076 .25702 Mdot
.3557 .25702 Mdot
.56734 .25702 Mdot
.6924 .25702 Mdot
.91366 .25702 Mdot
.09115 .26535 Mdot
.43747 .26535 Mdot
.56253 .26535 Mdot
.58177 .26535 Mdot
.79341 .26535 Mdot
.29798 .27368 Mdot
.38456 .27368 Mdot
.48076 .27368 Mdot
.42785 .28201 Mdot
.64911 .28201 Mdot
.36532 .29034 Mdot
.39418 .29034 Mdot
.52886 .29034 Mdot
.53848 .29034 Mdot
.5481 .29034 Mdot
.73088 .29034 Mdot
.21621 .29867 Mdot
.23545 .29867 Mdot
.28355 .29867 Mdot
.35089 .29867 Mdot
.60101 .29867 Mdot
.05748 .307 Mdot
.1633 .307 Mdot
.37494 .307 Mdot
.56734 .307 Mdot
.7405 .307 Mdot
.40861 .31533 Mdot
.55291 .31533 Mdot
.2114 .32367 Mdot
.31722 .32367 Mdot
.34608 .32367 Mdot
.38456 .32367 Mdot
.39418 .32367 Mdot
.43266 .32367 Mdot
.51924 .32367 Mdot
.5481 .32367 Mdot
.82708 .32367 Mdot
.84632 .32367 Mdot
.07191 .332 Mdot
.12963 .332 Mdot
.20659 .332 Mdot
.36051 .332 Mdot
.41823 .332 Mdot
.42785 .332 Mdot
.45671 .332 Mdot
.47595 .332 Mdot
.50481 .332 Mdot
.77417 .332 Mdot
.88961 .332 Mdot
.15368 .34033 Mdot
.22102 .34033 Mdot
.24988 .34033 Mdot
.26912 .34033 Mdot
.29798 .34033 Mdot
.37494 .34033 Mdot
.53848 .34033 Mdot
.55772 .34033 Mdot
.6924 .34033 Mdot
.48557 .34866 Mdot
.56253 .34866 Mdot
.62025 .34866 Mdot
.74531 .34866 Mdot
.81265 .34866 Mdot
.89923 .34866 Mdot
.20178 .35699 Mdot
.42304 .35699 Mdot
.50962 .35699 Mdot
.5481 .35699 Mdot
.61544 .35699 Mdot
.62506 .35699 Mdot
.82708 .35699 Mdot
.18735 .36532 Mdot
.39899 .36532 Mdot
.42785 .36532 Mdot
.45671 .36532 Mdot
.51443 .36532 Mdot
.54329 .36532 Mdot
.56253 .36532 Mdot
.85113 .36532 Mdot
.22102 .37365 Mdot
.32684 .37365 Mdot
.46152 .37365 Mdot
.48076 .37365 Mdot
.50962 .37365 Mdot
.51924 .37365 Mdot
.55772 .37365 Mdot
.61544 .37365 Mdot
.68278 .37365 Mdot
.70202 .37365 Mdot
.7405 .37365 Mdot
.84632 .37365 Mdot
.87518 .37365 Mdot
.91366 .37365 Mdot
.38937 .38198 Mdot
.43747 .38198 Mdot
.45671 .38198 Mdot
.52405 .38198 Mdot
.53367 .38198 Mdot
.61063 .38198 Mdot
.80303 .38198 Mdot
.95695 .38198 Mdot
.17292 .39032 Mdot
.2595 .39032 Mdot
.3557 .39032 Mdot
.36532 .39032 Mdot
.38456 .39032 Mdot
.39418 .39032 Mdot
.4038 .39032 Mdot
.43266 .39032 Mdot
.52886 .39032 Mdot
.53848 .39032 Mdot
.68278 .39032 Mdot
.70202 .39032 Mdot
.73088 .39032 Mdot
.86556 .39032 Mdot
.14887 .39865 Mdot
.25469 .39865 Mdot
.38937 .39865 Mdot
.40861 .39865 Mdot
.42785 .39865 Mdot
.46633 .39865 Mdot
.51443 .39865 Mdot
.54329 .39865 Mdot
.55291 .39865 Mdot
.57215 .39865 Mdot
.64911 .39865 Mdot
.74531 .39865 Mdot
.87999 .39865 Mdot
.88961 .39865 Mdot
.29798 .40698 Mdot
.31722 .40698 Mdot
.38456 .40698 Mdot
.4519 .40698 Mdot
.46152 .40698 Mdot
.5 .40698 Mdot
.57696 .40698 Mdot
.61544 .40698 Mdot
.79822 .40698 Mdot
.06229 .41531 Mdot
.15849 .41531 Mdot
.45671 .41531 Mdot
.46633 .41531 Mdot
.48557 .41531 Mdot
.49519 .41531 Mdot
.53367 .41531 Mdot
.54329 .41531 Mdot
.55291 .41531 Mdot
.60101 .41531 Mdot
.31722 .42364 Mdot
.32684 .42364 Mdot
.38456 .42364 Mdot
.41342 .42364 Mdot
.44228 .42364 Mdot
.50962 .42364 Mdot
.51924 .42364 Mdot
.52886 .42364 Mdot
.53848 .42364 Mdot
.55772 .42364 Mdot
.72126 .42364 Mdot
.73088 .42364 Mdot
.7886 .42364 Mdot
.84632 .42364 Mdot
.90404 .42364 Mdot
.37975 .43197 Mdot
.41823 .43197 Mdot
.43747 .43197 Mdot
.45671 .43197 Mdot
.48557 .43197 Mdot
.54329 .43197 Mdot
.58177 .43197 Mdot
.81265 .43197 Mdot
.24026 .4403 Mdot
.27874 .4403 Mdot
.31722 .4403 Mdot
.33646 .4403 Mdot
.34608 .4403 Mdot
.44228 .4403 Mdot
.5 .4403 Mdot
.51924 .4403 Mdot
.52886 .4403 Mdot
.56734 .4403 Mdot
.5962 .4403 Mdot
.60582 .4403 Mdot
.73088 .4403 Mdot
.87518 .4403 Mdot
.16811 .44863 Mdot
.31241 .44863 Mdot
.41823 .44863 Mdot
.47595 .44863 Mdot
.48557 .44863 Mdot
.55291 .44863 Mdot
.56253 .44863 Mdot
.58177 .44863 Mdot
.65873 .44863 Mdot
.77417 .44863 Mdot
.1633 .45696 Mdot
.33646 .45696 Mdot
.36532 .45696 Mdot
.43266 .45696 Mdot
.44228 .45696 Mdot
.46152 .45696 Mdot
.47114 .45696 Mdot
.48076 .45696 Mdot
.49038 .45696 Mdot
.50962 .45696 Mdot
.51924 .45696 Mdot
.52886 .45696 Mdot
.53848 .45696 Mdot
.56734 .45696 Mdot
.62506 .45696 Mdot
.66354 .45696 Mdot
.75012 .45696 Mdot
.23545 .4653 Mdot
.35089 .4653 Mdot
.38937 .4653 Mdot
.42785 .4653 Mdot
.45671 .4653 Mdot
.46633 .4653 Mdot
.47595 .4653 Mdot
.48557 .4653 Mdot
.50481 .4653 Mdot
.52405 .4653 Mdot
.53367 .4653 Mdot
.54329 .4653 Mdot
.56253 .4653 Mdot
.59139 .4653 Mdot
.65873 .4653 Mdot
.69721 .4653 Mdot
.84151 .4653 Mdot
.97619 .4653 Mdot
.32684 .47363 Mdot
.33646 .47363 Mdot
.34608 .47363 Mdot
.3557 .47363 Mdot
.41342 .47363 Mdot
.42304 .47363 Mdot
.44228 .47363 Mdot
.4519 .47363 Mdot
.47114 .47363 Mdot
.48076 .47363 Mdot
.49038 .47363 Mdot
.5 .47363 Mdot
.50962 .47363 Mdot
.53848 .47363 Mdot
.5481 .47363 Mdot
.20659 .48196 Mdot
.32203 .48196 Mdot
.35089 .48196 Mdot
.38937 .48196 Mdot
.44709 .48196 Mdot
.45671 .48196 Mdot
.48557 .48196 Mdot
.49519 .48196 Mdot
.51443 .48196 Mdot
.55291 .48196 Mdot
.59139 .48196 Mdot
.60101 .48196 Mdot
.63949 .48196 Mdot
.67797 .48196 Mdot
.75493 .48196 Mdot
.82227 .48196 Mdot
.93771 .48196 Mdot
.08634 .49029 Mdot
.1633 .49029 Mdot
.17292 .49029 Mdot
.2114 .49029 Mdot
.33646 .49029 Mdot
.41342 .49029 Mdot
.42304 .49029 Mdot
.44228 .49029 Mdot
.46152 .49029 Mdot
.47114 .49029 Mdot
.48076 .49029 Mdot
.49038 .49029 Mdot
.5 .49029 Mdot
.53848 .49029 Mdot
.55772 .49029 Mdot
.63468 .49029 Mdot
.72126 .49029 Mdot
.81746 .49029 Mdot
.89442 .49029 Mdot
.02381 .49862 Mdot
.17773 .49862 Mdot
.23545 .49862 Mdot
.32203 .49862 Mdot
.37975 .49862 Mdot
.39899 .49862 Mdot
.41823 .49862 Mdot
.43747 .49862 Mdot
.44709 .49862 Mdot
.47595 .49862 Mdot
.49519 .49862 Mdot
.50481 .49862 Mdot
.51443 .49862 Mdot
.53367 .49862 Mdot
.54329 .49862 Mdot
.55291 .49862 Mdot
.56253 .49862 Mdot
.58177 .49862 Mdot
.64911 .49862 Mdot
.72607 .49862 Mdot
.04786 .50695 Mdot
.20178 .50695 Mdot
.2114 .50695 Mdot
.24988 .50695 Mdot
.28836 .50695 Mdot
.38456 .50695 Mdot
.4038 .50695 Mdot
.41342 .50695 Mdot
.42304 .50695 Mdot
.44228 .50695 Mdot
.4519 .50695 Mdot
.46152 .50695 Mdot
.47114 .50695 Mdot
.48076 .50695 Mdot
.49038 .50695 Mdot
.5 .50695 Mdot
.50962 .50695 Mdot
.51924 .50695 Mdot
.53848 .50695 Mdot
.56734 .50695 Mdot
.60582 .50695 Mdot
.6443 .50695 Mdot
.76936 .50695 Mdot
.82708 .50695 Mdot
.12963 .51528 Mdot
.32203 .51528 Mdot
.40861 .51528 Mdot
.41823 .51528 Mdot
.42785 .51528 Mdot
.47595 .51528 Mdot
.49519 .51528 Mdot
.53367 .51528 Mdot
.56253 .51528 Mdot
.57215 .51528 Mdot
.62987 .51528 Mdot
.64911 .51528 Mdot
.67797 .51528 Mdot
.72607 .51528 Mdot
.04786 .52361 Mdot
.09596 .52361 Mdot
.10558 .52361 Mdot
.24026 .52361 Mdot
.27874 .52361 Mdot
.3076 .52361 Mdot
.32684 .52361 Mdot
.4038 .52361 Mdot
.41342 .52361 Mdot
.43266 .52361 Mdot
.4519 .52361 Mdot
.46152 .52361 Mdot
.47114 .52361 Mdot
.50962 .52361 Mdot
.52886 .52361 Mdot
.56734 .52361 Mdot
.58658 .52361 Mdot
.61544 .52361 Mdot
.75012 .52361 Mdot
.80784 .52361 Mdot
.19697 .53195 Mdot
.25469 .53195 Mdot
.34127 .53195 Mdot
.45671 .53195 Mdot
.46633 .53195 Mdot
.47595 .53195 Mdot
.52405 .53195 Mdot
.53367 .53195 Mdot
.55291 .53195 Mdot
.56253 .53195 Mdot
.57215 .53195 Mdot
.58177 .53195 Mdot
.64911 .53195 Mdot
.65873 .53195 Mdot
.74531 .53195 Mdot
.34608 .54028 Mdot
.38456 .54028 Mdot
.39418 .54028 Mdot
.4038 .54028 Mdot
.4519 .54028 Mdot
.46152 .54028 Mdot
.48076 .54028 Mdot
.49038 .54028 Mdot
.50962 .54028 Mdot
.52886 .54028 Mdot
.55772 .54028 Mdot
.58658 .54028 Mdot
.66354 .54028 Mdot
.73088 .54028 Mdot
.7405 .54028 Mdot
.90404 .54028 Mdot
.29317 .54861 Mdot
.33165 .54861 Mdot
.37975 .54861 Mdot
.45671 .54861 Mdot
.46633 .54861 Mdot
.49519 .54861 Mdot
.50481 .54861 Mdot
.51443 .54861 Mdot
.54329 .54861 Mdot
.59139 .54861 Mdot
.66835 .54861 Mdot
.70683 .54861 Mdot
.0671 .55694 Mdot
.2114 .55694 Mdot
.34608 .55694 Mdot
.4519 .55694 Mdot
.46152 .55694 Mdot
.47114 .55694 Mdot
.51924 .55694 Mdot
.52886 .55694 Mdot
.53848 .55694 Mdot
.57696 .55694 Mdot
.58658 .55694 Mdot
.60582 .55694 Mdot
.10077 .56527 Mdot
.36051 .56527 Mdot
.40861 .56527 Mdot
.41823 .56527 Mdot
.46633 .56527 Mdot
.47595 .56527 Mdot
.48557 .56527 Mdot
.50481 .56527 Mdot
.53367 .56527 Mdot
.56253 .56527 Mdot
.57215 .56527 Mdot
.60101 .56527 Mdot
.63949 .56527 Mdot
.70683 .56527 Mdot
.87999 .56527 Mdot
.88961 .56527 Mdot
.89923 .56527 Mdot
.07672 .5736 Mdot
.27874 .5736 Mdot
.28836 .5736 Mdot
.32684 .5736 Mdot
.39418 .5736 Mdot
.44228 .5736 Mdot
.47114 .5736 Mdot
.58658 .5736 Mdot
.62506 .5736 Mdot
.6443 .5736 Mdot
.07191 .58193 Mdot
.08153 .58193 Mdot
.37975 .58193 Mdot
.50481 .58193 Mdot
.56253 .58193 Mdot
.57215 .58193 Mdot
.59139 .58193 Mdot
.63949 .58193 Mdot
.65873 .58193 Mdot
.68759 .58193 Mdot
.14406 .59026 Mdot
.38456 .59026 Mdot
.47114 .59026 Mdot
.5481 .59026 Mdot
.63468 .59026 Mdot
.71164 .59026 Mdot
.07191 .59859 Mdot
.44709 .59859 Mdot
.49519 .59859 Mdot
.52405 .59859 Mdot
.53367 .59859 Mdot
.60101 .59859 Mdot
.71645 .59859 Mdot
.23064 .60693 Mdot
.24026 .60693 Mdot
.3557 .60693 Mdot
.38456 .60693 Mdot
.48076 .60693 Mdot
.5 .60693 Mdot
.50962 .60693 Mdot
.53848 .60693 Mdot
.15849 .61526 Mdot
.25469 .61526 Mdot
.29317 .61526 Mdot
.45671 .61526 Mdot
.50481 .61526 Mdot
.53367 .61526 Mdot
.56253 .61526 Mdot
.57215 .61526 Mdot
.68759 .61526 Mdot
.69721 .61526 Mdot
.27874 .62359 Mdot
.34608 .62359 Mdot
.3557 .62359 Mdot
.38456 .62359 Mdot
.4519 .62359 Mdot
.48076 .62359 Mdot
.70202 .62359 Mdot
.35089 .63192 Mdot
.41823 .63192 Mdot
.45671 .63192 Mdot
.61063 .63192 Mdot
.64911 .63192 Mdot
.67797 .63192 Mdot
.05748 .64025 Mdot
.1633 .64025 Mdot
.26912 .64025 Mdot
.66354 .64025 Mdot
.18735 .64858 Mdot
.33165 .64858 Mdot
.40861 .64858 Mdot
.42785 .64858 Mdot
.56253 .64858 Mdot
.69721 .64858 Mdot
.42304 .65691 Mdot
.44228 .65691 Mdot
.56734 .65691 Mdot
.61544 .65691 Mdot
.62506 .65691 Mdot
.77898 .65691 Mdot
.32203 .66524 Mdot
.34127 .66524 Mdot
.39899 .66524 Mdot
.40861 .66524 Mdot
.41823 .66524 Mdot
.47595 .66524 Mdot
.48557 .66524 Mdot
.50481 .66524 Mdot
.57215 .66524 Mdot
.94733 .66524 Mdot
.23064 .67358 Mdot
.33646 .67358 Mdot
.5 .67358 Mdot
.51924 .67358 Mdot
.6443 .67358 Mdot
.81746 .67358 Mdot
.87518 .67358 Mdot
.30279 .68191 Mdot
.33165 .68191 Mdot
.46633 .68191 Mdot
.60101 .68191 Mdot
.26912 .69024 Mdot
.34608 .69024 Mdot
.51924 .69024 Mdot
.6443 .69024 Mdot
.71164 .69024 Mdot
.72126 .69024 Mdot
.13925 .69857 Mdot
.45671 .69857 Mdot
.47595 .69857 Mdot
.50481 .69857 Mdot
.53367 .69857 Mdot
.58177 .69857 Mdot
.61063 .69857 Mdot
.07672 .7069 Mdot
.24026 .7069 Mdot
.32684 .7069 Mdot
.4038 .7069 Mdot
.43266 .7069 Mdot
.47114 .7069 Mdot
.5481 .7069 Mdot
.55772 .7069 Mdot
.57696 .7069 Mdot
.70202 .7069 Mdot
.75974 .7069 Mdot
.12001 .71523 Mdot
.29317 .71523 Mdot
.45671 .71523 Mdot
.48557 .71523 Mdot
.52405 .71523 Mdot
.62987 .71523 Mdot
.74531 .71523 Mdot
.13444 .72356 Mdot
.37494 .72356 Mdot
.4038 .72356 Mdot
.48076 .72356 Mdot
.84632 .72356 Mdot
.18735 .73189 Mdot
.22583 .73189 Mdot
.38937 .73189 Mdot
.40861 .73189 Mdot
.58177 .73189 Mdot
.82227 .73189 Mdot
.88961 .73189 Mdot
.15368 .74022 Mdot
.32684 .74022 Mdot
.37494 .74022 Mdot
.85594 .74022 Mdot
.23545 .74856 Mdot
.27393 .74856 Mdot
.70683 .74856 Mdot
.24988 .75689 Mdot
.3076 .75689 Mdot
.33646 .75689 Mdot
.43266 .75689 Mdot
.48076 .75689 Mdot
.5962 .75689 Mdot
.67316 .75689 Mdot
.19697 .76522 Mdot
.21621 .76522 Mdot
.43747 .76522 Mdot
.48557 .76522 Mdot
.51443 .76522 Mdot
.58177 .76522 Mdot
.73569 .76522 Mdot
.22102 .77355 Mdot
.23064 .77355 Mdot
.33646 .77355 Mdot
.38456 .77355 Mdot
.7405 .77355 Mdot
.46633 .78188 Mdot
.83189 .78188 Mdot
.39418 .79021 Mdot
.41342 .79021 Mdot
.4519 .79021 Mdot
.5 .79021 Mdot
.20659 .79854 Mdot
.40861 .79854 Mdot
.31722 .80687 Mdot
.46152 .80687 Mdot
.47114 .80687 Mdot
.7405 .80687 Mdot
.28355 .81521 Mdot
.20178 .82354 Mdot
.75974 .82354 Mdot
.22583 .83187 Mdot
.37975 .83187 Mdot
.38937 .83187 Mdot
.48557 .83187 Mdot
.60101 .83187 Mdot
.66835 .83187 Mdot
.77417 .83187 Mdot
.53848 .8402 Mdot
.18735 .84853 Mdot
.22583 .84853 Mdot
.39899 .84853 Mdot
.43747 .84853 Mdot
.28836 .85686 Mdot
.52886 .85686 Mdot
.55772 .85686 Mdot
.71164 .85686 Mdot
.31241 .86519 Mdot
.46633 .86519 Mdot
.61063 .86519 Mdot
.78379 .86519 Mdot
.30279 .88185 Mdot
.65873 .88185 Mdot
.4519 .89019 Mdot
.24507 .89852 Mdot
.55772 .90685 Mdot
.55772 .92351 Mdot
.66354 .92351 Mdot
.56734 .94017 Mdot
.37013 .9485 Mdot
.52405 .9485 Mdot
.52886 .95684 Mdot
.52405 .96517 Mdot
.57215 .96517 Mdot
.48076 .9735 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[57]:=",
  ImageSize->{288, 287.188},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001[Q000`40O003h00Oefmk00<006mkKg/0
eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/0
0`00Kg]_N`3FKg/00=M_N`<00=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk0039Kg/4000:Kg/00`00Kg]_N`3FKg/0
0<U_N`@000Y_N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk0036Kg/2000?Kg/00`00Kg]_N`09Kg/2
003;Kg/00<E_N`@000i_N`03001_Nfmk00Q_N`@00<Y_N`00aFmk10003Vmk00<006mkKg/026mk1000
bVmk0036Kg/2000?Kg/00`00Kg]_N`09Kg/2000<Kg/2002mKg/00=M_N`03001_Nfmk01I_N`@00;a_
N`00efmk00<006mkKg/05Vmk1000_6mk003GKg/00`00Kg]_N`0GKg/2002mKg/00<9_N`8001=_N`03
001_Nfmk0=I_N`00`Fmk10004Vmk00<006mkKg/0eVmk0031Kg/4000BKg/00`00Kg]_N`3FKg/00<9_
N`8001=_N`<00=I_N`00efmk00<006mkKg/01fmk0P00cFmk003GKg/00`00Kg]_N`06Kg/4003<Kg/0
0=M_N`03001_Nfmk00I_N`@00<a_N`00bVmk0P002fmk00<006mkKg/01fmk0P00cFmk0039Kg/4000:
Kg/00`00Kg]_N`3FKg/00<U_N`@000Y_N`03001_Nfmk0=I_N`00bVmk0P002fmk00<006mkKg/0eVmk
001iKg/2000;Kg/2000FKg/2000gKg/00`00Kg]_N`0hKg/2000TKg/2001fKg/007Q_N`@000U_N`@0
01A_N`@003I_N`03001_Nfmk03M_N`@0029_N`@007E_N`00N6mk10002Fmk100056mk1000=Vmk00<0
06mkKg/0=fmk10008Vmk1000MFmk001iKg/2000;Kg/2000FKg/2000fKg/2000jKg/2000TKg/2001f
Kg/00=E_N`@00=M_N`00eFmk1000efmk003FKg/2003HKg/00;M_N`8001i_N`03001_Nfmk021_N`80
0;A_N`00]Vmk10007Fmk00<006mkKg/07fmk1000/fmk002fKg/4000BKg/40007Kg/00`00Kg]_N`0O
Kg/4002cKg/00;M_N`8001E_N`03001_Nfmk00I_N`03001_Nfmk021_N`800;A_N`00V6mk0P00=6mk
00<006mkKg/01Fmk0P00:6mk0P006fmk0P00TFmk002GKg/4000_Kg/60005Kg/4000VKg/4000IKg/4
002@Kg/009M_N`@002I_N`H000A_N`04001_Nfmk0006Kg/6000TKg/4000IKg/4002@Kg/007E_N`80
00m_N`80011_N`80035_N`04001_Nfmk0007Kg/2000EKg/2000AKg/20008Kg/2000AKg/2000^Kg/2
001QKg/007A_N`@000e_N`@004=_N`03001_N`0000Q_N`03001_Nfmk019_N`@001U_N`@003m_N`@0
061_N`00M6mk10003Fmk1000@fmk00<006mk000026mk00<006mkKg/04Vmk10006Fmk1000?fmk1000
H6mk001eKg/2000?Kg/20015Kg/20008Kg/00`00Kg]_N`0CKg/2000KKg/20011Kg/2001QKg/00=M_
N`03001_Nfmk07e_N`8005M_N`00efmk00<006mkKg/0O6mk1000EVmk003GKg/00`00Kg]_N`1lKg/4
001FKg/00=M_N`03001_Nfmk07e_N`8005M_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3F
Kg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03
001_Nfmk0=I_N`00d6mk0P000Vmk0P0000A_N`000000021_N`800;A_N`00cfmk30007Vmk1000/fmk
003?Kg/<000NKg/4002cKg/00=1_N`80009_N`800004Kg/00000000PKg/2002dKg/006]_N`8006Y_
N`04001_NfmkKg/2000WKg/2002ZKg/006Y_N`@006U_N`03001_Nfmk00@002E_N`@00:U_N`00JVmk
1000JFmk1`009Fmk1000ZFmk001[Kg/2001ZKg/01000Kg]_Nfmk0P009fmk0P00ZVmk0030Kg/20002
Kg/2000AKg/00`00Kg]_N`3FKg/00;m_N`P0011_N`03001_Nfmk0=I_N`00_fmk200046mk00<006mk
Kg/0eVmk0030Kg/20002Kg/2000AKg/00`00Kg]_N`21Kg/2001CKg/00=M_N`03001_Nfmk081_N`@0
059_N`00efmk00<006mkKg/0P6mk1000DVmk003GKg/00`00Kg]_N`21Kg/2001CKg/009Y_N`8000m_
N`8000Y_N`8000M_N`80009_N`8000Y_N`80009_N`800003Kg/006mk03i_N`8009M_N`00VFmk1000
3Fmk100026mk10001Fmk200026mk2@00?Vmk1000UVmk002IKg/4000=Kg/40008Kg/40005Kg/80008
Kg/9000nKg/4002FKg/0069_N`8001=_N`8000Y_N`8001E_N`8000m_N`8000Y_N`8000M_N`80009_
N`8000Y_N`80009_N`800003Kg/006mk02m_N`8000e_N`8009M_N`00HFmk10004Fmk100026mk1000
DFmk00<006mkKg/0;Fmk1000YFmk001QKg/4000AKg/40008Kg/4001AKg/00`00Kg]_N`0]Kg/4002U
Kg/0069_N`8001=_N`8000Y_N`80059_N`03001_Nfmk02i_N`800:I_N`00]fmk0P001fmk0P001Vmk
0P003Fmk00<006mkKg/00fmk0P00dFmk002fKg/40005Kg/40004Kg/4000<Kg/00`00Kg]_N`02Kg/4
003@Kg/00;I_N`@000E_N`@000A_N`@000a_N`03001_Nfmk009_N`@00=1_N`00]fmk0P001fmk0P00
1Vmk0P003Fmk00<006mkKg/00fmk0P00dFmk001[Kg/2000FKg/2001BKg/3001CKg/20021Kg/006Y_
N`@001A_N`@0055_N`03001_Nfmk059_N`@0081_N`00JVmk100056mk1000DFmk00<006mkKg/0DVmk
1000P6mk001[Kg/2000@Kg/20004Kg/2001BKg/00`00Kg]_N`0KKg/2000?Kg/2000UKg/200000fmk
0000000[Kg/2001AKg/007a_N`@005M_N`03001_Nfmk01Y_N`@000e_N`@002I_N`@002U_N`@0051_
N`00O6mk1000Efmk00<006mkKg/06Vmk10003Fmk10009Vmk1000:Fmk1000D6mk001mKg/2001HKg/0
0`00Kg]_N`0KKg/2000?Kg/2000XKg/2000[Kg/2001AKg/00:U_N`80009_N`8002=_N`8000=_N`03
001_Nfmk04M_N`8001]_N`8001M_N`8005M_N`00Z6mk20008Fmk10000Vmk00<006mkKg/0AVmk1000
6Fmk10005Fmk1000EVmk002XKg/8000QKg/40002Kg/00`00Kg]_N`16Kg/4000IKg/4000EKg/4001F
Kg/00:U_N`80009_N`8002=_N`8000=_N`<003Q_N`8000M_N`8000A_N`8001U_N`@001M_N`8005M_
N`00efmk1000=Vmk10001Fmk10007Fmk1000LFmk003GKg/4000fKg/40005Kg/4000MKg/4001aKg/0
0=M_N`<003Q_N`8000M_N`8001m_N`80079_N`00CVmk0P00C6mk0P002fmk0P004fmk0P005fmk00<0
06mkKg/04Fmk0P00`fmk001=Kg/4001:Kg/40009Kg/4000AKg/4000FKg/00`00Kg]_N`0@Kg/40032
Kg/004e_N`@004Y_N`@000U_N`@0015_N`@001I_N`03001_Nfmk011_N`@00<9_N`00CVmk0P00C6mk
0P002fmk0P004fmk0P005fmk00<006mkKg/04Fmk0P00`fmk000cKg/2000FKg/2002:Kg/00`00Kg]_
N`1AKg/2000;Kg/2000WKg/2001=Kg/0039_N`@001A_N`@008U_N`03001_Nfmk051_N`@000U_N`@0
02E_N`@004a_N`00<Vmk100056mk1000RFmk00<006mkKg/0D6mk10002Fmk10009Fmk1000C6mk000c
Kg/2000FKg/2000fKg/2000CKg/2000mKg/3000IKg/2000dKg/4000;Kg/2000WKg/2000VKg/2000U
Kg/0089_N`@0015_N`@003a_N`03001_Nfmk01Q_N`@0039_N`@005a_N`@002A_N`00PVmk10004Fmk
1000?6mk00<006mkKg/066mk1000<Vmk1000G6mk100096mk0023Kg/2000CKg/2000mKg/00`00Kg]_
N`0IKg/2000dKg/2001NKg/2000UKg/002I_N`8009=_N`8001Y_N`03001_Nfmk01M_N`8000M_N`80
05U_N`8005U_N`009Fmk1000TFmk10006Fmk00<006mkKg/05Vmk10001Fmk1000Efmk1000F6mk000U
Kg/4002AKg/4000IKg/00`00Kg]_N`0FKg/40005Kg/4001GKg/4001HKg/002I_N`8005M_N`8002A_
N`8001A_N`80015_N`8000M_N`03001_Nfmk01M_N`8000M_N`8005U_N`8005U_N`00OVmk10008Vmk
10009Fmk10001Vmk00<006mkKg/0eVmk001nKg/4000RKg/4000UKg/40006Kg/00`00Kg]_N`3FKg/0
07m_N`8002A_N`8002M_N`8000M_N`03001_Nfmk0=I_N`00]fmk0P007Vmk00<006mkKg/0?Fmk0P00
Ufmk002fKg/4000MKg/00`00Kg]_N`0lKg/4002FKg/00;I_N`@001e_N`03001_Nfmk03a_N`@009I_
N`00W6mk0P002fmk0P0036mk0P007Vmk00<006mkKg/02Fmk0P000Vmk0P000Vmk0P00:Vmk0P008Fmk
0P00M6mk002KKg/40009Kg/4000[Kg/00`00Kg]_N`08Kg/<001;Kg/4001cKg/009]_N`@000U_N`@0
02]_N`03001_Nfmk00Q_N``004]_N`@007=_N`00W6mk0P002fmk0P007fmk1P001fmk00<006mkKg/0
2Fmk0P000Vmk0P000Vmk0P00CFmk0P00M6mk001LKg/20006Kg/2000CKg/2000KKg/2000bKg/00`00
Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0XKg/2002/Kg/005]_N`@000A_N`@0015_N`@001U_
N`@0039_N`03001_Nfmk00U_N`03001_Nfmk02M_N`@00:]_N`00Ffmk100016mk10004Fmk10006Fmk
1000<fmk00<006mkKg/026mk00<006mkKg/09fmk1000Zfmk001LKg/20006Kg/2000CKg/2000KKg/2
000YKg/60006Kg/00`00Kg]_N`07Kg/4000WKg/2002/Kg/001Q_N`8002]_N`8005U_N`8002a_N`03
001_Nfmk00I_N`03001_Nfmk01U_N`8004U_N`80071_N`005fmk1000:Fmk1000Efmk10009fmk00<0
06mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/066mk1000Afmk1000Kfmk000GKg/4000YKg/4001G
Kg/4000WKg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0HKg/40017Kg/4001_Kg/001Q_
N`8002]_N`8005U_N`8000e_N`8001Y_N`@000Q_N`03001_Nfmk01=_N`8000A_N`8004U_N`80071_
N`00[Vmk10009Fmk00<006mkKg/04Vmk1000`6mk002^Kg/4000UKg/00`00Kg]_N`0BKg/40030Kg/0
0:m_N`8002I_N`03001_Nfmk01=_N`800<5_N`00FVmk0P00;6mk0P002Vmk0P003fmk0P000Vmk0P00
3Vmk0P0076mk00<006mkKg/01Fmk0P002Vmk0P00MVmk0P001fmk0P00@Vmk001IKg/4000ZKg/40008
Kg/4000=Kg/8000<Kg/4000KKg/00`00Kg]_N`04Kg/40008Kg/4001dKg/40005Kg/40011Kg/005U_
N`@002Y_N`@000Q_N`@000e_N`P000a_N`@001]_N`03001_Nfmk00A_N`@000Q_N`@007A_N`@000E_
N`@0045_N`007Vmk0P005fmk0P007fmk1000;6mk0P002Vmk0P0016mk0P002Fmk0P000Vmk0P0026mk
0P000Vmk10002Fmk0P001Vmk0P002Fmk0`001Fmk0P002Vmk0P00H6mk0P0056mk0P001fmk0P0046mk
0P00<6mk000MKg/4000EKg/4000MKg/4000nKg/4000EKg/80009Kg/40004Kg/40008Kg/4001aKg/4
000]Kg/4000_Kg/001e_N`@001E_N`@001e_N`@003i_N`@001E_N`P000U_N`@000A_N`@000Q_N`@0
075_N`@002e_N`@002m_N`007Vmk0P005fmk0P007fmk0P00@6mk0P005fmk0P000Vmk0P002fmk0P00
1Vmk0P002Fmk0`00Lfmk0P00;fmk0P00<6mk0011Kg/2000KKg/2000;Kg/20006Kg/2000:Kg/2000O
Kg/2000eKg/00`00Kg]_N`0=Kg/20006Kg/2000hKg/20025Kg/0041_N`@001U_N`@000U_N`@000A_
N`@000Q_N`@001e_N`@003A_N`03001_Nfmk00a_N`@000A_N`@003I_N`@008A_N`00@6mk10006Fmk
10002Fmk100016mk100026mk10007Fmk1000=6mk00<006mkKg/036mk100016mk1000=Vmk1000Q6mk
0011Kg/2000KKg/2000;Kg/20006Kg/2000:Kg/2000OKg/2000eKg/00`00Kg]_N`0=Kg/20006Kg/2
000hKg/20025Kg/00=1_N`8000E_N`03001_Nfmk01M_N`8001M_N`8003A_N`8001]_N`8002=_N`80
02a_N`00cfmk100016mk00<006mkKg/05Vmk10005Fmk1000<Vmk10006Fmk10008Fmk1000:fmk003?
Kg/40004Kg/3000FKg/4000EKg/4000bKg/4000IKg/4000QKg/4000[Kg/005I_N`8005e_N`8001U_
N`8000E_N`04001_NfmkKg/2000>Kg/20004Kg/2000EKg/6000bKg/2000KKg/20004Kg/2000MKg/2
000/Kg/005E_N`@005]_N`@001m_N`03001_Nfmk00@000a_N`@001U_N`P005=_N`@004Y_N`00EFmk
1000Ffmk10007fmk00<006mkKg/0100036mk10006Fmk2000Dfmk1000BVmk001FKg/2001MKg/2000P
Kg/01000Kg]_Nfmk0P003Vmk0P006fmk0P000Vmk0P00EFmk0P00Bfmk001@Kg/2001IKg/2000:Kg/2
000;Kg/2000AKg/00`00Kg]_N`03Kg/2000:Kg/20006Kg/2001kKg/20010Kg/004m_N`@005M_N`@0
00Q_N`@000U_N`@0011_N`03001_Nfmk009_N`@000Q_N`@000A_N`@007U_N`@003m_N`00Cfmk1000
Efmk100026mk10002Fmk100046mk00<006mkKg/00Vmk100026mk100016mk1000NFmk1000?fmk001@
Kg/2000<Kg/2000/Kg/2000MKg/2000:Kg/2000;Kg/40006Kg/20007Kg/01000Kg]_Nfmk1P0026mk
0P0016mk10005Fmk0P006fmk0P001Vmk0P003fmk0P00;6mk100026mk0P003fmk0P009Fmk001MKg/4
000ZKg/4000fKg/40004Kg/40006Kg/00`00Kg]_N`08000<Kg/4000EKg/4000IKg/40004Kg/4000=
Kg/4000ZKg/40008Kg/4000=Kg/4000TKg/005e_N`@002Y_N`@003I_N`@000A_N`@000I_N`03001_
Nfmk00P000a_N`@001E_N`@001U_N`@000A_N`@000e_N`@002Y_N`@000Q_N`@000e_N`@002A_N`00
GVmk0P00;6mk0P00>6mk0P001Vmk0P001fmk00@006mkKg]_N`80009_N`8000i_N`8001M_N`8001]_
N`8000I_N`8000m_N`8002a_N`8000Y_N`8000m_N`8002E_N`00Yfmk0P004Vmk0P001fmk0P004Fmk
00<006mkKg/01fmk0P000Vmk0P007fmk0P00DFmk0P00@6mk0P004fmk002VKg/4000@Kg/40005Kg/4
000@Kg/00`00Kg]_N`06Kg/8000MKg/4001?Kg/4000nKg/4000BKg/00:I_N`@0011_N`@000E_N`@0
011_N`03001_Nfmk00I_N`P001e_N`@004m_N`@003i_N`@0019_N`00Yfmk0P004Vmk0P001fmk0P00
4Fmk00<006mkKg/01fmk0P000Vmk0P007fmk0P00DFmk0P00@6mk0P004fmk0019Kg/2000TKg/2000W
Kg/20002Kg/20007Kg/20002Kg/20002Kg/2000:Kg/2000LKg/00`00Kg]_N`09Kg/20002Kg/2000l
Kg/20006Kg/2000;Kg/2000hKg/2000jKg/004Q_N`@0029_N`@002E_N`P000E_N``000Q_N`@001]_
N`03001_Nfmk00Q_N`P003Y_N`@000A_N`@000U_N`@003I_N`@003U_N`00B6mk10008Vmk10009Fmk
20001Fmk300026mk10006fmk00<006mkKg/026mk2000>Vmk100016mk10002Fmk1000=Vmk1000>Fmk
000oKg/20008Kg/2000RKg/4000WKg/20002Kg/20007Kg/60002Kg/40006Kg/4000=Kg/2000=Kg/0
0`00Kg]_N`03Kg/20004Kg/20002Kg/40002Kg/20006Kg/2000PKg/2000<Kg/20006Kg/2000;Kg/2
0004Kg/2000bKg/20004Kg/20002Kg/2000`Kg/003i_N`@002Y_N`@003I_N`@000A_N`@000A_N`@0
00e_N`@000a_N`<0009_N`@000Q_N`P000A_N`@001i_N`@002E_N`@003I_N`P002m_N`00?Vmk1000
:Vmk1000=Vmk100016mk100016mk10003Fmk100036mk00<006mkKg/00Vmk100026mk200016mk1000
7Vmk10009Fmk1000=Vmk2000;fmk000oKg/2000/Kg/2000hKg/20006Kg/20006Kg/2000?Kg/2000=
Kg/00`00Kg]_N`03Kg/2000:Kg/20002Kg/20006Kg/2000PKg/2000WKg/2000hKg/20002Kg/2000`
Kg/007m_N`8000M_N`8001]_N`8001]_N`80009_N`8000i_N`80021_N`8000i_N`8004e_N`8005M_
N`00OVmk10001Fmk10006Fmk10006Fmk200036mk10007Vmk100036mk1000Bfmk1000EVmk001nKg/4
0005Kg/4000IKg/4000IKg/8000<Kg/4000NKg/4000<Kg/4001;Kg/4001FKg/001Y_N`8002M_N`80
03Y_N`8000M_N`8001]_N`8001]_N`P000I_N`80009_N`@000e_N`80009_N`80009_N`8000U_N`80
00Q_N`8000A_N`8004e_N`8005M_N`006Fmk10009Fmk1000OFmk200016mk2@0036mk30004Fmk1000
Zfmk000IKg/4000UKg/4001mKg/80004Kg/9000<Kg/<000AKg/4002[Kg/001Y_N`8002M_N`8007m_
N`80009_N`8000I_N`80009_N`800003Kg/006mk00a_N`80009_N`80009_N`8001=_N`800:a_N`00
R6mk0P000Vmk0P005fmk0P002Vmk0P002fmk0P005fmk00@006mkKg]_N`80009_N`80009_N`80009_
N`8000I_N`8004E_N`80009_N`8001M_N`8001M_N`8001I_N`8002Y_N`00Qfmk20005Fmk100026mk
10002Fmk10005Vmk00<006mkKg/0400016mk1000@fmk20005Fmk10005Fmk100056mk1000:Fmk0027
Kg/8000EKg/40008Kg/40009Kg/4000FKg/00`00Kg]_N`0@0004Kg/40013Kg/8000EKg/4000EKg/4
000DKg/4000YKg/008Q_N`80009_N`8001M_N`8000Y_N`8000]_N`8001M_N`04001_NfmkKg/20002
Kg/20002Kg/20002Kg/20006Kg/20015Kg/20002Kg/2000GKg/2000GKg/2000FKg/2000ZKg/00:=_
N`8000i_N`8000I_N`8000M_N`8000Y_N`8000E_N`03001_Nfmk00m_N`8000m_N`80065_N`80055_
N`00XVmk100036mk100016mk10001Fmk100026mk100016mk00<006mkKg/03Vmk10003Fmk1000Gfmk
1000D6mk002RKg/4000<Kg/40004Kg/40005Kg/40008Kg/40004Kg/00`00Kg]_N`0>Kg/4000=Kg/4
001OKg/4001@Kg/006I_N`8000m_N`8000m_N`8000I_N`80009_N`8000e_N`8000i_N`8000I_N`80
0003Kg/0000000A_N`8000Y_N`8000A_N`8000M_N`80009_N`8000A_N`8000Q_N`8000E_N`8000A_
N`80009_N`8003A_N`80025_N`8001U_N`8003I_N`00IFmk10003Fmk10003Fmk100016mk20009Vmk
100056mk10001Fmk200036mk10002Fmk2000<Vmk1000>Vmk1000=Fmk001UKg/4000=Kg/4000=Kg/4
0004Kg/8000VKg/4000DKg/40005Kg/8000<Kg/40009Kg/8000bKg/4000jKg/4000eKg/006I_N`80
00m_N`8000m_N`8000I_N`80009_N`8002Q_N`8001I_N`8000M_N`80009_N`8000i_N`8000]_N`80
009_N`8003A_N`8003a_N`8003I_N`00Afmk0P00?Fmk0P00:fmk0P005fmk0P000Vmk0P001Fmk0`00
4fmk0P000Vmk0P001fmk0P007fmk0P00<6mk0P00HFmk0016Kg/4000kKg/4000YKg/4000EKg/80004
Kg/00`00Kg]_N`0BKg/80005Kg/4000MKg/4000^Kg/4001PKg/004I_N`@003]_N`@002U_N`@001E_
N`P000A_N`03001_Nfmk019_N`P000E_N`@001e_N`@002i_N`@0061_N`00=6mk10003Fmk1000?6mk
1P001Fmk0P002Vmk0P005Fmk0P0016mk0P000fmk0P001Vmk0P000Vmk2P000fmk00@006mkKg]_N`80
009_N`80009_N`80009_N`8000A_N`80009_N`@000E_N`80011_N`8000e_N`@000M_N`H001I_N`80
00U_N`8002a_N`@0035_N`00=Vmk00<006mkKg/02fmk1000?Fmk00<006mkKg/00Vmk00<006mkKg/0
0Vmk100026mk10006Fmk100000=_N`0000000P0016mk40000Vmk00<006mkKg/0400026mk10005Fmk
10003Fmk10001Vmk00<006mkKg/00Vmk00<006mkKg/04fmk1000>6mk00<006mkKg/0<6mk000fKg/0
0`00Kg]_N`0;Kg/4000nKg/00`00Kg]_N`06Kg/40008Kg/4000IKg/400000fmk000000020004Kg/@
0002Kg/00`00Kg]_N`0@0008Kg/4000EKg/4000=Kg/40007Kg/00`00Kg]_N`0GKg/4000hKg/00`00
Kg]_N`0`Kg/0039_N`H000e_N`80041_N`03001_Nfmk00I_N`8000Y_N`8001]_N`8000=_N`8000I_
N`80009_N`80009_N`80009_N`8000=_N`04001_NfmkKg/20002Kg/20002Kg/20002Kg/2000:Kg/2
000GKg/2000?Kg/20009Kg/00`00Kg]_N`0GKg/2000eKg/6000aKg/002U_N`H000A_N`04001_Nfmk
000]Kg/2000FKg/60006Kg/00`00Kg]_N`0;Kg/2000?Kg/2000>Kg/2000;Kg/20002Kg/20002Kg/2
0002Kg/20005Kg/30007Kg/20002Kg/20002Kg/20006Kg/2000;Kg/2000KKg/2000<Kg/01000Kg/0
0000?Fmk0P003Vmk00@006mkKg/002I_N`8000Y_N`00<fmk00@006mkKg/002a_N`@0029_N`03001_
Nfmk00U_N`@000e_N`@000a_N`@000U_Na0000A_N`@000E_N``000A_N`@000U_N`@001U_N`@000a_
N`@003]_N`@000e_N`04001_Nfmk000UKg/40009Kg/003A_N`03001_N`0002a_N`@001i_N`03001_
Nfmk009_N`03001_Nfmk00Q_N`@000e_N`@000a_N`@000U_Na0000A_N`@000E_N``000A_N`@000U_
N`@001U_N`@000Q_N`04001_NfmkKg/4000kKg/4000>Kg/00`00Kg/0000UKg/40009Kg/003A_N`03
001_N`0002e_N`8001m_N`03001_Nfmk009_N`04001_N`000002Kg/20002Kg/6000=Kg/20008Kg/2
0002Kg/40005Kg/20002Kg/40002Kg/<0002Kg/400000fmk00000004Kg/20002Kg/80004Kg/2000;
Kg/2000KKg/20009Kg/00`00Kg]_N`02Kg/2000mKg/2000?Kg/00`00Kg/0000VKg/2000:Kg/003E_
N`8004m_N`@00003Kg/0000000h001E_N`P000E_N`P000A_Na000003Kg/00000008000Q_N`P003U_
N`@0055_N`80039_N`00Rfmk40005Fmk20001Fmk200016mk400000=_N`0000000P0026mk2000`Vmk
002<Kg/20002Kg/20002Kg/20002Kg/2000GKg/20002Kg/20007Kg/20002Kg/20006Kg/20002Kg/2
0002Kg/20002Kg/20003Kg/2000:Kg/20002Kg/20033Kg/005Q_N`80031_N`8000Y_N`8000m_N`80
01M_N`80009_N`8000Y_N`80009_N`800003Kg/006mk00A_N`8000i_N`8000m_N`80009_N`8000i_
N`8000m_N`8001m_N`8001]_N`80031_N`8001]_N`00Efmk1000;Vmk100026mk10003Fmk10005Fmk
200026mk2@0016mk100036mk10003Fmk200036mk10003Fmk10007Fmk10006Fmk1000;Vmk10006Vmk
001GKg/4000^Kg/40008Kg/4000=Kg/4000EKg/80008Kg/90004Kg/4000<Kg/4000=Kg/8000<Kg/4
000=Kg/4000MKg/4000IKg/4000^Kg/4000JKg/005Q_N`80031_N`8000Y_N`8000m_N`8001M_N`80
009_N`8000Y_N`80009_N`800003Kg/006mk00A_N`8000i_N`8000m_N`80009_N`8000i_N`8000m_
N`8001m_N`8001]_N`80031_N`8001]_N`0096mk0P007fmk0P000Vmk0P003fmk0P00=6mk0P007fmk
0P000Vmk0P001fmk0P001Vmk0P000Vmk0P000Vmk0P000Vmk0P000Vmk0P003fmk0P001Vmk0P007fmk
0P0096mk0P009fmk0P007fmk0P00;Vmk000SKg/4000MKg/8000=Kg/4000bKg/4000MKg/80005Kg/4
0004Kg/D000=Kg/40004Kg/4000MKg/4000RKg/4000UKg/4000MKg/4000]Kg/002=_N`@001e_N`P0
00e_N`@0039_N`@001e_N`P000E_N`@000A_Na@000e_N`@000A_N`@001e_N`@0029_N`@002E_N`@0
01e_N`@002e_N`00o`00/0000Fmk0008Kg/4000@Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0BKg/01000
Kg]_Nfmk10003Fmk00<006mkKg/01Fmk100026mk00<006mkKg/04Vmk00<006mkKg/00Vmk100036mk
00<006mkKg/01Vmk100016mk1@000fmk100016mk100000=_N`0000000P0026mk100016mk200000=_
N`0000000P0016mk40001Fmk10000fmk00<006mkKg/04Vmk1@0046mk00<006mkKg/02Vmk100016mk
00<006mkKg/04Fmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Vmk00<006mkKg/04Fmk
00<006mkKg/01fmk0008Kg/4000UKg/00`00Kg]_N`0FKg/4000EKg/4000MKg/00`00Kg]_N`02Kg/4
000EKg/40004Kg/40004Kg/40004Kg/400000fmk000000020008Kg/40004Kg/800000fmk00000002
0004Kg/@0005Kg/4000IKg/4000@Kg/00`00Kg]_N`0:Kg/40012Kg/00`00Kg]_N`0`Kg/000U_N`80
041_N`8001M_N`8002A_N`8001M_N`8000I_N`8000I_N`8000I_N`8000=_N`8000Y_N`8000I_N`80
0004Kg/000000003Kg/20006Kg/20002Kg/20002Kg/20002Kg/20007Kg/2000KKg/2000OKg/2001f
Kg/001A_N`80041_N`80009_N`8000m_N`8000i_N`8002Q_N`8000I_N`80009_N`80009_N`8000M_
N`80009_N`80009_N`80009_N`80009_N`80009_N`80009_N`8000=_N`80009_N`8000I_N`8000Y_
N`8000m_N`8000m_N`8003=_N`8001M_N`8004]_N`004fmk1000?Vmk20003Fmk100036mk10009Vmk
100016mk30001Fmk700000=_N`0000001P0016mk100026mk10003Fmk10003Fmk1000<Fmk10005Fmk
1000BVmk000CKg/4000nKg/8000=Kg/4000<Kg/4000VKg/40004Kg/<0005Kg/L00000fmk00000006
0004Kg/40008Kg/4000=Kg/4000=Kg/4000aKg/4000EKg/4001:Kg/001A_N`80025_N`8001e_N`80
009_N`8000m_N`8000i_N`8000e_N`8001U_N`8000I_N``000E_N`80009_N`80009_N`80009_N`H0
009_N`H000=_N`80009_N`8000A_N`@000Q_N`H000e_N`8000Q_N`8000E_N`@000Y_N`8001=_N`80
011_N`8001M_N`8004]_N`00=Vmk1000Cfmk10008Fmk30004Fmk100016mk1@0036mk100026mk2000
5Fmk10001Fmk100026mk10004Fmk1000MFmk000fKg/4001?Kg/4000QKg/<000AKg/40004Kg/5000<
Kg/40008Kg/8000EKg/40005Kg/40008Kg/4000AKg/4001eKg/003M_N`80055_N`8002=_N`80009_
N`80009_N`8001=_N`8000I_N`800003Kg/006mk00a_N`8000Y_N`80009_N`8001M_N`8000M_N`80
00Y_N`8001=_N`8007I_N`0056mk0P004Vmk0P000Vmk0P00>6mk0P003fmk0P002Vmk0P001fmk0P00
7fmk0P000Vmk0P001Vmk0P001fmk0P000Vmk0P000Vmk0P002fmk00@006mkKg]_N`8000I_N`8000i_
N`8000M_N`8000Y_N`8003Q_N`8001M_N`8005=_N`004fmk100046mk2000=Vmk10003Fmk100026mk
10001Fmk10007Fmk200016mk10001Fmk30002Vmk00<006mkKg/0100016mk100036mk10001Fmk1000
26mk1000=Vmk10005Fmk1000DVmk000CKg/4000@Kg/8000fKg/4000=Kg/40008Kg/40005Kg/4000M
Kg/80004Kg/40005Kg/<000:Kg/00`00Kg]_N`040004Kg/4000<Kg/40005Kg/40008Kg/4000fKg/4
000EKg/4001BKg/001A_N`80019_N`80009_N`8003Q_N`8000m_N`8000Y_N`8000M_N`8001m_N`80
009_N`8000I_N`8000M_N`80009_N`80009_N`8000]_N`04001_NfmkKg/20006Kg/2000>Kg/20007
Kg/2000:Kg/2000hKg/2000GKg/2001CKg/005A_N`8001M_N`8002=_N`80031_N`80009_N`80009_
N`8000U_N`03001_Nfmk00M_N`80009_N`8000I_N`80009_N`80009_N`8000=_N`8001]_N`80009_
N`8002=_N`8006i_N`00Dfmk10005Fmk10008Fmk1000;Vmk300026mk00<006mkKg/01Vmk200016mk
300000=_N`0000000P006Fmk20008Fmk1000KFmk001CKg/4000EKg/4000QKg/4000^Kg/<0008Kg/0
0`00Kg]_N`06Kg/80004Kg/<00000fmk00000002000IKg/8000QKg/4001]Kg/005A_N`8001M_N`80
02=_N`@000m_N`80009_N`80009_N`8001=_N`P0009_N`@0009_N`8000=_N`04001_NfmkKg/20004
Kg/60006Kg/60002Kg/20003Kg/4000IKg/20002Kg/4000KKg/20002Kg/40012Kg/2000ZKg/009=_
N`@000e_N``0015_N`P000A_N`P0009_N`03001_Nfmk00@000A_N`@000Q_N`@000U_N`@001e_N`@0
01U_N`P0049_N`@002U_N`00Tfmk10003Fmk30004Fmk200016mk20000Vmk1`0016mk100026mk1000
2Fmk10007Fmk10006Fmk2000@Vmk1000:Fmk002DKg/2000?Kg/20002Kg/20002Kg/2000CKg/20002
Kg/20006Kg/20002Kg/20003Kg/01000Kg]_Nfmk0P001Vmk0P002Vmk0P002fmk0P007fmk0P006fmk
0P000Vmk0P00A6mk0P00:Vmk001mKg/2000?Kg/2000CKg/2000OKg/20002Kg/2000:Kg/2000016mk
000000000fmk0P002Vmk0P004fmk0P007fmk0P003fmk0P00OVmk001lKg/4000=Kg/4000AKg/4000M
Kg/80008Kg/800000fmk000000020008Kg/4000AKg/4000MKg/4000=Kg/4001mKg/007a_N`@000e_
N`@0015_N`@001e_N`P000Q_N`P00003Kg/00000008000Q_N`@0015_N`@001e_N`@000e_N`@007e_
N`0076mk0P00?6mk0P008Fmk0P003fmk0P0016mk0P003Fmk0P007Fmk2P0026mk0P0000A_N`000000
00=_N`@0009_N`80009_N`@000e_N`80009_N`@000A_N`8001U_N`8000m_N`8007i_N`006fmk1000
>Vmk1000=Vmk1000:Vmk30002Vmk00<006mkKg/016mk30003Fmk200016mk1000ZFmk000KKg/4000j
Kg/4000fKg/4000ZKg/<000:Kg/00`00Kg]_N`04Kg/<000=Kg/80004Kg/4002YKg/001a_N`8003a_
N`8003Q_N`8002a_N`80009_N`80009_N`8000]_N`03001_Nfmk00E_N`80009_N`80009_N`8000m_
N`80009_N`8000I_N`800:Y_N`00:Vmk0P00KVmk0P004fmk0P000Vmk0P004fmk0P000Vmk0P000Vmk
0P001Fmk0`002fmk0P002Vmk0P000Vmk0P002fmk0P003Vmk0P0076mk0P00B6mk0P000Vmk0P000Vmk
0P00;6mk000YKg/4001/Kg/4000AKg/8000AKg/<0004Kg/40009Kg/40008Kg/80009Kg/4000<Kg/4
000JKg/40016Kg/<000[Kg/002U_N`@006a_N`@0015_N`P0015_N``000A_N`@000U_N`@000Q_N`P0
00U_N`@000a_N`@001Y_N`@004I_N``002]_N`00:Vmk0P00KVmk0P004fmk0P000Vmk0P004fmk0P00
0Vmk0P000Vmk0P001Fmk0`002fmk0P002Vmk0P000Vmk0P002fmk0P003Vmk0P0076mk0P00B6mk0P00
0Vmk0P000Vmk0P00;6mk000PKg/2001EKg/20002Kg/2000?Kg/2000KKg/2000CKg/2000:Kg/2000;
Kg/00`00Kg]_N`0RKg/2000>Kg/20007Kg/2002IKg/001m_N`@005=_N`P000e_N`@001U_N`@0015_
N`@000Q_N`@000Y_N`03001_Nfmk025_N`@000a_N`@000E_N`@009Q_N`007fmk1000Dfmk20003Fmk
10006Fmk10004Fmk100026mk10002Vmk00<006mkKg/08Fmk100036mk10001Fmk1000V6mk000NKg/6
001CKg/20002Kg/2000?Kg/2000EKg/20004Kg/2000CKg/2000:Kg/2000;Kg/3000GKg/20002Kg/2
0005Kg/4000<Kg/20004Kg/200000fmk00000004Kg/2000:Kg/20027Kg/001e_N`P007e_N`@0035_
N`@001E_N`P000E_N`@0011_N`@000E_N`@000Q_N`@008I_N`007Fmk2000OFmk1000<Fmk10005Fmk
20001Fmk100046mk10001Fmk100026mk1000QVmk000NKg/20002Kg/2001oKg/2000bKg/3000GKg/2
0002Kg/20007Kg/2000BKg/20007Kg/2000:Kg/20027Kg/003e_N`8006I_N`8002=_N`8000]_N`03
001_Nfmk015_N`8002=_N`80021_N`8007a_N`00?6mk1000I6mk10008Fmk10002Vmk0`0046mk1000
8Fmk10007Vmk1000Nfmk000lKg/4001TKg/4000QKg/4000:Kg/00`00Kg]_N`0@Kg/4000QKg/4000N
Kg/4001kKg/001i_N`8001e_N`8006I_N`8001U_N`8000Q_N`8000Q_N`800003Kg/006mk00Q_N`80
009_N`8000A_N`8001E_N`8000a_N`80021_N`@007Y_N`007Fmk1000WVmk100046mk1@0026mk2000
6Fmk1000;Vmk1000NFmk000MKg/4002NKg/4000@Kg/50008Kg/8000IKg/4000^Kg/4001iKg/001i_
N`800:1_N`80019_N`800003Kg/006mk00Q_N`80009_N`8001]_N`80031_N`8007Y_N`00HVmk0P00
0Vmk0P00<6mk0P002fmk0P009fmk0P001Vmk0P000fmk0P002Vmk0P00afmk001QKg/8000^Kg/40009
Kg/4000UKg/40004Kg/400000fmk000000020008Kg/40036Kg/0065_N`P002i_N`@000U_N`@002E_
N`@000A_N`@00003Kg/00000008000Q_N`@00<I_N`00HVmk0P000Vmk0P00<6mk0P002fmk0P009fmk
0P001Vmk0P000fmk0P002Vmk0P00afmk0013Kg/2000XKg/2000>Kg/20015Kg/2000AKg/3000;Kg/2
000:Kg/20002Kg/2000`Kg/20002Kg/20023Kg/0049_N`@002I_N`@000a_N`@004=_N`@0011_N`@0
00U_N`@000Q_N`P002i_N`P0089_N`00@Vmk10009Vmk100036mk1000@fmk100046mk10002Fmk1000
26mk2000;Vmk2000PVmk0013Kg/2000XKg/20008Kg/20004Kg/2000EKg/20002Kg/2000;Kg/2000K
Kg/40008Kg/20007Kg/3000;Kg/2000:Kg/20002Kg/2000`Kg/20002Kg/40021Kg/007I_N`@001U_
N`P000U_N`@001U_N`@000Q_N`@000I_N`03001_Nfmk059_N`@0081_N`00MVmk10006Fmk20002Fmk
10006Fmk100026mk10001Vmk00<006mkKg/0DVmk1000P6mk001gKg/2000KKg/20002Kg/2000;Kg/2
000KKg/2000:Kg/20007Kg/00`00Kg]_N`1CKg/20021Kg/009I_N`8001]_N`8000m_N`80015_N`03
001_Nfmk02a_N`8000m_N`8000Y_N`8008]_N`00UFmk10006Fmk10003Fmk100046mk00<006mkKg/0
:fmk10003Fmk100026mk1000RVmk002EKg/4000IKg/4000=Kg/4000@Kg/00`00Kg]_N`0[Kg/4000=
Kg/40008Kg/4002:Kg/001Q_N`8002]_N`8002a_N`80025_N`8001]_N`8000m_N`80015_N`03001_
Nfmk02a_N`8000m_N`8000A_N`8000A_N`8008]_N`005fmk1000:Fmk1000:Vmk1000HFmk0`00@Vmk
1000T6mk000GKg/4000YKg/4000ZKg/4001QKg/00`00Kg]_N`12Kg/4002@Kg/001Q_N`8002]_N`80
02a_N`80069_N`03001_Nfmk04=_N`80095_N`00D6mk0P00?6mk0P007fmk0P001Vmk0P007Vmk00<0
06mkKg/05fmk0P00>6mk0P00Pfmk001?Kg/4000jKg/4000MKg/40004Kg/4000MKg/00`00Kg]_N`0F
Kg/4000fKg/40022Kg/004m_N`@003Y_N`@001e_N`@000A_N`@001e_N`03001_Nfmk01I_N`@003I_
N`@0089_N`00D6mk0P00?6mk0P007fmk0P0016mk10001Fmk0P005fmk00<006mkKg/05fmk10004fmk
0P000Vmk0P007Fmk0P008Vmk0P00Gfmk002dKg/40005Kg/4000FKg/00`00Kg]_N`0HKg/4000AKg/8
000oKg/4001NKg/00;A_N`@000E_N`@001I_N`03001_Nfmk01Q_N`@0015_N`P003m_N`@005i_N`00
]Fmk0P001fmk0P005fmk00<006mkKg/06Fmk0P004fmk0P000Vmk0P00@Fmk0P00Gfmk002:Kg/20006
Kg/2000GKg/20002Kg/20002Kg/2000GKg/20002Kg/20005Kg/3000KKg/2002PKg/2000GKg/008U_
N`@000A_N`@001E_N``001E_N`P000A_N`@001U_N`@009i_N`@001I_N`00RFmk100016mk10005Fmk
30005Fmk200016mk10006Fmk1000WVmk10005Vmk002:Kg/20006Kg/2000GKg/20002Kg/20002Kg/2
000GKg/20002Kg/20005Kg/3000KKg/2002PKg/2000GKg/0069_N`8002a_N`8004A_N`8000M_N`80
03A_N`8004Q_N`8001M_N`8003I_N`00HFmk1000:Vmk1000@Vmk10001Fmk1000<Vmk1000AVmk1000
5Fmk1000=Fmk001QKg/4000ZKg/40012Kg/40005Kg/4000bKg/40016Kg/4000EKg/4000eKg/0069_
N`8001e_N`8000]_N`@003I_N`P000I_N`8000M_N`80025_N`80015_N`8004Q_N`8001M_N`8003I_
N`00P6mk10002Fmk1000=Vmk100016mk00<006mkKg/01Fmk00<006mkKg/09fmk1000Zfmk0020Kg/4
0009Kg/4000fKg/5000;Kg/00`00Kg]_N`0WKg/4002[Kg/0085_N`8000]_N`8003Q_N`80009_N`03
001_Nfmk00Q_N`03001_Nfmk02Q_N`800:a_N`00Lfmk0P007fmk0P00=fmk00<006mkKg/01fmk1000
16mk0P00=6mk0P006fmk0P000Vmk0P00N6mk001bKg/4000MKg/4000gKg/00`00Kg]_N`06Kg/00`00
Kg]_N`04Kg/4000bKg/4000IKg/8001gKg/0079_N`@001e_N`@003=_N`03001_Nfmk009_N`03001_
Nfmk00E_N`03001_Nfmk00A_N`@0039_N`@001U_N`P007M_N`00>fmk0P00=Vmk0P007fmk0P00;Vmk
0P0016mk00H006mk000006mk0007Kg/30005Kg/20004Kg/2000CKg/2000:Kg/2000=Kg/2000KKg/2
0002Kg/2001hKg/003Y_N`@008E_N`@000A_N`@000Q_N`@000U_N`@0015_N`@000Q_N`@00:M_N`00
>Vmk1000QFmk100016mk100026mk10002Fmk10004Fmk100026mk1000Yfmk000kKg/20027Kg/20006
Kg/20009Kg/3000;Kg/2000CKg/2000:Kg/2002XKg/0021_N`8004A_N`8002A_N`8001m_N`8000Y_
N`8000m_N`8000]_N`03001_Nfmk015_N`80009_N`8000M_N`8003=_N`8001M_N`8006Q_N`007fmk
1000@Vmk10008Vmk10007Fmk100026mk10003Fmk10002Vmk00<006mkKg/046mk20001Fmk1000<Fmk
10005Fmk1000Ifmk000OKg/40012Kg/4000RKg/4000MKg/40008Kg/4000=Kg/4000:Kg/00`00Kg]_
N`0@Kg/80005Kg/4000aKg/4000EKg/4001WKg/0021_N`8004A_N`8002A_N`8001m_N`8000Y_N`80
00m_N`8000]_N`03001_Nfmk015_N`80009_N`8000M_N`8003=_N`8001M_N`8006Q_N`00<fmk0P00
B6mk0P00AFmk0P002Vmk0P001Fmk00<006mkKg/01fmk0P00:fmk0P00<6mk0P00KVmk000bKg/40016
Kg/40013Kg/40008Kg/40004Kg/00`00Kg]_N`06Kg/4000YKg/4000^Kg/4001]Kg/0039_N`@004I_
N`@004=_N`@000Q_N`@000A_N`03001_Nfmk00I_N`@002U_N`@002i_N`@006e_N`00<fmk0P0016mk
0P00@Vmk0P008Fmk0P002fmk0P005Fmk0P0026mk10001Fmk00<006mkKg/01fmk0P00:fmk0P00<6mk
0P00:Vmk0P00@Vmk000hKg/4001SKg/40009Kg/4000MKg/40006Kg/00`00Kg]_N`2AKg/40011Kg/0
03Q_N`@006=_N`@000U_N`@001e_N`@000I_N`03001_Nfmk095_N`@0045_N`00>Fmk0P00IFmk0P00
2fmk0P007fmk0P001fmk00<006mkKg/0TVmk0P00@Vmk001@Kg/2000>Kg/20015Kg/20006Kg/2000V
Kg/00`00Kg]_N`0PKg/2001UKg/2000KKg/2000`Kg/004m_N`@000a_N`@004=_N`@000A_N`@002E_
N`03001_Nfmk01m_N`@006=_N`@001U_N`@002m_N`00Cfmk100036mk1000@fmk100016mk10009Fmk
0`007fmk1000Hfmk10006Fmk1000;fmk0011Kg/2000=Kg/2000>Kg/2000ZKg/2000BKg/20005Kg/2
0006Kg/2000VKg/00`00Kg]_N`0PKg/2001UKg/2000=Kg/2000<Kg/2000`Kg/0041_N`@004M_N`@0
011_N`@003A_N`03001_Nfmk09E_N`@003e_N`00@6mk1000Afmk100046mk1000=6mk00<006mkKg/0
UFmk1000?Fmk0011Kg/20019Kg/2000BKg/2000eKg/00`00Kg]_N`2FKg/2000nKg/006A_N`8000m_
N`80061_N`03001_Nfmk05I_N`8007i_N`00Hfmk10003Fmk1000Gfmk00<006mkKg/0EFmk1000OFmk
001SKg/4000=Kg/4001OKg/00`00Kg]_N`1EKg/4001mKg/006A_N`8000m_N`80061_N`03001_Nfmk
05I_N`8007i_N`00Jfmk0P005Vmk0P002fmk0P009fmk0P004fmk0P001fmk00<006mkKg/09Vmk0P00
7fmk0P00SFmk001ZKg/4000DKg/40009Kg/4000UKg/4000AKg/40006Kg/00`00Kg]_N`0UKg/4000M
Kg/4002<Kg/006Y_N`@001A_N`@000U_N`@002E_N`@0015_N`@000I_N`03001_Nfmk02E_N`@001e_
N`@008a_N`00E6mk0P001Vmk0P003Fmk0P005Vmk0P002fmk0P009fmk10004Fmk10001Fmk00<006mk
Kg/00fmk0P006fmk0P0016mk0P007fmk0P006Fmk0P00LVmk001CKg/40004Kg/4001KKg/4000AKg/4
0004Kg/00`00Kg]_N`02Kg/4000IKg/4000nKg/4001aKg/005=_N`@000A_N`@005]_N`@0015_N`@0
00A_N`03001_Nfmk009_N`@001U_N`@003i_N`@0075_N`00E6mk0P001Vmk0P00GFmk0P004fmk0P00
1Fmk00<006mkKg/00fmk0P006fmk0P00@6mk0P00LVmk001NKg/20002Kg/2000/Kg/2000CKg/2000`
Kg/00`00Kg]_N`1TKg/2001`Kg/005e_N`P002Y_N`@0015_N`@002m_N`03001_Nfmk06=_N`@006m_
N`00GFmk2000:Vmk10004Fmk1000;fmk00<006mkKg/0Hfmk1000Kfmk001NKg/20002Kg/2000/Kg/2
000CKg/2000QKg/2000=Kg/00`00Kg]_N`1TKg/2000UKg/20019Kg/00<M_N`@000a_N`03001_Nfmk
08Y_N`@004Q_N`00afmk100036mk0`00RVmk1000B6mk0038Kg/2000=Kg/00`00Kg]_N`2;Kg/20019
Kg/00:U_N`8000I_N`8000m_N`80019_N`800=Q_N`00Z6mk100016mk10003Fmk100046mk1000efmk
002XKg/40004Kg/4000=Kg/4000@Kg/4003GKg/005Q_N`8004m_N`8000A_N`@000m_N`80019_N`80
0=Q_N`00Efmk1000Dfmk10009Fmk00<006mkKg/0eVmk001GKg/4001CKg/4000UKg/00`00Kg]_N`3F
Kg/005Q_N`8005E_N`8002I_N`03001_Nfmk0=I_N`00R6mk0P00?6mk0P000Vmk0P002fmk00<006mk
Kg/0I6mk0P00L6mk0027Kg/4000jKg/8000:Kg/00`00Kg]_N`1SKg/4001_Kg/008M_N`@003Y_N`P0
00Y_N`03001_Nfmk06=_N`@006m_N`00R6mk0P00?6mk0P000Vmk0P002fmk00<006mkKg/0I6mk0P00
L6mk001iKg/2001LKg/00`00Kg]_N`3FKg/007Q_N`@005]_N`03001_Nfmk0=I_N`00N6mk1000Ffmk
00<006mkKg/0eVmk001FKg/2000QKg/2001LKg/00`00Kg]_N`1/Kg/2001XKg/005E_N`@007i_N`03
001_Nfmk06]_N`@006M_N`00EFmk1000OVmk00<006mkKg/0Jfmk1000Ifmk001FKg/2001oKg/00`00
Kg]_N`1/Kg/2001XKg/0061_N`80045_N`80009_N`8002M_N`8000E_N`03001_Nfmk02Q_N`8001]_
N`8002a_N`80065_N`00Gfmk1000?fmk20009Fmk100016mk0`009fmk10006Fmk1000:Vmk1000H6mk
001OKg/4000oKg/8000UKg/40004Kg/00`00Kg]_N`0WKg/4000IKg/4000ZKg/4001PKg/0061_N`80
045_N`80009_N`8002M_N`8000E_N`03001_Nfmk00e_N`8001U_N`8001]_N`8002a_N`80065_N`00
efmk00<006mkKg/036mk1000aVmk003GKg/00`00Kg]_N`0<Kg/40036Kg/00=M_N`03001_Nfmk00e_
N`800<M_N`00D6mk0P003Vmk0P00BFmk0P003Vmk0P006Vmk00<006mkKg/0eVmk001?Kg/4000<Kg/4
0017Kg/4000<Kg/4000IKg/00`00Kg]_N`3FKg/004m_N`@000a_N`@004M_N`@000a_N`@001U_N`03
001_Nfmk0=I_N`00D6mk0P003Vmk0P00BFmk0P003Vmk0P006Vmk00<006mkKg/0eVmk001kKg/2001J
Kg/00`00Kg]_N`09Kg/2000:Kg/20011Kg/2001lKg/007Y_N`@005U_N`03001_Nfmk00Q_N`@000Q_
N`@003m_N`@007]_N`00NVmk1000FFmk00<006mkKg/026mk100026mk1000?fmk1000Nfmk001kKg/2
0009Kg/20010Kg/2000=Kg/00`00Kg]_N`09Kg/2000:Kg/2000EKg/2000ZKg/2000MKg/2001MKg/0
08E_N`@003i_N`@000a_N`03001_Nfmk02]_N`@004M_N`@005a_N`00QFmk1000?Vmk100036mk00<0
06mkKg/0:fmk1000Afmk1000G6mk0026Kg/20010Kg/2000=Kg/00`00Kg]_N`0/Kg/20019Kg/2001M
Kg/00<a_N`@000M_N`03001_Nfmk0=I_N`00cVmk00<006mkKg/01Vmk00<006mkKg/0eVmk003>Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`3FKg/0085_N`8004M_N`H000M_N`03001_Nfmk045_N`8009=_N`00
P6mk1000Afmk00@006mkKg/000Q_N`@003m_N`@0099_N`00P6mk1000Afmk00@006mkKg/000Q_N`03
001_Nfmk041_N`@0099_N`00PFmk0P00BFmk00<006mk000026mk00<006mkKg/0@Fmk0P00Tfmk0032
Kg/20008Kg/00`00Kg/00008Kg/00`00Kg]_N`3FKg/00<5_N`@000Q_N`8000Q_N`03001_Nfmk0=I_
N`00`Fmk10004Vmk00<006mkKg/0eVmk0032Kg/2000CKg/00`00Kg]_N`3FKg/006U_N`8006a_N`03
001_Nfmk0=I_N`00J6mk1000Jfmk00<006mkKg/0eVmk001XKg/4001[Kg/00`00Kg]_N`3FKg/006U_
N`8006a_N`03001_Nfmk01E_N`800;m_N`00efmk00<006mkKg/056mk1000_Vmk003GKg/00`00Kg]_
N`0DKg/4002nKg/00=M_N`03001_Nfmk01E_N`800;m_N`00efmk00<006mkKg/0eVmk003GKg/00`00
Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/05Fmk0P00;6mk0P00TFmk003GKg/0
0`00Kg]_N`0DKg/4000ZKg/4002@Kg/00=M_N`03001_Nfmk01A_N`@002Y_N`@0091_N`00efmk0`00
5Fmk0P00;6mk0P00TFmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mk
Kg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk01U_N`800;]_N`00efmk00<006mkKg/0
66mk1000^Vmk003GKg/00`00Kg]_N`0HKg/4002jKg/009i_N`8003M_N`03001_Nfmk00M_N`80011_
N`800;]_N`00WFmk1000=Vmk00<006mkKg/01Vmk1000c6mk002MKg/4000fKg/00`00Kg]_N`06Kg/4
003<Kg/009i_N`8003M_N`03001_Nfmk00M_N`800<e_N`00efmk00<006mkKg/02Fmk0P00bfmk003G
Kg/00`00Kg]_N`08Kg/4003:Kg/00=M_N`03001_Nfmk00Q_N`@00<Y_N`00efmk00<006mkKg/01fmk
100046mk0P00^Fmk003GKg/00`00Kg]_N`06Kg/4000@Kg/4002hKg/00=M_N`03001_Nfmk00I_N`@0
011_N`@00;Q_N`00efmk00<006mkKg/01fmk0P004Vmk0P00^Fmk003>Kg/20007Kg/00`00Kg]_N`3F
Kg/00<e_N`@000I_N`03001_Nfmk0=I_N`00cFmk10001Vmk0`00eVmk003>Kg/20007Kg/00`00Kg]_
N`3FKg/00=M_N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_
N`03001_Nfmk0=I_N`00efmk00<006mkKg/0eVmk003GKg/00`00Kg]_N`3FKg/00=M_N`03001_Nfmk
0=I_N`00efmk00<006mkKg/0eVmk0000\
\>"],
  ImageRangeCache->{{{0, 431}, {429.75, 0}} -> {-5.19828, -5.13732, \
0.0361829, 0.0361829}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["after one iteration", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[pp, AspectRatio \[Rule] Automatic, \ 
      PlotStyle \[Rule] {PointSize[0.01], RGBColor[1, 0, 0]}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00271 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50502 0.0937202 0.495973 0.0937202 [
[.13014 .48347 -6 -9 ]
[.13014 .48347 6 0 ]
[.31758 .48347 -6 -9 ]
[.31758 .48347 6 0 ]
[.69246 .48347 -3 -9 ]
[.69246 .48347 3 0 ]
[.8799 .48347 -3 -9 ]
[.8799 .48347 3 0 ]
[.49252 .12109 -12 -4.5 ]
[.49252 .12109 0 4.5 ]
[.49252 .30853 -12 -4.5 ]
[.49252 .30853 0 4.5 ]
[.49252 .68341 -6 -4.5 ]
[.49252 .68341 0 4.5 ]
[.49252 .87085 -6 -4.5 ]
[.49252 .87085 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.00271 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13014 .49597 m
.13014 .50222 L
s
[(-4)] .13014 .48347 0 1 Mshowa
.31758 .49597 m
.31758 .50222 L
s
[(-2)] .31758 .48347 0 1 Mshowa
.69246 .49597 m
.69246 .50222 L
s
[(2)] .69246 .48347 0 1 Mshowa
.8799 .49597 m
.8799 .50222 L
s
[(4)] .8799 .48347 0 1 Mshowa
.125 Mabswid
.177 .49597 m
.177 .49972 L
s
.22386 .49597 m
.22386 .49972 L
s
.27072 .49597 m
.27072 .49972 L
s
.36444 .49597 m
.36444 .49972 L
s
.4113 .49597 m
.4113 .49972 L
s
.45816 .49597 m
.45816 .49972 L
s
.55188 .49597 m
.55188 .49972 L
s
.59874 .49597 m
.59874 .49972 L
s
.6456 .49597 m
.6456 .49972 L
s
.73932 .49597 m
.73932 .49972 L
s
.78618 .49597 m
.78618 .49972 L
s
.83304 .49597 m
.83304 .49972 L
s
.08328 .49597 m
.08328 .49972 L
s
.03642 .49597 m
.03642 .49972 L
s
.92676 .49597 m
.92676 .49972 L
s
.97362 .49597 m
.97362 .49972 L
s
.25 Mabswid
0 .49597 m
1 .49597 L
s
.50502 .12109 m
.51127 .12109 L
s
[(-4)] .49252 .12109 1 0 Mshowa
.50502 .30853 m
.51127 .30853 L
s
[(-2)] .49252 .30853 1 0 Mshowa
.50502 .68341 m
.51127 .68341 L
s
[(2)] .49252 .68341 1 0 Mshowa
.50502 .87085 m
.51127 .87085 L
s
[(4)] .49252 .87085 1 0 Mshowa
.125 Mabswid
.50502 .16795 m
.50877 .16795 L
s
.50502 .21481 m
.50877 .21481 L
s
.50502 .26167 m
.50877 .26167 L
s
.50502 .35539 m
.50877 .35539 L
s
.50502 .40225 m
.50877 .40225 L
s
.50502 .44911 m
.50877 .44911 L
s
.50502 .54283 m
.50877 .54283 L
s
.50502 .58969 m
.50877 .58969 L
s
.50502 .63655 m
.50877 .63655 L
s
.50502 .73027 m
.50877 .73027 L
s
.50502 .77713 m
.50877 .77713 L
s
.50502 .82399 m
.50877 .82399 L
s
.50502 .07423 m
.50877 .07423 L
s
.50502 .02737 m
.50877 .02737 L
s
.50502 .91771 m
.50877 .91771 L
s
.50502 .96457 m
.50877 .96457 L
s
.25 Mabswid
.50502 0 m
.50502 1.00271 L
s
0 0 m
1 0 L
1 1.00271 L
0 1.00271 L
closepath
clip
newpath
1 0 0 r
.01 w
.47668 .02387 Mdot
.46256 .04492 Mdot
.53059 .04244 Mdot
.5799 .05683 Mdot
.44714 .06888 Mdot
.5311 .08384 Mdot
.47579 .09113 Mdot
.28155 .08025 Mdot
.32353 .08263 Mdot
.38454 .0854 Mdot
.64633 .0785 Mdot
.72336 .09054 Mdot
.50404 .10035 Mdot
.43102 .11889 Mdot
.58187 .1075 Mdot
.37037 .12864 Mdot
.50708 .11875 Mdot
.60151 .11427 Mdot
.67376 .1247 Mdot
.27735 .13063 Mdot
.32853 .14249 Mdot
.55158 .13057 Mdot
.62307 .13271 Mdot
.76388 .12349 Mdot
.80547 .13282 Mdot
.48218 .14967 Mdot
.49154 .15403 Mdot
.51425 .15634 Mdot
.57715 .16358 Mdot
.25826 .15729 Mdot
.52976 .17316 Mdot
.61044 .17146 Mdot
.44652 .15372 Mdot
.46322 .16692 Mdot
.8077 .18016 Mdot
.3668 .18917 Mdot
.398 .18281 Mdot
.42231 .18355 Mdot
.45167 .19233 Mdot
.47091 .19433 Mdot
.49684 .19308 Mdot
.50389 .20136 Mdot
.65574 .18429 Mdot
.23268 .19946 Mdot
.28199 .19066 Mdot
.32294 .19057 Mdot
.61667 .19886 Mdot
.43407 .21385 Mdot
.45507 .22523 Mdot
.47664 .21495 Mdot
.5284 .20889 Mdot
.25736 .22967 Mdot
.33055 .22265 Mdot
.69834 .20225 Mdot
.30245 .23243 Mdot
.57272 .21949 Mdot
.61102 .22862 Mdot
.70487 .21787 Mdot
.81815 .218 Mdot
.39723 .22711 Mdot
.41907 .23203 Mdot
.48988 .24088 Mdot
.66611 .2276 Mdot
.7528 .22596 Mdot
.78257 .23183 Mdot
.51338 .24746 Mdot
.63803 .24638 Mdot
.65781 .24403 Mdot
.73883 .24561 Mdot
.20403 .23752 Mdot
.36656 .24258 Mdot
.40308 .25893 Mdot
.45245 .25121 Mdot
.545 .245 Mdot
.1358 .2517 Mdot
.18846 .26422 Mdot
.69761 .2574 Mdot
.73463 .26388 Mdot
.83314 .26625 Mdot
.32082 .2641 Mdot
.35852 .26353 Mdot
.57246 .26044 Mdot
.68709 .27887 Mdot
.90816 .26444 Mdot
.1027 .27011 Mdot
.44561 .27309 Mdot
.56158 .27777 Mdot
.59577 .27458 Mdot
.78391 .28262 Mdot
.30711 .28339 Mdot
.39624 .28061 Mdot
.48688 .28168 Mdot
.43609 .292 Mdot
.64918 .29186 Mdot
.36984 .29569 Mdot
.40808 .29477 Mdot
.52621 .29517 Mdot
.53884 .29511 Mdot
.55351 .29455 Mdot
.72775 .29554 Mdot
.22521 .29905 Mdot
.25773 .29495 Mdot
.29233 .30401 Mdot
.35166 .30376 Mdot
.60647 .30671 Mdot
.06467 .30901 Mdot
.17462 .30384 Mdot
.38576 .31137 Mdot
.57614 .31426 Mdot
.73999 .31514 Mdot
.41611 .31815 Mdot
.55678 .32206 Mdot
.22269 .32595 Mdot
.32738 .32932 Mdot
.35062 .33293 Mdot
.39454 .32889 Mdot
.40667 .33422 Mdot
.4472 .32277 Mdot
.52309 .32687 Mdot
.55183 .33062 Mdot
.81993 .31648 Mdot
.84897 .31787 Mdot
.08855 .34988 Mdot
.1348 .33856 Mdot
.21569 .33228 Mdot
.36405 .34252 Mdot
.42015 .3425 Mdot
.43612 .34064 Mdot
.46319 .33777 Mdot
.48178 .33487 Mdot
.50912 .33648 Mdot
.77283 .33555 Mdot
.88992 .32109 Mdot
.16679 .34856 Mdot
.24356 .35131 Mdot
.26231 .34669 Mdot
.28187 .34771 Mdot
.30927 .35071 Mdot
.38189 .35452 Mdot
.53733 .34566 Mdot
.56614 .34574 Mdot
.69234 .34048 Mdot
.49054 .35666 Mdot
.57217 .35313 Mdot
.62213 .34325 Mdot
.74168 .3538 Mdot
.80293 .35203 Mdot
.89791 .34859 Mdot
.2103 .36515 Mdot
.42946 .36213 Mdot
.51363 .35839 Mdot
.54768 .36413 Mdot
.60865 .36047 Mdot
.63833 .36419 Mdot
.8189 .36676 Mdot
.19228 .37501 Mdot
.40476 .36697 Mdot
.43609 .37051 Mdot
.46147 .36241 Mdot
.52032 .36681 Mdot
.54286 .37222 Mdot
.57473 .37192 Mdot
.84969 .36862 Mdot
.2391 .38832 Mdot
.33611 .37601 Mdot
.46929 .3776 Mdot
.48956 .38041 Mdot
.50559 .38332 Mdot
.52423 .37772 Mdot
.56404 .3811 Mdot
.61822 .38183 Mdot
.67373 .37239 Mdot
.70224 .37378 Mdot
.74309 .37311 Mdot
.83223 .38411 Mdot
.87153 .36737 Mdot
.91951 .37463 Mdot
.39451 .37769 Mdot
.44378 .38599 Mdot
.4623 .39085 Mdot
.52789 .38647 Mdot
.54195 .3837 Mdot
.6091 .39185 Mdot
.79154 .39038 Mdot
.96169 .3879 Mdot
.19309 .39413 Mdot
.27616 .38941 Mdot
.35942 .39519 Mdot
.37176 .39403 Mdot
.38562 .391 Mdot
.4074 .39491 Mdot
.41984 .39298 Mdot
.44133 .39541 Mdot
.52881 .39878 Mdot
.54328 .39445 Mdot
.6793 .40014 Mdot
.70537 .40215 Mdot
.72846 .39225 Mdot
.85623 .39882 Mdot
.15052 .3999 Mdot
.2632 .40954 Mdot
.39356 .40937 Mdot
.41885 .40567 Mdot
.43438 .40576 Mdot
.47703 .39925 Mdot
.51759 .40497 Mdot
.54837 .40375 Mdot
.56131 .40139 Mdot
.57663 .39921 Mdot
.64906 .40333 Mdot
.75171 .40727 Mdot
.87356 .40279 Mdot
.89128 .40852 Mdot
.30339 .40812 Mdot
.32911 .40359 Mdot
.39125 .41654 Mdot
.45317 .40993 Mdot
.46942 .40806 Mdot
.50581 .40707 Mdot
.58217 .41248 Mdot
.62026 .41158 Mdot
.79331 .40491 Mdot
.07859 .41911 Mdot
.17122 .4232 Mdot
.46129 .42238 Mdot
.47671 .42325 Mdot
.48782 .41876 Mdot
.50096 .42017 Mdot
.53549 .41497 Mdot
.54591 .41719 Mdot
.55679 .4194 Mdot
.60251 .41806 Mdot
.3241 .42963 Mdot
.34308 .42179 Mdot
.39423 .42664 Mdot
.41933 .42553 Mdot
.44688 .42382 Mdot
.51347 .42799 Mdot
.52215 .427 Mdot
.53189 .42767 Mdot
.54462 .42934 Mdot
.56464 .42925 Mdot
.70997 .42679 Mdot
.735 .4278 Mdot
.77962 .42763 Mdot
.83825 .43099 Mdot
.91148 .44012 Mdot
.38601 .44032 Mdot
.42497 .43665 Mdot
.44282 .4352 Mdot
.46541 .43858 Mdot
.48968 .43554 Mdot
.54784 .43928 Mdot
.58427 .43246 Mdot
.81366 .43812 Mdot
.25024 .43942 Mdot
.28733 .44514 Mdot
.3227 .44492 Mdot
.34635 .44267 Mdot
.36249 .43832 Mdot
.44987 .44635 Mdot
.50591 .44367 Mdot
.52194 .44517 Mdot
.53382 .44454 Mdot
.5708 .44116 Mdot
.59886 .44399 Mdot
.61167 .44366 Mdot
.72826 .4509 Mdot
.87196 .4502 Mdot
.18709 .44795 Mdot
.31656 .45319 Mdot
.42228 .45158 Mdot
.47983 .44766 Mdot
.49247 .44945 Mdot
.55353 .45136 Mdot
.56425 .45004 Mdot
.58676 .45374 Mdot
.6571 .44224 Mdot
.77517 .45378 Mdot
.16867 .46086 Mdot
.34735 .46056 Mdot
.37835 .457 Mdot
.43907 .45909 Mdot
.45093 .45778 Mdot
.46511 .45607 Mdot
.47595 .45792 Mdot
.48647 .46006 Mdot
.49903 .45996 Mdot
.51282 .458 Mdot
.52233 .45935 Mdot
.53292 .457 Mdot
.54402 .45681 Mdot
.57165 .4607 Mdot
.62683 .45971 Mdot
.66766 .45752 Mdot
.74691 .45882 Mdot
.25217 .46262 Mdot
.36422 .46288 Mdot
.39794 .46523 Mdot
.43442 .46817 Mdot
.46165 .46754 Mdot
.4716 .46971 Mdot
.48186 .46813 Mdot
.49295 .46818 Mdot
.50942 .46671 Mdot
.52659 .47121 Mdot
.53647 .46988 Mdot
.54947 .46653 Mdot
.56728 .47163 Mdot
.59402 .46658 Mdot
.65679 .47334 Mdot
.69873 .465 Mdot
.84063 .4689 Mdot
.97619 .46467 Mdot
.33077 .47291 Mdot
.33882 .476 Mdot
.34998 .47595 Mdot
.37336 .47871 Mdot
.41624 .47404 Mdot
.43072 .47689 Mdot
.44737 .47462 Mdot
.45998 .47457 Mdot
.47547 .47838 Mdot
.48571 .47771 Mdot
.49643 .47499 Mdot
.5049 .47613 Mdot
.51564 .4767 Mdot
.53992 .47897 Mdot
.55304 .47655 Mdot
.22447 .47076 Mdot
.32533 .48349 Mdot
.36674 .49308 Mdot
.39602 .48295 Mdot
.45245 .48513 Mdot
.46477 .48539 Mdot
.49018 .48437 Mdot
.50176 .48442 Mdot
.51983 .48535 Mdot
.55794 .48433 Mdot
.59108 .48493 Mdot
.60795 .48487 Mdot
.64062 .47937 Mdot
.67998 .48791 Mdot
.7564 .48333 Mdot
.81754 .47514 Mdot
.9323 .48604 Mdot
.09907 .47338 Mdot
.16248 .49078 Mdot
.18843 .48988 Mdot
.22396 .48681 Mdot
.35326 .49918 Mdot
.41833 .48836 Mdot
.43331 .49164 Mdot
.44859 .49112 Mdot
.46715 .49245 Mdot
.47615 .49126 Mdot
.48659 .49208 Mdot
.49542 .49339 Mdot
.5067 .49145 Mdot
.54166 .4898 Mdot
.56333 .48936 Mdot
.62937 .49024 Mdot
.71396 .48454 Mdot
.80773 .48834 Mdot
.88523 .49446 Mdot
.02381 .48971 Mdot
.1937 .5094 Mdot
.25126 .49539 Mdot
.33067 .49988 Mdot
.38242 .49869 Mdot
.40643 .49747 Mdot
.42435 .50025 Mdot
.44271 .50025 Mdot
.45643 .50008 Mdot
.48209 .50044 Mdot
.49939 .50001 Mdot
.50999 .49903 Mdot
.52024 .49784 Mdot
.5341 .50007 Mdot
.54793 .50114 Mdot
.55429 .5007 Mdot
.56732 .50014 Mdot
.5866 .49912 Mdot
.6557 .49702 Mdot
.72407 .50008 Mdot
.0636 .50052 Mdot
.20776 .51702 Mdot
.22695 .51108 Mdot
.2655 .50132 Mdot
.29883 .50188 Mdot
.38952 .51287 Mdot
.40989 .50608 Mdot
.42131 .50849 Mdot
.43264 .50643 Mdot
.44882 .51073 Mdot
.45926 .50929 Mdot
.4678 .50824 Mdot
.47549 .50816 Mdot
.48803 .50821 Mdot
.49446 .50821 Mdot
.50573 .5092 Mdot
.51421 .51039 Mdot
.52527 .50961 Mdot
.5427 .51062 Mdot
.57161 .50727 Mdot
.60697 .50655 Mdot
.64503 .50928 Mdot
.76981 .50825 Mdot
.83331 .52187 Mdot
.15121 .51725 Mdot
.33184 .51534 Mdot
.41262 .51641 Mdot
.42585 .51838 Mdot
.4367 .51731 Mdot
.48326 .51686 Mdot
.5002 .51895 Mdot
.53822 .51588 Mdot
.56091 .5163 Mdot
.57896 .51479 Mdot
.62749 .51748 Mdot
.65228 .51784 Mdot
.68484 .51362 Mdot
.71796 .51631 Mdot
.05985 .53392 Mdot
.11543 .52277 Mdot
.12908 .52745 Mdot
.25135 .53208 Mdot
.28896 .52629 Mdot
.31419 .52808 Mdot
.3391 .52566 Mdot
.40837 .52575 Mdot
.42397 .52909 Mdot
.44257 .52903 Mdot
.45571 .52276 Mdot
.46731 .52219 Mdot
.47818 .52252 Mdot
.51402 .52399 Mdot
.53211 .52261 Mdot
.57184 .52368 Mdot
.59393 .51999 Mdot
.61611 .52822 Mdot
.75505 .52673 Mdot
.80093 .53538 Mdot
.20253 .5434 Mdot
.26798 .54137 Mdot
.35343 .52666 Mdot
.46047 .53246 Mdot
.47286 .53284 Mdot
.48308 .53285 Mdot
.52519 .53246 Mdot
.54136 .53274 Mdot
.55158 .53093 Mdot
.5657 .53273 Mdot
.57447 .53591 Mdot
.58449 .53265 Mdot
.64272 .53538 Mdot
.66199 .5327 Mdot
.75322 .53264 Mdot
.36058 .53762 Mdot
.38965 .53756 Mdot
.40356 .54074 Mdot
.41416 .54381 Mdot
.4526 .54037 Mdot
.47038 .54053 Mdot
.48647 .54154 Mdot
.49626 .53871 Mdot
.51352 .5378 Mdot
.5338 .54177 Mdot
.56073 .54563 Mdot
.59206 .54237 Mdot
.66733 .54419 Mdot
.72315 .54529 Mdot
.74425 .54705 Mdot
.91 .52439 Mdot
.30623 .5476 Mdot
.33435 .55318 Mdot
.38414 .55209 Mdot
.46008 .54864 Mdot
.47543 .54813 Mdot
.49995 .55005 Mdot
.50825 .54953 Mdot
.52048 .54931 Mdot
.54953 .54847 Mdot
.5977 .54616 Mdot
.67193 .55194 Mdot
.70253 .54603 Mdot
.06734 .54666 Mdot
.22419 .56358 Mdot
.3576 .55955 Mdot
.45272 .5591 Mdot
.46615 .5595 Mdot
.47958 .55417 Mdot
.52286 .55915 Mdot
.53015 .55654 Mdot
.54531 .55689 Mdot
.57615 .55427 Mdot
.58639 .55632 Mdot
.6138 .55345 Mdot
.13595 .57024 Mdot
.37148 .56843 Mdot
.41499 .56509 Mdot
.43015 .56473 Mdot
.46941 .56851 Mdot
.4848 .56501 Mdot
.49531 .56576 Mdot
.50994 .56623 Mdot
.53921 .57138 Mdot
.56065 .56433 Mdot
.57583 .56271 Mdot
.60597 .56613 Mdot
.64001 .5558 Mdot
.70617 .56693 Mdot
.8577 .57064 Mdot
.8799 .57284 Mdot
.9047 .57465 Mdot
.08912 .56338 Mdot
.28056 .57491 Mdot
.30416 .57611 Mdot
.33413 .57894 Mdot
.40316 .57164 Mdot
.4482 .57418 Mdot
.47535 .57765 Mdot
.59046 .57559 Mdot
.62129 .57169 Mdot
.64661 .57163 Mdot
.07202 .59028 Mdot
.11378 .58916 Mdot
.38439 .57992 Mdot
.51009 .58063 Mdot
.56308 .58438 Mdot
.57436 .58552 Mdot
.59598 .58502 Mdot
.64039 .58768 Mdot
.6672 .5839 Mdot
.68334 .57859 Mdot
.16051 .58519 Mdot
.3946 .5922 Mdot
.47625 .58891 Mdot
.55267 .58698 Mdot
.63298 .59842 Mdot
.71407 .58512 Mdot
.08416 .61314 Mdot
.45114 .59516 Mdot
.49814 .59328 Mdot
.52604 .59463 Mdot
.53744 .59238 Mdot
.60445 .59972 Mdot
.72538 .59777 Mdot
.22821 .60434 Mdot
.25434 .60223 Mdot
.36301 .59795 Mdot
.39598 .60472 Mdot
.48394 .60547 Mdot
.50406 .60469 Mdot
.51964 .60508 Mdot
.54425 .6071 Mdot
.17166 .60896 Mdot
.26744 .61416 Mdot
.31261 .61289 Mdot
.46353 .60885 Mdot
.51037 .6209 Mdot
.53779 .62326 Mdot
.56375 .61433 Mdot
.58002 .61365 Mdot
.67837 .60824 Mdot
.69597 .61591 Mdot
.2922 .62137 Mdot
.34442 .6172 Mdot
.37068 .62198 Mdot
.39488 .62504 Mdot
.45424 .62288 Mdot
.48706 .62642 Mdot
.71434 .6291 Mdot
.36211 .6372 Mdot
.42592 .62366 Mdot
.46527 .63662 Mdot
.61022 .62523 Mdot
.64351 .62532 Mdot
.67629 .63034 Mdot
.0697 .64649 Mdot
.17152 .64213 Mdot
.28029 .64591 Mdot
.6622 .64184 Mdot
.2087 .65108 Mdot
.33631 .64188 Mdot
.40661 .63555 Mdot
.43876 .64303 Mdot
.56286 .64243 Mdot
.70123 .65194 Mdot
.43015 .65662 Mdot
.457 .65609 Mdot
.57049 .65425 Mdot
.61289 .65499 Mdot
.63197 .65401 Mdot
.77326 .65089 Mdot
.31781 .65547 Mdot
.36161 .65832 Mdot
.39763 .66565 Mdot
.41621 .66675 Mdot
.42804 .67237 Mdot
.47883 .65911 Mdot
.4916 .6568 Mdot
.5127 .65508 Mdot
.57608 .66497 Mdot
.94243 .66242 Mdot
.23891 .66628 Mdot
.3485 .66845 Mdot
.49976 .67157 Mdot
.53065 .6656 Mdot
.6494 .66857 Mdot
.81401 .6676 Mdot
.87269 .66417 Mdot
.30693 .67443 Mdot
.34 .68251 Mdot
.46864 .67718 Mdot
.60196 .67676 Mdot
.28072 .68462 Mdot
.36805 .69571 Mdot
.52548 .68489 Mdot
.65065 .68885 Mdot
.70621 .68238 Mdot
.72844 .67875 Mdot
.16102 .67215 Mdot
.45431 .68923 Mdot
.48528 .69122 Mdot
.5088 .69584 Mdot
.53778 .69144 Mdot
.58606 .69182 Mdot
.61505 .69655 Mdot
.07871 .70382 Mdot
.25176 .69747 Mdot
.33762 .70906 Mdot
.4126 .69314 Mdot
.44008 .69934 Mdot
.47562 .70145 Mdot
.55239 .70381 Mdot
.56081 .70389 Mdot
.57832 .70555 Mdot
.68983 .70932 Mdot
.76872 .7012 Mdot
.12385 .71331 Mdot
.30148 .71114 Mdot
.45767 .7191 Mdot
.49766 .71493 Mdot
.52806 .72356 Mdot
.63333 .7182 Mdot
.74513 .71583 Mdot
.15383 .7299 Mdot
.37658 .71131 Mdot
.41049 .71693 Mdot
.48875 .72878 Mdot
.83878 .71071 Mdot
.20048 .7209 Mdot
.24116 .71473 Mdot
.39537 .73189 Mdot
.4228 .73286 Mdot
.5853 .72784 Mdot
.80153 .72639 Mdot
.90156 .72974 Mdot
.16538 .74774 Mdot
.33757 .73126 Mdot
.38022 .74119 Mdot
.85971 .74434 Mdot
.24558 .73739 Mdot
.29141 .74523 Mdot
.7048 .74439 Mdot
.26887 .75341 Mdot
.3074 .75447 Mdot
.35154 .75066 Mdot
.43901 .74399 Mdot
.48427 .74247 Mdot
.60779 .75234 Mdot
.66835 .75346 Mdot
.191 .7631 Mdot
.21496 .75639 Mdot
.44299 .75773 Mdot
.49208 .75893 Mdot
.53049 .75627 Mdot
.578 .76792 Mdot
.73293 .75099 Mdot
.24058 .77408 Mdot
.26103 .77842 Mdot
.35048 .77508 Mdot
.38725 .76792 Mdot
.7437 .76714 Mdot
.47166 .7688 Mdot
.82604 .78665 Mdot
.39239 .77893 Mdot
.4291 .78475 Mdot
.45714 .78571 Mdot
.51499 .789 Mdot
.20958 .79674 Mdot
.41633 .79749 Mdot
.33316 .80105 Mdot
.4595 .80746 Mdot
.48043 .80389 Mdot
.73442 .8044 Mdot
.29027 .80522 Mdot
.20152 .80803 Mdot
.75614 .81323 Mdot
.24673 .82613 Mdot
.36903 .82323 Mdot
.40072 .82536 Mdot
.49755 .83006 Mdot
.60496 .8166 Mdot
.66684 .81784 Mdot
.77952 .8225 Mdot
.54262 .81998 Mdot
.18527 .84915 Mdot
.24767 .85419 Mdot
.41072 .85723 Mdot
.43851 .83772 Mdot
.29183 .84484 Mdot
.52317 .85637 Mdot
.56898 .85145 Mdot
.71233 .85483 Mdot
.33716 .85346 Mdot
.47845 .85862 Mdot
.61389 .86254 Mdot
.78866 .87179 Mdot
.31614 .89059 Mdot
.65909 .87366 Mdot
.4563 .8944 Mdot
.25287 .90042 Mdot
.56241 .88164 Mdot
.56134 .91133 Mdot
.66519 .92154 Mdot
.59127 .93341 Mdot
.3785 .93856 Mdot
.51066 .91966 Mdot
.53257 .94812 Mdot
.52189 .97883 Mdot
.59231 .96737 Mdot
.47269 .96773 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{288, 288.75},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/A000`40O003h00OfFmk00<006mkKg/0
e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/0
0`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00c6mk0W`02fmk00<006mkKg/0e6mk003;Kg/4O00:Kg/00`00Kg]_
N`3DKg/00<]_N`Al00Y_N`03001_Nfmk0=A_N`00c6mk0W`02fmk0`00e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03
001_Nfmk00Q_N`9l0<Y_N`00aVmk0W`04Fmk00<006mkKg/01fmk17`0bFmk0035Kg/4O00@Kg/00`00
Kg]_N`07Kg/4O039Kg/00<E_N`Al011_N`03001_Nfmk00Q_N`9l0<Y_N`00aVmk0W`04Fmk00<006mk
Kg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk01e_N`9l0;E_N`00fFmk00<006mkKg/0
76mk17`0]6mk003IKg/00`00Kg]_N`0LKg/4O02dKg/00=U_N`03001_Nfmk01e_N`9l0;E_N`00fFmk
00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00<1_N`9l01M_N`03001_Nfmk0=A_N`00_fmk17`0
5Vmk00<006mkKg/0e6mk002oKg/4O00FKg/00`00Kg]_N`3DKg/00<1_N`9l01M_N`<00=A_N`00fFmk
00<006mkKg/0>Fmk0W`0VFmk001hKg/2O01OKg/00`00Kg]_N`0hKg/4O02HKg/007M_N`Al00m_N`9l
04e_N`03001_Nfmk00Q_N`9l02i_N`Al09Q_N`00Mfmk17`03Vmk17`066mk0W`0<Vmk00<006mkKg/0
1fmk17`0;Vmk0W`0VFmk001hKg/2O00?Kg/4O00GKg/4O00aKg/00`00Kg]_N`07Kg/4O039Kg/008Y_
N`9l01Q_N`Al02A_N`9l00]_N`03001_Nfmk00Q_N`9l055_N`9l07M_N`00YFmk0W`096mk17`02Vmk
00<006mkKg/0FVmk17`0MVmk003;Kg/4O00:Kg/00`00Kg]_N`1JKg/4O01fKg/00<a_N`9l00]_N`03
001_Nfmk05]_N`9l07M_N`00f6mk0W`0eVmk003GKg/4O03EKg/00=M_N`Al0=E_N`00f6mk0W`086mk
0W`0]6mk003IKg/00`00Kg]_N`0MKg/4O02cKg/00=U_N`03001_Nfmk01e_N`Al0;=_N`00fFmk00<0
06mkKg/07Vmk0W`01Vmk0W`0[6mk003>Kg/40007Kg/00`00Kg]_N`0UKg/4O02[Kg/00;U_N`9l01E_
N`03001_Nfmk00I_N`9l02I_N`Al0:]_N`00^6mk17`056mk00<006mkKg/01Fmk17`09Vmk0W`0[6mk
002hKg/4O00@Kg/60006Kg/4O01/Kg/2O01VKg/00;U_N`9l00Q_N`H000A_N`04001_Nfmk0008Kg/2
O0020014Kg/2O00TKg/4O01UKg/009m_N`9l02a_N`04001_Nfmk0008Kg/00`00Kg]_N`14Kg/4O00S
Kg/4O01UKg/007I_N`9l02I_N`Al02a_N`03001_N`0000Q_N`03001_Nfmk015_N`9l035_N`Al02A_
N`9l06I_N`00MFmk17`09Fmk17`0;6mk00<006mk000026mk00<006mkKg/046mk17`06fmk0W`056mk
0W`0=fmk0W`0E6mk001eKg/4O00VKg/2O00^Kg/20008Kg/00`00Kg]_N`0@Kg/4O00JKg/4O01;Kg/4
O01CKg/007I_N`9l065_N`03001_Nfmk015_N`9l01]_N`Al04]_N`Al05=_N`00fFmk00<006mkKg/0
;fmk0W`0CFmk0W`0E6mk002<Kg/2O01;Kg/00`00Kg]_N`3DKg/008]_N`Al04Y_N`03001_Nfmk0=A_
N`00Rfmk17`0BVmk00<006mkKg/0e6mk002<Kg/2O01;Kg/00`00Kg]_N`3DKg/00<m_N`9l00Q_N`03
001_Nfmk0=A_N`00_fmk0W`03Fmk17`000=_Ng`0O00016mk00<006mkKg/0e6mk002nKg/4O00<Kg/8
O003Kg/01000Kg]_Nfmk0W`0dFmk001^Kg/2O01>Kg/4O00=Kg/2O0000fmkO01l0002O003Kg/00`00
Kg]_N`04O03@Kg/006e_N`Al04i_N`9l019_N`9l00A_N`03001_Nfmk00Al0=1_N`00KFmk17`0J6mk
00@006mkKg]_N`9l01U_N`9l0;I_N`00KVmk0W`0JFmk00<006mkKg/06fmk17`0]Fmk0037Kg/2O00@
Kg/00`00Kg]_N`0KKg/4O02eKg/00<I_N`Al00m_N`03001_Nfmk01a_N`9l0;I_N`00aVmk17`03fmk
0`00:Vmk0W`0Z6mk0037Kg/2O00@Kg/00`00Kg]_N`07Kg/2O00PKg/4O02WKg/00=U_N`03001_Nfmk
00I_N`Al01m_N`Al0:M_N`00fFmk00<006mkKg/01Vmk17`086mk0W`0Z6mk003IKg/00`00Kg]_N`07
Kg/2O01fKg/2O01CKg/00:Y_N`9l00U_N`9l029_N`03001_Nfmk03e_N`9l03m_N`Al059_N`00ZFmk
17`01fmk17`08Fmk00<006mkKg/0?6mk17`0?Vmk17`0DVmk002YKg/4O007Kg/4O00QKg/00`00Kg]_
N`0lKg/4O00oKg/2O01CKg/007Q_N`9l011_N`9l015_N`9l00]_N`9l00U_N`9l029_N`03001_Nfmk
03e_N`9l09E_N`00Mfmk17`03Vmk17`03fmk17`08Vmk0W`04Fmk0W`00Vmk00<006mkKg/0e6mk001g
Kg/4O00>Kg/4O00?Kg/4O00QKg/4O005Kg/2O008Kg/4O0000fmk001_N`3EKg/007Q_N`9l011_N`9l
015_N`9l029_N`Al00A_N`Al00M_N`Al0003Kg/006mk0=E_N`00Hfmk0W`0GFmk0W`01Fmk17`026mk
0W`00Vmk00<006mkKg/0;Fmk0W`0YFmk001RKg/4O01TKg/2O00<Kg/2O00^Kg/4O00PKg/2O022Kg/0
069_N`Al075_N`Al02e_N`Al01m_N`Al085_N`00Hfmk0W`0LVmk17`0;Vmk0W`086mk17`0PFmk003H
Kg/2O009Kg/2O017Kg/2O022Kg/00=U_N`03001_Nfmk00I_N`Al0<Y_N`00^Vmk0W`07Fmk00<006mk
Kg/01Vmk17`0bVmk002iKg/4O00?Kg/2O00;Kg/00`00Kg]_N`07Kg/2O03;Kg/00;U_N`Al00i_N`Al
00Y_N`<005=_N`9l02i_N`9l04m_N`00^Vmk0W`03fmk17`02Vmk00<006mkKg/06Vmk0W`0=Vmk17`0
;6mk17`0CVmk002=Kg/2O00mKg/2O00;Kg/00`00Kg]_N`0IKg/4O00eKg/4O00/Kg/4O01>Kg/008a_
N`Al03=_N`9l01A_N`03001_Nfmk01U_N`Al03I_N`9l019_N`9l01Y_N`9l04m_N`00S6mk17`06Vmk
0W`05Vmk17`04fmk00<006mkKg/06Vmk0W`09Vmk0W`08Vmk17`0JVmk001^Kg/2O00MKg/2O00JKg/4
O00EKg/4O00CKg/00`00Kg]_N`0ZKg/2O00EKg/4O00QKg/4O01ZKg/006e_N`Al011_N`9l02I_N`Al
00I_N`9l00i_N`9l01A_N`03001_Nfmk02U_N`Al01A_N`Al029_N`9l00]_N`9l05i_N`00KFmk17`0
3fmk17`09Vmk0W`01Vmk17`08fmk00<006mkKg/0:Fmk17`05Fmk0W`0;fmk17`0GFmk001GKg/2O00E
Kg/2O00@Kg/4O00^Kg/4O00SKg/00`00Kg]_N`0ZKg/2O017Kg/4O01MKg/005I_N`Al02M_N`9l031_
N`9l02A_N`03001_Nfmk07A_N`9l05i_N`00EVmk17`0N6mk0W`01Fmk00<006mkKg/0e6mk001GKg/2
O014Kg/2O00bKg/4O004Kg/00`00Kg]_N`0nKg/2O02DKg/009a_N`Al035_N`Al00A_N`03001_Nfmk
00i_N`9l02I_N`9l00E_N`Al021_N`9l075_N`00W6mk17`0<Vmk0W`01Fmk00<006mkKg/00W`02fmk
17`096mk17`016mk17`07fmk17`0L6mk000iKg/2O01RKg/2O00SKg/2O00EKg/00`00Kg]l0003O00:
Kg/4O00TKg/4O005Kg/2O00PKg/4O01`Kg/003Q_N`Al08E_N`Al01A_N`03001_Ng`000=l00]_N`9l
02I_N`9l02U_N`9l075_N`00>6mk17`0QFmk17`056mk00<006mkKg/00W`0dVmk000iKg/2O027Kg/2
O00EKg/00`00Kg]_N`1@Kg/2O022Kg/00:e_N`9l02Y_N`03001_Nfmk01Y_N`9l03=_N`Al085_N`00
[6mk17`0:Fmk00<006mkKg/06Fmk17`0<Vmk17`0PFmk001@Kg/2O00gKg/2O00>Kg/2O00AKg/4O00Y
Kg/3000IKg/4O00cKg/2O00=Kg/2O019Kg/2O00XKg/004m_N`Al03E_N`Al00a_N`Al015_N`9l02Y_
N`03001_Nfmk01Y_N`9l049_N`Al02Q_N`9l01e_N`Al02M_N`00:fmk0W`08Vmk17`0=Fmk17`036mk
17`0?Fmk00<006mkKg/0GVmk17`09fmk17`076mk17`09fmk000ZKg/4O00RKg/2O00gKg/2O00>Kg/2
O00nKg/00`00Kg]_N`1OKg/2O00XKg/4O00MKg/2O00XKg/002Y_N`Al095_N`9l01Q_N`03001_Nfmk
02A_N`9l06A_N`9l04Q_N`00:fmk0W`0TFmk17`05fmk00<006mkKg/08fmk17`0[Fmk002nKg/4O00G
Kg/00`00Kg]_N`0EKg/2O00<Kg/4O00TKg/2O027Kg/00:Y_N`9l01=_N`9l011_N`9l00I_N`03001_
Nfmk01A_N`Al00a_N`9l02A_N`Al08I_N`00Pfmk0W`096mk17`08fmk17`01Fmk00<006mkKg/056mk
17`0<Vmk17`09fmk0W`0GFmk0022Kg/4O00SKg/4O00SKg/4O005Kg/00`00Kg]_N`0EKg/2O00dKg/2
O00WKg/4O01LKg/0089_N`Al02A_N`9l02E_N`9l00I_N`03001_Nfmk07A_N`Al05a_N`00Pfmk0W`0
E6mk00<006mkKg/0MFmk0W`0GFmk002kKg/2O00LKg/00`00Kg]_N`0kKg/2O02GKg/006i_N`9l02i_
N`9l00m_N`9l00U_N`Al01]_N`03001_Nfmk00I_N`9l00=_N`9l00A_N`9l02M_N`Al01m_N`9l07E_
N`00KFmk17`0;6mk17`03Fmk17`026mk17`06fmk00<006mkKg/01Fmk17`000=_Ng`0O0000W`00Vmk
17`09Vmk17`07Vmk17`0M6mk001PKg/2O00;Kg/4O00/Kg/4O00=Kg/4O009Kg/2O00LKg/00`00Kg]_
N`05Kg/4O0000fmkO01l0002O002Kg/4O00WKg/2O00OKg/4O01dKg/005m_N`Al00]_N`9l02i_N`9l
00m_N`9l02Q_N`03001_Nfmk00I_N`9l00=_N`9l00A_N`9l04Y_N`9l07E_N`00BVmk0W`04fmk17`0
6Vmk0W`05fmk0W`0=6mk1P001fmk00<006mkKg/0e6mk0019Kg/4O00CKg/2O00JKg/4O00EKg/4O00c
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0XKg/2O02ZKg/001]_N`9l02a_N`Al02m_
N`Al01E_N`Al03A_N`03001_Nfmk00U_N`03001_Nfmk02M_N`Al0:U_N`006Vmk17`0;6mk0W`0<Fmk
0W`05fmk0W`03Fmk0W`09fmk00<006mkKg/026mk10009Vmk17`0ZFmk000JKg/4O026Kg/4O00KKg/6
0006Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0KKg/2O00;Kg/2O02ZKg/001]_N`9l08M_N`Al02Q_N`03
001_Nfmk00I_N`03001_Nfmk01Y_N`Al04A_N`9l021_N`9l04i_N`00YFmk0W`02fmk0W`066mk00<0
06mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/06Vmk17`0@fmk17`07Vmk17`02Vmk0W`0@Fmk002a
Kg/4O00GKg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0KKg/2O014Kg/4O00NKg/4O009
Kg/4O00>Kg/2O00`Kg/00;5_N`Al00]_N`9l00]_N`@000Q_N`03001_Nfmk01=_N`9l04e_N`9l021_
N`9l00Y_N`Al00e_N`Al02m_N`00Gfmk0W`0DFmk0W`02fmk17`05Vmk00<006mkKg/04Vmk17`0Nfmk
0W`03Vmk17`0;fmk001NKg/4O01MKg/4O00FKg/00`00Kg]_N`04Kg/2O00<Kg/4O02<Kg/2O00`Kg/0
05i_N`Al02Y_N`9l01]_N`9l01E_N`9l01M_N`03001_Nfmk00=_N`Al00Y_N`Al0;m_N`00G6mk0W`0
00=_Ng`0O000:Vmk17`01fmk0W`046mk17`0;Fmk00<006mkKg/00fmk17`02Fmk17`0`6mk001KKg/4
O00/Kg/4O006Kg/4O00?Kg/4O002Kg/2O00OKg/2O008Kg/00`00Kg]_N`04Kg/2O00:Kg/4O030Kg/0
05]_N`Al02e_N`9l00M_N`Al011_N`9l009_N`Al01e_N`Al00M_N`03001l07`0015_N`9l05e_N`9l
069_N`00>Fmk0W`08Fmk0W`0>6mk0W`05Fmk17`05Vmk0W`01Fmk17`01fmk17`0KVmk17`0HFmk000h
Kg/4O01bKg/2O00;Kg/2O009Kg/4O005Kg/2O008Kg/4O01<Kg/2O00PKg/4O01QKg/003Q_N`Al061_
N`9l01I_N`9l00A_N`Al00Q_N`Al00m_N`03001l07`002m_N`9l01]_N`Al021_N`9l069_N`00>Fmk
0W`0=Fmk0W`0:Fmk17`056mk17`00fmk17`02Fmk0W`046mk00<006mkKg/02Vmk0W`02fmk0W`05Fmk
17`06Vmk17`0Q6mk0017Kg/2O00VKg/4O005Kg/2O00QKg/4O00DKg/4O004Kg/2O00LKg/00`00Kg]_
N`09Kg/4O009Kg/4O00DKg/4O00KKg/2O01GKg/2O00/Kg/002E_N`9l01m_N`Al01i_N`9l00E_N`Al
00A_N`Al00U_N`9l01I_N`9l01I_N`9l02=_N`03001_Nfmk00U_N`Al00U_N`Al01E_N`9l07A_N`Al
02]_N`0096mk17`07Vmk17`07Fmk17`01Fmk0W`01Fmk17`026mk17`0DVmk00<006mkKg/02Vmk0W`0
2fmk17`0B6mk0W`066mk0W`09Vmk17`0:fmk000TKg/4O00OKg/2O00NKg/4O00=Kg/2O009Kg/4O00L
Kg/2O00dKg/00`00Kg]_N`0HKg/4O016Kg/4O00FKg/4O00VKg/2O00/Kg/002E_N`9l045_N`9l01Y_
N`9l01a_N`Al02a_N`9l00E_N`03001_Nfmk009l01I_N`Al04I_N`Al01I_N`Al05A_N`00XVmk17`0
:fmk17`016mk0P0017`05Vmk0W`03Vmk0W`0>6mk0W`066mk0W`0EFmk002SKg/2O00CKg/2O00<Kg/2
O009Kg/4O004Kg/00`00Kg]l0003O00UKg/4O02XKg/005Y_N`9l05]_N`Al00Y_N`Al00U_N`9l00E_
N`03001_Nfmk009l00e_N`9l01M_N`Al00Y_N`9l09a_N`00FFmk17`0D6mk0W`026mk17`02Vmk17`0
46mk00<006mkKg/00fmk0W`02Fmk17`05fmk0W`02Vmk17`0Bfmk0W`056mk0W`0>6mk001IKg/4O01?
Kg/4O008Kg/2O00<Kg/2O00AKg/00`00Kg]_N`02Kg/4O008Kg/4O00SKg/4O01:Kg/4O00:Kg/2O006
Kg/4O00gKg/005Y_N`9l051_N`Al00]_N`9l01a_N`03001_Nfmk009_N`Al00M_N`Al00Y_N`9l01U_
N`9l00e_N`9l03a_N`Al00U_N`Al00E_N`Al03M_N`00[Fmk0W`02fmk17`06fmk00<006mkKg/00fmk
0W`01fmk17`02Vmk17`09Vmk17`02Vmk0W`03fmk0W`07fmk0W`02Vmk17`01Vmk0W`04fmk0W`08fmk
001BKg/2O00lKg/2O00XKg/4O00KKg/00`00Kg]_N`0<Kg/4O00:Kg/4O00VKg/4O009Kg/4O00=Kg/4
O00[Kg/2O00KKg/4O00RKg/0055_N`Al03Y_N`Al01I_N`9l011_N`9l00a_N`9l00i_N`03001_Nfmk
00E_N`9l00I_N`9l00a_N`9l02Q_N`9l00Y_N`Al00e_N`Al04Q_N`Al029_N`00DFmk17`0>Vmk17`0
5Fmk17`076mk17`01Vmk0W`01Fmk00<006mkKg/016mk17`03Vmk0W`0>Vmk0W`03fmk0W`0BVmk0W`0
8fmk001BKg/2O00lKg/2O00FKg/4O00LKg/4O005Kg/4O004Kg/2O005Kg/4O004Kg/2O007Kg/4O00D
Kg/2O02UKg/00:U_N`9l01=_N`9l00U_N`9l00I_N`Al00=_N`Al00E_N`9l00A_N`Al00I_N`Al01=_
N`Al05Y_N`9l04Q_N`00IVmk0W`0EFmk17`04Fmk0W`016mk17`01Vmk0W`00fmk17`01fmk0W`056mk
17`0FFmk17`0=6mk0W`04Fmk001UKg/4O00=Kg/2O015Kg/4O005Kg/2O00AKg/2O006Kg/4O003Kg/2
O00OKg/2O019Kg/2O00?Kg/4O00cKg/4O00@Kg/006E_N`Al00a_N`Al02a_N`9l00e_N`9l00Q_N`9l
00E_N`Al011_N`03001_Nfmk00E_N`Al021_N`9l039_N`9l01Q_N`Al00m_N`9l03A_N`Al011_N`00
DVmk0W`04Vmk0W`03Fmk17`08Fmk0W`00fmk0W`00fmk17`01Vmk0W`00fmk17`01Vmk0W`01Vmk17`0
46mk00<006mkKg/01Vmk0W`01Fmk0W`06Fmk17`0<6mk17`05fmk17`0AVmk0W`04Fmk001AKg/4O00Q
Kg/2O00QKg/4O0000fmkO01l0002O002Kg/4O005Kg/4O002Kg/4O005Kg/4O006Kg/2O00AKg/00`00
Kg]_N`0<Kg/4O00HKg/4O00`Kg/4O00HKg/2O01JKg/0041_N`9l00m_N`Al04A_N`Al0003Kg]l07`0
009l00=_N`9l00I_N`Al00=_N`9l00I_N`Al00a_N`9l00]_N`03001_Nfmk00M_N`9l00=_N`Al00]_
N`9l00a_N`9l01e_N`9l01=_N`9l03E_N`9l03i_N`00?fmk17`03fmk0W`0AVmk0W`00fmk0W`03Fmk
0W`03Fmk0W`036mk17`02Vmk00<006mkKg/01Vmk17`00fmk0W`01Vmk0W`00fmk17`0:Fmk17`026mk
0W`0?Vmk17`0?Fmk000oKg/4O01:Kg/2O00lKg/4O00:Kg/00`00Kg]_N`06Kg/4O005Kg/2O003Kg/4
O002Kg/4O00MKg/2O00:Kg/4O007Kg/4O00SKg/2O00HKg/4O004Kg/2O00gKg/0041_N`9l04Y_N`Al
02=_N`9l00E_N`9l011_N`9l00]_N`9l0003001_Nfmk009l00=_N`9l00E_N`Al009_N`Al00=_N`9l
01e_N`Al00Y_N`9l00Q_N`Al029_N`Al01Q_N`9l00A_N`Al03I_N`00L6mk0W`046mk0W`026mk17`0
6Fmk0W`01fmk17`00fmk17`036mk0W`03Fmk17`000=_Ng`0O0000W`02Fmk17`00fmk0W`08fmk17`0
5Fmk0W`04Vmk0W`03fmk17`07Vmk17`01Fmk0W`0;fmk001_Kg/4O00>Kg/4O008Kg/2O00IKg/4O006
Kg/4O003Kg/4O005Kg/2O004Kg/4O00<Kg/4O0000fmkO01l0002O00:Kg/2O00MKg/2O00;Kg/2O00Y
Kg/4O00?Kg/2O00PKg/2O005Kg/4O00^Kg/006m_N`Al00i_N`Al02=_N`Al00M_N`9l00E_N`9l00E_
N`Al00=_N`Al00e_N`9l00=_N`9l01Y_N`9l00e_N`Al03E_N`Al03Q_N`Al02i_N`00L6mk0W`046mk
0W`09Fmk0W`05Vmk17`016mk0W`03Vmk00<006mkKg/02Vmk0W`04Fmk17`036mk17`0=Vmk0W`0>Vmk
0W`0;fmk002XKg/2O00HKg/2O00=Kg/2O006Kg/00`00Kg]_N`09Kg/4O0000fmkO01l000=Kg/4O006
Kg/2O005Kg/2O02TKg/0025_N`9l08A_N`Al02E_N`Al00=_N`9l0003001_Nfmk00U_N`Ql009_N`9l
00U_N`9l00I_N`Al0:Y_N`0086mk17`09Fmk0W`0B6mk0W`04Vmk17`06fmk0W`016mk0W`00Vmk17`0
0Vmk17`036mk0W`000=_Ng`0O0000W`000=_Ng`0O0000W`046mk17`0ZVmk000PKg/4O00TKg/4O016
Kg/4O00BKg/2O00:Kg/2O009Kg/2O004Kg/4O002Kg/4O002Kg/2O003Kg/4O00@Kg/2O002Kg/4O00A
Kg/2O02[Kg/0025_N`9l02E_N`Al04I_N`Al01=_N`9l00Q_N`Al00M_N`Al00=_N`Al009_N`Al00Q_
N`9l0003001_Nfmk009l009_N`9l009_N`9l00U_N`9l041_N`9l00U_N`9l015_N`9l05m_N`00BFmk
0W`0@6mk0W`01Vmk0W`04fmk17`01fmk17`01fmk17`016mk0W`016mk0W`02fmk00<006mkO0002g`0
0fmk0W`01Vmk0W`0?6mk17`01fmk17`03fmk17`0GVmk002:Kg/4O00JKg/4O008Kg/2O009Kg/2O00H
Kg/00`00Kg]l000;O002Kg/4O004Kg/4O006Kg/2O00cKg/4O007Kg/4O00?Kg/4O00FKg/2O016Kg/0
08Y_N`Al01]_N`9l02i_N`03001_Nfmk009l009_N`9l009_N`9l00=_N`Al00A_N`Al00E_N`Al03=_
N`9l00U_N`9l015_N`9l01I_N`Al04E_N`00Rfmk0W`0:Fmk0W`01Vmk0W`04Vmk0W`01Fmk00<006mk
Kg/03Vmk0W`01Vmk0W`01Vmk17`0JFmk17`0AFmk001[Kg/2O00^Kg/2O00HKg/4O004Kg/4O006Kg/2
O008Kg/4O004Kg/00`00Kg]_N`0?Kg/2O00>Kg/2O01QKg/2O008Kg/2O016Kg/006Y_N`Al02a_N`Al
00M_N`9l00i_N`Al00A_N`Al00E_N`Al00M_N`Al00A_N`03001_Nfmk00i_N`Al00M_N`9l06I_N`Al
02M_N`9l02I_N`00JVmk17`09Vmk0W`016mk17`01Vmk17`03Vmk0W`01Vmk0W`01Vmk17`026mk0W`0
1Fmk0W`03fmk17`01Vmk17`02Fmk0W`016mk0W`04Fmk0W`0@Fmk17`09Vmk17`09Fmk001[Kg/2O00>
Kg/2O00=Kg/2O007Kg/4O004Kg/2O007Kg/4O00IKg/2O004Kg/2O00?Kg/4O004Kg/2O003Kg/2O004
Kg/2O007Kg/4O008Kg/4O002Kg/4O00?Kg/4O011Kg/2O00WKg/4O00UKg/0051_N`9l02Q_N`Al00]_
N`Al00I_N`Al00i_N`9l01U_N`Al00Y_N`9l00Q_N`Al00=_N`Al0003Kg]l07`0009l00e_N`9l00U_
N`Al009_N`Al00m_N`Al06]_N`9l02I_N`00Cfmk17`09fmk17`02fmk17`01fmk0W`0:Vmk17`02Fmk
17`00Vmk0W`016mk0W`016mk17`000=_Ng`0O0000W`02Vmk0W`03Fmk0W`016mk0W`04Fmk0W`07Fmk
0W`0?6mk0W`0=fmk001?Kg/4O00XKg/2O00:Kg/2O0000fmkO01l000YKg/2O00:Kg/2O00:Kg/4O000
0fmkO01l0002O003Kg/30004Kg/2O003Kg/2O006Kg/2O002Kg/4O013Kg/4O00jKg/4O00fKg/0051_
N`9l03A_N`Al02Y_N`Al01I_N`9l009_N`Al00=_N`03001_Nfmk011_N`Al0003Kg]l07`0009l00M_
N`9l03Y_N`Al015_N`9l02M_N`Al03I_N`00QVmk17`066mk0W`046mk17`02Fmk0W`016mk0W`00fmk
0W`01Fmk0W`016mk00<006mkKg/00W`01fmk0W`00Vmk0W`000=_Ng`0O0000W`00Vmk0W`01fmk17`0
86mk0W`066mk0W`04Fmk17`09fmk0W`0=fmk000kKg/40018Kg/2O0060006Kg/2O00:Kg/4O00@Kg/2
O005Kg/2O002Kg/4O002Kg/4O0000fmkO01l0002O002Kg/2O003Kg/2O0000fmk001_N`04O0000fmk
O01l0002Kg/8O0000fmkO01l000<Kg/4O00>Kg/2O00?Kg/4O004Kg/6000EKg/2O009Kg/4O00YKg/4
000cKg/003e_N`03001_Nfmk00Q_N`9l029_N`9l01]_N`03001_Nfmk009_N`03001_Nfmk00=_N`Al
00A_N`9l00=_N`Al01I_N`Al0003Kg]l07`0009l009_N`Al0003Kg]l07`0009l0003Kg]l07`0009l
0003Kg]l07`0009l0003001_Ng`000Ml0003Kg]l07`000Il00U_N`9l00E_N`9l00i_N`Al00i_N`Al
00A_N`03001_Nfmk009_N`03001_Nfmk019_N`Al00U_N`9l02a_N`03001_Nfmk039_N`00?Fmk00<0
06mkKg/01fmk17`086mk17`06fmk00<006mkKg/01fmk17`00fmk17`00fmk0W`01Vmk0W`03fmk17`0
0Vmk0W`016mk0W`00fmk0W`00Vmk17`000=_Ng`0O0000W`000<006mkKg/00W`000=_Ng`0O0000W`0
0Vmk0W`00Vmk0W`02Fmk17`056mk17`03fmk0W`01Vmk00<006mkKg/00Vmk0W`04Vmk17`0=fmk00<0
06mkKg/09Vmk0W`02Vmk000iKg/60008Kg/4O00PKg/4O00LKg/00`00Kg]_N`07Kg/2O004Kg/4O00:
Kg/4O00?Kg/2O008Kg/2O009Kg/2O003Kg/2O00016mk001l07`016mk0W`02Vmk0W`01Vmk17`01fmk
0W`036mk0W`06Fmk00<006mkKg/017`04Vmk0W`0=6mk1P009Vmk17`02Fmk000`Kg/60004Kg/01000
Kg]_N`002Vmk0W`08Vmk0W`04Vmk1P001Vmk00<006mkKg/03Fmk0W`02fmk17`03Fmk0W`02Fmk17`0
00=_Ng`0O0000fmk0W`00Vmk0W`016mk17`02Fmk0W`00fmk17`01Vmk0W`01fmk17`09fmk00<006mk
O0000g`0>Vmk0W`03Fmk00@006mkKg/002M_N`Al00U_N`00>Vmk00@006mkKg/0029_N`9l02]_N`03
001_Nfmk01Y_N`9l00e_N`Al00Q_N`Ql0003Kg]l07`000Il00=_N`Al00E_N`9l0003Kg]l07`0009l
009_N`Al00A_N`9l00U_N`Al02Q_N`04001_Ng`0O00jKg/4O00<Kg/01000Kg]_N`00:6mk0W`02Vmk
000ZKg/2O00?Kg/00`00Kg/0000QKg/4O00VKg/01000Kg]_Nfmk0W`08fmk0W`01Fmk17`02Fmk0W`0
00=_Ng`0O0000W`000=_Ng`0O0001W`00fmk00<007`0O0001Fmk27`00fmk0W`016mk17`02Fmk0W`0
6Fmk0W`02Vmk00<006mkKg/00Vmk00<006mkKg/0>Vmk17`03Fmk00<006mk0000=6mk000YKg/4O00>
Kg/00`00Kg/0000QKg/4O00VKg/00`00Kg]_N`04O0000fmkO01l0003Kg/2O00IKg/4O005Kg/2O004
Kg/2O003Kg/2O003Kg/2O003Kg/2O002Kg/4O0000fmkO01l0003Kg/2O002Kg/4O0000fmkO01l0005
Kg/2O003Kg/4O00SKg/4O009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0aKg/2O008Kg/2O00>Kg/00`00
Kg/0000dKg/002U_N`Al00m_N`80029_N`9l02Q_N`8000Ql0003Kg]l07`0009l00M_N`9l00m_N`Al
00A_N`9l00A_N`Al0003Kg]l07`0009l00A_N`9l009_N`9l009_N`Ml0003Kg]l07`0009l009_N`9l
00A_N`9l009_N`Al00=_N`9l02A_N`Al00Y_N`@003=_N`Al01Q_N`8003A_N`00:Vmk0W`0HFmk0W`0
00=_Ng`0O0000W`000=_Ng`0O0000W`01Vmk17`03fmk0W`016mk17`00fmk17`000=_Ng`0O0000W`0
0fmk27`000=_Ng`0O0001G`000=_Ng`0O0000W`01fmk17`000=_Ng`0O0000W`08fmk0W`01Fmk0W`0
@Vmk17`0CVmk002;Kg/2O004Kg/2O003Kg/2O007Kg/4O007Kg/2O00<Kg/4O004Kg/2O003Kg/2O004
Kg/8O002Kg/2O0000fmkO01l0003Kg/2O008Kg/4O002Kg/2O00SKg/4O00_Kg/2O00HKg/2O01?Kg/0
08Y_N`Al019_N`9l00M_N`Al00a_N`9l00M_N`9l00=_N`9l00=_N`9l009_N`Al00=_N`9l0003001_
Nfmk00=_N`9l00M_N`9l00E_N`9l00e_N`9l00E_N`9l00]_N`Al01e_N`9l00m_N`Al04U_N`9l01e_
N`00Gfmk0W`0:Fmk17`06fmk17`01Vmk0W`036mk17`000=_Ng`0O0000W`01fmk17`000=_Ng`0O000
0W`016mk17`036mk17`02fmk17`00fmk17`02fmk0W`03fmk0W`036mk17`03Vmk17`04fmk0W`0<fmk
17`076mk0009Kg/2O015Kg/2O00<Kg/4O00YKg/2O00MKg/2O006Kg/4O00;Kg/4O0000fmkO01l0002
O007Kg/4O0000fmkO01l0002O004Kg/4O006Kg/2O004Kg/6O009Kg/4O003Kg/4O006Kg/2O00CKg/4
O00;Kg/4O00?Kg/2O00CKg/4O00bKg/4O00LKg/000Q_N`Al03U_N`9l00Q_N`Al00]_N`Al03]_N`9l
01=_N`Al00A_N`9l00A_N`Al00=_N`=l009_N`9l00=_N`=l00=_N`Al00A_N`9l00I_N`Al00A_N`Il
00U_N`9l00E_N`9l00I_N`Al019_N`Al00a_N`9l02E_N`Al03=_N`9l01e_N`0026mk17`0>6mk17`0
1fmk17`036mk0W`02Vmk0W`0;fmk17`04fmk0W`016mk17`00Vmk17`016mk27`000=_Ng`0O00017`0
0Vmk17`02fmk17`01Vmk17`066mk17`04fmk0W`0=Fmk0W`07fmk0W`0<Vmk0009Kg/2O00iKg/4O008
Kg/2O00HKg/4O00^Kg/4O00>Kg/2O009Kg/4O002Kg/4O004Kg/8O0000fmkO01l0005O0000fmkO01l
0002O00<Kg/2O008Kg/2O00JKg/2O009Kg/2O01PKg/4O00aKg/004D0009l02<000Al01l0009l00P0
009l00@0009l00D0009l00L000Al00T0009l00@0009l00H0009l0080009l00<000Ml0003001l07`0
009l0080009l01/0009l01X000Al05l000Al0300005_N`003fmk00<006mkKg/026mk0W`01fmk00<0
06mkKg/04Vmk00<006mkKg/04Fmk00<006mkKg/04Fmk00<006mkKg/026mk0W`016mk0W`000=_N`00
Kg/02Vmk0W`01Vmk00@006mkKg]_N`Al00I_N`Al00=_N`03001_Nfmk00=_N`Al00I_N`Al0003001_
Nfmk009_N`9l00I_N`9l00A_N`9l00U_N`9l00=_N`El0003001l07`000Il00=_N`9l00A_N`9l0003
001l07`000=_N`9l00I_N`Al00=_N`03001_Nfmk015_N`03001_Ng`000=l00i_N`03001_Nfmk00Y_
N`9l00E_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk015_N`03001l07`0015_N`03001_
Nfmk015_N`03001_Nfmk00Y_N`003fmk00<006mkKg/01fmk17`01Vmk00<006mkKg/04Vmk00<006mk
Kg/04Fmk00<006mkKg/04Fmk00<006mkKg/03Fmk17`000<006mkKg/026mk17`01Fmk00@006mkKg]_
N`Al00I_N`Al00=_N`03001_Nfmk00=_N`Al00M_N`9l0003Kg/006mk009_N`Al00A_N`Al009_N`Al
00M_N`Al00=_N`Al0003001l07`000Il009_N`Al009_N`Ml0003Kg]l07`0009l00E_N`Al00=_N`03
001_Nfmk015_N`03001_Nfmk009l00m_N`03001_Nfmk00U_N`Al00A_N`03001_Nfmk015_N`03001_
Nfmk019_N`03001_Nfmk015_N`03001_Nfmk015_N`03001_Nfmk015_N`03001_Nfmk00Y_N`006Fmk
17`06fmk00<006mkKg/0=Fmk17`02fmk17`01Fmk00<006mkKg/00Vmk0W`026mk0W`02fmk0W`02Vmk
0W`00fmk1W`00Vmk17`00Vmk17`01fmk17`016mk0W`000=_N`00Kg/00W`00Vmk0W`00fmk17`00Vmk
1g`000=_Ng`0O0000W`01Vmk0W`01Vmk0W`096mk00<006mkKg/02Fmk17`0@Fmk00<006mkKg/0<Vmk
000JKg/2O01EKg/2O00=Kg/2O00]Kg/4O0000fmkO01l0006O002Kg/2O004Kg/3O002Kg/2O00016mk
O01l06mk17`000=_Ng`0O0000fmk0W`02Vmk0W`016mk0W`000=_Ng`0O0000fmk17`036mk17`03Vmk
0W`086mk0W`04Vmk0W`0Hfmk001BKg/2O00=Kg/2O01<Kg/8O0000fmkO01l0002O004Kg/2O002Kg/;
O0000fmkO01l0005O0000fmkO01l0002O0000fmkO01l0002Kg/2O006Kg/2O009Kg/4O00;Kg/4O00=
Kg/4O00bKg/4O01RKg/0055_N`Al00]_N`Al04=_N`9l00M_N`9l0003Kg]l07`0009l009_N`9l00A_
N`Al0003Kg]l07`000Ul0003Kg]l07`000El0003Kg]l07`000Yl00A_N`Al00Q_N`Al00a_N`9l00i_
N`Al00i_N`9l029_N`Al069_N`00DFmk17`02fmk17`0:Vmk0W`05Vmk17`02Vmk0W`02Fmk17`00Vmk
0W`00Vmk0W`000=_Ng`0O0000fmk0W`000=_Ng`0O0000fmk0W`000=_Ng`0O0001W`00fmk1G`02Fmk
0W`000=_Ng`0O0006fmk0W`03Vmk17`08Vmk0W`0Hfmk0010Kg/2O00@Kg/2O004Kg/2O007Kg/2O00Z
Kg/4O00EKg/4O007Kg/2O003Kg/2O003Kg/2O003Kg/2O00=Kg/2O008Kg/01000Kg]_Nfmk0W`00Vmk
0W`00fmk1G`01Vmk0W`016mk17`04Vmk0W`02Fmk0W`02fmk17`02fmk0W`0NVmk000oKg/4O00DKg/4
O00bKg/4O00FKg/2O007Kg/4O0000fmkO01l0002O0000fmkO01l0002O00@Kg/4O004Kg/2O0000fmk
001_N`0;Kg/4O006Kg/4O003Kg/4O004Kg/2O00;Kg/4O007Kg/4O00;Kg/2O00;Kg/4O01iKg/0035_
N`9l00a_N`Al01A_N`Al03=_N`9l021_N`Al0003Kg]l07`0009l0003Kg]l07`0009l00E_N`9l00=_
N`9l00=_N`El00=_N`Al0003001_Nfmk00Q_N`9l0003Kg]l07`000M_N`Al00A_N`9l00A_N`Al00Y_
N`Al00M_N`Al01Q_N`Al02m_N`9l04Q_N`00<6mk17`036mk0W`05Vmk0W`0Efmk0W`00fmk0W`00fmk
0W`01Fmk17`000=_Ng`0O0000W`000=_Ng`0O0000g`016mk17`000<006mkKg/00W`01Fmk17`02Vmk
0W`00Vmk0W`01fmk17`02fmk0W`02Fmk0W`06Vmk0W`0;fmk17`07Vmk0W`09fmk000`Kg/4O003Kg/2
O012Kg/2O00DKg/2O004Kg/2O00FKg/2O00AKg/4O0000fmkO01l0002O0000fmkO01l0002O006Kg/2
O0000fmk001_N`04O004Kg/4O00=Kg/4O007Kg/2O013Kg/2O00OKg/4O00MKg/4O00VKg/0035_N`9l
00=_N`Al041_N`Al00Q_N`9l00Q_N`Al009_N`Al01A_N`Al00A_N`9l00I_N`9l00=_N`9l00=_N`9l
00=_N`9l00Y_N`03001_Ng`000=l00E_N`9l00i_N`Al011_N`9l03U_N`Al01m_N`9l01i_N`Al02I_
N`00=Vmk17`0<Fmk0W`03Fmk17`01fmk17`01fmk17`00Vmk17`056mk17`00fmk17`016mk17`016mk
0W`04Vmk00<006mkKg/00W`00fmk0W`02Vmk0W`01Vmk0W`046mk17`0>6mk17`0@6mk0W`09fmk000I
Kg/2O00LKg/2O00aKg/4O00=Kg/2O008Kg/4O008Kg/2O004Kg/2O00FKg/2O004Kg/4O004Kg/4O003
Kg/4O003Kg/2O002Kg/2O008Kg/00`00Kg]_N`04Kg/4O004Kg/2O002Kg/4O003Kg/2O006Kg/2O00:
Kg/4O00AKg/2O00VKg/2O01ZKg/001Q_N`Al04i_N`Al01Q_N`9l02i_N`9l00I_N`9l00A_N`Al009_
N`Ql00M_N`03001_Nfmk00A_N`Al00=_N`Al0003Kg]l07`0009l009_N`Il009_N`Al00Y_N`9l00Y_
N`9l00E_N`Al02A_N`Al015_N`9l05I_N`0066mk17`0Cfmk0W`0;Fmk0W`02fmk0W`076mk0W`00fmk
27`00fmk0W`00Vmk00<006mkKg/00W`00fmk0W`016mk17`00Vmk0W`00fmk1g`000=_Ng`0O0000W`0
5Fmk17`016mk17`096mk17`046mk17`0EFmk000IKg/2O01GKg/2O00UKg/4O009Kg/4O003Kg/2O00C
Kg/2O006Kg/3O002Kg/4O0000fmkO01l0002O0000fmk001_N`04O006Kg/2O0000fmkO01l0009Kg/6
O002Kg/2O00FKg/4O005Kg/2O00VKg/2O00AKg/4O01EKg/005I_N`9l01U_N`Al02A_N`Al00U_N`Al
009_N`Al0003Kg]l07`000i_N`Al00A_N`Al00=_N`Ql0003Kg/006mk00Al00E_N`Al00i_N`9l00I_
N`9l01A_N`9l049_N`9l05I_N`00EFmk17`066mk17`09Fmk0W`02fmk0W`00fmk27`03Fmk17`016mk
17`00fmk17`000=_Ng`0O0000Vmk0`000W`01Vmk17`02Fmk0W`02Vmk1G`076mk0W`03Vmk0W`01fmk
0W`0Mfmk000LKg/2O00gKg/4O00IKg/2O00?Kg/2O00XKg/2O0000fmkO01l0002O00>Kg/2O0000fmk
O01l0003Kg/4O003Kg/2O006Kg/00`00Kg]_N`09Kg/2O005Kg/2O002Kg/4O009Kg/6O00JKg/4O00<
Kg/4O005Kg/4O006Kg/2O01^Kg/001]_N`Al03M_N`9l02Y_N`Al02]_N`9l015_N`Al00=_N`Al00M_
N`9l0004Kg/007`0O003Kg/2O00:Kg/4O0000fmkO01l0002O00:Kg/5O00JKg/4O00<Kg/4O005Kg/4
O005Kg/4O01]Kg/001]_N`Al06=_N`Al00U_N`9l01=_N`9l01i_N`Al00=_N`Al00I_N`Ql0003Kg]l
07`0009l00U_N`Al009_N`9l00e_N`9l01a_N`Al00a_N`9l00M_N`9l00I_N`Al06e_N`0076mk0W`0
IFmk0W`02Fmk17`04Fmk17`07Vmk0W`01Fmk17`01Fmk27`000=_Ng`0O0000W`02Vmk0W`02Fmk0W`0
3Vmk0W`05Vmk17`07Fmk0W`0KVmk002>Kg/4O00AKg/4O00VKg/4O005Kg/2O00016mk001l07`00fmk
0W`00Vmk0W`01Fmk0W`02Vmk17`00Vmk0W`026mk17`02Fmk0W`02Vmk17`0SFmk002?Kg/2O008Kg/2
O009Kg/2O00LKg/2O004Kg/2O003Kg/4O008Kg/00`00Kg]_N`04Kg/6O003Kg/4O009Kg/4O0000fmk
O01l0002O007Kg/4O008Kg/4O00:Kg/2O02>Kg/009Q_N`Al02E_N`Al009_N`Al00=_N`9l00U_N`03
001_Nfmk00=_N`Ml00=_N`Al00Y_N`9l009_N`Al00Q_N`9l00U_N`Al09Y_N`009Fmk0W`0>Fmk0W`0
=Vmk17`076mk0W`01fmk17`00Vmk17`01Fmk0W`01fmk00<006mkKg/00fmk1W`01Fmk0W`01Fmk0W`0
16mk0W`00fmk0W`05Fmk0W`0Vfmk000TKg/4O00gKg/4O00fKg/2O00GKg/2O003Kg/4O007Kg/2O004
Kg/2O005Kg/4O0000fmkO01l0003Kg/01000Kg]l07`00fmk0W`03Vmk17`00Vmk17`02Vmk0W`0:Fmk
0W`0Ofmk000TKg/4O00gKg/4O00lKg/2O00@Kg/4O002Kg/4O00>Kg/2O004Kg/8O002Kg/00`00O01l
0002O00BKg/4O002Kg/4O009Kg/4O00WKg/4O01nKg/002E_N`9l019_N`9l02E_N`9l03a_N`Al00]_
N`9l009_N`Al00=_N`9l00i_N`Al00A_N`9l0003Kg]l07`0009l009_N`03001l07`0009l00U_N`9l
00Q_N`9l00A_N`9l00Y_N`Al00A_N`9l00U_N`9l01I_N`Al03m_N`9l03e_N`00>6mk17`0HVmk17`0
2Vmk17`00Vmk0W`036mk0W`01Vmk17`026mk0W`00fmk00@006mkO01l00U_N`Al01Y_N`9l00A_N`Al
00M_N`Al01I_N`9l03m_N`Al00I_N`9l03A_N`00>6mk17`0?6mk0W`026mk0W`06fmk0W`02fmk17`0
3fmk17`01Vmk0W`03Vmk00<006mkKg/02Vmk17`04fmk0W`02fmk17`01fmk17`0Efmk17`01Fmk17`0
26mk0W`0:Fmk000iKg/2O00lKg/4O006Kg/4O00:Kg/2O00LKg/2O00@Kg/4O009Kg/2O00;Kg/00`00
Kg]_N`0;Kg/2O00CKg/4O00;Kg/2O009Kg/2O00=Kg/2O01:Kg/2O006Kg/4O007Kg/4O00XKg/007M_
N`Al00I_N`Al00U_N`Al01=_N`9l01U_N`9l00U_N`Al00Y_N`04001_Ng`0O00OKg/4O00TKg/4O01B
Kg/2O008Kg/4O00XKg/007Q_N`9l00Q_N`9l00Y_N`Al019_N`Al02=_N`Al00Y_N`03001l07`0009l
01m_N`9l02E_N`Al05e_N`9l02U_N`00A6mk0W`0BFmk0W`04fmk17`096mk0W`02fmk00<007`0O000
0W`056mk0W`00Vmk0W`026mk0W`076mk0W`01Fmk0W`036mk0W`0Nfmk0013Kg/4O01NKg/2O00bKg/0
1000Kg]l07`046mk0W`00Vmk27`01Vmk17`046mk0W`026mk17`04Fmk17`0NVmk000NKg/2O00@Kg/2
O00AKg/4O025Kg/2O00;Kg/00`00Kg]_N`0@Kg/4O0000fmkO01l0006O006Kg/4O00?Kg/4O007Kg/4
O00AKg/4O01jKg/001e_N`Al00i_N`Al015_N`9l06=_N`9l021_N`Al00Y_N`03001_Nfmk00]_N`9l
00=_N`Al009_N`9l009_N`9l00Q_N`9l011_N`Al00Q_N`9l01=_N`9l07]_N`007Fmk17`03Vmk17`0
MFmk17`05Fmk0W`026mk17`01fmk0W`000A_N`00000000I_N`9l009_N`Al00=_N`9l02A_N`9l09]_
N`007Vmk0W`046mk0W`0MVmk17`056mk17`026mk0W`01fmk17`000<006mkKg/01Fmk17`000=_Ng`0
O0000W`0aVmk002KKg/2O00<Kg/2O00EKg/4O00AKg/4O0000`00Kg]_N`05Kg/4O002Kg/2O00JKg/2
O00;Kg/2O00VKg/2O01fKg/009Y_N`Al02=_N`9l01=_N`9l0003Kg/006mk00M_N`9l01i_N`Al00U_
N`Al02A_N`Al07E_N`00HFmk0W`02Vmk0W`0:fmk17`0>fmk00<006mkKg/09Vmk17`02Fmk17`096mk
17`0MFmk001PKg/4O008Kg/4O00[Kg/2O00=Kg/2O00SKg/2O007Kg/2O005Kg/2O00RKg/2O00;Kg/2
O00VKg/2O01fKg/004U_N`9l01E_N`Al00Q_N`Al03U_N`Al01Y_N`9l00E_N`Al00E_N`Al00=_N`Al
00M_N`9l03Q_N`9l08]_N`00B6mk17`05Fmk0W`02Vmk0W`0>Vmk17`06Fmk17`016mk17`01Fmk17`0
0fmk17`01Vmk17`0=Vmk17`0RVmk000SKg/2O00SKg/4O00jKg/2O00RKg/2O00JKg/4O005Kg/2O007
Kg/2O005Kg/2O007Kg/4O00=Kg/2O00WKg/4O02:Kg/0029_N`Al02=_N`9l02M_N`9l015_N`Al03i_
N`9l011_N`03001_Nfmk00e_N`9l00M_N`9l00A_N`Al02M_N`9l00I_N`9l08=_N`008Vmk17`0Bfmk
17`046mk17`02Vmk0W`0A6mk00<006mkKg/05Fmk17`00fmk17`0;Vmk17`0PVmk000SKg/2O01<Kg/4
O00AKg/2O00:Kg/4O013Kg/00`00Kg]_N`0EKg/4O004Kg/2O00_Kg/4O022Kg/0079_N`9l00U_N`9l
01=_N`Al00U_N`9l029_N`9l01A_N`04001_Ng`0O00EKg/2O00gKg/2O023Kg/007a_N`Al01=_N`9l
00U_N`Al00M_N`9l00]_N`9l00Y_N`Al01=_N`03001l07`0009l00U_N`9l01e_N`9l00a_N`9l09Y_
N`00O6mk17`07Vmk17`01Vmk17`02Fmk17`02Fmk17`02fmk0W`01Vmk00<007`0O0000W`026mk17`0
6fmk17`02Vmk17`0VFmk001mKg/2O00PKg/2O007Kg/4O009Kg/4O00:Kg/2O00;Kg/4O005Kg/01000
Kg]l07`02Fmk17`06fmk17`02Vmk17`076mk0W`0Nfmk002YKg/2O00;Kg/2O00HKg/4O005Kg/00`00
Kg]_N`0;Kg/2O00MKg/2O00<Kg/2O00<Kg/2O00>Kg/4O01jKg/00=5_N`9l00I_N`03001_Nfmk04E_
N`Al00e_N`Al07Y_N`00[Vmk0W`05fmk0W`046mk00<006mkKg/0AFmk17`03Vmk0W`0Nfmk002KKg/2
O00@Kg/4O00EKg/4O00?Kg/00`00Kg]_N`16Kg/2O02<Kg/009Y_N`Al00m_N`Al01E_N`Al00m_N`<0
0=A_N`00BFmk0W`0AFmk0W`026mk17`046mk0W`036mk0W`02Fmk0W`046mk00<006mkKg/05Fmk0W`0
:Fmk0W`0TVmk0018Kg/4O00/Kg/2O00EKg/4O008Kg/2O00NKg/4O00JKg/00`00Kg]_N`0DKg/4O00W
Kg/4O02AKg/001e_N`9l02U_N`Al02]_N`Al01A_N`Al02Q_N`Al01Y_N`03001_Nfmk01A_N`Al02M_
N`Al095_N`0076mk17`0:Fmk0W`0;6mk17`05Fmk0W`0:Vmk0W`06fmk00<006mkKg/05Fmk0W`0:Fmk
0W`0TVmk000LKg/4O00iKg/2O00MKg/2O01OKg/00`00Kg]_N`1AKg/2O00MKg/2O01RKg/001e_N`9l
03U_N`Al02a_N`9l04m_N`03001_Nfmk009l01M_N`9l011_N`9l00I_N`9l01]_N`Al01]_N`Al065_
N`00F6mk17`0:fmk17`0;Fmk0W`02Vmk0W`03Fmk0W`016mk00<006mkO0000g`05Fmk17`03Vmk17`0
16mk17`06Vmk17`06fmk17`0HFmk001IKg/2O00/Kg/4O00@Kg/2O00JKg/4O008Kg/4O006Kg/2O003
Kg/4O003Kg/00`00Kg]l0003O00EKg/4O00>Kg/4O004Kg/4O00KKg/2O00MKg/2O01RKg/008Q_N`9l
011_N`Al01U_N`Al00Q_N`Al00E_N`Al009_N`Al00=_N`03001_Nfmk009l01M_N`9l011_N`9l00I_
N`9l08A_N`9l01U_N`00VVmk17`06Vmk0W`02Vmk0W`01Vmk17`00fmk0W`016mk00<006mkKg/0Vfmk
0W`06fmk17`066mk001VKg/2O00cKg/2O00=Kg/2O006Kg/2O00IKg/2O00:Kg/00`00Kg]_N`08Kg/2
O00AKg/2O01mKg/4O00JKg/4O00HKg/006E_N`Al02a_N`9l019_N`Al00A_N`Al02A_N`03001_Nfmk
00M_N`Al00m_N`Al01e_N`9l04E_N`9l01I_N`Al01]_N`9l01U_N`00IFmk17`0:fmk17`04Fmk17`0
16mk17`08Fmk0W`000=_N`00Kg/026mk17`03fmk17`076mk17`0@fmk17`05Vmk0W`0=fmk0014Kg/2
O00PKg/2O00/Kg/4O00BKg/2O006Kg/2O003Kg/2O00LKg/4O0000`00Kg]_N`08Kg/2O00AKg/2O00M
Kg/4O013Kg/4O01?Kg/004=_N`Al03a_N`9l011_N`9l01m_N`Al01]_N`Al0003001_Nfmk03]_N`9l
04E_N`9l051_N`00@fmk17`0>fmk17`0<6mk17`03fmk0W`000=_N`000000100016mk0W`000=_N`00
Kg/09fmk0W`0[6mk0014Kg/2O00lKg/4O00aKg/2O00?Kg/4O0000`00Kg]_N`02Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0UKg/4O00dKg/2O01eKg/008=_N`9l00a_N`9l03E_N`Al0003Kg/006mk00Y_N`03
001_Nfmk02E_N`Al02Y_N`9l00M_N`Al07A_N`00N6mk0W`05Vmk17`0=Fmk0W`00fmk00<006mkKg/0
26mk00<006mkKg/01Fmk0W`07fmk0W`0:Vmk17`01Vmk17`0M6mk001gKg/4O00EKg/4O00kKg/00`00
Kg]_N`07Kg/40003Kg/4O01:Kg/4O007Kg/2O01eKg/007M_N`Al01I_N`9l031_N`9l00]_N`03001_
Nfmk00I_N`03001_Nfmk00A_N`Al03=_N`9l01I_N`9l07m_N`00N6mk0W`0B6mk17`01Vmk00@006mk
Kg]_N`9l00M_N`03001_Nfmk00E_N`9l00A_N`9l019_N`9l01U_N`Al09I_N`00/Fmk0W`03fmk17`0
1Vmk00<006mkKg/017`01Vmk00<006mkKg/02Vmk17`046mk17`066mk17`0UVmk002NKg/2O00@Kg/4
O00?Kg/2O008Kg/20004O006Kg/00`00O01l000:Kg/4O00@Kg/4O00:Kg/2O00=Kg/2O02GKg/006]_
N`9l031_N`Al00m_N`Al00U_N`9l015_N`9l00M_N`Al00Y_N`9l019_N`9l00Y_N`Al0:E_N`00JVmk
17`0;fmk17`046mk0W`02Fmk17`036mk0W`02fmk17`0:Vmk17`0?fmk0W`0I6mk000QKg/2O017Kg/4
O00`Kg/2O00LKg/4O00;Kg/4O00:Kg/00`00O01l000AKg/2O002Kg/2O00EKg/2O00oKg/4O01SKg/0
021_N`Al04M_N`9l051_N`9l00a_N`Al00Y_N`03001_Nfmk011_N`Ql00A_N`9l04m_N`Al06=_N`00
86mk17`0Z6mk0W`02fmk00<006mkKg/046mk27`00fmk17`0Cfmk0W`0I6mk000QKg/2O01NKg/2O00=
Kg/2O017Kg/00`00Kg]_N`0AKg/2O002Kg/2O004Kg/4O00]Kg/2O00nKg/2O016Kg/003A_N`9l04Y_
N`Al00]_N`Al00i_N`9l03I_N`03001_Nfmk01a_N`9l02e_N`Al03a_N`Al04E_N`00<fmk17`0<6mk
0W`05fmk17`02fmk17`03Fmk17`0<Fmk0W`00Vmk00<006mkKg/0Bfmk17`05Fmk0W`09Fmk17`0AFmk
000cKg/4O00_Kg/4O00GKg/2O00=Kg/2O00>Kg/4O00<Kg/2O00RKg/4O0000fmk001_N`1=Kg/2O00E
Kg/4O00UKg/2O016Kg/003A_N`9l031_N`Al03M_N`9l00a_N`Al015_N`9l00i_N`Al0003Kg/006mk
03E_N`9l02e_N`Al06e_N`00EFmk0W`046mk0W`0AVmk17`046mk17`03Vmk0W`00Vmk00<006mkKg/0
<fmk17`0;Fmk0W`0KVmk001DKg/4O01HKg/2O00AKg/4O00BKg/00`00Kg]_N`06Kg/2O00[Kg/4O02M
Kg/005A_N`Al06a_N`9l01=_N`03001_Nfmk00E_N`Al02]_N`9l04I_N`9l05I_N`00EFmk0W`0Nfmk
0W`01Fmk00<006mkKg/01Fmk17`05Vmk0W`0FVmk17`0:6mk0W`0:fmk0011Kg/2O01=Kg/2O00GKg/2
O00VKg/4O004Kg/00`00Kg]_N`06Kg/2O00FKg/4O01IKg/4O00WKg/4O00ZKg/0041_N`Al04]_N`Al
01E_N`Al00U_N`9l01Y_N`Al00A_N`<001i_N`Al05Y_N`9l02Q_N`Al02Y_N`00@6mk17`0Bfmk17`0
5Fmk17`026mk17`06Vmk0W`01Fmk00<006mkKg/07fmk0W`0QVmk0W`0:fmk0011Kg/2O00VKg/2O00U
Kg/2O00GKg/2O009Kg/4O00QKg/00`00Kg]_N`3DKg/006Q_N`Al03M_N`9l011_N`9l029_N`03001_
Nfmk0=A_N`00J6mk17`0=Vmk17`0:Vmk0W`01fmk00<006mkKg/0e6mk001YKg/2O00AKg/2O00TKg/4
O00FKg/2O00AKg/4O006Kg/00`00Kg]_N`1CKg/2O010Kg/2O00mKg/004I_N`9l03=_N`Al02A_N`9l
01I_N`Al011_N`Al00I_N`03001_Nfmk059_N`Al03i_N`Al03a_N`00AFmk17`0<Vmk17`05fmk0W`0
8fmk17`04Fmk0W`01fmk00<006mkKg/0DVmk17`0?Vmk17`0?6mk0015Kg/4O00cKg/2O00GKg/4O00S
Kg/2O00KKg/00`00Kg]_N`0YKg/2O00XKg/2O00:Kg/2O00dKg/2O00mKg/004I_N`9l02]_N`9l00i_
N`9l011_N`Al041_N`03001_Nfmk02Q_N`Al01M_N`9l01U_N`Al079_N`00G6mk0W`056mk17`036mk
17`046mk0W`0@Fmk00<006mkKg/026mk0W`07Vmk17`05Vmk17`066mk17`0LVmk001KKg/4O00CKg/4
O00<Kg/4O00hKg/2O00CKg/2O004Kg/00`00Kg]_N`07Kg/4O00NKg/2O00GKg/4O00IKg/2O01cKg/0
05]_N`Al01A_N`9l00i_N`9l03Q_N`Al015_N`Al00=_N`03001_Nfmk00M_N`Al03Q_N`9l08m_N`00
DFmk0W`02Fmk0W`0Gfmk17`04Fmk17`00fmk00<006mkKg/026mk0W`0bVmk001@Kg/4O01ZKg/2O00C
Kg/2O004Kg/00`00Kg]_N`3DKg/0051_N`Al059_N`9l029_N`9l00e_N`03001_Nfmk01a_N`9l04E_
N`9l06m_N`00DFmk0W`0DVmk17`086mk17`036mk00<006mkKg/06fmk17`0@fmk17`0KVmk002UKg/4
O00PKg/4O00<Kg/00`00Kg]_N`0KKg/4O013Kg/4O01^Kg/006M_N`9l02e_N`9l00i_N`9l029_N`9l
00e_N`03001_Nfmk01a_N`9l04E_N`9l06m_N`00IVmk17`01Fmk0W`096mk17`0@6mk00<006mkKg/0
e6mk001VKg/4O004Kg/4O00SKg/4O00?Kg/2O00_Kg/3003DKg/006M_N`9l00E_N`Al02A_N`9l00m_
N`Al02i_N`03001_Nfmk0=A_N`00Kfmk0W`0=Vmk17`03Fmk0W`07fmk00<006mkKg/0e6mk002XKg/2
O00=Kg/4O009Kg/2O00CKg/00`00Kg]_N`27Kg/2O01;Kg/00;M_N`Al00Q_N`Al019_N`04001_Nfmk
Kg/2O023Kg/4O01:Kg/00;Q_N`9l00U_N`Al019_N`03001_Nfmk00Al089_N`Al04Y_N`00a6mk0W`0
4fmk00<006mkKg/017`0Pfmk0W`0Bfmk001IKg/2O01nKg/01000Kg]_Nfmk0W`0dFmk001HKg/4O01F
Kg/2O00UKg/00`00Kg]_N`3DKg/005Q_N`Al039_N`9l025_N`Al02A_N`03001_Nfmk0=A_N`00FFmk
0W`0<Vmk17`086mk17`06Fmk0W`02Fmk00<006mkKg/0e6mk001lKg/2O00?Kg/4O00QKg/2O00IKg/4
O008Kg/00`00Kg]_N`1OKg/2O01cKg/005I_N`9l02=_N`Al00m_N`9l03E_N`9l00I_N`Al00Q_N`03
001_Nfmk05i_N`Al079_N`00EFmk17`08Vmk17`0AFmk17`01Vmk0W`02Fmk00<006mkKg/0GVmk17`0
LVmk001EKg/4O00SKg/2O016Kg/4O00AKg/00`00Kg]_N`1OKg/2O008Kg/2O01YKg/005I_N`9l06e_
N`9l019_N`03001_Nfmk06Q_N`Al06Q_N`00fFmk00<006mkKg/0:6mk0W`066mk0W`096mk17`0J6mk
003IKg/00`00Kg]_N`0=Kg/2O00HKg/4O00FKg/4O00TKg/2O01YKg/00=U_N`03001_Nfmk00a_N`Al
01M_N`Al01I_N`Al02i_N`9l05m_N`00WVmk0W`0>Fmk00<006mkKg/036mk17`066mk0W`066mk0W`0
;Vmk17`0GVmk001YKg/2O00bKg/4O00;Kg/2O00[Kg/3000=Kg/2O01SKg/4O01NKg/006Q_N`Al035_
N`Al00Y_N`Al02Y_N`03001_Nfmk07=_N`9l05m_N`00J6mk17`0<Vmk0W`02fmk17`09Vmk0W`00Vmk
00<006mkKg/0e6mk001YKg/2O011Kg/2O00VKg/4O0000fmk001_N`3EKg/00=A_N`Al0003Kg/006mk
0=E_N`00_6mk0W`05fmk0W`00Vmk00<006mkKg/0e6mk002kKg/4O00JKg/00`00Kg]_N`3DKg/00;]_
N`Al01Y_N`03001_Nfmk0=A_N`00OFmk0W`0?Fmk0W`06fmk00<006mkKg/0e6mk001lKg/4O01IKg/0
0`00Kg]_N`3DKg/004m_N`9l02]_N`Al05U_N`03001_Nfmk0=A_N`00CVmk17`0:fmk0W`0FVmk00<0
06mkKg/066mk0W`0^Vmk001>Kg/4O00HKg/2O00TKg/2O017Kg/00`00Kg]_N`0GKg/4O00kKg/2O01l
Kg/004m_N`9l01Q_N`Al029_N`Al01e_N`9l02M_N`03001_Nfmk00A_N`9l015_N`Al03Y_N`Al07]_
N`00JFmk17`08Vmk17`076mk17`06Vmk0W`02Vmk00<006mkKg/00fmk17`04Fmk0W`0>fmk17`0Nfmk
001ZKg/2O00TKg/2O00MKg/4O00IKg/4O009Kg/00`00Kg]_N`03Kg/4O01?Kg/2O01lKg/00;1_N`9l
01Y_N`Al00U_N`03001_Nfmk00A_N`9l02E_N`9l0:M_N`00cFmk0W`00`001fmk00<006mkKg/0:Vmk
17`0YVmk003@Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0ZKg/4O02VKg/00=1_N`03001_Nfmk00I_N`03
001_Nfmk02]_N`9l0:M_N`00c6mk1P001fmk00<006mkKg/0Mfmk0W`0Ffmk003=Kg/01000Kg]_N`00
26mk1000?Vmk0W`0=Fmk17`0FVmk003=Kg/01000Kg]_N`0026mk00<006mkKg/0?Vmk17`0=6mk17`0
FVmk003>Kg/00`00Kg/00008Kg/00`00Kg]_N`0nKg/4O00eKg/2O01KKg/00<i_N`03001_N`0000Q_
N`03001_Nfmk01E_N`9l02Q_N`9l09=_N`00cfmk0P0026mk00<006mkKg/056mk17`0_6mk003IKg/0
0`00Kg]_N`0DKg/4O02lKg/00=U_N`03001_Nfmk01E_N`9l0;e_N`00Qfmk0W`0D6mk00<006mkKg/0
e6mk0026Kg/4O00jKg/2O00CKg/00`00Kg]_N`3DKg/008I_N`Al03U_N`Al019_N`03001_Nfmk0=A_
N`00Qfmk0W`0>Vmk17`04Vmk00<006mkKg/0e6mk001/Kg/2O01FKg/2O00CKg/00`00Kg]_N`3DKg/0
06]_N`Al06Y_N`03001_Nfmk0=A_N`00Jfmk17`0JVmk00<006mkKg/0e6mk001/Kg/2O01[Kg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/05Fmk0W`0_Fmk003IKg/00`00Kg]_
N`0DKg/4O02lKg/00=U_N`03001_Nfmk01A_N`Al0;a_N`00fFmk00@006mkO01l01A_N`9l0;e_N`00
fFmk00<007`0O0000W`0@6mk0W`0T6mk003IKg/00`00O01l0002O00oKg/4O02?Kg/00=U_N`04001_
Ng`0O010Kg/4O02?Kg/00=U_N`03001_Nfmk049_N`9l091_N`00fFmk00<006mkKg/0e6mk003IKg/0
0`00Kg]_N`0RKg/2O02`Kg/00=U_N`03001_Nfmk025_N`Al0:m_N`00XVmk0W`0=Fmk00<006mkKg/0
8Fmk17`0[fmk002QKg/4O00dKg/00`00Kg]_N`0RKg/2O02`Kg/00:5_N`Al03A_N`03001_Nfmk0=A_
N`00XVmk0W`0=Fmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk00Q_N`9l
0<Y_N`00fFmk00<006mkKg/01fmk17`0bFmk003IKg/00`00Kg]_N`07Kg/4O039Kg/00=U_N`03001_
Nfmk00Q_N`9l0<Y_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk
0=A_N`00fFmk00<006mkKg/0e6mk003;Kg/2O00<Kg/3000RKg/2O02`Kg/00<Y_N`Al00]_N`03001_
Nfmk025_N`Al0:m_N`00bVmk17`02fmk00<006mkKg/08Fmk17`0[fmk003;Kg/2O00<Kg/00`00Kg]_
N`0RKg/2O02`Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/016mk0W`0cVmk003IKg/00`00
Kg]_N`03Kg/4O03=Kg/00=U_N`03001_Nfmk00=_N`Al0<e_N`00fFmk00<006mkKg/016mk0W`0cVmk
003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/0
0=U_N`03001_Nfmk0=A_N`00\
\>"],
  ImageRangeCache->{{{0, 431}, {432.125, 0}} -> {-5.38918, -5.29211, \
0.0371388, 0.0371388}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[%, %%]\)], "Input",
  CellLabel->"In[59]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.00271 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.50502 0.0937202 0.495973 0.0937202 [
[.13014 .48347 -6 -9 ]
[.13014 .48347 6 0 ]
[.31758 .48347 -6 -9 ]
[.31758 .48347 6 0 ]
[.69246 .48347 -3 -9 ]
[.69246 .48347 3 0 ]
[.8799 .48347 -3 -9 ]
[.8799 .48347 3 0 ]
[.49252 .12109 -12 -4.5 ]
[.49252 .12109 0 4.5 ]
[.49252 .30853 -12 -4.5 ]
[.49252 .30853 0 4.5 ]
[.49252 .68341 -6 -4.5 ]
[.49252 .68341 0 4.5 ]
[.49252 .87085 -6 -4.5 ]
[.49252 .87085 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.00271 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13014 .49597 m
.13014 .50222 L
s
[(-4)] .13014 .48347 0 1 Mshowa
.31758 .49597 m
.31758 .50222 L
s
[(-2)] .31758 .48347 0 1 Mshowa
.69246 .49597 m
.69246 .50222 L
s
[(2)] .69246 .48347 0 1 Mshowa
.8799 .49597 m
.8799 .50222 L
s
[(4)] .8799 .48347 0 1 Mshowa
.125 Mabswid
.177 .49597 m
.177 .49972 L
s
.22386 .49597 m
.22386 .49972 L
s
.27072 .49597 m
.27072 .49972 L
s
.36444 .49597 m
.36444 .49972 L
s
.4113 .49597 m
.4113 .49972 L
s
.45816 .49597 m
.45816 .49972 L
s
.55188 .49597 m
.55188 .49972 L
s
.59874 .49597 m
.59874 .49972 L
s
.6456 .49597 m
.6456 .49972 L
s
.73932 .49597 m
.73932 .49972 L
s
.78618 .49597 m
.78618 .49972 L
s
.83304 .49597 m
.83304 .49972 L
s
.08328 .49597 m
.08328 .49972 L
s
.03642 .49597 m
.03642 .49972 L
s
.92676 .49597 m
.92676 .49972 L
s
.97362 .49597 m
.97362 .49972 L
s
.25 Mabswid
0 .49597 m
1 .49597 L
s
.50502 .12109 m
.51127 .12109 L
s
[(-4)] .49252 .12109 1 0 Mshowa
.50502 .30853 m
.51127 .30853 L
s
[(-2)] .49252 .30853 1 0 Mshowa
.50502 .68341 m
.51127 .68341 L
s
[(2)] .49252 .68341 1 0 Mshowa
.50502 .87085 m
.51127 .87085 L
s
[(4)] .49252 .87085 1 0 Mshowa
.125 Mabswid
.50502 .16795 m
.50877 .16795 L
s
.50502 .21481 m
.50877 .21481 L
s
.50502 .26167 m
.50877 .26167 L
s
.50502 .35539 m
.50877 .35539 L
s
.50502 .40225 m
.50877 .40225 L
s
.50502 .44911 m
.50877 .44911 L
s
.50502 .54283 m
.50877 .54283 L
s
.50502 .58969 m
.50877 .58969 L
s
.50502 .63655 m
.50877 .63655 L
s
.50502 .73027 m
.50877 .73027 L
s
.50502 .77713 m
.50877 .77713 L
s
.50502 .82399 m
.50877 .82399 L
s
.50502 .07423 m
.50877 .07423 L
s
.50502 .02737 m
.50877 .02737 L
s
.50502 .91771 m
.50877 .91771 L
s
.50502 .96457 m
.50877 .96457 L
s
.25 Mabswid
.50502 0 m
.50502 1.00271 L
s
0 0 m
1 0 L
1 1.00271 L
0 1.00271 L
closepath
clip
newpath
1 0 0 r
.01 w
.47668 .02387 Mdot
.46256 .04492 Mdot
.53059 .04244 Mdot
.5799 .05683 Mdot
.44714 .06888 Mdot
.5311 .08384 Mdot
.47579 .09113 Mdot
.28155 .08025 Mdot
.32353 .08263 Mdot
.38454 .0854 Mdot
.64633 .0785 Mdot
.72336 .09054 Mdot
.50404 .10035 Mdot
.43102 .11889 Mdot
.58187 .1075 Mdot
.37037 .12864 Mdot
.50708 .11875 Mdot
.60151 .11427 Mdot
.67376 .1247 Mdot
.27735 .13063 Mdot
.32853 .14249 Mdot
.55158 .13057 Mdot
.62307 .13271 Mdot
.76388 .12349 Mdot
.80547 .13282 Mdot
.48218 .14967 Mdot
.49154 .15403 Mdot
.51425 .15634 Mdot
.57715 .16358 Mdot
.25826 .15729 Mdot
.52976 .17316 Mdot
.61044 .17146 Mdot
.44652 .15372 Mdot
.46322 .16692 Mdot
.8077 .18016 Mdot
.3668 .18917 Mdot
.398 .18281 Mdot
.42231 .18355 Mdot
.45167 .19233 Mdot
.47091 .19433 Mdot
.49684 .19308 Mdot
.50389 .20136 Mdot
.65574 .18429 Mdot
.23268 .19946 Mdot
.28199 .19066 Mdot
.32294 .19057 Mdot
.61667 .19886 Mdot
.43407 .21385 Mdot
.45507 .22523 Mdot
.47664 .21495 Mdot
.5284 .20889 Mdot
.25736 .22967 Mdot
.33055 .22265 Mdot
.69834 .20225 Mdot
.30245 .23243 Mdot
.57272 .21949 Mdot
.61102 .22862 Mdot
.70487 .21787 Mdot
.81815 .218 Mdot
.39723 .22711 Mdot
.41907 .23203 Mdot
.48988 .24088 Mdot
.66611 .2276 Mdot
.7528 .22596 Mdot
.78257 .23183 Mdot
.51338 .24746 Mdot
.63803 .24638 Mdot
.65781 .24403 Mdot
.73883 .24561 Mdot
.20403 .23752 Mdot
.36656 .24258 Mdot
.40308 .25893 Mdot
.45245 .25121 Mdot
.545 .245 Mdot
.1358 .2517 Mdot
.18846 .26422 Mdot
.69761 .2574 Mdot
.73463 .26388 Mdot
.83314 .26625 Mdot
.32082 .2641 Mdot
.35852 .26353 Mdot
.57246 .26044 Mdot
.68709 .27887 Mdot
.90816 .26444 Mdot
.1027 .27011 Mdot
.44561 .27309 Mdot
.56158 .27777 Mdot
.59577 .27458 Mdot
.78391 .28262 Mdot
.30711 .28339 Mdot
.39624 .28061 Mdot
.48688 .28168 Mdot
.43609 .292 Mdot
.64918 .29186 Mdot
.36984 .29569 Mdot
.40808 .29477 Mdot
.52621 .29517 Mdot
.53884 .29511 Mdot
.55351 .29455 Mdot
.72775 .29554 Mdot
.22521 .29905 Mdot
.25773 .29495 Mdot
.29233 .30401 Mdot
.35166 .30376 Mdot
.60647 .30671 Mdot
.06467 .30901 Mdot
.17462 .30384 Mdot
.38576 .31137 Mdot
.57614 .31426 Mdot
.73999 .31514 Mdot
.41611 .31815 Mdot
.55678 .32206 Mdot
.22269 .32595 Mdot
.32738 .32932 Mdot
.35062 .33293 Mdot
.39454 .32889 Mdot
.40667 .33422 Mdot
.4472 .32277 Mdot
.52309 .32687 Mdot
.55183 .33062 Mdot
.81993 .31648 Mdot
.84897 .31787 Mdot
.08855 .34988 Mdot
.1348 .33856 Mdot
.21569 .33228 Mdot
.36405 .34252 Mdot
.42015 .3425 Mdot
.43612 .34064 Mdot
.46319 .33777 Mdot
.48178 .33487 Mdot
.50912 .33648 Mdot
.77283 .33555 Mdot
.88992 .32109 Mdot
.16679 .34856 Mdot
.24356 .35131 Mdot
.26231 .34669 Mdot
.28187 .34771 Mdot
.30927 .35071 Mdot
.38189 .35452 Mdot
.53733 .34566 Mdot
.56614 .34574 Mdot
.69234 .34048 Mdot
.49054 .35666 Mdot
.57217 .35313 Mdot
.62213 .34325 Mdot
.74168 .3538 Mdot
.80293 .35203 Mdot
.89791 .34859 Mdot
.2103 .36515 Mdot
.42946 .36213 Mdot
.51363 .35839 Mdot
.54768 .36413 Mdot
.60865 .36047 Mdot
.63833 .36419 Mdot
.8189 .36676 Mdot
.19228 .37501 Mdot
.40476 .36697 Mdot
.43609 .37051 Mdot
.46147 .36241 Mdot
.52032 .36681 Mdot
.54286 .37222 Mdot
.57473 .37192 Mdot
.84969 .36862 Mdot
.2391 .38832 Mdot
.33611 .37601 Mdot
.46929 .3776 Mdot
.48956 .38041 Mdot
.50559 .38332 Mdot
.52423 .37772 Mdot
.56404 .3811 Mdot
.61822 .38183 Mdot
.67373 .37239 Mdot
.70224 .37378 Mdot
.74309 .37311 Mdot
.83223 .38411 Mdot
.87153 .36737 Mdot
.91951 .37463 Mdot
.39451 .37769 Mdot
.44378 .38599 Mdot
.4623 .39085 Mdot
.52789 .38647 Mdot
.54195 .3837 Mdot
.6091 .39185 Mdot
.79154 .39038 Mdot
.96169 .3879 Mdot
.19309 .39413 Mdot
.27616 .38941 Mdot
.35942 .39519 Mdot
.37176 .39403 Mdot
.38562 .391 Mdot
.4074 .39491 Mdot
.41984 .39298 Mdot
.44133 .39541 Mdot
.52881 .39878 Mdot
.54328 .39445 Mdot
.6793 .40014 Mdot
.70537 .40215 Mdot
.72846 .39225 Mdot
.85623 .39882 Mdot
.15052 .3999 Mdot
.2632 .40954 Mdot
.39356 .40937 Mdot
.41885 .40567 Mdot
.43438 .40576 Mdot
.47703 .39925 Mdot
.51759 .40497 Mdot
.54837 .40375 Mdot
.56131 .40139 Mdot
.57663 .39921 Mdot
.64906 .40333 Mdot
.75171 .40727 Mdot
.87356 .40279 Mdot
.89128 .40852 Mdot
.30339 .40812 Mdot
.32911 .40359 Mdot
.39125 .41654 Mdot
.45317 .40993 Mdot
.46942 .40806 Mdot
.50581 .40707 Mdot
.58217 .41248 Mdot
.62026 .41158 Mdot
.79331 .40491 Mdot
.07859 .41911 Mdot
.17122 .4232 Mdot
.46129 .42238 Mdot
.47671 .42325 Mdot
.48782 .41876 Mdot
.50096 .42017 Mdot
.53549 .41497 Mdot
.54591 .41719 Mdot
.55679 .4194 Mdot
.60251 .41806 Mdot
.3241 .42963 Mdot
.34308 .42179 Mdot
.39423 .42664 Mdot
.41933 .42553 Mdot
.44688 .42382 Mdot
.51347 .42799 Mdot
.52215 .427 Mdot
.53189 .42767 Mdot
.54462 .42934 Mdot
.56464 .42925 Mdot
.70997 .42679 Mdot
.735 .4278 Mdot
.77962 .42763 Mdot
.83825 .43099 Mdot
.91148 .44012 Mdot
.38601 .44032 Mdot
.42497 .43665 Mdot
.44282 .4352 Mdot
.46541 .43858 Mdot
.48968 .43554 Mdot
.54784 .43928 Mdot
.58427 .43246 Mdot
.81366 .43812 Mdot
.25024 .43942 Mdot
.28733 .44514 Mdot
.3227 .44492 Mdot
.34635 .44267 Mdot
.36249 .43832 Mdot
.44987 .44635 Mdot
.50591 .44367 Mdot
.52194 .44517 Mdot
.53382 .44454 Mdot
.5708 .44116 Mdot
.59886 .44399 Mdot
.61167 .44366 Mdot
.72826 .4509 Mdot
.87196 .4502 Mdot
.18709 .44795 Mdot
.31656 .45319 Mdot
.42228 .45158 Mdot
.47983 .44766 Mdot
.49247 .44945 Mdot
.55353 .45136 Mdot
.56425 .45004 Mdot
.58676 .45374 Mdot
.6571 .44224 Mdot
.77517 .45378 Mdot
.16867 .46086 Mdot
.34735 .46056 Mdot
.37835 .457 Mdot
.43907 .45909 Mdot
.45093 .45778 Mdot
.46511 .45607 Mdot
.47595 .45792 Mdot
.48647 .46006 Mdot
.49903 .45996 Mdot
.51282 .458 Mdot
.52233 .45935 Mdot
.53292 .457 Mdot
.54402 .45681 Mdot
.57165 .4607 Mdot
.62683 .45971 Mdot
.66766 .45752 Mdot
.74691 .45882 Mdot
.25217 .46262 Mdot
.36422 .46288 Mdot
.39794 .46523 Mdot
.43442 .46817 Mdot
.46165 .46754 Mdot
.4716 .46971 Mdot
.48186 .46813 Mdot
.49295 .46818 Mdot
.50942 .46671 Mdot
.52659 .47121 Mdot
.53647 .46988 Mdot
.54947 .46653 Mdot
.56728 .47163 Mdot
.59402 .46658 Mdot
.65679 .47334 Mdot
.69873 .465 Mdot
.84063 .4689 Mdot
.97619 .46467 Mdot
.33077 .47291 Mdot
.33882 .476 Mdot
.34998 .47595 Mdot
.37336 .47871 Mdot
.41624 .47404 Mdot
.43072 .47689 Mdot
.44737 .47462 Mdot
.45998 .47457 Mdot
.47547 .47838 Mdot
.48571 .47771 Mdot
.49643 .47499 Mdot
.5049 .47613 Mdot
.51564 .4767 Mdot
.53992 .47897 Mdot
.55304 .47655 Mdot
.22447 .47076 Mdot
.32533 .48349 Mdot
.36674 .49308 Mdot
.39602 .48295 Mdot
.45245 .48513 Mdot
.46477 .48539 Mdot
.49018 .48437 Mdot
.50176 .48442 Mdot
.51983 .48535 Mdot
.55794 .48433 Mdot
.59108 .48493 Mdot
.60795 .48487 Mdot
.64062 .47937 Mdot
.67998 .48791 Mdot
.7564 .48333 Mdot
.81754 .47514 Mdot
.9323 .48604 Mdot
.09907 .47338 Mdot
.16248 .49078 Mdot
.18843 .48988 Mdot
.22396 .48681 Mdot
.35326 .49918 Mdot
.41833 .48836 Mdot
.43331 .49164 Mdot
.44859 .49112 Mdot
.46715 .49245 Mdot
.47615 .49126 Mdot
.48659 .49208 Mdot
.49542 .49339 Mdot
.5067 .49145 Mdot
.54166 .4898 Mdot
.56333 .48936 Mdot
.62937 .49024 Mdot
.71396 .48454 Mdot
.80773 .48834 Mdot
.88523 .49446 Mdot
.02381 .48971 Mdot
.1937 .5094 Mdot
.25126 .49539 Mdot
.33067 .49988 Mdot
.38242 .49869 Mdot
.40643 .49747 Mdot
.42435 .50025 Mdot
.44271 .50025 Mdot
.45643 .50008 Mdot
.48209 .50044 Mdot
.49939 .50001 Mdot
.50999 .49903 Mdot
.52024 .49784 Mdot
.5341 .50007 Mdot
.54793 .50114 Mdot
.55429 .5007 Mdot
.56732 .50014 Mdot
.5866 .49912 Mdot
.6557 .49702 Mdot
.72407 .50008 Mdot
.0636 .50052 Mdot
.20776 .51702 Mdot
.22695 .51108 Mdot
.2655 .50132 Mdot
.29883 .50188 Mdot
.38952 .51287 Mdot
.40989 .50608 Mdot
.42131 .50849 Mdot
.43264 .50643 Mdot
.44882 .51073 Mdot
.45926 .50929 Mdot
.4678 .50824 Mdot
.47549 .50816 Mdot
.48803 .50821 Mdot
.49446 .50821 Mdot
.50573 .5092 Mdot
.51421 .51039 Mdot
.52527 .50961 Mdot
.5427 .51062 Mdot
.57161 .50727 Mdot
.60697 .50655 Mdot
.64503 .50928 Mdot
.76981 .50825 Mdot
.83331 .52187 Mdot
.15121 .51725 Mdot
.33184 .51534 Mdot
.41262 .51641 Mdot
.42585 .51838 Mdot
.4367 .51731 Mdot
.48326 .51686 Mdot
.5002 .51895 Mdot
.53822 .51588 Mdot
.56091 .5163 Mdot
.57896 .51479 Mdot
.62749 .51748 Mdot
.65228 .51784 Mdot
.68484 .51362 Mdot
.71796 .51631 Mdot
.05985 .53392 Mdot
.11543 .52277 Mdot
.12908 .52745 Mdot
.25135 .53208 Mdot
.28896 .52629 Mdot
.31419 .52808 Mdot
.3391 .52566 Mdot
.40837 .52575 Mdot
.42397 .52909 Mdot
.44257 .52903 Mdot
.45571 .52276 Mdot
.46731 .52219 Mdot
.47818 .52252 Mdot
.51402 .52399 Mdot
.53211 .52261 Mdot
.57184 .52368 Mdot
.59393 .51999 Mdot
.61611 .52822 Mdot
.75505 .52673 Mdot
.80093 .53538 Mdot
.20253 .5434 Mdot
.26798 .54137 Mdot
.35343 .52666 Mdot
.46047 .53246 Mdot
.47286 .53284 Mdot
.48308 .53285 Mdot
.52519 .53246 Mdot
.54136 .53274 Mdot
.55158 .53093 Mdot
.5657 .53273 Mdot
.57447 .53591 Mdot
.58449 .53265 Mdot
.64272 .53538 Mdot
.66199 .5327 Mdot
.75322 .53264 Mdot
.36058 .53762 Mdot
.38965 .53756 Mdot
.40356 .54074 Mdot
.41416 .54381 Mdot
.4526 .54037 Mdot
.47038 .54053 Mdot
.48647 .54154 Mdot
.49626 .53871 Mdot
.51352 .5378 Mdot
.5338 .54177 Mdot
.56073 .54563 Mdot
.59206 .54237 Mdot
.66733 .54419 Mdot
.72315 .54529 Mdot
.74425 .54705 Mdot
.91 .52439 Mdot
.30623 .5476 Mdot
.33435 .55318 Mdot
.38414 .55209 Mdot
.46008 .54864 Mdot
.47543 .54813 Mdot
.49995 .55005 Mdot
.50825 .54953 Mdot
.52048 .54931 Mdot
.54953 .54847 Mdot
.5977 .54616 Mdot
.67193 .55194 Mdot
.70253 .54603 Mdot
.06734 .54666 Mdot
.22419 .56358 Mdot
.3576 .55955 Mdot
.45272 .5591 Mdot
.46615 .5595 Mdot
.47958 .55417 Mdot
.52286 .55915 Mdot
.53015 .55654 Mdot
.54531 .55689 Mdot
.57615 .55427 Mdot
.58639 .55632 Mdot
.6138 .55345 Mdot
.13595 .57024 Mdot
.37148 .56843 Mdot
.41499 .56509 Mdot
.43015 .56473 Mdot
.46941 .56851 Mdot
.4848 .56501 Mdot
.49531 .56576 Mdot
.50994 .56623 Mdot
.53921 .57138 Mdot
.56065 .56433 Mdot
.57583 .56271 Mdot
.60597 .56613 Mdot
.64001 .5558 Mdot
.70617 .56693 Mdot
.8577 .57064 Mdot
.8799 .57284 Mdot
.9047 .57465 Mdot
.08912 .56338 Mdot
.28056 .57491 Mdot
.30416 .57611 Mdot
.33413 .57894 Mdot
.40316 .57164 Mdot
.4482 .57418 Mdot
.47535 .57765 Mdot
.59046 .57559 Mdot
.62129 .57169 Mdot
.64661 .57163 Mdot
.07202 .59028 Mdot
.11378 .58916 Mdot
.38439 .57992 Mdot
.51009 .58063 Mdot
.56308 .58438 Mdot
.57436 .58552 Mdot
.59598 .58502 Mdot
.64039 .58768 Mdot
.6672 .5839 Mdot
.68334 .57859 Mdot
.16051 .58519 Mdot
.3946 .5922 Mdot
.47625 .58891 Mdot
.55267 .58698 Mdot
.63298 .59842 Mdot
.71407 .58512 Mdot
.08416 .61314 Mdot
.45114 .59516 Mdot
.49814 .59328 Mdot
.52604 .59463 Mdot
.53744 .59238 Mdot
.60445 .59972 Mdot
.72538 .59777 Mdot
.22821 .60434 Mdot
.25434 .60223 Mdot
.36301 .59795 Mdot
.39598 .60472 Mdot
.48394 .60547 Mdot
.50406 .60469 Mdot
.51964 .60508 Mdot
.54425 .6071 Mdot
.17166 .60896 Mdot
.26744 .61416 Mdot
.31261 .61289 Mdot
.46353 .60885 Mdot
.51037 .6209 Mdot
.53779 .62326 Mdot
.56375 .61433 Mdot
.58002 .61365 Mdot
.67837 .60824 Mdot
.69597 .61591 Mdot
.2922 .62137 Mdot
.34442 .6172 Mdot
.37068 .62198 Mdot
.39488 .62504 Mdot
.45424 .62288 Mdot
.48706 .62642 Mdot
.71434 .6291 Mdot
.36211 .6372 Mdot
.42592 .62366 Mdot
.46527 .63662 Mdot
.61022 .62523 Mdot
.64351 .62532 Mdot
.67629 .63034 Mdot
.0697 .64649 Mdot
.17152 .64213 Mdot
.28029 .64591 Mdot
.6622 .64184 Mdot
.2087 .65108 Mdot
.33631 .64188 Mdot
.40661 .63555 Mdot
.43876 .64303 Mdot
.56286 .64243 Mdot
.70123 .65194 Mdot
.43015 .65662 Mdot
.457 .65609 Mdot
.57049 .65425 Mdot
.61289 .65499 Mdot
.63197 .65401 Mdot
.77326 .65089 Mdot
.31781 .65547 Mdot
.36161 .65832 Mdot
.39763 .66565 Mdot
.41621 .66675 Mdot
.42804 .67237 Mdot
.47883 .65911 Mdot
.4916 .6568 Mdot
.5127 .65508 Mdot
.57608 .66497 Mdot
.94243 .66242 Mdot
.23891 .66628 Mdot
.3485 .66845 Mdot
.49976 .67157 Mdot
.53065 .6656 Mdot
.6494 .66857 Mdot
.81401 .6676 Mdot
.87269 .66417 Mdot
.30693 .67443 Mdot
.34 .68251 Mdot
.46864 .67718 Mdot
.60196 .67676 Mdot
.28072 .68462 Mdot
.36805 .69571 Mdot
.52548 .68489 Mdot
.65065 .68885 Mdot
.70621 .68238 Mdot
.72844 .67875 Mdot
.16102 .67215 Mdot
.45431 .68923 Mdot
.48528 .69122 Mdot
.5088 .69584 Mdot
.53778 .69144 Mdot
.58606 .69182 Mdot
.61505 .69655 Mdot
.07871 .70382 Mdot
.25176 .69747 Mdot
.33762 .70906 Mdot
.4126 .69314 Mdot
.44008 .69934 Mdot
.47562 .70145 Mdot
.55239 .70381 Mdot
.56081 .70389 Mdot
.57832 .70555 Mdot
.68983 .70932 Mdot
.76872 .7012 Mdot
.12385 .71331 Mdot
.30148 .71114 Mdot
.45767 .7191 Mdot
.49766 .71493 Mdot
.52806 .72356 Mdot
.63333 .7182 Mdot
.74513 .71583 Mdot
.15383 .7299 Mdot
.37658 .71131 Mdot
.41049 .71693 Mdot
.48875 .72878 Mdot
.83878 .71071 Mdot
.20048 .7209 Mdot
.24116 .71473 Mdot
.39537 .73189 Mdot
.4228 .73286 Mdot
.5853 .72784 Mdot
.80153 .72639 Mdot
.90156 .72974 Mdot
.16538 .74774 Mdot
.33757 .73126 Mdot
.38022 .74119 Mdot
.85971 .74434 Mdot
.24558 .73739 Mdot
.29141 .74523 Mdot
.7048 .74439 Mdot
.26887 .75341 Mdot
.3074 .75447 Mdot
.35154 .75066 Mdot
.43901 .74399 Mdot
.48427 .74247 Mdot
.60779 .75234 Mdot
.66835 .75346 Mdot
.191 .7631 Mdot
.21496 .75639 Mdot
.44299 .75773 Mdot
.49208 .75893 Mdot
.53049 .75627 Mdot
.578 .76792 Mdot
.73293 .75099 Mdot
.24058 .77408 Mdot
.26103 .77842 Mdot
.35048 .77508 Mdot
.38725 .76792 Mdot
.7437 .76714 Mdot
.47166 .7688 Mdot
.82604 .78665 Mdot
.39239 .77893 Mdot
.4291 .78475 Mdot
.45714 .78571 Mdot
.51499 .789 Mdot
.20958 .79674 Mdot
.41633 .79749 Mdot
.33316 .80105 Mdot
.4595 .80746 Mdot
.48043 .80389 Mdot
.73442 .8044 Mdot
.29027 .80522 Mdot
.20152 .80803 Mdot
.75614 .81323 Mdot
.24673 .82613 Mdot
.36903 .82323 Mdot
.40072 .82536 Mdot
.49755 .83006 Mdot
.60496 .8166 Mdot
.66684 .81784 Mdot
.77952 .8225 Mdot
.54262 .81998 Mdot
.18527 .84915 Mdot
.24767 .85419 Mdot
.41072 .85723 Mdot
.43851 .83772 Mdot
.29183 .84484 Mdot
.52317 .85637 Mdot
.56898 .85145 Mdot
.71233 .85483 Mdot
.33716 .85346 Mdot
.47845 .85862 Mdot
.61389 .86254 Mdot
.78866 .87179 Mdot
.31614 .89059 Mdot
.65909 .87366 Mdot
.4563 .8944 Mdot
.25287 .90042 Mdot
.56241 .88164 Mdot
.56134 .91133 Mdot
.66519 .92154 Mdot
.59127 .93341 Mdot
.3785 .93856 Mdot
.51066 .91966 Mdot
.53257 .94812 Mdot
.52189 .97883 Mdot
.59231 .96737 Mdot
.47269 .96773 Mdot
0 g
.4769 .03764 Mdot
.46753 .05387 Mdot
.53314 .05387 Mdot
.56594 .06199 Mdot
.45816 .0701 Mdot
.52845 .07822 Mdot
.4769 .08634 Mdot
.29415 .09445 Mdot
.32227 .09445 Mdot
.3785 .09445 Mdot
.64091 .09445 Mdot
.72526 .09445 Mdot
.50502 .10257 Mdot
.43473 .11069 Mdot
.58468 .11069 Mdot
.36444 .1188 Mdot
.50502 .1188 Mdot
.59874 .1188 Mdot
.66434 .1188 Mdot
.28478 .12692 Mdot
.32227 .12692 Mdot
.55657 .12692 Mdot
.62217 .12692 Mdot
.77212 .12692 Mdot
.79555 .13504 Mdot
.49096 .15938 Mdot
.50033 .15938 Mdot
.50971 .15938 Mdot
.58468 .15938 Mdot
.26135 .1675 Mdot
.51439 .1675 Mdot
.60811 .1675 Mdot
.45347 .17562 Mdot
.46285 .17562 Mdot
.80492 .18373 Mdot
.36913 .19185 Mdot
.40661 .19185 Mdot
.43473 .19185 Mdot
.45347 .19185 Mdot
.46285 .19185 Mdot
.49096 .19185 Mdot
.50033 .19185 Mdot
.65029 .19185 Mdot
.2426 .19997 Mdot
.28946 .19997 Mdot
.31758 .19997 Mdot
.61748 .19997 Mdot
.43473 .20808 Mdot
.45347 .20808 Mdot
.47222 .20808 Mdot
.51908 .20808 Mdot
.26135 .2162 Mdot
.31758 .2162 Mdot
.70183 .2162 Mdot
.30352 .22432 Mdot
.57531 .22432 Mdot
.6128 .22432 Mdot
.70652 .22432 Mdot
.80961 .22432 Mdot
.40193 .23243 Mdot
.4113 .23243 Mdot
.49565 .23243 Mdot
.67372 .23243 Mdot
.73932 .23243 Mdot
.79555 .23243 Mdot
.50971 .24055 Mdot
.64091 .24055 Mdot
.65966 .24055 Mdot
.73463 .24055 Mdot
.19574 .24867 Mdot
.37381 .24867 Mdot
.40193 .24867 Mdot
.44879 .24867 Mdot
.55188 .24867 Mdot
.13483 .25678 Mdot
.19106 .25678 Mdot
.69715 .25678 Mdot
.72526 .25678 Mdot
.81898 .25678 Mdot
.31758 .2649 Mdot
.36444 .2649 Mdot
.57062 .2649 Mdot
.69246 .2649 Mdot
.90802 .2649 Mdot
.10671 .27301 Mdot
.4441 .27301 Mdot
.56594 .27301 Mdot
.58468 .27301 Mdot
.79087 .27301 Mdot
.30821 .28113 Mdot
.39256 .28113 Mdot
.48628 .28113 Mdot
.43473 .28925 Mdot
.65029 .28925 Mdot
.37381 .29736 Mdot
.40193 .29736 Mdot
.53314 .29736 Mdot
.54251 .29736 Mdot
.55188 .29736 Mdot
.72995 .29736 Mdot
.22855 .30548 Mdot
.24729 .30548 Mdot
.29415 .30548 Mdot
.35975 .30548 Mdot
.60343 .30548 Mdot
.07391 .3136 Mdot
.177 .3136 Mdot
.38318 .3136 Mdot
.57062 .3136 Mdot
.73932 .3136 Mdot
.41599 .32171 Mdot
.55657 .32171 Mdot
.22386 .32983 Mdot
.32695 .32983 Mdot
.35507 .32983 Mdot
.39256 .32983 Mdot
.40193 .32983 Mdot
.43942 .32983 Mdot
.52376 .32983 Mdot
.55188 .32983 Mdot
.82367 .32983 Mdot
.84241 .32983 Mdot
.08797 .33795 Mdot
.1442 .33795 Mdot
.21917 .33795 Mdot
.36913 .33795 Mdot
.42536 .33795 Mdot
.43473 .33795 Mdot
.46285 .33795 Mdot
.48159 .33795 Mdot
.50971 .33795 Mdot
.77212 .33795 Mdot
.88459 .33795 Mdot
.16763 .34606 Mdot
.23323 .34606 Mdot
.26135 .34606 Mdot
.28009 .34606 Mdot
.30821 .34606 Mdot
.38318 .34606 Mdot
.54251 .34606 Mdot
.56125 .34606 Mdot
.69246 .34606 Mdot
.49096 .35418 Mdot
.56594 .35418 Mdot
.62217 .35418 Mdot
.74401 .35418 Mdot
.80961 .35418 Mdot
.89396 .35418 Mdot
.21449 .36229 Mdot
.43004 .36229 Mdot
.51439 .36229 Mdot
.55188 .36229 Mdot
.61748 .36229 Mdot
.62686 .36229 Mdot
.82367 .36229 Mdot
.20043 .37041 Mdot
.40661 .37041 Mdot
.43473 .37041 Mdot
.46285 .37041 Mdot
.51908 .37041 Mdot
.54719 .37041 Mdot
.56594 .37041 Mdot
.8471 .37041 Mdot
.23323 .37853 Mdot
.33632 .37853 Mdot
.46753 .37853 Mdot
.48628 .37853 Mdot
.51439 .37853 Mdot
.52376 .37853 Mdot
.56125 .37853 Mdot
.61748 .37853 Mdot
.68309 .37853 Mdot
.70183 .37853 Mdot
.73932 .37853 Mdot
.84241 .37853 Mdot
.87053 .37853 Mdot
.90802 .37853 Mdot
.39724 .38664 Mdot
.4441 .38664 Mdot
.46285 .38664 Mdot
.52845 .38664 Mdot
.53782 .38664 Mdot
.6128 .38664 Mdot
.80024 .38664 Mdot
.95019 .38664 Mdot
.18637 .39476 Mdot
.27072 .39476 Mdot
.36444 .39476 Mdot
.37381 .39476 Mdot
.39256 .39476 Mdot
.40193 .39476 Mdot
.4113 .39476 Mdot
.43942 .39476 Mdot
.53314 .39476 Mdot
.54251 .39476 Mdot
.68309 .39476 Mdot
.70183 .39476 Mdot
.72995 .39476 Mdot
.86116 .39476 Mdot
.16294 .40288 Mdot
.26603 .40288 Mdot
.39724 .40288 Mdot
.41599 .40288 Mdot
.43473 .40288 Mdot
.47222 .40288 Mdot
.51908 .40288 Mdot
.54719 .40288 Mdot
.55657 .40288 Mdot
.57531 .40288 Mdot
.65029 .40288 Mdot
.74401 .40288 Mdot
.87521 .40288 Mdot
.88459 .40288 Mdot
.30821 .41099 Mdot
.32695 .41099 Mdot
.39256 .41099 Mdot
.45816 .41099 Mdot
.46753 .41099 Mdot
.50502 .41099 Mdot
.58 .41099 Mdot
.61748 .41099 Mdot
.79555 .41099 Mdot
.07859 .41911 Mdot
.17231 .41911 Mdot
.46285 .41911 Mdot
.47222 .41911 Mdot
.49096 .41911 Mdot
.50033 .41911 Mdot
.53782 .41911 Mdot
.54719 .41911 Mdot
.55657 .41911 Mdot
.60343 .41911 Mdot
.32695 .42723 Mdot
.33632 .42723 Mdot
.39256 .42723 Mdot
.42067 .42723 Mdot
.44879 .42723 Mdot
.51439 .42723 Mdot
.52376 .42723 Mdot
.53314 .42723 Mdot
.54251 .42723 Mdot
.56125 .42723 Mdot
.72058 .42723 Mdot
.72995 .42723 Mdot
.78618 .42723 Mdot
.84241 .42723 Mdot
.89865 .42723 Mdot
.38787 .43534 Mdot
.42536 .43534 Mdot
.4441 .43534 Mdot
.46285 .43534 Mdot
.49096 .43534 Mdot
.54719 .43534 Mdot
.58468 .43534 Mdot
.80961 .43534 Mdot
.25198 .44346 Mdot
.28946 .44346 Mdot
.32695 .44346 Mdot
.3457 .44346 Mdot
.35507 .44346 Mdot
.44879 .44346 Mdot
.50502 .44346 Mdot
.52376 .44346 Mdot
.53314 .44346 Mdot
.57062 .44346 Mdot
.59874 .44346 Mdot
.60811 .44346 Mdot
.72995 .44346 Mdot
.87053 .44346 Mdot
.18169 .45158 Mdot
.32227 .45158 Mdot
.42536 .45158 Mdot
.48159 .45158 Mdot
.49096 .45158 Mdot
.55657 .45158 Mdot
.56594 .45158 Mdot
.58468 .45158 Mdot
.65966 .45158 Mdot
.77212 .45158 Mdot
.177 .45969 Mdot
.3457 .45969 Mdot
.37381 .45969 Mdot
.43942 .45969 Mdot
.44879 .45969 Mdot
.46753 .45969 Mdot
.4769 .45969 Mdot
.48628 .45969 Mdot
.49565 .45969 Mdot
.51439 .45969 Mdot
.52376 .45969 Mdot
.53314 .45969 Mdot
.54251 .45969 Mdot
.57062 .45969 Mdot
.62686 .45969 Mdot
.66434 .45969 Mdot
.74869 .45969 Mdot
.24729 .46781 Mdot
.35975 .46781 Mdot
.39724 .46781 Mdot
.43473 .46781 Mdot
.46285 .46781 Mdot
.47222 .46781 Mdot
.48159 .46781 Mdot
.49096 .46781 Mdot
.50971 .46781 Mdot
.52845 .46781 Mdot
.53782 .46781 Mdot
.54719 .46781 Mdot
.56594 .46781 Mdot
.59405 .46781 Mdot
.65966 .46781 Mdot
.69715 .46781 Mdot
.83773 .46781 Mdot
.96894 .46781 Mdot
.33632 .47592 Mdot
.3457 .47592 Mdot
.35507 .47592 Mdot
.36444 .47592 Mdot
.42067 .47592 Mdot
.43004 .47592 Mdot
.44879 .47592 Mdot
.45816 .47592 Mdot
.4769 .47592 Mdot
.48628 .47592 Mdot
.49565 .47592 Mdot
.50502 .47592 Mdot
.51439 .47592 Mdot
.54251 .47592 Mdot
.55188 .47592 Mdot
.21917 .48404 Mdot
.33164 .48404 Mdot
.35975 .48404 Mdot
.39724 .48404 Mdot
.45347 .48404 Mdot
.46285 .48404 Mdot
.49096 .48404 Mdot
.50033 .48404 Mdot
.51908 .48404 Mdot
.55657 .48404 Mdot
.59405 .48404 Mdot
.60343 .48404 Mdot
.64091 .48404 Mdot
.6784 .48404 Mdot
.75338 .48404 Mdot
.81898 .48404 Mdot
.93145 .48404 Mdot
.10202 .49216 Mdot
.177 .49216 Mdot
.18637 .49216 Mdot
.22386 .49216 Mdot
.3457 .49216 Mdot
.42067 .49216 Mdot
.43004 .49216 Mdot
.44879 .49216 Mdot
.46753 .49216 Mdot
.4769 .49216 Mdot
.48628 .49216 Mdot
.49565 .49216 Mdot
.50502 .49216 Mdot
.54251 .49216 Mdot
.56125 .49216 Mdot
.63623 .49216 Mdot
.72058 .49216 Mdot
.8143 .49216 Mdot
.88927 .49216 Mdot
.04111 .50027 Mdot
.19106 .50027 Mdot
.24729 .50027 Mdot
.33164 .50027 Mdot
.38787 .50027 Mdot
.40661 .50027 Mdot
.42536 .50027 Mdot
.4441 .50027 Mdot
.45347 .50027 Mdot
.48159 .50027 Mdot
.50033 .50027 Mdot
.50971 .50027 Mdot
.51908 .50027 Mdot
.53782 .50027 Mdot
.54719 .50027 Mdot
.55657 .50027 Mdot
.56594 .50027 Mdot
.58468 .50027 Mdot
.65029 .50027 Mdot
.72526 .50027 Mdot
.06454 .50839 Mdot
.21449 .50839 Mdot
.22386 .50839 Mdot
.26135 .50839 Mdot
.29884 .50839 Mdot
.39256 .50839 Mdot
.4113 .50839 Mdot
.42067 .50839 Mdot
.43004 .50839 Mdot
.44879 .50839 Mdot
.45816 .50839 Mdot
.46753 .50839 Mdot
.4769 .50839 Mdot
.48628 .50839 Mdot
.49565 .50839 Mdot
.50502 .50839 Mdot
.51439 .50839 Mdot
.52376 .50839 Mdot
.54251 .50839 Mdot
.57062 .50839 Mdot
.60811 .50839 Mdot
.6456 .50839 Mdot
.76744 .50839 Mdot
.82367 .50839 Mdot
.1442 .51651 Mdot
.33164 .51651 Mdot
.41599 .51651 Mdot
.42536 .51651 Mdot
.43473 .51651 Mdot
.48159 .51651 Mdot
.50033 .51651 Mdot
.53782 .51651 Mdot
.56594 .51651 Mdot
.57531 .51651 Mdot
.63154 .51651 Mdot
.65029 .51651 Mdot
.6784 .51651 Mdot
.72526 .51651 Mdot
.06454 .52462 Mdot
.1114 .52462 Mdot
.12077 .52462 Mdot
.25198 .52462 Mdot
.28946 .52462 Mdot
.31758 .52462 Mdot
.33632 .52462 Mdot
.4113 .52462 Mdot
.42067 .52462 Mdot
.43942 .52462 Mdot
.45816 .52462 Mdot
.46753 .52462 Mdot
.4769 .52462 Mdot
.51439 .52462 Mdot
.53314 .52462 Mdot
.57062 .52462 Mdot
.58937 .52462 Mdot
.61748 .52462 Mdot
.74869 .52462 Mdot
.80492 .52462 Mdot
.2098 .53274 Mdot
.26603 .53274 Mdot
.35038 .53274 Mdot
.46285 .53274 Mdot
.47222 .53274 Mdot
.48159 .53274 Mdot
.52845 .53274 Mdot
.53782 .53274 Mdot
.55657 .53274 Mdot
.56594 .53274 Mdot
.57531 .53274 Mdot
.58468 .53274 Mdot
.65029 .53274 Mdot
.65966 .53274 Mdot
.74401 .53274 Mdot
.35507 .54086 Mdot
.39256 .54086 Mdot
.40193 .54086 Mdot
.4113 .54086 Mdot
.45816 .54086 Mdot
.46753 .54086 Mdot
.48628 .54086 Mdot
.49565 .54086 Mdot
.51439 .54086 Mdot
.53314 .54086 Mdot
.56125 .54086 Mdot
.58937 .54086 Mdot
.66434 .54086 Mdot
.72995 .54086 Mdot
.73932 .54086 Mdot
.89865 .54086 Mdot
.30352 .54897 Mdot
.34101 .54897 Mdot
.38787 .54897 Mdot
.46285 .54897 Mdot
.47222 .54897 Mdot
.50033 .54897 Mdot
.50971 .54897 Mdot
.51908 .54897 Mdot
.54719 .54897 Mdot
.59405 .54897 Mdot
.66903 .54897 Mdot
.70652 .54897 Mdot
.08328 .55709 Mdot
.22386 .55709 Mdot
.35507 .55709 Mdot
.45816 .55709 Mdot
.46753 .55709 Mdot
.4769 .55709 Mdot
.52376 .55709 Mdot
.53314 .55709 Mdot
.54251 .55709 Mdot
.58 .55709 Mdot
.58937 .55709 Mdot
.60811 .55709 Mdot
.11608 .56521 Mdot
.36913 .56521 Mdot
.41599 .56521 Mdot
.42536 .56521 Mdot
.47222 .56521 Mdot
.48159 .56521 Mdot
.49096 .56521 Mdot
.50971 .56521 Mdot
.53782 .56521 Mdot
.56594 .56521 Mdot
.57531 .56521 Mdot
.60343 .56521 Mdot
.64091 .56521 Mdot
.70652 .56521 Mdot
.87521 .56521 Mdot
.88459 .56521 Mdot
.89396 .56521 Mdot
.09265 .57332 Mdot
.28946 .57332 Mdot
.29884 .57332 Mdot
.33632 .57332 Mdot
.40193 .57332 Mdot
.44879 .57332 Mdot
.4769 .57332 Mdot
.58937 .57332 Mdot
.62686 .57332 Mdot
.6456 .57332 Mdot
.08797 .58144 Mdot
.09734 .58144 Mdot
.38787 .58144 Mdot
.50971 .58144 Mdot
.56594 .58144 Mdot
.57531 .58144 Mdot
.59405 .58144 Mdot
.64091 .58144 Mdot
.65966 .58144 Mdot
.68777 .58144 Mdot
.15826 .58955 Mdot
.39256 .58955 Mdot
.4769 .58955 Mdot
.55188 .58955 Mdot
.63623 .58955 Mdot
.7112 .58955 Mdot
.08797 .59767 Mdot
.45347 .59767 Mdot
.50033 .59767 Mdot
.52845 .59767 Mdot
.53782 .59767 Mdot
.60343 .59767 Mdot
.71589 .59767 Mdot
.2426 .60579 Mdot
.25198 .60579 Mdot
.36444 .60579 Mdot
.39256 .60579 Mdot
.48628 .60579 Mdot
.50502 .60579 Mdot
.51439 .60579 Mdot
.54251 .60579 Mdot
.17231 .6139 Mdot
.26603 .6139 Mdot
.30352 .6139 Mdot
.46285 .6139 Mdot
.50971 .6139 Mdot
.53782 .6139 Mdot
.56594 .6139 Mdot
.57531 .6139 Mdot
.68777 .6139 Mdot
.69715 .6139 Mdot
.28946 .62202 Mdot
.35507 .62202 Mdot
.36444 .62202 Mdot
.39256 .62202 Mdot
.45816 .62202 Mdot
.48628 .62202 Mdot
.70183 .62202 Mdot
.35975 .63014 Mdot
.42536 .63014 Mdot
.46285 .63014 Mdot
.6128 .63014 Mdot
.65029 .63014 Mdot
.6784 .63014 Mdot
.07391 .63825 Mdot
.177 .63825 Mdot
.28009 .63825 Mdot
.66434 .63825 Mdot
.20043 .64637 Mdot
.34101 .64637 Mdot
.41599 .64637 Mdot
.43473 .64637 Mdot
.56594 .64637 Mdot
.69715 .64637 Mdot
.43004 .65449 Mdot
.44879 .65449 Mdot
.57062 .65449 Mdot
.61748 .65449 Mdot
.62686 .65449 Mdot
.77681 .65449 Mdot
.33164 .6626 Mdot
.35038 .6626 Mdot
.40661 .6626 Mdot
.41599 .6626 Mdot
.42536 .6626 Mdot
.48159 .6626 Mdot
.49096 .6626 Mdot
.50971 .6626 Mdot
.57531 .6626 Mdot
.94082 .6626 Mdot
.2426 .67072 Mdot
.3457 .67072 Mdot
.50502 .67072 Mdot
.52376 .67072 Mdot
.6456 .67072 Mdot
.8143 .67072 Mdot
.87053 .67072 Mdot
.31289 .67883 Mdot
.34101 .67883 Mdot
.47222 .67883 Mdot
.60343 .67883 Mdot
.28009 .68695 Mdot
.35507 .68695 Mdot
.52376 .68695 Mdot
.6456 .68695 Mdot
.7112 .68695 Mdot
.72058 .68695 Mdot
.15357 .69507 Mdot
.46285 .69507 Mdot
.48159 .69507 Mdot
.50971 .69507 Mdot
.53782 .69507 Mdot
.58468 .69507 Mdot
.6128 .69507 Mdot
.09265 .70318 Mdot
.25198 .70318 Mdot
.33632 .70318 Mdot
.4113 .70318 Mdot
.43942 .70318 Mdot
.4769 .70318 Mdot
.55188 .70318 Mdot
.56125 .70318 Mdot
.58 .70318 Mdot
.70183 .70318 Mdot
.75806 .70318 Mdot
.13483 .7113 Mdot
.30352 .7113 Mdot
.46285 .7113 Mdot
.49096 .7113 Mdot
.52845 .7113 Mdot
.63154 .7113 Mdot
.74401 .7113 Mdot
.14888 .71942 Mdot
.38318 .71942 Mdot
.4113 .71942 Mdot
.48628 .71942 Mdot
.84241 .71942 Mdot
.20043 .72753 Mdot
.23792 .72753 Mdot
.39724 .72753 Mdot
.41599 .72753 Mdot
.58468 .72753 Mdot
.81898 .72753 Mdot
.88459 .72753 Mdot
.16763 .73565 Mdot
.33632 .73565 Mdot
.38318 .73565 Mdot
.85178 .73565 Mdot
.24729 .74377 Mdot
.28478 .74377 Mdot
.70652 .74377 Mdot
.26135 .75188 Mdot
.31758 .75188 Mdot
.3457 .75188 Mdot
.43942 .75188 Mdot
.48628 .75188 Mdot
.59874 .75188 Mdot
.67372 .75188 Mdot
.2098 .76 Mdot
.22855 .76 Mdot
.4441 .76 Mdot
.49096 .76 Mdot
.51908 .76 Mdot
.58468 .76 Mdot
.73463 .76 Mdot
.23323 .76812 Mdot
.2426 .76812 Mdot
.3457 .76812 Mdot
.39256 .76812 Mdot
.73932 .76812 Mdot
.47222 .77623 Mdot
.82835 .77623 Mdot
.40193 .78435 Mdot
.42067 .78435 Mdot
.45816 .78435 Mdot
.50502 .78435 Mdot
.21917 .79246 Mdot
.41599 .79246 Mdot
.32695 .80058 Mdot
.46753 .80058 Mdot
.4769 .80058 Mdot
.73932 .80058 Mdot
.29415 .8087 Mdot
.21449 .81681 Mdot
.75806 .81681 Mdot
.23792 .82493 Mdot
.38787 .82493 Mdot
.39724 .82493 Mdot
.49096 .82493 Mdot
.60343 .82493 Mdot
.66903 .82493 Mdot
.77212 .82493 Mdot
.54251 .83305 Mdot
.20043 .84116 Mdot
.23792 .84116 Mdot
.40661 .84116 Mdot
.4441 .84116 Mdot
.29884 .84928 Mdot
.53314 .84928 Mdot
.56125 .84928 Mdot
.7112 .84928 Mdot
.32227 .8574 Mdot
.47222 .8574 Mdot
.6128 .8574 Mdot
.78149 .8574 Mdot
.31289 .87363 Mdot
.65966 .87363 Mdot
.45816 .88175 Mdot
.25666 .88986 Mdot
.56125 .89798 Mdot
.56125 .91421 Mdot
.66434 .91421 Mdot
.57062 .93044 Mdot
.3785 .93856 Mdot
.52845 .93856 Mdot
.53314 .94668 Mdot
.52845 .95479 Mdot
.57531 .95479 Mdot
.48628 .96291 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[59]:=",
  ImageSize->{288, 288.75},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/A000`40O003h00OfFmk00<006mkKg/0
e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/0
0`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00c6mk0W`02fmk00<006mkKg/0e6mk003;Kg/4O00:Kg/00`00Kg]_
N`3DKg/00<]_N`Al00Y_N`03001_Nfmk0=A_N`00c6mk0W`02fmk0`00e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00c6mk0P002fmk00<006mkKg/0e6mk003;Kg/4000:Kg/00`00Kg]_
N`3DKg/00<]_N`@000Y_N`03001_Nfmk00Q_N`9l0<Y_N`00aVmk0W`016mk0P002fmk00<006mkKg/0
1fmk17`0bFmk0035Kg/4O00@Kg/00`00Kg]_N`07Kg/4O039Kg/00<E_N`Al011_N`03001_Nfmk00Q_
N`9l0<Y_N`00aVmk0W`04Fmk00<006mkKg/0e6mk0038Kg/2000?Kg/00`00Kg]_N`09Kg/20039Kg/0
0<M_N`@000i_N`03001_Nfmk00Q_N`@0015_N`9l0;E_N`00afmk10003Vmk00<006mkKg/026mk1000
46mk17`0]6mk0038Kg/2000?Kg/00`00Kg]_N`09Kg/2000AKg/4O02dKg/00=U_N`03001_Nfmk01M_
N`8000A_N`9l0;E_N`00fFmk00<006mkKg/05Vmk1000^Vmk003IKg/00`00Kg]_N`0FKg/4002jKg/0
0<1_N`9l009_N`8001=_N`03001_Nfmk01M_N`800;]_N`00_fmk17`010004Vmk00<006mkKg/0e6mk
002oKg/4O004000BKg/00`00Kg]_N`3DKg/00<1_N`9l009_N`8001=_N`<00=A_N`00fFmk00<006mk
Kg/01fmk0P00<6mk0W`0VFmk001hKg/2O01OKg/00`00Kg]_N`06Kg/4000^Kg/4O02HKg/007M_N`Al
00m_N`9l04e_N`03001_Nfmk00I_N`@002i_N`Al09Q_N`00Mfmk17`03Vmk17`066mk0W`09Fmk0P00
2fmk00<006mkKg/01fmk0P000W`0;Vmk0W`0VFmk001hKg/2O00?Kg/4O00GKg/4O00SKg/4000:Kg/0
0`00Kg]_N`07Kg/4O039Kg/008Y_N`9l01Q_N`Al02=_N`@000Y_N`03001_Nfmk00Q_N`9l055_N`9l
07M_N`00YFmk0W`096mk00Al0000001l00Y_N`03001_Nfmk05Y_N`Al07I_N`00OVmk0P002Vmk0P00
5Vmk0P009fmk17`02Vmk00<006mkKg/0=fmk0P008Fmk00Al0000001l07I_N`00OFmk100026mk1000
56mk10009fmk0W`02fmk00<006mkKg/0=Vmk100086mk1000MVmk001mKg/40008Kg/4000DKg/4000c
Kg/2O00hKg/4000PKg/4001fKg/007i_N`8000Y_N`8001I_N`8003=_N`9l008003Q_N`80029_N`80
07M_N`00efmk00=l000000000P00e6mk003HKg/4000NKg/2O02dKg/00=U_N`8001i_N`Al0;=_N`00
^Vmk0P007Fmk00<006mkKg/07Fmk0W`00P00/fmk002iKg/4000LKg/00`00Kg]_N`0NKg/40004Kg/2
O02/Kg/00;U_N`@0015_N`@000M_N`03001_Nfmk01i_N`@000=_N`Al0:]_N`00W6mk0P006fmk00=l
0000000056mk00<006mkKg/01Vmk0P0086mk0P0016mk0P000W`066mk0P00TFmk002KKg/4000IKg/4
O00DKg/00`00Kg]_N`05Kg/4000TKg/4000HKg/4002@Kg/009]_N`@001U_N`Al011_N`H000I_N`@0
02A_N`@001Q_N`@002Q_N`9l06I_N`00W6mk0P006fmk0W`026mk1P0016mk00@006mkKg/000Q_N`@0
02A_N`8001Y_N`80009_N`9l02A_N`Al06E_N`00NVmk0P003Vmk0P004fmk0W`0;6mk00@006mkKg/0
00Q_N`03001_Nfmk01=_N`8001Y_N`8001=_N`Al02=_N`Al0003Kg/00000069_N`00MVmk0W`000=_
N`0000000P0036mk10004Fmk17`0;6mk00<006mk000026mk00<006mkKg/04Fmk00=l000000000P00
66mk10004Vmk17`096mk0W`000=_N`0000000P00HFmk001eKg/4O004000<Kg/4000AKg/4O00/Kg/0
0`00Kg/00008Kg/00`00Kg]_N`0@Kg/2O004000HKg/4000CKg/2O00XKg/4000;Kg/2O01DKg/007E_
N`Al0003Kg/0000000i_N`8001=_N`9l02i_N`8000Q_N`03001_Nfmk011_N`=l008001U_N`04O000
0000O00nKg/20008Kg/200000fmkO01l0002O01CKg/007I_N`9l065_N`03001_Nfmk015_N`9l01]_
N`Al04M_N`@000Al05=_N`00fFmk00<006mkKg/0;fmk0W`0B6mk100000=_Ng`0O000E6mk002<Kg/2
O01;Kg/00`00Kg]_N`1jKg/2001HKg/008]_N`Al04Y_N`03001_Nfmk0=A_N`00Rfmk17`0BVmk00<0
06mkKg/0e6mk002<Kg/2O01;Kg/00`00Kg]_N`3DKg/00<m_N`9l00Q_N`03001_Nfmk0=A_N`00_fmk
0W`03Fmk17`000=_Ng`0O00016mk00<006mkKg/0e6mk002nKg/4O00<Kg/8O003Kg/01000Kg]_Nfmk
0W`0dFmk001^Kg/2O01>Kg/4O00=Kg/2O0000fmkO01l0002O003Kg/00`00Kg]_N`04O03@Kg/006e_
N`Al04i_N`9l015_N`800003O01_Nfmk00<00003Kg/0000000=l01]_N`800;=_N`00KFmk17`0H6mk
100000=_N`0000001P0000=l06mkKg/05fmk0W`01000/Vmk001^Kg/2O01QKg/400000fmk00000006
000IKg/3O004002bKg/0071_N`8005E_N`9l00U_N`8000=_N`<00003Kg/00000008001Q_N`Al0080
00Q_N`800:U_N`00Kfmk1000Dfmk17`03fmk00<006mkKg/0100066mk0W`02Vmk1000Z6mk001_Kg/4
001CKg/4O00?Kg/7000TKg/4002XKg/0071_N`8005E_N`9l011_N`04001_NfmkKg/20004Kg/2O00P
Kg/20002O02WKg/00<9_N`80009_N`80015_N`03001_Nfmk00I_N`Al01m_N`Al0:M_N`00`Fmk2000
46mk00<006mkKg/01Vmk17`086mk0W`0Z6mk0031Kg/8000@Kg/00`00Kg]_N`07Kg/2O01fKg/2O01C
Kg/00:Y_N`9l00U_N`9l00]_N`80009_N`80015_N`03001_Nfmk03e_N`9l03m_N`80009l059_N`00
ZFmk17`01fmk17`08Fmk00<006mkKg/0?6mk17`0?Fmk100000=l06mkKg/0D6mk002YKg/4O007Kg/4
O00QKg/00`00Kg]_N`0lKg/4O00mKg/4001CKg/007Q_N`9l011_N`9l015_N`9l00]_N`9l00U_N`9l
029_N`03001_Nfmk03e_N`9l03m_N`8005A_N`00Mfmk17`03Vmk17`03fmk0W`00P003Vmk0P002Vmk
0P001Vmk0P000Vmk0P002Vmk0P0000=_Ng`0O0000`00?Fmk0P00Ufmk001gKg/4O00>Kg/4O00?Kg/0
0g`000000002000<Kg/40008Kg/40004Kg/800000fmkO01l0005Kg/400000g`000000002000lKg/4
002FKg/007Q_N`9l011_N`9l015_N`@000a_N`@000Q_N`@000A_N`P000Al00A_N`@00003O0000000
008003a_N`@009I_N`00Hfmk0W`00Vmk0P004fmk0P002Vmk0P0056mk0P003Vmk0P002Vmk0P001Vmk
0P000Vmk0P0000=_Ng`0O0000W`01Fmk0P0000=_Ng`0O0000`00;fmk0P0036mk0P00Ufmk001RKg/4
O004000AKg/40008Kg/4000oKg/2O00<Kg/2O00^Kg/4000PKg/2O022Kg/0069_N`Al00@0015_N`@0
00Q_N`@004a_N`Al02e_N`@001m_N`Al085_N`00Hfmk0W`00Vmk0P004fmk0P002Vmk0P00CFmk17`0
;Vmk0P0086mk17`0PFmk002jKg/20006Kg/20006Kg/2000<Kg/2O005Kg/20002Kg/2O017Kg/2O022
Kg/00;U_N`@000A_N`@000A_N`@000a_N`03001_Nfmk009_N`@000Al0<Y_N`00^Fmk100016mk1000
16mk100036mk00<006mkKg/00Vmk100017`0bVmk001`Kg/2000FKg/2000_Kg/017`0000007`01Fmk
0P001Vmk0P000W`02fmk00<006mkKg/00fmk0P000Vmk0W`0B6mk0P00PFmk001_Kg/4000DKg/4000^
Kg/4O00>Kg/4O00:Kg/3001@Kg/400000g`0Kg]_N`0/Kg/2O01?Kg/006m_N`@001A_N`@002m_N`9l
00m_N`Al00Y_N`03001_Nfmk01Y_N`9l03A_N`@0009l02a_N`Al04i_N`00L6mk0P005Vmk0P000fmk
0W`0?Fmk0W`02fmk00<006mkKg/06Fmk17`0=6mk0P000g`0;6mk17`0CVmk0022Kg/20008Kg/4O00c
Kg/2O00DKg/00`00Kg]_N`0IKg/2O002000>Kg/2000VKg/2000BKg/2O00GKg/200000fmkO01l001?
Kg/0085_N`@000M_N`Al01Y_N`9l01I_N`Al01=_N`03001_Nfmk01Y_N`@000a_N`@001A_N`9l00i_
N`@0011_N`Al01E_N`@0055_N`00KVmk0W`04Fmk100026mk0W`06Vmk17`05Fmk17`04fmk00<006mk
Kg/06Vmk100036mk10004fmk17`03Fmk100046mk17`05Fmk1000DFmk001]Kg/4O00@Kg/00g`00000
000UKg/3O0020002Kg/200000fmkO01l000>Kg/2O00@Kg/20002Kg/00`00Kg]_N`0KKg/2000<Kg/2
O002000DKg/4O002000<Kg/2000=Kg/20003Kg/2O00;Kg/2O004Kg/20004Kg/2001BKg/006e_N`Al
00m_N`Al02I_N`03O000000000H000=l01i_N`@00003Kg/006mk02Y_N`Al01E_N`9l00@001U_N`@0
00i_N`Al009_N`@005M_N`00Efmk0W`05Fmk0W`046mk17`09fmk20000g`07Vmk100000=_N`00Kg/0
:fmk0W`066mk10006Fmk10003Vmk17`00Vmk1000Efmk001FKg/4O00WKg/2O00YKg/20002Kg/20000
0fmkO01l000PKg/20002Kg/00`00Kg]_N`15Kg/2000KKg/2000@Kg/2O004Kg/2001HKg/005I_N`Al
07Q_N`9l00E_N`04001_N`00000fKg/20006Kg/2000NKg/2001cKg/005M_N`9l04A_N`9l039_N`Al
00A_N`D003A_N`@000A_N`@001a_N`@0079_N`00W6mk17`0<Fmk17`016mk1@0036mk0W`09Vmk1000
0fmk00=l000000000P0076mk100000=l06mkKg/0Kfmk001CKg/20017Kg/4O002000:Kg/2000BKg/2
000@Kg/2O005Kg/01@00Kg/00000O0002fmk17`00P008Vmk0W`00P0016mk0W`00P007Vmk0P000g`0
L6mk000iKg/2O00GKg/40017Kg/2O0040008Kg/4000@Kg/400000g`0Kg]_N`0CKg/00`00Kg]l0003
O00:Kg/3O004000QKg/4O005Kg/2O00PKg/4O01`Kg/003Q_N`Al01I_N`@004U_N`@000Q_N`@0011_
N`@0009l01A_N`03001_Ng`000=l00]_N`9l00@0029_N`9l02U_N`9l075_N`00>6mk17`05fmk0P00
Bfmk0P002Vmk0P004Vmk0P000g`056mk00<006mkKg/00W`03fmk0P00`Fmk000iKg/2000FKg/2001_
Kg/2O00EKg/00`00Kg]_N`1?Kg/200000g`0Kg]_N`07Kg/2000WKg/2001>Kg/003Q_N`@001A_N`@0
05U_N`9l02Y_N`03001_Nfmk01Y_N`9l039_N`@00003O01_Nfmk00E_N`@002E_N`@004e_N`00>6mk
100056mk1000F6mk17`0:Fmk00<006mkKg/06Fmk17`0<Fmk100000=l06mkKg/01Fmk10009Fmk1000
CFmk000iKg/2000EKg/00g`00000000eKg/200000g`0Kg]_N`0<Kg/2O0000fmk0000000>Kg/4O00Y
Kg/3000IKg/20002O00`Kg/400000g`0Kg]_N`07Kg/20002Kg/2O00SKg/2000TKg/2000XKg/004m_
N`Al03A_N`@00003O01_Nfmk00Y_N`=l00@000i_N`9l02Y_N`03001_Nfmk01Q_N`@0031_N`@000i_
N`Al02Q_N`9l01e_N`@002M_N`00:fmk0W`08Vmk17`0=6mk100000=l06mkKg/02Vmk0g`01000>Vmk
00<006mkKg/066mk1000<6mk10003Vmk17`09fmk17`076mk10009fmk000ZKg/4O00RKg/2O00fKg/2
00000g`0Kg]_N`0<Kg/2O0000fmk0000000kKg/00`00Kg]_N`0IKg/2000bKg/2000@Kg/2O00XKg/4
O00MKg/2000XKg/002Y_N`=l008008m_N`800003O01_Nfmk01I_N`03001_Nfmk01M_N`8000I_N`80
00=_N`9l059_N`80011_N`9l04Q_N`00:fmk00=l000000000P00SFmk100000=l06mkKg/05Fmk00<0
06mkKg/05Vmk100016mk100000=_Ng`0O0000W`0D6mk1000FFmk000/Kg/4002=Kg/400000g`0Kg]_
N`0EKg/00`00Kg]_N`0EKg/00g`0000000020004Kg/400000fmkO01l0002O00TKg/2O00ZKg/4001I
Kg/002e_N`8005E_N`80029_N`80009l019_N`800003O01_Nfmk00e_N`800003O01_Nfmk00A_N`03
001_Nfmk01A_N`=l008000I_N`8000=_N`9l02A_N`Al02Y_N`8005Y_N`00Pfmk100086mk10000W`0
8Vmk100000=l06mkKg/00fmk00<006mkKg/056mk17`0<Vmk17`09fmk0W`0GFmk0022Kg/00g`00000
0002000PKg/40002O00RKg/400000g`0Kg]_N`03Kg/00`00Kg]_N`0EKg/2O00dKg/2O00WKg/4O01L
Kg/0089_N`9l0080029_N`80009l02A_N`800003O01_Nfmk00A_N`03001_Nfmk07A_N`Al05a_N`00
Pfmk0W`0=Fmk0P007Fmk00<006mkKg/0>fmk0P00>6mk0W`0GFmk002iKg/4000LKg/00`00Kg]_N`0j
Kg/4002FKg/006i_N`9l02i_N`9l00m_N`9l00Q_N`@00003O01_Nfmk01U_N`03001_Nfmk00I_N`9l
00=_N`9l00A_N`9l02M_N`@001m_N`9l07E_N`00KFmk17`0;6mk0g`00P002Vmk0P0017`026mk0P00
0W`06fmk00<006mkKg/01Fmk17`00P000W`00P0000E_Ng`0000007`002I_N`04O0000000O00NKg/0
17`0000007`0M6mk001PKg/2O00;Kg/4O00/Kg/2O0040008Kg/40003O009Kg/2O00LKg/00`00Kg]_
N`05Kg/3O00<000WKg/2O00OKg/4001dKg/005m_N`Al00]_N`9l02i_N`03O0000000008000Q_N`@0
009l02Q_N`03001_Nfmk00I_N`9l00`004Q_N`@007A_N`00BVmk0W`04fmk17`06Vmk0W`05fmk0W`0
26mk0P002Vmk0P007Vmk1P001fmk00<006mkKg/02Fmk0P000Vmk0P000Vmk0P00BVmk0P00MFmk0019
Kg/4O00CKg/00g`000000006Kg/2000AKg/2O002000EKg/4O0000fmk0000000`Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0WKg/200000g`0Kg]_N`2XKg/001]_N`9l02a_N`Al01=_N`@0
00A_N`@0011_N`03O0000000008001A_N`Al00@0031_N`03001_Nfmk00U_N`03001_Nfmk02I_N`@0
0003O01_Nfmk0:M_N`006Vmk17`0;6mk0W`056mk100016mk10004Fmk10005Fmk0W`000=_N`000000
0P0026mk0W`09fmk00<006mkKg/026mk10009Fmk100000=l06mkKg/0Yfmk000JKg/4O0000fmk0000
000ZKg/2000DKg/20006Kg/2000CKg/2000JKg/20008Kg/20002O00KKg/60006Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`0IKg/20002O00:Kg/200000g`0Kg]_N`0fKg/2001`Kg/001]_N`9l0003Kg/00000
008002Q_N`@005E_N`@00003O01_Nfmk02I_N`03001_Nfmk00I_N`03001_Nfmk01Q_N`@0009l04=_
N`@001m_N`9l04i_N`007Vmk1000:6mk1000EFmk10002fmk0W`066mk00<006mkKg/00Vmk00<006mk
Kg/01Fmk00<006mkKg/066mk10000W`0@fmk10007Vmk17`02Vmk0W`0@Fmk000OKg/2000ZKg/2001G
Kg/2000;Kg/4O00GKg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0IKg/20002O014Kg/0
17`0000007`07Vmk17`02Fmk17`03Vmk0W`0<6mk002aKg/017`0000007`02fmk0W`02fmk100026mk
00<006mkKg/04fmk0P00CFmk0W`086mk0W`02Vmk17`03Fmk17`0;fmk001OKg/2O01@Kg/4000:Kg/4
O00FKg/00`00Kg]_N`0BKg/4001kKg/2O00>Kg/4O00_Kg/005i_N`Al04m_N`@000Y_N`Al01I_N`03
001_Nfmk00A_N`9l00a_N`@008a_N`9l031_N`00GVmk00Al0000001l02Y_N`8000Y_N`8000i_N`80
0004O01_N`000004Kg/20008Kg/20002Kg/2O00GKg/00`00Kg]_N`03Kg/2O002000:Kg/4001aKg/2
0006Kg/20014Kg/005a_N`9l00@002U_N`@000M_N`03O0000000008000a_N`P000a_N`@001Y_N`03
001_Nfmk00=_N`03O0000000008000Q_N`@0075_N`@000A_N`@004=_N`00Ffmk0g`01000:Fmk1000
1Vmk0W`0100036mk200000=l06mkKg/02Fmk100046mk0W`026mk00<006mkKg/016mk100026mk1000
LFmk100016mk1000@fmk001KKg/4O002000[Kg/20007Kg/3O002000>Kg/2000017`0Kg/000000g`0
2fmk0P0046mk17`01fmk00<007`0O0001Fmk0P002Vmk0P00GFmk0W`056mk0P001Vmk0P00A6mk000U
Kg/2000BKg/2O002Kg/2000MKg/00g`00000000gKg/2O006Kg/2000=Kg/4O005Kg/20002Kg/2000:
Kg/200000g`0Kg]_N`03Kg/20002O007Kg/2O002001^Kg/017`0000007`0;Fmk0P00<Vmk000TKg/4
000@Kg/4O004000LKg/4000mKg/4000=Kg/2O005Kg/80008Kg/4000017`0Kg]_Nfmk100026mk00=l
000000000P00Bfmk0W`086mk1000;6mk1000<Fmk000TKg/4000@Kg/4O004000LKg/4000lKg/00g`0
00000002000CKg/00g`00000000600000g`0Kg]_N`05Kg/4000017`0Kg]_Nfmk100026mk1@00;Fmk
0W`06fmk17`07fmk1000;6mk1000<Fmk000UKg/2000BKg/2O002Kg/20008Kg/2000DKg/20004Kg/2
000;Kg/20006Kg/2000:Kg/2000EKg/3O0020004Kg/2000=Kg/3O0020002Kg/20002O008Kg/20000
0g`0Kg]_N`03Kg/20009Kg/01000Kg/000002Fmk0W`000=_N`0000001Vmk0P000W`05Fmk17`06Vmk
00Al0000001l021_N`8002i_N`80039_N`00AVmk100066mk10002Fmk100016mk100026mk100056mk
17`016mk100036mk17`016mk0W`076mk00<006mkKg/02Fmk0g`0100016mk10000W`056mk17`06Vmk
1000EVmk0W`0;6mk000UKg/2O00OKg/4000HKg/40002Kg/2O005Kg/40004Kg/40008Kg/4000EKg/2
O005Kg/4000=Kg/2O00SKg/00`00Kg]_N`09Kg/3O0040004Kg/40002O00EKg/2O00KKg/4001EKg/4
O00[Kg/002A_N`Al01i_N`04O0000000O00IKg/20002Kg/4O005Kg/20005Kg/017`0000007`026mk
00Al0000001l01e_N`8003=_N`03001_Nfmk00Y_N`9l0003Kg/0000000I_N`8000Al039_N`8001A_
N`9l01Q_N`9l02I_N`Al02]_N`0096mk17`07fmk0W`07Vmk17`03Fmk0W`02Fmk17`076mk0W`0;Fmk
0P001Fmk00<006mkKg/05fmk0P000g`04fmk0P00<Fmk0W`00P005Vmk17`00P008Vmk0P000W`0;6mk
000UKg/2O011Kg/2O00JKg/2O00LKg/4O00[Kg/40004Kg/00`00Kg]_N`02O00DKg/40002O00BKg/4
000`Kg/00g`000000002000EKg/3O004000PKg/4000]Kg/00:9_N`Al02]_N`@000A_N`8000Al01=_
N`@00003O01_Nfmk00a_N`9l00=_N`@0035_N`@001I_N`9l00@0021_N`@002e_N`00Ffmk0P00AVmk
0W`04fmk0P0036mk0W`02Fmk00Al0000001l00A_N`04001_Ng`0O002000>Kg/20004Kg/2000?Kg/4
O0000fmk00000004000aKg/2000JKg/20004Kg/2000LKg/2000^Kg/005Y_N`@005U_N`@000Y_N`Al
00U_N`9l00E_N`03001_Nfmk00@000]_N`03O0000000008001A_N`Al00P0009_N`9l04e_N`@004]_
N`00FFmk00=l000000000P00Cfmk0W`026mk10002Vmk17`046mk00<006mkKg/0100000=l06mkKg/0
1fmk0W`010005Fmk0W`000=_N`0000001P0000=_Ng`0O0000W`0Bfmk00=l000000000P004Fmk0W`0
>6mk001IKg/2O002001?Kg/4O008Kg/2000<Kg/2O00AKg/01000Kg]_Nfmk0P000g`026mk0g`00P00
6Vmk0P000Vmk0P000Vmk17`0BVmk0g`00P002Fmk0W`01Vmk17`0=fmk001EKg/20003Kg/2O01@Kg/2
O002000:Kg/200000g`0Kg]_N`07Kg/2000AKg/00`00Kg]_N`02Kg/017`0000007`01fmk0W`00P00
1Vmk0P000Vmk0W`06Fmk0W`03Fmk0W`0?6mk17`02Fmk0P000W`01Fmk17`0=fmk001DKg/4001EKg/4
0008Kg/400000g`0Kg]_N`05Kg/4000@Kg/00`00Kg]_N`02Kg/40006Kg/2O0040004Kg/40004O00V
Kg/4O00:Kg/2O00?Kg/2O00OKg/2O009Kg/400000g`0Kg]_N`04Kg/2O00CKg/2O00SKg/0059_N`9l
00@003Q_N`9l01]_N`@000Q_N`@00003O01_Nfmk00E_N`@0011_N`03001_Nfmk009_N`@000I_N`9l
00@000A_N`@000Al02I_N`Al00U_N`Al00e_N`Al02U_N`@001]_N`Al029_N`00DFmk17`00P0036mk
0P00:Vmk00Al0000001l01I_N`9l00=_N`8000Y_N`800003O01_Nfmk00M_N`@00003O01_Nfmk00=_
N`8000M_N`04001_NfmkKg/60006Kg/2O0020004Kg/40002Kg/2O00@Kg/2000FKg/2O002Kg/20006
Kg/20002O00=Kg/20002O00XKg/40008Kg/2000>Kg/20002Kg/4O00RKg/0055_N`Al00e_N`@002U_
N`@001E_N`Al01]_N`@00004O01_NfmkKg/400000g`0Kg]_N`03Kg/00`00Kg]_N`08000<Kg/4000D
Kg/4000HKg/40004Kg/4000=Kg/4000XKg/40008Kg/4000<Kg/40002Kg/2O00SKg/0059_N`9l00i_
N`@002U_N`@001E_N`Al01]_N`@00004O01_NfmkKg/40002O004Kg/2O0000fmk000000060004Kg/2
O006Kg/400000g`0Kg]_N`0AKg/4000HKg/40004Kg/4000=Kg/4000XKg/40008Kg/4000<Kg/4000W
Kg/006=_N`8002]_N`8001M_N`9l01=_N`9l00Q_N`800003O01_Nfmk00=_N`8000=l00=_N`Al0003
Kg/00000009_N`8000A_N`Al00I_N`80009l01=_N`04O0000000O00IKg/20006Kg/2000?Kg/2000V
Kg/2O002Kg/2000:Kg/2000>Kg/2000XKg/006I_N`9l049_N`80015_N`04O0000000O005Kg/2000:
Kg/2O004Kg/4O006Kg/00g`000000002Kg/20002O007Kg/2O00CKg/20003O01<Kg/2000;Kg/4O00_
Kg/20003Kg/2O00AKg/006E_N`Al00e_N`9l035_N`@0011_N`@000A_N`@0011_N`9l00I_N`03O000
000000H001a_N`@00003O01_Nfmk04M_N`9l0003Kg/00000008000Y_N`Al02i_N`@00003Kg]l07`0
009l011_N`00IFmk17`036mk17`0;6mk0W`00Vmk10001fmk0W`01fmk100016mk100046mk00<006mk
Kg/01Fmk00=l000000001P006fmk00=l000000000P00;fmk0W`066mk17`010002fmk0W`0;fmk1000
00=_Ng`0O0000W`046mk001?Kg/200000fmkO01l000BKg/2O00<Kg/20003O00QKg/2O002000016mk
O00000000Vmk17`01P000W`00P0000=_Ng`0O0000W`01Fmk10001Fmk00Al0000001l011_N`03001_
Nfmk00I_N`03O000000000H001U_N`=l008001a_N`8000I_N`8000U_N`04O0000000O00GKg/4O000
0fmk0000000HKg/2000TKg/20003Kg/2O00AKg/004i_N`@000=l01i_N`@00003O01_Nfmk01m_N`9l
00P00004Kg]l07`0O00<0004O004Kg/400000g`0Kg]_N`04Kg/2O00AKg/00`00Kg]_N`08Kg/8000H
Kg/4O00LKg/40004Kg/40008Kg/4000HKg/2O00KKg/4000kKg/0041_N`9l00a_N`@000=l01i_N`@0
029_N`9l00P0009_N`9l00`00003Kg]l07`000E_N`@00003O01_Nfmk00Y_N`9l00]_N`03001_Nfmk
00M_N`03O000000000H000]_N`9l00a_N`9l01e_N`@000A_N`@000Q_N`@003A_N`03O00000000080
03]_N`00?fmk17`036mk0P0000=_Ng`0O00086mk0P0096mk0W`00P0000A_Ng`0000000I_N`80009_
N`80009l008000Y_N`800003O01_Nfmk00Y_N`Al00Y_N`03001_Nfmk00I_N`=l0080009_N`8000I_
N`9l00=_N`Al02U_N`9l008000I_N`80009l00Q_N`8003A_N`=l008003a_N`00?fmk17`00Vmk0P00
:fmk0P006Fmk0W`06fmk0P001Vmk0P001Vmk0P003Vmk0P000g`02Vmk00<006mkKg/00fmk0P0000=_
Ng`0O0000W`01Fmk0P000Vmk0P000g`00Vmk00Al0000001l01e_N`8000Y_N`Al00M_N`Al00i_N`80
01=_N`9l01Q_N`Al00A_N`03O0000000009_N`80039_N`00@6mk0W`00Vmk1000:Fmk10005fmk17`0
6Fmk100016mk100016mk100036mk100000=l06mkKg/02Fmk0W`000<006mkKg/0100000=_Ng`0O000
1Fmk20000W`00Vmk100076mk10002Vmk0W`026mk17`03Fmk10004Fmk17`066mk0W`016mk00=l0000
00001P00<Fmk0014Kg/4000XKg/00g`000000002000=Kg/2O008Kg/4O00IKg/40004Kg/4000017`0
Kg]_Nfmk100036mk10002fmk17`000=_Ng`000000`0026mk200000Al06mkKg]_N`@001a_N`@001E_
N`9l00i_N`@0009l00m_N`Al01i_N`03O000000000H0009l02m_N`00AFmk0P00:6mk0g`00P003Fmk
0g`00P001Vmk0P0000=l06mkKg/05fmk10001Vmk0P000W`00fmk00Al0000001l00E_N`9l0080009_
N`@000a_N`05O0000000O01_N`02O002000:Kg/20002Kg/20006Kg/4000>Kg/200000g`0Kg]_N`09
Kg/2000WKg/20004O00?Kg/00g`00000000OKg/00g`000000002Kg/20004O00^Kg/006m_N`Al00i_
N`9l00@000A_N`@001Q_N`@00003O01_Nfmk00E_N`9l00E_N`9l00E_N`9l00P00003O01_Nfmk00Y_
N`@0009_N`9l01Q_N`@000a_N`@00003O01_Nfmk03=_N`Al00m_N`@002E_N`Al02i_N`00L6mk0W`0
46mk00=l000000000P0016mk100066mk10005Vmk0W`020003Fmk10002Vmk0W`046mk100000=l06mk
Kg/02Fmk100000=l06mkKg/0=6mk0W`046mk10009Vmk0W`0;fmk0024Kg/20006Kg/2000JKg/2000H
Kg/2O0020002Kg/20007Kg/2O006Kg/2000:Kg/4O0000fmkO01l000=Kg/20002O006Kg/2O004Kg/2
00000g`0Kg]_N`18Kg/2001HKg/0025_N`8002I_N`8005a_N`Al01]_N`80009_N`8000A_N`9l0080
00=_N`<000]_N`9l0080009l0080009_N`8000U_N`9l00I_N`04O0000000O02ZKg/0021_N`@002A_
N`@004M_N`9l019_N`Al01Y_N`P00004O01_NfmkO00400000fmk00000002000<Kg/<000@Kg/4002Z
Kg/0021_N`@002A_N`@004I_N`Al019_N`9l00Y_N`9l00U_N`9l00A_N`P0009l009_N`@00003Kg/0
0000008000a_N``0011_N`@00:Y_N`008Fmk0P009Fmk00Al0000001l041_N`80009_N`8000Al019_
N`800003O01_Nfmk00I_N`04O0000000O007Kg/2O0020003Kg/01G`0000007`0Kg/00P000g`00fmk
0P000fmk0`000Vmk00El0000001_Ng`000800003Kg]l000000L0009_N`@0011_N`8002a_N`9l009_
N`80009_N`800003Kg]l07`0015_N`9l0003Kg/0000001I_N`8001I_N`8002a_N`00BFmk0W`0@6mk
20000W`04Vmk100000=l06mkKg/01Fmk10001fmk00=l000000000P000fmk0W`016mk0W`02fmk00<0
06mkO000400016mk1000?6mk17`020000g`03fmk0g`0100056mk100056mk1000:fmk002:Kg/00g`0
00000006000DKg/400000g`0Kg]_N`05Kg/40008Kg/4000FKg/00`00Kg]l000@000017`0Kg]_Nfmk
100000=l06mkKg/016mk0W`0<fmk17`020000g`03fmk0g`010004fmk00=l000000000P0056mk1000
:fmk002:Kg/2O0020002Kg/2000FKg/200000g`0Kg]_N`07Kg/2000:Kg/2000GKg/01000Kg]_Ng`0
0P0000I_Ng`0000006mkO0020002Kg/20002O004Kg/20002O005Kg/4O00cKg/2O002Kg/20002Kg/2
00000fmkO01l000AKg/2O0000fmk0000000CKg/3O002000FKg/2000/Kg/008]_N`9l01U_N`8000i_
N`8000I_N`8000I_N`8000Y_N`8000E_N`03001_Nfmk00i_N`03O000000000E_N`9l00I_N`04O000
0000O01NKg/20009Kg/4O015Kg/006]_N`9l02i_N`9l00Q_N`@000a_N`@000A_N`@000A_N`@000Q_
N`@000A_N`03001_Nfmk00i_N`@000a_N`@005e_N`@00003O01_Nfmk00I_N`9l04I_N`00JVmk17`0
;6mk17`01fmk100036mk100016mk100016mk100000=l06mkKg/01Fmk100016mk00<006mkKg/03Vmk
10001fmk0W`00fmk1000GFmk10000W`09fmk0W`09Vmk001ZKg/017`0000007`03Vmk0P003Vmk0P00
1Vmk0P000Vmk0P0017`01Vmk0W`00P003Vmk0P001Vmk100016mk0P000W`026mk0P001Fmk0P001Vmk
0P000Vmk0P000fmk00Al0000001l00I_N`04O0000000O003Kg/20004Kg/20002Kg/20002O00AKg/2
O00MKg/2000QKg/20003O00EKg/2000?Kg/4O00UKg/006Y_N`@000e_N`@000]_N`03O00000000080
00A_N`P0009l00M_N`Al01M_N`@000A_N`9l00m_N`@000A_N`P000=_N`9l00M_N`@000Q_N`P0009l
00m_N`Al01]_N`@0029_N`9l01E_N`@000i_N`Al02E_N`00D6mk0W`066mk100036mk00=l00000000
0P002Vmk0W`0100016mk20002Vmk0W`066mk100000=l06mkKg/026mk0W`026mk10000fmk00=l0000
00001P0036mk100026mk20000W`03fmk17`06fmk1000>Fmk10003fmk0W`09Vmk001?Kg/4O00HKg/2
000=Kg/2O002000;Kg/3O0020006Kg/20002Kg/2000VKg/20002O009Kg/4O002Kg/2O004Kg/20004
Kg/2O00200001FmkO0000000O0002Vmk0W`000=_N`0000002Vmk0P000Vmk0P000W`04Fmk0W`07Fmk
0P00>fmk0P0000=l06mkKg/0=Fmk001=Kg/20004O00XKg/2O00:Kg/2O0000fmk0000000YKg/00g`0
00000009Kg/2O00:Kg/01G`0000007`0Kg/00P000W`00fmk0`0016mk0W`00fmk0W`01Vmk0W`00P00
0W`00P001Vmk0P007Vmk0P006fmk17`046mk0P00:6mk17`0=Vmk001<Kg/40002O00dKg/3O004000W
Kg/00g`000000002000DKg/800001G`0Kg]_Nfmk00004Vmk0W`0200016mk100076mk10006Vmk17`0
3fmk10009fmk17`0=Vmk001<Kg/4000fKg/3O004000EKg/2O00@Kg/00g`0000000020008Kg/2O004
Kg/2O003Kg/00g`0000000060004Kg/00`00Kg]_N`02O007Kg/2O002Kg/2O0000fmkO01l00080004
Kg/400000g`0Kg]_N`0IKg/400000fmkO01l000HKg/2O00@Kg/400000g`0Kg]_N`0UKg/2O00gKg/0
03]_N`@000a_N`@003Q_N`9l00H000E_N`800003O01_Nfmk00M_N`8000=l011_N`03O000000000A_
N`80009_N`80009l009_N`9l00800003Kg]l000000L00007Kg/00000O01_N`00Kg/00W`00P0000I_
Ng`0000006mkO0020002O002000017`0Kg]l07`00P000Vmk100016mk0P000W`03Vmk0P0036mk1000
0g`016mk1P005Fmk00=l0000000026mk0P000W`0:Fmk1000<fmk000mKg/00`00Kg]_N`08Kg/2O004
000NKg/2O00KKg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/400000g`0Kg]_N`02Kg/2O0000fmk0000
00020002O00FKg/8000017`0Kg]_Ng`0300000=l000000000P0000Al0000Kg]l010000Q_N`@000A_
N`9l00i_N`@000a_N`@0009l00A_N`03001_Nfmk009_N`03001_Nfmk019_N`03O0000000008000Q_
N`9l02a_N`03001_Nfmk039_N`00?Fmk00<006mkKg/01fmk0g`010007Fmk17`06fmk00<006mkKg/0
1Vmk100000Al06mkKg]_N`Al00@00003O01_Nfmk00A_N`9l00m_N`P000A_N``00003O00000000080
0004O00006mkKg/@0008Kg/4000DKg/4000<Kg/400000g`0Kg]_N`04Kg/00`00Kg]_N`02Kg/2O00B
Kg/00g`000000002000fKg/00`00Kg]_N`0VKg/2O00:Kg/003U_N`H000Q_N`Al008001i_N`Al01a_
N`03001_Nfmk00I_N`800003O01_Nfmk009_N`Al0003Kg/0000000M_N`Al00m_N`80009_N`8000A_
N`9l0080009_N`80009_N`800003O01_Nfmk00800003O01_N`00009l0005Kg/00000Kg]l00020002
Kg/20002Kg/200000fmkO01l0006Kg/017`0000007`01fmk0W`036mk0P003Vmk0P002Fmk00<006mk
Kg/017`04Vmk00=l00000000<fmk1P009Vmk17`02Fmk000`Kg/60004Kg/01000Kg]_N`002Vmk0W`0
7fmk0P0000=_Ng`0O0004Vmk1P001Vmk00<006mkKg/02fmk0P000W`02fmk00Al0000001l00e_N`80
00U_N`05O0000000O01_N`020002Kg/200001G`0Kg/00000O00016mk0W`00P001Vmk0P0000A_Ng`0
0000009_N`80009l00A_N`80009l00M_N`04O0000000O00IKg/2000<Kg/01000Kg/000000W`0>Fmk
0P0000=l06mkKg/02fmk00@006mkKg/002A_N`800003Kg]l07`0009l00U_N`00>Vmk00@006mkKg/0
029_N`9l00I_N`@0025_N`03001_Nfmk00U_N`@000a_N`@000a_N`@000Q_Na000005O01_NfmkKg]l
00040004Kg/<000017`0Kg]_Nfmk100026mk100066mk100036mk1000>Fmk100000=l06mkKg/02Vmk
00@006mkKg/002=_N`@00003Kg]l07`000Y_N`00:Vmk0W`03fmk00<006mk00008Fmk17`01Fmk1000
7Fmk00@006mkKg]_N`9l00Y_N`@000a_N`@000E_N`9l00E_N`@000Q_Na000004O01_NfmkKg/50003
Kg/00g`00000000:0004Kg/40008Kg/4000HKg/40008Kg/01000Kg]_Nfmk1000>Fmk100000=l06mk
Kg/02fmk00<006mk00008fmk10003Fmk000YKg/4O00>Kg/00`00Kg/0000QKg/4O006Kg/2000NKg/0
0`00Kg]_N`04O002000017`0Kg/000000W`01P0036mk0P001Fmk0g`00P000Vmk100016mk0P000Vmk
10000Vmk2P0000El0000001_Ng`000H0009_N`9l00800003Kg]l000000L000=_N`04O0000000O009
Kg/2000HKg/2O0020009Kg/00`00Kg]_N`02Kg/2000bKg/2O007Kg/200000g`0Kg]_N`0<Kg/00`00
Kg/0000TKg/2000>Kg/002U_N`Al00m_N`80029_N`9l02Q_N`8000=l01000003Kg]l07`000m_N`9l
00P000A_N`P00004O01_NfmkKg/800000fmk0000000:0002Kg/2O004Kg/80003Kg/2O00TKg/4O00:
Kg/4000cKg/4O00HKg/2000dKg/002Y_N`9l065_N`9l010000Al00m_N`03O000000000H00004O01_
NfmkKg/8000017`0Kg]_Nfmk200000=_N`0000002P001fmk00=l000000001P008fmk0W`01Fmk0W`0
@Vmk17`0CVmk002;Kg/2O003Kg/2000017`0Kg/000000W`00P000Vmk0P0000=_Ng`0O0000W`01fmk
0W`026mk0P000Vmk0P000W`016mk0P000Vmk0P0000=l06mkKg/00Vmk00=l000000000W`00P0000=l
06mkKg/00P0000A_Ng`00000009_N`8000Q_N`9l0080009_N`8002=_N`Al02m_N`9l01Q_N`9l04m_
N`00GFmk0P00:fmk17`00P002Vmk0P0016mk0W`01fmk00Al0000001l00a_N`9l00M_N`80009_N`80
0004O01_NfmkKg/2O002Kg/2O0020003Kg/30005Kg/20007Kg/2O005Kg/2000=Kg/00g`000000002
Kg/20002O00;Kg/017`0000007`03Fmk0P003Vmk0W`03fmk0P000W`066mk0P00;Vmk0P0000=l06mk
Kg/06fmk001LKg/400000g`0Kg]_N`0WKg/3O0040008Kg/4000<Kg/40006Kg/2O00<Kg/800000g`0
Kg]_N`05Kg/400000fmk000000020004Kg/4000<Kg/4000;Kg/00g`0000000060002O00:Kg/4000<
Kg/4000<Kg/4O00=Kg/400000g`0Kg]_N`0AKg/2O002Kg/4000/Kg/400000g`0Kg]_N`0JKg/000U_
N`9l04E_N`9l00Y_N`@0009l02U_N`9l00@000Q_N`@000a_N`@000E_N`Al00]_N`P00003O01_Nfmk
00E_N`@00003Kg/00000008000A_N`@000I_N`9l00A_N`@0009l00U_N`03O000000000H0009l00I_
N`9l009_N`@000a_N`@00003O01_Nfmk00U_N`Al00e_N`@001=_N`Al0003Kg/00000008002a_N`@0
0003O01_Nfmk01Y_N`0026mk17`07fmk0P0066mk0W`016mk0P000Vmk0P000W`02Vmk100000=l06mk
Kg/0:Vmk0P0016mk0P0016mk0P0000=_Ng`0O0002fmk0P001Vmk0W`00P000Vmk0P000W`016mk1000
0Vmk10000Vmk0P000Vmk100000=_N`000000100016mk0P001Vmk0W`00P0016mk10000W`02Fmk00=l
000000000Vmk0P000W`01Vmk17`010003Vmk0P000W`036mk0W`00P003Fmk0P0056mk17`0100076mk
0P0046mk0P0000=l06mkKg/06fmk0008Kg/4O00NKg/4000FKg/4O002Kg/800000g`0Kg]_N`09Kg/4
0009Kg/2O00VKg/40005Kg/4O00CKg/80002O002Kg/40004Kg/<00000g`000000006000;Kg/00g`0
000000020004Kg/400000g`0Kg]_N`0FKg/3O004000@Kg/2O00>Kg/4000SKg/2O004000KKg/00g`0
00000002000_Kg/000U_N`9l01m_N`@001I_N`Al009_N`P000a_N`@000Q_N`Al02E_N`@000E_N`Al
00i_N`9l00=_N`P0009l009_N`@000A_N``00003O000000000H000a_N`@000A_N`@001Y_N`9l00@0
00E_N`9l01U_N`@002E_N`@001Y_N`9l00@002m_N`00A@000W`08`0017`07`000W`020000W`01000
0W`01@000W`01`0017`02@000W`05P000g`00P0000Al00000000009l0080009l01/0009l01X000Al
05l000=l0340005_N`003fmk00@006mk000000M_N`9l00M_N`03001_Nfmk019_N`03001_Nfmk015_
N`03001_Nfmk009_N`8000e_N`03001_Nfmk00I_N`80009l00A_N`9l0003Kg/006mk00Y_N`9l00I_
N`04001_NfmkKg/2O0020006Kg/4O003Kg/00`00Kg]_N`03Kg/3O0020005Kg/01G`0000007`00000
16mk0P001Vmk0P000Vmk0P000W`026mk0P0000Al06mkKg]_N`=l00<00003O0000000009l00800004
O01_NfmkKg/2O0020002Kg/300000g`000000002Kg/20006Kg/20002O003Kg/00`00Kg]_N`0AKg/3
0003O00>Kg/00`00Kg]_N`0:Kg/20005Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0BKg/00`00Kg]_N`0A
Kg/00`00O01l000AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0:Kg/000m_N`D000E_N`Al00I_N`03001_
Nfmk019_N`03001_Nfmk015_N`04001_NfmkKg/4000<Kg/00`00Kg]_N`05Kg/40004Kg/4O0000`00
Kg]_N`08Kg/4O005Kg/01@00Kg]_NfmkO00010001Fmk17`00fmk00<006mkKg/00fmk0W`0100016mk
1@000fmk100016mk20000W`01Vmk100000El06mkKg]_Ng`000`0009_N`9l010000A_N`@00005O01_
NfmkKg/0000CKg/400000g`0Kg]_N`0=Kg/00`00Kg]_N`09Kg/40004Kg/00`00Kg]_N`0AKg/00`00
Kg]_N`0BKg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0:Kg/0011_
N`@000E_N`Al01]_N`03001_Nfmk01E_N`@001A_N`@000A_N`Al00]_N`Al00E_N`03001_Nfmk009_
N`@000I_N`9l00]_N`03O0000000008000A_N`@00004O01_NfmkKg/40002O002Kg/80002O006Kg/4
00000g`0Kg]_N`02Kg/<0002Kg/2O00@0004Kg/40006Kg/2O00@Kg/4000@Kg/00`00Kg]_N`09Kg/4
0011Kg/00`00Kg]_N`0bKg/0015_N`8000M_N`03O000000003A_N`8000Q_N`80009_N`8000Q_N`80
00E_N`800003O01_Nfmk00]_N`8000a_N`8001I_N`@000A_N`@00003O01_N`0000D0009l009_N`P0
0006O01_N`00001l06mk1P0000=l06mkO0003P000Vmk0W`01P0000A_Ng`00000009_N`@000A_N`80
00I_N`9l008000i_N`@001i_N`80015_N`800003O01_Nfmk01=_N`8004a_N`006Vmk1000=6mk0W`0
1Vmk200000=l06mkKg/02Vmk100036mk100096mk100016mk300000Al06mkKg]_Na@00003O0000000
00h000A_N`@000Q_N`@000]_N`03O0000000008000a_N`@0035_N`@00003O01_Nfmk015_N`@004]_
N`006Vmk1000<fmk17`01Fmk20000W`02fmk100036mk100096mk100016mk300016mk500000=l0000
00003P0016mk100026mk100036mk100036mk10003Vmk0W`08Fmk100000=l06mkKg/04Fmk1000Bfmk
000KKg/2000dKg/4O006Kg/20002Kg/20003O00<Kg/2000>Kg/2000<Kg/2O00FKg/2O0020006Kg/2
0002Kg/20002Kg/20005Kg/01G`0000007`0Kg/00P0000Il06mk000007`0Kg/20002Kg/200000g`0
Kg]l00020002Kg/2000016mkO00000000W`00P0000Al06mkKg]_N`9l00800003O01_Nfmk00M_N`80
0003Kg]l07`000]_N`8000i_N`8000i_N`Al025_N`800003O01_Nfmk01=_N`8004a_N`00?Fmk0P00
00=_Ng`0O00046mk0W`016mk0W`01fmk0W`0:Vmk00Al0000001l01E_N`Al00M_N`03O0000000009_
N`80009_N`800004O01_NfmkKg/2O00<Kg/200000g`0Kg]_N`04Kg/30003Kg/2O002Kg/2O003Kg/0
0g`000000002O006Kg/2O0020002Kg/20002O00BKg/2O0020006Kg/200000g`0Kg]_N`07Kg/20004
O00;Kg/2O0000fmk0000001gKg/003a_N`@000=l01A_N`Al039_N`@001I_N`9l00M_N`03O0000000
00X00003O01_Nfmk00e_N`@00003O01_Nfmk009_N`@000a_N`@000I_N`9l00P00003O01_Nfmk009_
N`9l00]_N`9l00@000A_N`@00003O01_Nfmk00E_N`@0009l00]_N`=l00@007I_N`00<Fmk0W`02Fmk
10000g`056mk17`0<Vmk10007fmk00=l000000002P0000=l06mkKg/00fmk0W`00fmk0W`00fmk1000
00El06mkKg]_Ng`000@000Y_N`9l00@000I_N`9l00P000A_N`Al00Y_N`9l00@000A_N`@00003O01_
Nfmk00E_N`@000e_N`=l00@002a_N`9l04Q_N`006fmk0P004Vmk0P000W`00P0026mk0P0000=_Ng`0
O0005Vmk0W`04Fmk0P003fmk0P002Vmk0P0016mk10007Vmk20000Vmk100016mk0W`00P0000I_Ng`0
000007`0Kg/400000g`0Kg]_N`02Kg/2O0030002Kg/00g`000000004Kg/2O0040008Kg/2O0060004
Kg/20003O007Kg/20002Kg/2O0020006Kg/200000g`0Kg]_N`07Kg/2000?Kg/2O0000fmk00000009
Kg/2000FKg/20009Kg/4O00NKg/2O00WKg/001Y_N`@0011_N`P00003Kg]l07`0035_N`@000e_N`@0
00Q_N`@000A_N`@000A_N`9l01I_N`P000A_N`@000=_N`03O000000000X00003O01_Nfmk00A_N`9l
0004Kg/006mkO0040003Kg/00g`000000002000<Kg/40004Kg/400000g`0Kg]_N`05Kg/4000eKg/4
00000g`0Kg]_N`0AKg/40008Kg/4O00MKg/4O00VKg/001Y_N`@0011_N`P000Al031_N`@000a_N`03
O0000000008000M_N`03O0000000008000A_N`@00003O01_Nfmk00Al01A_N`03O000000000H00004
O01_NfmkKg/4000017`0Kg]_Nfmk30002Vmk00<006mkO000100016mk100036mk100016mk100026mk
1000=Fmk10000W`04Vmk10002Fmk0W`07Vmk17`09Vmk000KKg/2000BKg/20002Kg/200000fmkO01l
0002O00aKg/2000=Kg/2O0020007Kg/3O0020006Kg/20002O002Kg/4O00DKg/2O0020002Kg/20003
O003Kg/20003O003Kg/2000017`0Kg/000000Vmk0P002fmk00@006mkKg]l0080009_N`9l009_N`80
00I_N`9l00I_N`8000I_N`8000Q_N`9l008003M_N`8000=l01=_N`8002]_N`9l02M_N`006Fmk0W`0
76mk0W`086mk0P003fmk17`016mk0P001fmk0W`026mk17`026mk0W`00fmk0P0000=l06mkKg/056mk
0W`016mk17`016mk17`00fmk0W`00P000Vmk0P0000El06mk000007`000Q_N`03001_Nfmk00A_N`=l
0080009_N`800003O01_Nfmk00=l0080009_N`80009_N`80009_N`8000Y_N`Al00a_N`80009_N`80
0003O01_Nfmk021_N`80009_N`9l06Y_N`0066mk17`0?6mk10003Vmk17`00fmk10004Fmk0W`03Fmk
10007Fmk0W`01Vmk0W`016mk00=l000000002P0000=l06mkKg/01Fmk00<006mkKg/016mk0W`02000
00Al06mkO01l010000Y_N`9l00Y_N`9l00P00003O01_Nfmk01i_N`@000Al015_N`9l05I_N`0066mk
17`0?6mk10003fmk0W`016mk100086mk100000=_Ng`0O0002fmk0W`076mk300000Al06mkKg]_N`9l
009_N`03001_Nfmk009l00=_N`03O000000000H00004O01_NfmkO00@000EKg/3O00800000g`0Kg]_
N`0NKg/40004O00@Kg/4O01EKg/001U_N`9l03i_N`8001M_N`80029_N`@000=l00U_N`9l0080009_
N`800004O01_N`00000@Kg/2O00800000g`0Kg/0000300000g`0Kg]l0002000017`0Kg/006mk0W`0
0P0016mk1P0000=l06mkKg/00fmk1P000W`00P000Vmk100056mk17`00P000Vmk10006Vmk0P000fmk
10000Vmk0W`04Fmk17`09fmk0P00;6mk001FKg/2O00IKg/4O00RKg/40002O009Kg/00g`00000000:
000>Kg/2O0080002O002Kg/400000g`000000002000016mk001_Ng`0100016mk100026mk10000Vmk
0W`016mk100056mk0W`01Vmk100066mk100000=_N`0000000P005fmk0W`09fmk1000:fmk001EKg/4
O00HKg/4O00RKg/400000g`0Kg]_N`09Kg/<00000g`0Kg]_N`0;Kg/2O0080002O002Kg/400000g`0
0000000200000fmk000000050004Kg/40008Kg/40008Kg/40002O00JKg/4000>Kg/2O007Kg/00g`0
0000000200000fmk000000020010Kg/4000[Kg/001a_N`9l03M_N`Al01U_N`9l00m_N`9l01=_N`80
00i_N`80009_N`800004O01_N`000002O00>Kg/2O002000017`0Kg/0000017`00Vmk0P0000=l06mk
Kg/00P000Vmk00@006mkKg]_N`8000I_N`8000E_N`9l009_N`04O0000000O009Kg/20004O00JKg/2
0002O00<Kg/4O005Kg/3O0020003Kg/20002O010Kg/2000/Kg/001]_N`Al03M_N`9l02Y_N`80009l
00a_N`80019_N`8000U_N`9l015_N`9l0080009_N`8000=l00M_N`05O0000000001l00020002Kg/2
000:Kg/20002O0000fmkO01l0002O00:Kg/00g`000000002O00JKg/2O002000<Kg/2O0020005Kg/4
O005Kg/4O01]Kg/001]_N`Al069_N`@00003O01_Nfmk00M_N`9l00@000m_N`03O0000000008001]_
N`03O000000000H0009l00I_N`03O000000000X000Q_N`@00003O01_Nfmk009l00]_N`@001a_N`@0
00a_N`@000E_N`9l00I_N`Al06e_N`0076mk0W`0Hfmk10002Fmk0g`010003Vmk0W`0100076mk2000
0g`01Fmk00=l000000002P0026mk10002Fmk0W`01Fmk10001Fmk0W`05Fmk100000=l06mkKg/02Fmk
10003Vmk0W`0KVmk000SKg/2000jKg/2000QKg/2000:Kg/4O0020004Kg/20009Kg/3O002000LKg/:
0003O005Kg/01G`000000000O0000P000Vmk10000W`00P000Vmk10002Fmk0g`00P0000=_Ng`00000
0`0016mk0P000g`02Fmk0W`02Vmk0P000W`036mk0P00Ofmk000RKg/4000hKg/4000]Kg/2O006Kg/4
0009Kg/2O00LKg/00g`00000000:0002O008Kg/00`00Kg]_N`04Kg/<00000g`0Kg]_N`07Kg/2O008
0004Kg/40002O008Kg/4O00:Kg/2O02>Kg/0029_N`@003Q_N`@003E_N`@00003O01_Nfmk02=_N`9l
00`00003O01_Nfmk00M_N`03001_Nfmk00=_N`03O000000000X00003O01_Nfmk00Q_N`03O0000000
00H000A_N`@00003O01_Nfmk00M_N`Al09Y_N`008fmk0P000W`0>6mk0P0000=l06mkKg/0=6mk0P00
0W`076mk0W`01fmk0g`00P0000I_Ng`0000007`0Kg/20002Kg/2O007Kg/00`00Kg]_N`03Kg/2O002
0002O0020002Kg/200000g`0Kg]_N`03Kg/2O004Kg/2O002000016mkO00000001Vmk0P0036mk0W`0
Vfmk000TKg/4O009Kg/2000/Kg/4O00fKg/2O003Kg/2000BKg/20002Kg/20003O007Kg/2O004Kg/2
O0020002Kg/20002O0020002O003Kg/01000Kg/000000fmk0W`01Fmk0P001fmk0g`00P0000E_Ng`0
000007`000U_N`800003O01_Nfmk00]_N`8001Y_N`8004M_N`80009_N`80009_N`8002i_N`0096mk
17`026mk1000:fmk17`0>Vmk100046mk20000W`03Vmk30000W`00Vmk1@0026mk10001Vmk0W`02000
26mk100000=l06mkKg/02Fmk100066mk1000AFmk3000;Fmk000UKg/2O009Kg/40005Kg/2O00UKg/2
O00kKg/400000g`0Kg]_N`09Kg/2O002Kg/800000g`0Kg]_N`0<Kg/00g`00000000:0002O002Kg/5
0008Kg/40007Kg/00g`0000000060008Kg/400000g`0Kg]_N`02Kg/2O005Kg/40002O00FKg/4000o
Kg/2O004Kg/<000]Kg/002M_N`8000Q_N`8000E_N`Al041_N`80009_N`8000i_N`8000a_N`80009l
00Y_N`80009l009_N`80009_N`8000Q_N`8000I_N`9l00H0009_N`80009l00=_N`04001_N`000009
Kg/017`0000007`02Fmk0P000Vmk0P0016mk0P0016mk0P0000=l06mkKg/00Vmk0g`00P0016mk1000
0W`05Vmk0P00?fmk17`016mk0P000W`00P000Vmk0P00;Vmk000VKg/4000>Kg/4O00lKg/2O0000fmk
0000000600000g`0Kg]_N`09Kg/4000<Kg/2O00:Kg/400000g`0Kg]_N`0=Kg/40006Kg/2O004000:
Kg/00`00Kg]_N`0:Kg/4O00BKg/4000:Kg/2O0040004Kg/400000g`0Kg]_N`1EKg/4O005Kg/4O008
Kg/2O00YKg/002I_N`@000m_N`9l03a_N`Al00P0009l00Y_N`@001Q_N`@0011_N`@000Q_N`@000Y_
N`03001_Nfmk00]_N`9l01=_N`@000]_N`03O0000000008000A_N`@000e_N`9l04Y_N`9l00I_N`Al
00M_N`Al02Q_N`009fmk0P00CVmk17`000=_N`0000000Vmk0P000g`02Fmk0W`00P004fmk0W`01Fmk
0P004Vmk0P002Fmk00Al0000001l00Y_N`04001_Ng`0O00OKg/017`0000007`03Fmk0P001Vmk0P00
3Fmk17`0DVmk0W`026mk17`0:6mk000UKg/20002Kg/2001=Kg/2O008Kg/2O00:Kg/4O00BKg/2O002
000SKg/4O00:Kg/01@00O0000000O0005Fmk0P000Vmk0P0016mk0W`00P004Vmk0P001Vmk0P001fmk
0g`00P00G6mk0W`0:Fmk000TKg/8000HKg/2O019Kg/2O00CKg/00g`000000002000SKg/2O00;Kg/5
000DKg/80004Kg/4000@Kg/40004Kg/40002O005Kg/00g`0000000020009Kg/2O01kKg/002A_N`P0
01M_N`Al05i_N`@0031_N`D000m_N`9l009_N`03O000000000H000A_N`@00003O01_Nfmk00e_N`@0
00A_N`@000=l00E_N`@000Q_N`Al07Y_N`007Vmk0W`01Fmk0P000Vmk0P001Fmk0W`04Fmk0P000W`0
Gfmk10008Vmk0P002fmk00@006mk000000m_N`05O0000000O01_N`02O0020002O0020006Kg/20002
O00>Kg/400000g`0Kg]_N`03Kg/20004O006Kg/20008Kg/20003O01jKg/001e_N`Al00i_N`Al00m_
N`@0065_N`@0021_N`@000Y_N`03001_Nfmk00]_N`9l00=_N`@0009_N`9l009_N`9l00Q_N`9l00i_
N`@0009l00Q_N`9l011_N`@00003O01_Nfmk07U_N`007Fmk17`03Vmk17`03fmk1000HFmk100000=l
06mkKg/04fmk0W`026mk10001fmk0W`000A_N`00000000I_N`9l009_N`Al009_N`@0021_N`@00003
O01_Nfmk01U_N`@007a_N`007Vmk0W`046mk0W`04Fmk0P00Hfmk0P000W`056mk17`026mk0P001fmk
17`000<006mkKg/01Fmk17`000=_Ng`0O0000W`00fmk0P008Vmk0P007Vmk0P00OFmk000UKg/2001d
Kg/2O00<Kg/2O00EKg/2O002000AKg/2O0030007Kg/2O0020002Kg/2000JKg/2000;Kg/2O00QKg/2
0003Kg/2O01fKg/002A_N`@0079_N`Al02=_N`@0015_N`@000Q_N`P001Q_N`@000U_N`Al01m_N`@0
0003Kg]l07`0009l07E_N`0096mk1000>Fmk0W`02Vmk0W`0:fmk17`08fmk10004Fmk100026mk2000
66mk10002Fmk17`07fmk100000=_Ng`0O0000W`0MFmk000UKg/2000iKg/4O003Kg/20002Kg/20003
O00[Kg/00g`00000000:Kg/20002O00FKg/2000;Kg/00g`000000005Kg/40002Kg/20002O002Kg/2
0002Kg/4000HKg/2000;Kg/2O00QKg/20003Kg/2O01fKg/004U_N`9l01E_N`Al009_N`P0009l02]_
N`@000Q_N`@0009l01Y_N`9l00E_N`03O0000000008000A_N`03O000000000H0009l00I_N`@003M_
N`9l08]_N`00B6mk17`05Fmk0W`00fmk200000=l06mkKg/0:Vmk100026mk10000W`06Fmk17`016mk
00=l000000000P0016mk00=l000000001P000W`01Vmk1000=Vmk17`0RVmk000SKg/2O00SKg/4O00K
Kg/20002Kg/2000IKg/2O00DKg/2000:Kg/20002O00JKg/4O005Kg/00g`000000006Kg/00g`00000
0002Kg/20002O007Kg/017`0000007`03Fmk0W`09fmk17`0RVmk000RKg/4O00SKg/2000WKg/2000>
Kg/200000fmkO01l0002O00mKg/200000g`0Kg]_N`0>Kg/01000Kg/000002Vmk0P000W`01fmk00=l
000000000Vmk0P000g`09fmk0W`00Vmk0P000Vmk0P00Pfmk000RKg/4O00RKg/4000UKg/4000<Kg/4
0004O00:Kg/2O00`Kg/4000@Kg/50008Kg/40007Kg/00g`0000000060002O00ZKg/80022Kg/002=_
N`9l02=_N`@002E_N`@000a_N`@00003Kg]l07`000Y_N`Al02m_N`@0011_N`D000Q_N`@000M_N`03
O000000000H00003O01_Nfmk02U_N`P0089_N`00BFmk0P009fmk0P0026mk0P0000Al06mkKg]_N`80
00i_N`Al009_N`80009_N`800003Kg]l07`000M_N`8001U_N`03O0000000008000Q_N`8000M_N`04
001_N`00000:Kg/20009Kg/00g`000000002Kg/2000^Kg/20002Kg/40021Kg/007]_N`@00003O01_
Nfmk015_N`9l009_N`P000=l00E_N`@000]_N`9l00Y_N`03O0000000008000Q_N`@000I_N`03001l
07`0009l00U_N`9l01e_N`9l00a_N`9l01I_N`@0081_N`00Nfmk100000=l06mkKg/05Fmk20000g`0
1Fmk100000=l06mkKg/01fmk17`02Fmk00=l000000000P0026mk10001Vmk00<007`0O0000W`026mk
17`06fmk17`02Vmk17`05Fmk1000P6mk001lKg/200000g`0Kg]_N`0GKg/20002Kg/200000fmkO01l
0007Kg/20002O009Kg/4O00:Kg/00g`00000000:Kg/20002O005Kg/01000Kg]l07`02Fmk17`06fmk
17`02Vmk17`05Vmk0P0016mk0W`0Nfmk002JKg/2000=Kg/2O00;Kg/2000>Kg/20008Kg/4O005Kg/0
0`00Kg]_N`0;Kg/2O00MKg/00g`00000000;Kg/2O0000fmk00000009Kg/00g`00000000=Kg/4O01j
Kg/009U_N`@001Q_N`@000a_N`@000Q_N`9l00I_N`03001_Nfmk02Y_N`@000a_N`@000M_N`03O000
0000008000a_N`Al07Y_N`00VFmk10004Fmk0W`01Fmk100036mk100046mk00<006mkKg/0:Vmk1000
36mk10001fmk00=l000000000P003Fmk0W`0Nfmk000OKg/2000ZKg/2000[Kg/2000PKg/200000g`0
Kg]_N`0>Kg/4O005Kg/2000>Kg/20002O00?Kg/00`00Kg]_N`0[Kg/2000>Kg/20004Kg/20003Kg/0
0g`00000002;Kg/001i_N`@002Q_N`@002U_N`@001m_N`Al00m_N`Al01E_N`Al00m_N`<0041_N`@0
091_N`007Vmk10009fmk00=l000000000P00:Fmk10005Fmk0W`026mk17`046mk0W`036mk0W`02Fmk
0W`046mk00<006mkKg/05Fmk0W`0:Fmk1000T6mk000OKg/2000WKg/3O002000[Kg/2000EKg/4O008
Kg/2O00NKg/4O00JKg/00`00Kg]_N`0DKg/4O00WKg/2O002002AKg/001e_N`9l02U_N`Al00U_N`80
021_N`Al01A_N`=l008001i_N`8000I_N`8000=l01Y_N`03001_Nfmk01A_N`=l008002I_N`Al00a_
N`8008=_N`0076mk17`0:Fmk0W`02Fmk10007fmk17`05Fmk00=l000000000P0076mk100016mk1000
00=l06mkKg/06Fmk00<006mkKg/05Fmk00=l000000000P009Vmk0W`036mk1000PVmk000LKg/4O00d
Kg/400000fmkO01l000MKg/2O00GKg/4000LKg/40004Kg/4000LKg/00`00Kg]_N`0FKg/4000dKg/4
00000g`0Kg]_N`0KKg/2O01RKg/001e_N`9l03I_N`800003Kg]l07`0009l02a_N`9l00Q_N`8001i_
N`8000A_N`@000A_N`8001M_N`03001_Nfmk009l01E_N`@0011_N`9l0080009_N`80009l01Y_N`80
00=l01]_N`=l0080061_N`00F6mk17`0:fmk17`0;6mk100016mk100000=_Ng`0O0003Fmk0W`016mk
00<006mkO0000g`05Fmk10003Vmk0W`020000W`06Vmk17`06fmk0W`01000Gfmk001IKg/2O00/Kg/4
O00@Kg/2O00JKg/40004Kg/40004O006Kg/2O003Kg/4O003Kg/00`00Kg]l0003O00EKg/4000>Kg/2
O0080002O00KKg/2O00MKg/00g`000000002001OKg/008Q_N`9l011_N`Al01U_N`04O0000000O005
Kg/200000fmkO01l0002O005Kg/4O002Kg/4O003Kg/00`00Kg]_N`02O00GKg/2000@Kg/2O0020002
Kg/20002O00mKg/20015Kg/2O00IKg/008i_N`8000I_N`80009_N`Al011_N`80009_N`80009_N`80
009l00Y_N`9l00I_N`9l0080009_N`800003O01_Nfmk009_N`04001_N`00000JKg/2001nKg/2O00K
Kg/20002O00HKg/006I_N`9l02E_N`@000A_N`@0009_N`9l00e_N`9l0003Kg/0000000X001A_N`P0
00A_N`D000I_N`9l011_N`@007a_N`Al01U_N`@00003O01_Nfmk01I_N`00IFmk17`096mk100016mk
100046mk17`0300056mk200016mk1@001Fmk17`03fmk10007Fmk0W`0AFmk0W`05Vmk17`06Fmk1000
6Fmk001UKg/2O002000UKg/20004Kg/4000AKg/4O0001Fmk000006mkO0000P0000Al06mk000001I_
N`80009_N`80009_N`9l0003Kg/00000008000A_N`8000Al00m_N`04O0000000O00KKg/20003O013
Kg/017`0000007`05Fmk0P0000=l06mkKg/06Fmk0P006Vmk0014Kg/2O00PKg/4000YKg/400000g`0
Kg]_N`0@Kg/2O006Kg/2O003Kg/2O00LKg/3O0040004Kg/40002O00AKg/2O00KKg/40002O013Kg/4
000DKg/4000gKg/004=_N`Al01m_N`@001U_N`9l00i_N`@001m_N`Al01]_N`=l00@000A_N`@0031_
N`@00003O01_Nfmk049_N`@001A_N`@003M_N`00@fmk17`086mk0P006Fmk17`03Vmk0P0086mk17`0
3fmk0W`000=_N`000000100016mk0W`000=_N`0000001Vmk0P007fmk0W`04Fmk0P00Afmk0P005Vmk
0P00>6mk0014Kg/2O00lKg/4O002000:Kg/2000SKg/2O00?Kg/2O0030004Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`0UKg/2O002000dKg/2O01eKg/008=_N`9l00@000Q_N`@003=_N`03O000000000<000]_
N`03001_Nfmk02E_N`03O0000000008002U_N`9l00M_N`Al07A_N`00N6mk0W`02fmk10001fmk00=l
000000000P00=6mk100000=_N`00Kg/02Fmk00<006mkKg/01Fmk0W`07fmk1000:6mk17`01Vmk17`0
M6mk001gKg/017`0000007`02fmk0P0026mk0W`00P0016mk0P00<6mk0P000fmk00<006mkKg/01fmk
10000fmk00Al0000001l01m_N`80011_N`8001M_N`=l0080009_N`80009_N`9l07E_N`00Mfmk1000
5Vmk0W`016mk1000:6mk0W`02fmk00<006mkKg/01Vmk00<006mkKg/016mk1000<6mk100000=l06mk
Kg/056mk00=l000000001P00N6mk001gKg/4000LKg/4000WKg/4O006Kg/01000Kg]_Nfmk0W`01fmk
00<006mkKg/016mk10000fmk0W`04Vmk0W`05fmk10000W`05Vmk2000N6mk001hKg/2000NKg/2000G
Kg/2O00?Kg/4O006Kg/00`00Kg]_N`04O006Kg/00`00Kg]_N`05Kg/20003Kg/4O00@Kg/4O00GKg/2
0003O00GKg/20002Kg/2001iKg/0045_N`8005]_N`9l011_N`Al00m_N`9l0003Kg/0000000E_N`<0
00=l00I_N`04001l00000009Kg/017`0000007`046mk00Al0000001l00U_N`800003O01_Nfmk00]_
N`9l09M_N`00@6mk10009fmk0W`0<6mk17`03fmk17`02Fmk0W`01Vmk100016mk100000=l06mkKg/0
1Fmk00=l000000000P0026mk100046mk100026mk100000=l06mkKg/0Xfmk0010Kg/4000VKg/4O00_
Kg/4O00@Kg/2O009Kg/4O005Kg/40003Kg/00g`0000000020008Kg/00g`0000000020008Kg/4000@
Kg/40008Kg/400000g`0Kg]_N`0mKg/2O01TKg/0025_N`9l00A_N`8001Q_N`8002M_N`04O0000000
O00RKg/2000<Kg/2O00@Kg/2000:Kg/20002O006Kg/20003Kg/00g`0000000020009Kg/01000O000
00002Vmk0P0016mk0P000Vmk0P001Vmk10002Vmk0P0000=l06mkKg/08Fmk0P005fmk0P0000=_Ng`0
O0000W`0Hfmk000PKg/4O002Kg/40010Kg/4000QKg/4000LKg/40008Kg/4000<Kg/4000:Kg/00`00
Kg]_N`0@Kg/80004Kg/4000`Kg/4000EKg/40004O01SKg/0021_N`Al009_N`@0041_N`@0025_N`@0
01a_N`@000Q_N`@000a_N`@000Y_N`03001_Nfmk011_N`P000=_N`03O00000000080031_N`@001E_
N`@00003Kg]l07`006A_N`008Fmk0W`016mk0P00@Vmk0P0056mk0W`03Fmk0P007Vmk0P002Vmk0P00
3Vmk0P002fmk00<006mkKg/04Fmk0P000Vmk0P0016mk0W`00P00;Fmk0W`00fmk0P005fmk0P0086mk
0W`0AVmk000dKg/2O003Kg/20015Kg/2O002000;Kg/4O00>Kg/2O00SKg/2000:Kg/20005Kg/00`00
Kg]_N`07Kg/2000CKg/2O00EKg/2000FKg/4O00EKg/2000UKg/4O015Kg/003=_N`Al0003Kg/00000
008002]_N`9l01M_N`03O0000000008000Y_N`Al00e_N`Al025_N`@000Q_N`@0009l009_N`03001_
Nfmk00I_N`@002Q_N`@001E_N`Al01A_N`@002A_N`Al04E_N`00<fmk17`000=_N`0000000P00:Vmk
17`05fmk10002fmk0W`03Vmk17`036mk0W`04fmk100026mk10000g`000=_N`00Kg/01fmk1000:6mk
10005Vmk0W`05Fmk10009Fmk0W`0AVmk000dKg/2O003Kg/20004Kg/2000UKg/4O00HKg/2000MKg/2
O0000fmk00000009Kg/017`0000007`04Fmk0W`00P0026mk100017`000=_N`00Kg/026mk0P00:Vmk
0P0000=l06mkKg/0:fmk00Al0000001l02M_N`8004A_N`00?Vmk10004fmk0W`046mk0W`0>Vmk1000
26mk100046mk17`026mk10000Vmk0W`00Vmk00<006mkKg/0<fmk17`0;Fmk0W`09fmk1000@fmk000n
Kg/4000BKg/4O01;Kg/40008Kg/4000@Kg/4O008Kg/40006Kg/00`00Kg]_N`06Kg/2O00[Kg/4O01F
Kg/40013Kg/003m_N`8001=_N`Al04a_N`8000Y_N`80019_N`9l00Y_N`8000M_N`03001_Nfmk00E_
N`Al02]_N`9l04I_N`9l011_N`8004A_N`00EFmk0P003Vmk0P00@fmk0P001Vmk0P007Vmk0W`01Fmk
00<006mkKg/01Fmk17`05Vmk0P00FVmk17`01Fmk0P006Vmk0P001Fmk0W`0:fmk0011Kg/2O00AKg/4
000<Kg/4000XKg/2O00GKg/40004Kg/4000LKg/4O004Kg/00`00Kg]_N`06Kg/2O00FKg/4001IKg/4
O004Kg/4000HKg/40003Kg/4O00ZKg/0041_N`Al011_N`@000a_N`@002M_N`Al01E_N`03O0000000
008000A_N`@0009l01Y_N`Al00A_N`<001i_N`@005Y_N`9l00E_N`@001Q_N`@000=_N`Al02Y_N`00
@6mk17`00fmk0P0036mk0P003Vmk0P00:6mk00Al0000001l015_N`80009_N`9l008000I_N`8000Al
01Y_N`9l00E_N`03001_Nfmk01m_N`8006=_N`8000a_N`8000a_N`8000E_N`9l02]_N`00@Fmk0W`0
0fmk10007fmk0W`096mk100046mk10000Vmk0W`02Fmk17`08Fmk00<006mkKg/0TFmk1000?fmk0016
Kg/4000NKg/4O00SKg/4000@Kg/4000>Kg/2O00RKg/00`00Kg]_N`2AKg/4000oKg/004M_N`8001m_
N`Al02A_N`80011_N`9l008002Y_N`9l00M_N`03001_Nfmk099_N`80041_N`00JFmk0P003fmk0P00
0W`096mk17`05Vmk0W`04Fmk17`01Vmk00<006mkKg/0Dfmk0P00@6mk0W`0?Fmk0016Kg/2O00PKg/4
000=Kg/40002O00TKg/2O00FKg/4O00@Kg/4O006Kg/00`00Kg]_N`1BKg/4000nKg/4O00lKg/004E_
N`Al01m_N`@000e_N`@0009l01M_N`9l02=_N`Al015_N`9l00M_N`03001_Nfmk059_N`@003i_N`Al
03a_N`00AFmk17`086mk0P001Fmk0P0026mk0P000W`02Vmk0P002Vmk0P000g`08fmk0P004Vmk0P00
1fmk00<006mkKg/09Fmk0P000Vmk0W`06Vmk0P0036mk0P002Vmk0W`0=6mk0W`0?Fmk0016Kg/2O00W
Kg/40002O00>Kg/2O002Kg/40008Kg/40002O00RKg/4000@Kg/40006Kg/00`00Kg]_N`0TKg/40004
O00GKg/00g`000000002000FKg/4O01bKg/005a_N`9l015_N`@000=l00a_N`Al0003Kg/000000080
00Q_N`@00003O01_Nfmk025_N`@0011_N`@000I_N`03001_Nfmk00Q_N`9l01Y_N`@000Al01I_N`9l
00@001I_N`Al079_N`00Ffmk17`04Fmk0P0017`036mk17`00Vmk0P002Vmk0P009Vmk0P000W`046mk
0P0000=_Ng`0O00016mk00<006mkKg/01fmk17`06Vmk0P000Vmk0W`05fmk0g`00P0066mk0W`0Lfmk
001IKg/20004O002Kg/2000@Kg/2O00>Kg/2O00hKg/017`0000007`04Fmk0P000W`00fmk00<006mk
Kg/00fmk0P000Vmk17`056mk0P008Vmk0W`06Vmk0P00Lfmk001AKg/2O005Kg/40002O002Kg/4001I
Kg/4000@Kg/400001G`0Kg]_Nfmk000016mk10000Vmk0W`056mk1000?6mk1000LVmk001@Kg/4O004
Kg/40004Kg/4001IKg/4000@Kg/40004Kg/00`00Kg]_N`02Kg/4000HKg/4000lKg/4001bKg/0051_
N`Al00E_N`8000I_N`@0009_N`8002]_N`80011_N`9l008001A_N`8000Y_N`9l00I_N`8000E_N`03
001_Nfmk00=_N`8001M_N`9l0003Kg/0000003i_N`800004Kg/00000O01_Kg/0055_N`9l00m_N`P0
02U_N`@000i_N`9l00@001i_N`Al00a_N`03001_Nfmk01]_N`Al049_N`@00003O01_Nfmk06a_N`00
HVmk2000:Fmk10003Vmk0W`010007Vmk17`036mk00<006mkKg/06fmk17`0@Vmk100000=l06mkKg/0
K6mk001SKg/20002Kg/2000[Kg/20002O00>Kg/2O002000PKg/2O00=Kg/00`00Kg]_N`0LKg/2O014
Kg/200000g`0Kg]_N`1]Kg/006I_N`Al00E_N`9l02A_N`Al035_N`8000e_N`03001_Nfmk08Q_N`80
04Y_N`00IVmk17`016mk17`08fmk17`03fmk0W`07fmk100036mk0`00Qfmk1000BFmk001WKg/2O005
Kg/4O00TKg/2O00?Kg/4O00NKg/4000<Kg/00`00Kg]_N`27Kg/40019Kg/006m_N`9l03I_N`Al0003
Kg/0000000I_N`80009_N`9l00Y_N`8000A_N`8000e_N`8008U_N`8004Y_N`00Z6mk0W`000=_N`00
00000P0016mk100017`026mk10004Fmk1000Qfmk0W`0Bfmk002[Kg/40004Kg/40004O008Kg/4000A
Kg/400000fmkO01l0023Kg/4O01:Kg/00:a_N`8000I_N`80009_N`9l00U_N`04O0000000O00BKg/2
00000fmkO01l0002O022Kg/4O01:Kg/005e_N`8005=_N`80011_N`9l01=_N`03001_Nfmk00Al08=_
N`9l04]_N`00FFmk0W`000=_N`0000000P00DFmk100096mk00@006mkKg]_N`9l0=5_N`00F6mk17`0
1000DFmk100096mk00<006mkKg/0e6mk001HKg/4O0000fmk0000000]Kg/20002O00QKg/017`00000
07`04fmk0P000Vmk0P002fmk00<006mkKg/0HVmk0P00L6mk001IKg/2O00`Kg/40002O00PKg/4O00B
Kg/800000g`0Kg]_N`07Kg/00`00Kg]_N`1QKg/4001_Kg/007a_N`9l00e_N`@0009l025_N`9l01=_
N`P0009l00Q_N`03001_Nfmk05m_N`9l00@006m_N`00EVmk0W`08fmk17`03Fmk0P000W`0=Fmk0W`0
00=_N`0000000Vmk0P000g`026mk00<006mkKg/0GVmk17`00P00L6mk001EKg/4O00RKg/3O0020014
Kg/4O006Kg/2O009Kg/00`00Kg]_N`1NKg/4O01bKg/005E_N`Al02=_N`03O0000000008004=_N`Al
015_N`03001_Nfmk05m_N`9l00Q_N`9l06U_N`00EVmk0W`09Fmk1000A6mk0W`04Vmk00<006mkKg/0
J6mk17`0J6mk001KKg/2000QKg/2001IKg/00`00Kg]_N`0XKg/2O00HKg/2O00TKg/2O002001XKg/0
05Y_N`@007]_N`03001_Nfmk00e_N`9l01Q_N`Al01I_N`Al02A_N`@006M_N`00FVmk1000Nfmk00<0
06mkKg/036mk17`05fmk17`05Vmk17`096mk10001Vmk0W`0Gfmk001KKg/20011Kg/2O00iKg/00`00
Kg]_N`0<Kg/4O00HKg/2O00HKg/2O00VKg/20006Kg/4O01NKg/006E_N`80009_N`9l039_N`Al00E_
N`80009_N`80009l02A_N`8000E_N`<000e_N`9l01Q_N`8001Y_N`8002]_N`8000Al05i_N`00I6mk
100017`0<Fmk17`016mk20000W`08Vmk100016mk00<006mkKg/09Vmk100066mk1000:Fmk10000W`0
Gfmk001TKg/40004O00bKg/2O005Kg/80002O00RKg/40002O002Kg/00`00Kg]_N`0VKg/4000HKg/4
000YKg/4001QKg/006E_N`80009_N`9l03]_N`80009_N`80009l02A_N`8000Al0003Kg/006mk00i_
N`8001Q_N`8001Y_N`8002]_N`80069_N`00e6mk17`000=_N`00Kg/03Fmk1000a6mk002lKg/2O00G
Kg/2O002Kg/00`00Kg]_N`0<Kg/40034Kg/00;]_N`Al01Y_N`03001_Nfmk00e_N`800<E_N`00EFmk
0P003Vmk0P00Afmk0P002fmk0g`00P006Fmk00<006mkKg/0e6mk001DKg/4000<Kg/4000EKg/2O00^
Kg/4000;Kg/00g`000000002000HKg/00`00Kg]_N`3DKg/005A_N`@000a_N`@001A_N`Al02e_N`@0
00a_N`@001Q_N`03001_Nfmk0=A_N`00Cfmk0W`016mk0P003Vmk0P005Fmk17`00P00;6mk0P003Vmk
0P006Fmk00<006mkKg/02Fmk0P002Vmk0P00?Vmk0P00OFmk001>Kg/4O00[Kg/2O004001FKg/00`00
Kg]_N`08Kg/40008Kg/40002O00jKg/4001lKg/004i_N`Al01Q_N`9l01=_N`@000e_N`9l04M_N`03
001_Nfmk00Q_N`@000Q_N`@000=l03U_N`@007a_N`00Cfmk0W`066mk17`04fmk0P0026mk0P000fmk
17`07Fmk0W`066mk0P003Fmk00<006mkKg/016mk0W`00fmk0P002Vmk0P0017`046mk0P00:6mk0P00
0W`06fmk0P00GVmk001YKg/4O00LKg/40002Kg/4O00LKg/4O00FKg/40002O00:Kg/00`00Kg]_N`03
Kg/4O00AKg/2O00@Kg/4000WKg/4O00JKg/4001MKg/006Y_N`9l01e_N`@000=_N`9l01e_N`Al01I_
N`@000=l00U_N`03001_Nfmk00=_N`Al02=_N`@002Q_N`9l01]_N`@005e_N`00RVmk0P0096mk0W`0
66mk0P0017`02Fmk00<006mkKg/016mk0W`09Fmk0P00Afmk0P00GVmk003=Kg/2O0030007Kg/00`00
Kg]_N`0ZKg/4O02VKg/00=1_N`03001_Nfmk00I_N`03001_Nfmk02Y_N`Al0:I_N`00d6mk00<006mk
Kg/01Vmk00<006mkKg/0:fmk0W`0Yfmk0026Kg/20014Kg/60007Kg/00`00Kg]_N`0oKg/2000fKg/2
O01KKg/008E_N`@004A_N`04001_Nfmk0008Kg/4000mKg/4000dKg/4O01JKg/008E_N`@004A_N`04
001_Nfmk0008Kg/00`00Kg]_N`0nKg/4000dKg/4O01JKg/008I_N`8004I_N`03001_N`0000Q_N`03
001_Nfmk03i_N`04O0000000O00eKg/2O01KKg/00<A_N`8000Q_N`03001_N`0000Q_N`03001_Nfmk
01E_N`9l02Q_N`9l09=_N`00`fmk100026mk0P0026mk00<006mkKg/056mk17`0_6mk0033Kg/4000B
Kg/00`00Kg]_N`0DKg/4O02lKg/006i_N`8005A_N`8001=_N`03001_Nfmk01E_N`9l0;e_N`00KFmk
10005Vmk0W`0D6mk00<006mkKg/0e6mk001]Kg/4000EKg/4O00jKg/2O00CKg/00`00Kg]_N`3DKg/0
06i_N`8001I_N`Al03U_N`Al019_N`03001_Nfmk0=A_N`00Qfmk0W`0>Vmk17`04Vmk00<006mkKg/0
5Fmk0P00_Fmk001/Kg/2O01FKg/2O00CKg/00`00Kg]_N`0DKg/4002lKg/006]_N`Al06Y_N`03001_
Nfmk01A_N`@00;a_N`00Jfmk17`0JVmk00<006mkKg/05Fmk0P00_Fmk001/Kg/2O01[Kg/00`00Kg]_
N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/05Fmk0W`0_Fmk003IKg/00`00Kg]_N`0D
Kg/017`0000007`0:Fmk0P00TFmk003IKg/00`00Kg]_N`0DKg/4000XKg/4002@Kg/00=U_N`04001_
Ng`0O00CKg/4000XKg/4002@Kg/00=U_N`03001l07`0009l01=_N`8002Y_N`800003O01_Nfmk08i_
N`00fFmk00<007`0O0000W`0?fmk17`0Sfmk003IKg/01000Kg]l07`0@6mk17`0Sfmk003IKg/00`00
Kg]_N`12Kg/2O02@Kg/00=U_N`03001_Nfmk01U_N`800;U_N`00fFmk00<006mkKg/066mk10001Vmk
0W`0/6mk003IKg/00`00Kg]_N`0HKg/40005Kg/4O02_Kg/00:9_N`8003E_N`03001_Nfmk00M_N`80
011_N`8000I_N`Al0:m_N`00XFmk1000=6mk00<006mkKg/01Vmk100066mk0W`0/6mk002QKg/4000d
Kg/00`00Kg]_N`06Kg/4003:Kg/00:9_N`8003E_N`03001_Nfmk00M_N`800<]_N`00fFmk00<006mk
Kg/02Fmk0P00bFmk003IKg/00`00Kg]_N`08Kg/40038Kg/00=U_N`03001_Nfmk00M_N`03O0000000
00800<Q_N`00fFmk00<006mkKg/01fmk100046mk0P00]fmk003IKg/00`00Kg]_N`06Kg/4000@Kg/4
002fKg/00=U_N`03001_Nfmk00I_N`@0011_N`@00;I_N`00fFmk00<006mkKg/01fmk0P004Vmk0P00
]fmk003@Kg/20007Kg/00`00Kg]_N`3DKg/00<m_N`@000I_N`03001_Nfmk0=A_N`00bfmk0W`00Vmk
10001Vmk0`008Vmk0W`0/6mk003:Kg/4O002Kg/20007Kg/00`00Kg]_N`0QKg/4O02_Kg/00<Y_N`Al
00]_N`03001_Nfmk025_N`Al0:m_N`00bfmk0W`036mk00<006mkKg/08Vmk0W`0/6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk00A_N`9l0<i_N`00fFmk00<006mkKg/00fmk17`0cFmk003IKg/0
0`00Kg]_N`03Kg/4O03=Kg/00=U_N`03001_Nfmk00A_N`9l0<i_N`00fFmk00<006mkKg/0e6mk003I
Kg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_
N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {432.125, 0}} -> {-5.38918, -5.29211, \
0.0371388, 0.0371388}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
All these efforts up till now only moves meshpoints for one step. In order to \
go further, we need to define a function by wrapping up those temporary \
variables inside.\
\>", "Text"],

Cell[BoxData[
    \(forcemove[p_] := 
      Module[{t, bars, l0, F, Fvec, forcematrix, dp}, \[IndentingNewLine]t = 
          DelaunayTriangulation[p]; \[IndentingNewLine] (*\ 
          select\ only\ interia\ meshbars\ *) \[IndentingNewLine]bars = 
          Select[meshbar[t], d[middlepoint[p, #]] < 0 &]; 
        l0 = With[{Fscale = 1.2}, 
            Fscale\ \[Times]\ 
              scale[\(h[middlepoint[p, #]] &\) /@ bars, \ {p, bars}]]; 
        F = \(Max[#, 
                0] &\) /@ \((l0 - \((\(barlength[p, #] &\) /@ bars)\))\); 
        Fvec = F \((\(Subtract @@ p[\([#]\)]\/barlength[p, #] &\) /@ 
                bars)\); \[IndentingNewLine]forcematrix = \(SparseArray[#, \
{Length[p], Length[p]}] &\)@\((MapThread[ForceRule, {bars, Fvec}] // 
                Flatten[#, 1] &)\); \[IndentingNewLine]dp = 
          With[{deltat = 0.2}, 
            deltat\ \[Times]\ 
              Table[Plus @@ \((ReleaseHold /@ forcematrix[\([i]\)])\), {i, 
                  Length[p]}]]; \[IndentingNewLine]Return[
          p + dp]\[IndentingNewLine]]\)], "Input",
  CellLabel->"In[60]:="],

Cell["Now we can try more iterations.", "Text"],

Cell[BoxData[{
    \(\(d[{x_, y_}] := 
        dcircle[{x, y}, {0, 0, 2}];\)\), "\[IndentingNewLine]", 
    \(\(h[{x_, y_}] := 
        0.1 + 0.1 \@\( x\^2 + y\^2\);\)\), "\[IndentingNewLine]", 
    \(pts = selectMeshpoints[d, \ {\(-10\), \(-10\), 10, 10}, 0.1]; 
    values = scale[\((\(1\/h[#]\^2 &\) /@ pts)\)];\), "\n", 
    \(\(p2 = 
        Extract[pts, \ 
          Position[
            values, \ _?\((# > Random[] &)\)]];\)\), "\[IndentingNewLine]", 
    \(\(pp2 = Nest[forcemove, p2, 10];\)\)}], "Input",
  CellLabel->"In[101]:="],

Cell["So after 10 iterations, the result is quite good already. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[pp2, AspectRatio \[Rule] Automatic, \ 
      PlotStyle \[Rule] {PointSize[0.01], RGBColor[1, 0, 0]}]\)], "Input",
  CellLabel->"In[106]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99351 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.505309 0.227465 0.479557 0.227465 [
[.05038 .46706 -6 -9 ]
[.05038 .46706 6 0 ]
[.27784 .46706 -6 -9 ]
[.27784 .46706 6 0 ]
[.73277 .46706 -3 -9 ]
[.73277 .46706 3 0 ]
[.96024 .46706 -3 -9 ]
[.96024 .46706 3 0 ]
[.49281 .02463 -12 -4.5 ]
[.49281 .02463 0 4.5 ]
[.49281 .25209 -12 -4.5 ]
[.49281 .25209 0 4.5 ]
[.49281 .70702 -6 -4.5 ]
[.49281 .70702 0 4.5 ]
[.49281 .93449 -6 -4.5 ]
[.49281 .93449 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99351 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05038 .47956 m
.05038 .48581 L
s
[(-2)] .05038 .46706 0 1 Mshowa
.27784 .47956 m
.27784 .48581 L
s
[(-1)] .27784 .46706 0 1 Mshowa
.73277 .47956 m
.73277 .48581 L
s
[(1)] .73277 .46706 0 1 Mshowa
.96024 .47956 m
.96024 .48581 L
s
[(2)] .96024 .46706 0 1 Mshowa
.125 Mabswid
.09587 .47956 m
.09587 .48331 L
s
.14137 .47956 m
.14137 .48331 L
s
.18686 .47956 m
.18686 .48331 L
s
.23235 .47956 m
.23235 .48331 L
s
.32334 .47956 m
.32334 .48331 L
s
.36883 .47956 m
.36883 .48331 L
s
.41432 .47956 m
.41432 .48331 L
s
.45982 .47956 m
.45982 .48331 L
s
.5508 .47956 m
.5508 .48331 L
s
.59629 .47956 m
.59629 .48331 L
s
.64179 .47956 m
.64179 .48331 L
s
.68728 .47956 m
.68728 .48331 L
s
.77827 .47956 m
.77827 .48331 L
s
.82376 .47956 m
.82376 .48331 L
s
.86925 .47956 m
.86925 .48331 L
s
.91475 .47956 m
.91475 .48331 L
s
.00489 .47956 m
.00489 .48331 L
s
.25 Mabswid
0 .47956 m
1 .47956 L
s
.50531 .02463 m
.51156 .02463 L
s
[(-2)] .49281 .02463 1 0 Mshowa
.50531 .25209 m
.51156 .25209 L
s
[(-1)] .49281 .25209 1 0 Mshowa
.50531 .70702 m
.51156 .70702 L
s
[(1)] .49281 .70702 1 0 Mshowa
.50531 .93449 m
.51156 .93449 L
s
[(2)] .49281 .93449 1 0 Mshowa
.125 Mabswid
.50531 .07012 m
.50906 .07012 L
s
.50531 .11561 m
.50906 .11561 L
s
.50531 .16111 m
.50906 .16111 L
s
.50531 .2066 m
.50906 .2066 L
s
.50531 .29759 m
.50906 .29759 L
s
.50531 .34308 m
.50906 .34308 L
s
.50531 .38857 m
.50906 .38857 L
s
.50531 .43406 m
.50906 .43406 L
s
.50531 .52505 m
.50906 .52505 L
s
.50531 .57054 m
.50906 .57054 L
s
.50531 .61604 m
.50906 .61604 L
s
.50531 .66153 m
.50906 .66153 L
s
.50531 .75251 m
.50906 .75251 L
s
.50531 .79801 m
.50906 .79801 L
s
.50531 .8435 m
.50906 .8435 L
s
.50531 .88899 m
.50906 .88899 L
s
.50531 .97998 m
.50906 .97998 L
s
.25 Mabswid
.50531 0 m
.50531 .99351 L
s
0 0 m
1 0 L
1 .99351 L
0 .99351 L
closepath
clip
newpath
1 0 0 r
.01 w
.62819 .03028 Mdot
.3921 .02365 Mdot
.47262 .03992 Mdot
.54579 .04991 Mdot
.32226 .03848 Mdot
.68439 .04411 Mdot
.22619 .08251 Mdot
.2593 .0697 Mdot
.34451 .11039 Mdot
.40495 .09986 Mdot
.47661 .11011 Mdot
.58128 .10949 Mdot
.71215 .10982 Mdot
.82104 .1027 Mdot
.18915 .13617 Mdot
.28785 .14128 Mdot
.42409 .15447 Mdot
.63759 .12694 Mdot
.24562 .18186 Mdot
.54111 .14837 Mdot
.58952 .19002 Mdot
.75115 .1485 Mdot
.34986 .1685 Mdot
.48893 .16494 Mdot
.53334 .2052 Mdot
.67717 .17382 Mdot
.70021 .22113 Mdot
.76888 .1892 Mdot
.85149 .16428 Mdot
.33438 .21957 Mdot
.39188 .18891 Mdot
.44788 .20204 Mdot
.63425 .21267 Mdot
.11073 .19057 Mdot
.29555 .21253 Mdot
.36913 .23523 Mdot
.41458 .23991 Mdot
.48616 .22358 Mdot
.79129 .22833 Mdot
.17996 .22442 Mdot
.2302 .24103 Mdot
.27954 .2569 Mdot
.45183 .25815 Mdot
.51092 .2588 Mdot
.63806 .26483 Mdot
.90426 .22885 Mdot
.32167 .27629 Mdot
.36497 .27357 Mdot
.48786 .28006 Mdot
.55453 .24398 Mdot
.73929 .25487 Mdot
.83342 .25094 Mdot
.18511 .30434 Mdot
.40069 .28551 Mdot
.43952 .29313 Mdot
.55066 .28801 Mdot
.59472 .2581 Mdot
.68138 .27645 Mdot
.73858 .29914 Mdot
.79121 .30022 Mdot
.12247 .26911 Mdot
.23348 .2948 Mdot
.28793 .30679 Mdot
.34381 .31341 Mdot
.39778 .31808 Mdot
.48621 .30714 Mdot
.5303 .30831 Mdot
.58276 .30718 Mdot
.61618 .31509 Mdot
.64672 .32115 Mdot
.1107 .33329 Mdot
.28326 .33645 Mdot
.37723 .3323 Mdot
.42255 .34417 Mdot
.44536 .32537 Mdot
.48035 .33751 Mdot
.51702 .33666 Mdot
.58803 .35234 Mdot
.68155 .33076 Mdot
.71985 .32704 Mdot
.86288 .30719 Mdot
.0308 .34316 Mdot
.21512 .36236 Mdot
.25123 .35029 Mdot
.30703 .35916 Mdot
.33713 .34654 Mdot
.4682 .35896 Mdot
.5546 .34174 Mdot
.79239 .34172 Mdot
.9368 .31302 Mdot
.97181 .34059 Mdot
.16525 .36705 Mdot
.2815 .39587 Mdot
.35627 .37305 Mdot
.51099 .36271 Mdot
.54452 .37352 Mdot
.62162 .36718 Mdot
.66325 .36905 Mdot
.72306 .36692 Mdot
.76546 .36769 Mdot
.83575 .36367 Mdot
.89453 .38156 Mdot
.10309 .39975 Mdot
.32428 .39609 Mdot
.37527 .38354 Mdot
.39937 .36723 Mdot
.42189 .39057 Mdot
.4427 .3732 Mdot
.46137 .39505 Mdot
.48245 .38776 Mdot
.50759 .39186 Mdot
.53044 .39888 Mdot
.57412 .38463 Mdot
.84032 .4219 Mdot
.34618 .42093 Mdot
.38266 .40798 Mdot
.40867 .41075 Mdot
.44904 .41341 Mdot
.49142 .41838 Mdot
.53663 .42476 Mdot
.56112 .41312 Mdot
.60019 .40215 Mdot
.63128 .41162 Mdot
.66687 .40585 Mdot
.70368 .39805 Mdot
.17781 .41692 Mdot
.23884 .4095 Mdot
.31837 .43642 Mdot
.37085 .43391 Mdot
.4162 .4339 Mdot
.4404 .43624 Mdot
.4721 .42792 Mdot
.51148 .42938 Mdot
.57804 .43275 Mdot
.74049 .41991 Mdot
.78485 .40715 Mdot
.89699 .45456 Mdot
.9654 .40372 Mdot
.03111 .43611 Mdot
.18648 .45454 Mdot
.24956 .44568 Mdot
.28844 .44632 Mdot
.38012 .4564 Mdot
.40692 .45678 Mdot
.47138 .44764 Mdot
.49702 .44994 Mdot
.52416 .45652 Mdot
.54208 .44724 Mdot
.56609 .45392 Mdot
.60463 .44059 Mdot
.65945 .441 Mdot
.70025 .4438 Mdot
.76006 .45996 Mdot
.80377 .45509 Mdot
.97619 .47013 Mdot
.23677 .48069 Mdot
.29795 .48234 Mdot
.34085 .46649 Mdot
.37468 .48539 Mdot
.43611 .46427 Mdot
.45874 .46259 Mdot
.48799 .47027 Mdot
.51223 .47157 Mdot
.5516 .47652 Mdot
.6219 .45852 Mdot
.65471 .47337 Mdot
.72855 .47392 Mdot
.81909 .49077 Mdot
.11292 .46068 Mdot
.26218 .50486 Mdot
.32885 .50103 Mdot
.3965 .49593 Mdot
.4192 .48553 Mdot
.45339 .49056 Mdot
.47388 .48584 Mdot
.49824 .49114 Mdot
.52173 .48805 Mdot
.53839 .48865 Mdot
.5856 .47268 Mdot
.60247 .49541 Mdot
.62956 .49528 Mdot
.68555 .4837 Mdot
.02381 .49902 Mdot
.18442 .50141 Mdot
.35581 .51325 Mdot
.39456 .52086 Mdot
.43259 .50769 Mdot
.46045 .51623 Mdot
.48227 .50886 Mdot
.51183 .5099 Mdot
.54669 .51002 Mdot
.57291 .50218 Mdot
.66661 .51602 Mdot
.71758 .50834 Mdot
.86985 .50392 Mdot
.96472 .53445 Mdot
.13041 .51088 Mdot
.21441 .53822 Mdot
.25392 .56621 Mdot
.28607 .53017 Mdot
.35327 .54178 Mdot
.42431 .53269 Mdot
.44872 .54035 Mdot
.49349 .52894 Mdot
.52906 .52245 Mdot
.56616 .5301 Mdot
.60042 .52867 Mdot
.63358 .52704 Mdot
.70938 .53579 Mdot
.76489 .50959 Mdot
.07246 .55779 Mdot
.14797 .56782 Mdot
.31488 .54502 Mdot
.38736 .552 Mdot
.47398 .54212 Mdot
.51017 .54571 Mdot
.53349 .55127 Mdot
.5564 .55208 Mdot
.73442 .55796 Mdot
.76943 .57114 Mdot
.79658 .53998 Mdot
.83745 .55836 Mdot
.04739 .63158 Mdot
.19425 .59235 Mdot
.30917 .57908 Mdot
.41467 .55861 Mdot
.47315 .56499 Mdot
.49777 .56583 Mdot
.59244 .55721 Mdot
.63607 .5586 Mdot
.6752 .55194 Mdot
.90161 .56269 Mdot
.13371 .64187 Mdot
.27478 .60787 Mdot
.3553 .57787 Mdot
.43425 .57446 Mdot
.4572 .5792 Mdot
.5068 .5825 Mdot
.53009 .58386 Mdot
.56013 .58202 Mdot
.58606 .59369 Mdot
.6145 .58567 Mdot
.63171 .60992 Mdot
.66024 .60175 Mdot
.68339 .58485 Mdot
.71385 .59285 Mdot
.81806 .60934 Mdot
.33689 .60871 Mdot
.38727 .5909 Mdot
.4189 .59993 Mdot
.44699 .62018 Mdot
.4722 .60329 Mdot
.49379 .60593 Mdot
.67904 .64091 Mdot
.72549 .62506 Mdot
.41365 .63316 Mdot
.46526 .64238 Mdot
.50921 .62685 Mdot
.53713 .61411 Mdot
.5559 .63102 Mdot
.58375 .62263 Mdot
.77306 .62003 Mdot
.87934 .62024 Mdot
.2219 .62807 Mdot
.31835 .63665 Mdot
.37664 .62545 Mdot
.49529 .65705 Mdot
.53492 .66138 Mdot
.60319 .64752 Mdot
.63947 .65314 Mdot
.19414 .68267 Mdot
.36522 .65415 Mdot
.41828 .66351 Mdot
.45048 .66898 Mdot
.50088 .69482 Mdot
.53808 .70785 Mdot
.57358 .67637 Mdot
.70298 .68033 Mdot
.75939 .66838 Mdot
.90966 .68251 Mdot
.30588 .68288 Mdot
.34659 .69015 Mdot
.38845 .68648 Mdot
.43545 .71655 Mdot
.47035 .70655 Mdot
.75528 .71574 Mdot
.82476 .67066 Mdot
.26497 .65976 Mdot
.40186 .71816 Mdot
.58295 .73123 Mdot
.61634 .69765 Mdot
.66254 .70259 Mdot
.82926 .73048 Mdot
.91101 .74496 Mdot
.25206 .71072 Mdot
.33772 .72809 Mdot
.102 .74659 Mdot
.13133 .73577 Mdot
.20048 .76104 Mdot
.2726 .75558 Mdot
.38424 .7481 Mdot
.4508 .76277 Mdot
.50188 .74932 Mdot
.63607 .75519 Mdot
.70098 .74883 Mdot
.77104 .77588 Mdot
.31495 .75539 Mdot
.39641 .78686 Mdot
.55084 .76506 Mdot
.68411 .81402 Mdot
.85654 .80755 Mdot
.25666 .81345 Mdot
.33458 .79976 Mdot
.18387 .84726 Mdot
.2977 .86757 Mdot
.37206 .84884 Mdot
.553 .82082 Mdot
.60998 .80546 Mdot
.76442 .84527 Mdot
.43924 .82246 Mdot
.4953 .80703 Mdot
.26317 .91022 Mdot
.36277 .92479 Mdot
.43608 .88537 Mdot
.63415 .87445 Mdot
.50288 .87572 Mdot
.57014 .88987 Mdot
.70438 .90081 Mdot
.45469 .96356 Mdot
.51485 .96086 Mdot
.54514 .96985 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[106]:=",
  ImageSize->{288, 286.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001[A000`40O003h00OfFmk00<006mkKg/0
e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/0
0`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003<Kg/60007Kg/00`00
Kg]_N`3DKg/00<a_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0=A_N`00Z6mk0W`08fmk
00<006mkKg/02Fmk00<006mkKg/0e6mk002WKg/4O00SKg/00`00Kg]_N`08Kg/00`00Kg]_N`3DKg/0
0:M_N`Al01Q_N`H000I_N`03001_Nfmk00M_N`@00==_N`00Z6mk0W`09Vmk00<006mkKg/01Vmk00<0
06mkKg/0<Vmk0W`0X6mk003<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0aKg/4O02O
Kg/00<a_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk035_N`Al09m_N`00cFmk100026mk
00<006mkKg/0<Vmk0W`0X6mk002:Kg/2O00oKg/2O00<Kg/00`00Kg]_N`3DKg/008U_N`Al03e_N`Al
00]_N`03001_Nfmk0=A_N`00RFmk17`0?Fmk17`02fmk00<006mkKg/0BVmk0W`0R6mk002:Kg/2O00o
Kg/2O00<Kg/00`00Kg]_N`19Kg/4O027Kg/00=U_N`03001_Nfmk00i_N`9l03U_N`Al08M_N`00fFmk
00<006mkKg/03Fmk17`0>Fmk0W`0R6mk003IKg/00`00Kg]_N`0=Kg/4O033Kg/00=U_N`03001_Nfmk
00i_N`9l0<A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_
N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/006m_N`9l06Q_N`03001_Nfmk0=A_N`00
KVmk17`0Ifmk00<006mkKg/0e6mk001^Kg/4O01WKg/3003DKg/006m_N`9l06Q_N`03001_Nfmk0=A_
N`00fFmk00<006mkKg/0e6mk001PKg/2O01gKg/00`00Kg]_N`3DKg/005m_N`Al07I_N`03001_Nfmk
0=A_N`00Gfmk17`0MVmk00<006mkKg/0e6mk001PKg/2O01gKg/00`00Kg]_N`3DKg/00=U_N`03001_
Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00
[Fmk0W`0:Vmk00<006mkKg/0e6mk002/Kg/4O00YKg/00`00Kg]_N`25Kg/2O01=Kg/00:a_N`Al02U_
N`03001_Nfmk08A_N`Al04a_N`00[Fmk0W`0:Vmk00<006mkKg/0Q6mk17`0C6mk003<Kg/2O00;Kg/0
0`00Kg]_N`0MKg/2O00gKg/2O00]Kg/2O01=Kg/009=_N`9l03I_N`Al00Y_N`03001_Nfmk01a_N`Al
03E_N`Al07]_N`00TVmk17`0=Fmk17`02Vmk00<006mkKg/076mk17`0=Fmk17`0Nfmk002BKg/4O00f
Kg/2O00;Kg/00`00Kg]_N`0MKg/2O00gKg/2O01lKg/009=_N`9l04A_N`<00=A_N`00fFmk00<006mk
Kg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0=Vmk0W`0
W6mk003IKg/00`00Kg]_N`0eKg/4O02KKg/00=U_N`03001_Nfmk03E_N`Al09]_N`00fFmk00<006mk
Kg/0=Vmk0W`0W6mk001@Kg/2O027Kg/00`00Kg]_N`3DKg/004m_N`Al08I_N`03001_Nfmk0=A_N`00
Cfmk17`0:6mk0W`0G6mk00<006mkKg/0e6mk001@Kg/2O00XKg/4O01KKg/00`00Kg]_N`3DKg/007Y_
N`Al05]_N`03001_Nfmk0=A_N`00Nfmk0W`0G6mk00<006mkKg/036mk0W`0FFmk0W`0Jfmk003IKg/0
0`00Kg]_N`0;Kg/4O01GKg/4O01ZKg/00=U_N`03001_Nfmk00]_N`Al05M_N`Al06Y_N`00]Vmk0W`0
8Fmk00<006mkKg/036mk0W`0FFmk0W`0Jfmk002eKg/4O00PKg/00`00Kg]_N`3DKg/00;E_N`Al021_
N`03001_Nfmk0=A_N`00]Vmk0W`08Fmk00<006mkKg/0e6mk003BKg/2O005Kg/3002BKg/2O010Kg/0
0=5_N`Al00A_N`03001_Nfmk095_N`Al03m_N`00UVmk0W`0>Fmk17`016mk00<006mkKg/0TFmk17`0
?fmk002EKg/4O00iKg/2O005Kg/00`00Kg]_N`2BKg/2O010Kg/009E_N`Al041_N`03001_Nfmk04M_
N`9l08]_N`00UVmk0W`0@Fmk00<006mkKg/0AVmk17`0RVmk003IKg/00`00Kg]_N`16Kg/4O02:Kg/0
06U_N`9l06i_N`03001_Nfmk04M_N`9l08]_N`00J6mk17`0KFmk00<006mkKg/0e6mk001XKg/4O01]
Kg/00`00Kg]_N`3DKg/006U_N`9l03e_N`9l02m_N`03001_Nfmk06i_N`9l06A_N`00;fmk0W`0MVmk
17`0;Vmk00<006mkKg/08Fmk0W`0BVmk17`0Hfmk000^Kg/4O01eKg/4O00^Kg/00`00Kg]_N`0PKg/4
O019Kg/4O01SKg/002i_N`Al07I_N`9l02m_N`03001_Nfmk021_N`Al04Y_N`9l06A_N`00;fmk0W`0
Z6mk00<006mkKg/08Fmk0W`0/Fmk003IKg/00`00Kg]_N`3DKg/00<1_N`9l01M_N`03001_Nfmk0=A_
N`00_fmk17`05Vmk00<006mkKg/02Fmk0W`0bFmk002oKg/4O00FKg/00`00Kg]_N`08Kg/4O038Kg/0
0<1_N`9l01M_N`<000Q_N`Al0<Q_N`00fFmk00<006mkKg/02Fmk0W`0bFmk001nKg/2O01IKg/00`00
Kg]_N`0dKg/2O02NKg/007e_N`Al05Q_N`03001_Nfmk03=_N`Al09e_N`00OFmk17`0F6mk00<006mk
Kg/0<fmk17`0WFmk001nKg/2O00?Kg/2O018Kg/00`00Kg]_N`0dKg/2O00KKg/2O021Kg/008i_N`Al
03i_N`9l00M_N`03001_Nfmk051_N`Al081_N`00C6mk0W`0@6mk17`0?Fmk17`01Vmk00<006mkKg/0
D6mk17`0P6mk001;Kg/4O010Kg/2O00nKg/4O006Kg/00`00Kg]_N`1AKg/2O00UKg/2O01JKg/004]_
N`Al085_N`9l00M_N`03001_Nfmk07M_N`Al02i_N`9l02U_N`00C6mk0W`0Rfmk00<006mkKg/0Mfmk
17`0;Fmk17`0:6mk002NKg/2O00iKg/00`00Kg]_N`1hKg/2O00^Kg/4O00XKg/009e_N`Al03Q_N`03
001_Nfmk0:U_N`9l02U_N`00WFmk17`04Fmk0W`09Fmk00<006mkKg/0e6mk001RKg/2O00jKg/2O00A
Kg/4O00TKg/00`00Kg]_N`3DKg/0065_N`Al04a_N`Al02A_N`03001_Nfmk019_N`9l0<1_N`00HFmk
17`0CFmk0W`066mk1`001Vmk00<006mkKg/04Fmk17`0_fmk001RKg/2O01[Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`0AKg/4O02oKg/00<m_N`03001_Nfmk00M_N`03001_Nfmk019_N`9l07I_N`9l04Q_N`00
cfmk00<006mkKg/01fmk00<006mkKg/0RFmk17`0Afmk0033Kg/60006Kg/00`00Kg]_N`07Kg/4001Q
Kg/2O00UKg/4O017Kg/007M_N`9l04U_N`9l00]_N`03001_Nfmk00M_N`04001_Ng`0O00RKg/2O00l
Kg/4O00UKg/2O018Kg/007I_N`Al04M_N`Al00Y_N`03001_Nfmk00M_N`03001l07`0009l021_N`Al
03]_N`Al06m_N`00MVmk17`0Afmk17`026mk0`002Fmk00<007`0O0000W`086mk17`0?6mk0W`0L6mk
001gKg/2O019Kg/2O00;Kg/00`00Kg]_N`07Kg/01000Kg]l07`08Vmk0W`04Fmk0W`0W6mk003IKg/0
0`00Kg]_N`0eKg/4O02KKg/003A_N`9l0:=_N`03001_Nfmk03E_N`Al09]_N`00<fmk17`0XVmk00<0
06mkKg/0=Vmk0W`0W6mk000cKg/4O01UKg/2O00kKg/00`00Kg]_N`3DKg/003A_N`9l05A_N`9l00m_
N`Al03Y_N`03001_Nfmk04U_N`9l08U_N`00RFmk17`03Vmk17`0>Vmk00<006mkKg/0B6mk17`0R6mk
0029Kg/4O00?Kg/2O00cKg/2O006Kg/00`00Kg]_N`18Kg/4O028Kg/008Y_N`9l04A_N`Al00E_N`03
001_Nfmk04U_N`9l08U_N`00[6mk0W`08Vmk17`01Fmk00<006mkKg/0e6mk002[Kg/4O00RKg/2O006
Kg/00`00Kg]_N`0@Kg/2O032Kg/00:]_N`Al02Y_N`03001_Nfmk00m_N`Al0<5_N`00[6mk0W`03Vmk
0W`06fmk00<006mkKg/03fmk17`0`Fmk001TKg/2O01EKg/4O00JKg/00`00Kg]_N`0@Kg/2O032Kg/0
06=_N`Al05A_N`Al01Y_N`03001_Nfmk0=A_N`00Hfmk17`0EFmk0W`06fmk00<006mkKg/0HFmk0W`0
5Fmk0W`0FVmk001TKg/2O01cKg/3001PKg/4O00CKg/4O01IKg/004m_N`9l08Q_N`03001_Nfmk061_
N`Al01=_N`Al05U_N`00CVmk17`0:Fmk0W`0Dfmk0W`01fmk00<006mkKg/07Vmk0W`0@Fmk0W`05Fmk
0W`07Fmk0W`0>fmk001>Kg/4O00XKg/4O01AKg/4O006Kg/00`00Kg]_N`07Kg/2O00DKg/4O01eKg/4
O00jKg/004m_N`9l02U_N`Al055_N`Al00I_N`03001_Nfmk00I_N`Al01=_N`Al07E_N`Al03Y_N`00
Nfmk0W`05Vmk0W`0>fmk0W`01fmk00<006mkKg/01Vmk17`056mk0W`0Mfmk0W`07Vmk0W`06fmk002B
Kg/4O013Kg/00`00Kg]_N`07Kg/2O00SKg/2O028Kg/4O00JKg/0099_N`Al01A_N`9l02e_N`03001_
Nfmk02]_N`Al08M_N`Al01Y_N`00Tfmk0W`056mk17`0;6mk00<006mkKg/0:fmk17`02fmk0W`0Nfmk
0W`06fmk002YKg/4O00/Kg/00`00Kg]_N`0/Kg/2O00;Kg/4O02GKg/00:Y_N`9l01=_N`9l01Q_N`03
001_Nfmk03U_N`Al09M_N`00_Vmk17`05fmk00<006mkKg/0>Vmk0W`07Fmk0W`0NFmk002nKg/4O00G
Kg/00`00Kg]_N`19Kg/2O00=Kg/4O01hKg/00:5_N`9l01a_N`9l01Q_N`03001_Nfmk04Q_N`Al00a_
N`Al07Q_N`00;fmk0W`0Kfmk17`0=Fmk00<006mkKg/0B6mk17`03Fmk0W`0NFmk000^Kg/4O017Kg/2
O00UKg/4O00ZKg/2O009Kg/00`00Kg]_N`02Kg/2O015Kg/2O029Kg/002i_N`Al04I_N`Al02E_N`9l
02Y_N`Al00Q_N`04001_NfmkKg/4O03?Kg/002m_N`9l04M_N`Al055_N`Al00Q_N`04001_NfmkKg/4
O00=Kg/2O01TKg/2O01<Kg/2O00<Kg/000a_N`9l06]_N`9l03Y_N`9l01M_N`9l00U_N`03001_Nfmk
009_N`9l00e_N`Al069_N`Al04Y_N`Al00]_N`002fmk17`0PFmk0W`08Vmk17`08Fmk0`004Fmk17`0
HVmk17`0BVmk17`02fmk000;Kg/4O020Kg/4O00QKg/4O00QKg/00`00Kg]_N`0BKg/2O01TKg/2O01<
Kg/2O00<Kg/000a_N`9l05e_N`9l029_N`Al029_N`9l029_N`03001_Nfmk0=A_N`00JVmk17`08Vmk
0W`0Afmk00<006mkKg/086mk0W`0/Vmk001ZKg/4O01[Kg/00`00Kg]_N`0OKg/4O02aKg/006]_N`9l
06a_N`03001_Nfmk01m_N`Al0;5_N`00Pfmk0W`0A6mk0W`03Vmk00<006mkKg/086mk0W`0/Vmk001L
Kg/2O00TKg/4O012Kg/4O00=Kg/01000Kg]l07`0dfmk001KKg/4O00SKg/4O012Kg/4O00=Kg/00`00
O01l0002O029Kg/2O017Kg/004I_N`9l01=_N`Al02A_N`9l02I_N`9l01a_N`9l00i_N`03001l07`0
009l02e_N`9l02Y_N`9l011_N`9l01]_N`Al04I_N`00AFmk17`04fmk0W`0C6mk17`0:fmk00@006mk
O01l02e_N`Al00m_N`9l01M_N`Al00i_N`Al01Y_N`Al04I_N`00AFmk17`0HFmk17`0:fmk00<006mk
Kg/0;Vmk17`03Vmk17`05Vmk17`03Vmk17`06fmk0W`0Afmk0016Kg/2O01@Kg/2O00AKg/2O00AKg/2
O00IKg/00`00Kg]_N`0>Kg/2O00OKg/2O00?Kg/4O00GKg/2O00@Kg/2O01UKg/009M_N`Al029_N`Al
01Q_N`03001_Nfmk00e_N`Al031_N`9l095_N`00Ufmk17`08Vmk17`066mk00<006mkKg/03Fmk17`0
`fmk002HKg/2O00TKg/2O00IKg/00`00Kg]_N`0>Kg/2O02DKg/2O00^Kg/00:5_N`9l03I_N`03001_
Nfmk0:=_N`Al02e_N`00X6mk17`0=Fmk00<006mkKg/06Vmk0W`0Qfmk17`0;Fmk002PKg/4O00[Kg/2
O008Kg/00`00Kg]_N`0IKg/4O027Kg/2O00^Kg/00:5_N`9l019_N`9l01M_N`Al00M_N`03001_Nfmk
01U_N`Al0;M_N`00]6mk17`05Vmk17`01fmk00<007`0O0006Vmk0W`0^6mk002dKg/4O00>Kg/2O007
Kg/2O008Kg/4O03CKg/007Q_N`9l015_N`9l02Q_N`9l00i_N`Al011_N`Al055_N`9l081_N`00:fmk
0W`0BVmk17`03fmk17`0=fmk17`046mk00<007`0O0001fmk0W`0B6mk17`0Ofmk000ZKg/4O019Kg/4
O00?Kg/4O00hKg/2O00AKg/00`00Kg]_N`06Kg/4O00LKg/2O00YKg/4O01oKg/002Y_N`Al04Y_N`9l
015_N`9l04a_N`03001_Nfmk00I_N`Al01]_N`Al02U_N`9l06m_N`9l00m_N`00:fmk0W`0[6mk00<0
06mkKg/01fmk0W`076mk17`06Fmk0W`0<Fmk0W`0Bfmk17`03Vmk001VKg/2O00lKg/2O00cKg/00`00
Kg]_N`0VKg/2O00IKg/4O00_Kg/4O01:Kg/4O00>Kg/006E_N`Al03Y_N`Al00Q_N`9l02Q_N`03001_
Nfmk03=_N`9l00a_N`Al02m_N`Al04]_N`9l00m_N`00IFmk17`0>Vmk17`01fmk17`03Vmk0W`05fmk
00<006mkKg/05Fmk0W`06fmk17`036mk0W`0<Fmk0W`0GFmk001VKg/2O00lKg/2O008Kg/4O00=Kg/4
O00FKg/00`00Kg]_N`0DKg/4O00JKg/4O02NKg/004a_N`9l065_N`9l00i_N`Al011_N`9l00A_N`03
001_Nfmk01A_N`Al01]_N`9l09m_N`00Bfmk17`0AFmk0W`0:Vmk0W`046mk17`00fmk00<006mkKg/0
5Fmk0W`0Bfmk0W`0L6mk001;Kg/4O014Kg/4O00kKg/4O003Kg/00`00Kg]_N`1QKg/4O00XKg/2O015
Kg/004a_N`9l04E_N`Al03a_N`9l00A_N`03001_Nfmk00Y_N`9l05E_N`Al02M_N`Al04A_N`00U6mk
0W`0=6mk0W`03Fmk00<006mkKg/02Fmk17`0EFmk0W`0:6mk17`0A6mk0039Kg/4O00<Kg/01000Kg]l
07`026mk17`0P6mk0W`0AFmk0039Kg/4O00<Kg/00`00O01l0002O008Kg/2O00@Kg/2O02fKg/009m_
N`9l015_N`9l01I_N`9l00e_N`03001l07`0009l01U_N`Al0;E_N`0036mk0W`0NVmk0W`056mk17`0
3fmk17`026mk0W`06Vmk0P000W`06Vmk17`0]Fmk000;Kg/4O01hKg/4O00CKg/4O00?Kg/4O007Kg/4
O00IKg/00`00Kg]_N`0LKg/2O02fKg/000]_N`Al07Q_N`Al01A_N`9l015_N`9l00Q_N`Al01U_N`03
001_Nfmk02M_N`9l01I_N`9l09=_N`0036mk0W`026mk1P00G6mk1`002Fmk0W`0<fmk0W`06Vmk00<0
06mkKg/09Vmk17`056mk17`03fmk0W`02Fmk1`00Ffmk1P0046mk000FKg/00`00Kg]_N`02Kg/00`00
Kg]_N`1<Kg/2O00?Kg/2O01LKg/00`00Kg]_N`0VKg/4O00DKg/4O00>Kg/4O00;Kg/00`00Kg]_N`1L
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/001M_N`03001_Nfmk04m_N`Al00e_N`Al04a_N`9l00e_
N`03001_Nfmk00e_N`9l01Q_N`9l01I_N`9l00m_N`Al00]_N`03001_Nfmk05e_N`03001_Nfmk019_
N`0066mk00<006mkKg/0CVmk17`03Fmk17`0Bfmk17`026mk0W`00Vmk00<006mkKg/036mk17`0@Fmk
0W`036mk00<006mkKg/0GVmk00<006mkKg/04Fmk000=Kg/60006Kg/00`00Kg]_N`1>Kg/2O003Kg/6
0006Kg/2O01<Kg/4O007Kg/4O0000fmk001_N`0=Kg/4O01?Kg/00`00Kg]_N`1OKg/00`00Kg]_N`0@
Kg/001Y_N`03001_Nfmk039_N`9l02Y_N`03001_Nfmk04a_N`9l00Q_N`Al0003Kg/006mk00i_N`9l
00Q_N`9l04I_N`03001_Nfmk01]_N`9l02I_N`9l01]_N`03001_Nfmk00m_N`005Vmk00<006mkKg/0
0Vmk00<006mkKg/0<6mk17`0:Fmk00<006mkKg/09Fmk0W`02Fmk0W`09Fmk0W`00Vmk00<006mkKg/0
1Fmk0W`03fmk17`0AFmk00<006mkKg/06Vmk17`096mk17`05Vmk00<006mkKg/00Vmk00<006mkKg/0
3Vmk000FKg/00`00Kg]_N`02Kg/00`00Kg]_N`0BKg/2O00LKg/4O00WKg/3000VKg/4O007Kg/4O00X
Kg/00`00Kg]_N`04Kg/4O00>Kg/4O00EKg/2O00/Kg/3000:Kg/2O00@Kg/4O00TKg/4O00FKg/00`00
Kg]_N`02Kg/00`00Kg]_N`0>Kg/001M_N`@001A_N`Al01a_N`9l02Y_N`03001_Nfmk02A_N`Al00M_
N`Al01A_N`9l019_N`03001_Nfmk00A_N`Al00m_N`9l01E_N`Al02e_N`03001_Nfmk00M_N`Al011_
N`9l02I_N`9l01Q_N`@0015_N`00;fmk17`0L6mk0W`02Fmk0W`02fmk0W`01fmk17`04Fmk00<006mk
Kg/01Fmk0W`09fmk17`0=fmk17`0Ifmk000`Kg/2O01PKg/2O00VKg/4O006Kg/4O00AKg/00`00Kg]_
N`0_Kg/2O00iKg/2O01XKg/0095_N`Al02E_N`Al00M_N`9l019_N`03001_Nfmk0=A_N`00TFmk17`0
9Vmk0W`056mk0W`01Vmk00<006mkKg/00W`0aVmk0W`02Vmk002BKg/2O00lKg/4O005Kg/00`00Kg]l
0003O00LKg/2O00LKg/2O00NKg/2O01XKg/4O009Kg/00=1_N`Al00E_N`03001_Ng`000=l00i_N`9l
00]_N`Al01Y_N`Al01a_N`Al06M_N`Al00U_N`00dFmk0W`01Vmk00<006mkKg/00W`03Vmk17`02Vmk
17`06Vmk17`076mk17`0J6mk0W`02Vmk001UKg/2O01bKg/00`00Kg]_N`0@Kg/4O00;Kg/2O00LKg/2
O00NKg/2O01eKg/006@000Al01L0009l06`0009l03L0009l08L0005_N`000Vmk00<006mkKg/046mk
00<006mkKg/04Fmk00<006mkKg/046mk00<006mkKg/04Fmk00<006mkKg/04Fmk17`03fmk00<006mk
Kg/016mk17`02Fmk00<006mkKg/046mk00@006mkO01l011_N`04001_Ng`0O00@Kg/00`00Kg]_N`02
Kg/2O00<Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0>Kg/4O00B
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@
Kg/00`00Kg]_N`0@Kg/0009_N`03001_Nfmk011_N`03001_Nfmk015_N`03001_Nfmk011_N`03001_
Nfmk015_N`03001_Nfmk015_N`03001l07`0011_N`03001_Nfmk00A_N`Al00U_N`03001_Nfmk011_
N`03001l07`0009l00m_N`03001l07`0009l00m_N`04001_NfmkKg/4O00;Kg/00`00Kg]_N`04Kg/2
O00;Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0>Kg/4O00BKg/00`00Kg]_N`0AKg/0
0`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0@Kg/0
01E_N`03001_Nfmk05m_N`03001_Nfmk00E_N`9l01i_N`Al011_N`Al00]_N`9l00I_N`Al00]_N`03
001_Nfmk00=_N`Al00A_N`9l03e_N`9l01=_N`03001_Nfmk029_N`9l03]_N`03001_Nfmk011_N`00
X6mk0W`04Vmk0W`02fmk17`01Vmk0W`02Fmk0W`000=_N`00Kg/016mk17`00fmk17`0MFmk17`0CFmk
0031Kg/4O00@Kg/4O0000`00Kg]_N`04Kg/2O004Kg/4O00IKg/2O009Kg/2O01?Kg/4O01=Kg/00:Y_
N`9l01I_N`9l015_N`Al0003001_Nfmk00]_N`9l01U_N`Al00M_N`Al04m_N`9l04i_N`002Fmk0W`0
WVmk17`0:Fmk0W`000=_N`00Kg/09fmk17`01fmk17`0Wfmk0008Kg/4O012Kg/2O00mKg/2O00JKg/4
O00/Kg/00`00Kg]_N`0JKg/2O00;Kg/2O009Kg/2O02PKg/000Q_N`Al045_N`Al03]_N`Al01Y_N`9l
02e_N`03001_Nfmk01U_N`Al07e_N`9l03Q_N`002Fmk0W`0@Vmk17`07fmk0W`06Vmk17`0BFmk00<0
06mkKg/06Fmk17`0O6mk17`0=fmk001>Kg/2O00OKg/4O00JKg/2O00ZKg/2O00DKg/2O008Kg/00`00
Kg]_N`0JKg/2O00lKg/2O00oKg/4O00gKg/003M_N`9l03I_N`Al04E_N`Al019_N`Al00M_N`04001_
Ng`0O00=Kg/2O017Kg/4O00BKg/2O00[Kg/2O00hKg/003I_N`Al03I_N`9l02I_N`9l01i_N`Al019_
N`Al00M_N`03001l07`0009l00]_N`Al04I_N`Al015_N`Al06A_N`00=Vmk17`0GFmk17`07Vmk0W`0
2Vmk0W`026mk0W`026mk00<007`0O0000W`02fmk17`0<Fmk0W`056mk0W`04Vmk17`0I6mk000gKg/2
O01NKg/4O00YKg/4O00AKg/01000Kg]l07`03Fmk0W`0<Fmk17`0:6mk0W`0IFmk002HKg/2O00?Kg/2
O00IKg/4O00AKg/00`00Kg]_N`11Kg/4O02?Kg/00:Q_N`Al01U_N`9l019_N`03001_Nfmk00M_N`9l
03U_N`9l091_N`00Z6mk17`0;Fmk00<006mkKg/01Vmk17`0bVmk002YKg/2O00^Kg/00`00Kg]_N`06
Kg/4O00ZKg/2O02NKg/007Y_N`9l05Q_N`9l00=_N`<000M_N`9l00i_N`9l00e_N`9l00]_N`Al09e_
N`00NFmk17`0EVmk17`00Vmk00<006mkKg/05Vmk17`02fmk17`02Vmk17`0WFmk001iKg/4O00iKg/2
O00KKg/4O002Kg/00`00Kg]_N`0FKg/4O00;Kg/4O00;Kg/2O02=Kg/2O00?Kg/007Y_N`9l03U_N`Al
01]_N`9l00=_N`03001_Nfmk01M_N`9l00e_N`9l02e_N`9l06]_N`Al00i_N`00Ffmk0W`0F6mk17`0
86mk00<006mkKg/0E6mk17`0JVmk17`03Vmk001JKg/4O00iKg/2O00MKg/2O008Kg/2O00GKg/00`00
Kg]_N`1DKg/4O00RKg/2O017Kg/2O00?Kg/005Y_N`Al03Q_N`Al02E_N`Al00Q_N`9l00a_N`03001_
Nfmk05E_N`9l029_N`Al05M_N`00Ffmk0W`0:Vmk0W`03Fmk17`09Fmk17`01fmk17`02fmk00@006mk
O01l07Q_N`Al05M_N`00QVmk17`03Fmk0W`09fmk0W`026mk17`02fmk00<007`0O0000W`0N6mk0W`0
F6mk0026Kg/4O011Kg/2O00<Kg/00`00O01l0002O03BKg/008M_N`9l01e_N`9l035_N`04001_Ng`0
O008Kg/2O008Kg/2O00aKg/2O02<Kg/00:E_N`Al031_N`03001_Nfmk00Q_N`Al00I_N`Al02m_N`Al
08]_N`007Vmk0W`0QFmk17`0<6mk00<006mkKg/026mk17`01Vmk17`036mk0W`08Fmk17`05Vmk0W`0
Lfmk000MKg/4O025Kg/2O00:Kg/2O00UKg/00`00Kg]_N`09Kg/2O008Kg/2O00<Kg/4O00@Kg/2O00?
Kg/2O00FKg/4O00ZKg/2O016Kg/001e_N`Al091_N`Al02A_N`03001_Nfmk025_N`Al00m_N`Al02I_
N`Al02U_N`Al01Q_N`9l02]_N`007Vmk0W`0TFmk17`05Vmk0W`036mk00<006mkKg/08Vmk0W`046mk
17`09fmk0W`0:Vmk17`05fmk17`0:Vmk001/Kg/2O014Kg/2O00FKg/4O007Kg/2O002Kg/00`00Kg]_
N`0eKg/2O01EKg/2O00HKg/4O00ZKg/003m_N`9l02Y_N`Al05]_N`Al00I_N`Al0003Kg/006mk0:Q_
N`9l02]_N`00?Vmk17`0:Fmk17`0G6mk0W`01fmk17`000=_N`00Kg/0Kfmk0W`0I6mk000nKg/4O00Z
Kg/2O01WKg/2O002Kg/3001]Kg/4O01SKg/003m_N`9l07U_N`9l01e_N`03001_Nfmk06e_N`Al06=_
N`00V6mk0W`07fmk17`076mk00<006mkKg/0KVmk0W`0I6mk0024Kg/2O00AKg/4O00NKg/4O007Kg/2
O00CKg/00`00Kg]_N`3DKg/008=_N`Al011_N`Al01m_N`9l00M_N`Al019_N`9l01E_N`9l0;i_N`00
Pfmk17`04Fmk0W`0:Fmk17`04Fmk17`01fmk0W`02Vmk17`05Fmk0W`06fmk0W`0RFmk0024Kg/2O00n
Kg/2O00BKg/4O006Kg/4O009Kg/4O00DKg/4O00IKg/4O028Kg/00=U_N`9l00M_N`Al00Y_N`9l01E_
N`Al01U_N`Al08Q_N`00Dfmk0W`0DFmk0W`0<Fmk00<006mkKg/01fmk0W`08fmk0W`06fmk0W`036mk
0W`0Nfmk001BKg/4O01?Kg/4O00`Kg/00`00Kg]_N`0OKg/2O00eKg/4O01jKg/0059_N`Al04m_N`Al
031_N`03001_Nfmk01i_N`Al03A_N`Al07Y_N`00Dfmk0W`0DFmk0W`02fmk0W`096mk00<006mkKg/0
7Vmk17`0=Fmk0W`0Nfmk002bKg/4O00SKg/00`00Kg]_N`0OKg/2O00NKg/2O02CKg/00;9_N`Al01A_
N`9l00e_N`03001_Nfmk03i_N`Al099_N`00/fmk0W`056mk17`01fmk0W`00fmk00<006mkKg/0?Vmk
17`0TVmk001eKg/2O00IKg/2O00gKg/4O006Kg/4O002Kg/00`00Kg]_N`0oKg/2O02CKg/007A_N`Al
01M_N`Al03M_N`9l00M_N`Al009_N`03001_Nfmk03=_N`9l04i_N`9l04m_N`00M6mk17`05fmk17`0
@Fmk0W`00fmk00<006mkKg/0<Vmk17`0C6mk17`0CVmk001eKg/2O00IKg/2O017Kg/00`00Kg]_N`0:
Kg/2O00VKg/4O01<Kg/4O01>Kg/00=U_N`03001_Nfmk00U_N`Al02I_N`9l04i_N`9l04m_N`00`6mk
0W`05fmk0`002Fmk17`0Hfmk0W`0;6mk0W`0=6mk002oKg/4O00FKg/00`00Kg]_N`0:Kg/2O00BKg/2
O01?Kg/4O00ZKg/4O00cKg/00:5_N`9l01a_N`Al01I_N`03001_Nfmk01e_N`Al03]_N`9l015_N`Al
02Y_N`Al03=_N`00X6mk17`076mk0W`05fmk00<007`0O0007Fmk17`0>Vmk17`04Fmk0W`0;6mk0W`0
=6mk001OKg/2O00oKg/4O00eKg/4O00MKg/2O00kKg/4O01eKg/001=_N`9l04U_N`Al03m_N`9l03I_
N`Al015_N`9l04Q_N`9l07I_N`004Vmk17`0B6mk17`0Cfmk0W`09Vmk00<007`0O0004Fmk17`0_fmk
000BKg/4O019Kg/2O00WKg/2O00VKg/4O00UKg/00`00Kg]_N`0AKg/4O02oKg/001=_N`9l079_N`Al
02E_N`Al02E_N`03001_Nfmk019_N`9l0<1_N`00Qfmk17`09Vmk0W`09Vmk00<006mkKg/0B6mk0W`0
RVmk000iKg/2O01=Kg/2O00mKg/2O00@Kg/00`00Kg]_N`17Kg/4O029Kg/003Q_N`Al08Y_N`Al00m_
N`03001_Nfmk04M_N`Al08U_N`00>6mk17`0RVmk17`03fmk00<006mkKg/09fmk0W`07fmk0W`0RVmk
000iKg/2O02<Kg/2O00@Kg/00`00Kg]_N`0VKg/4O02ZKg/00=U_N`03001_Nfmk02I_N`Al00a_N`9l
09a_N`00W6mk0W`0>fmk00<006mkKg/09fmk0W`036mk17`0Vfmk002KKg/4O00eKg/2O003Kg/00`00
Kg]_N`0eKg/4O02KKg/0075_N`9l02Q_N`Al03A_N`Al009_N`03001_Nfmk03I_N`9l09a_N`00L6mk
17`0:6mk0W`0=Fmk17`00Vmk00<006mkKg/02Fmk0W`0bFmk001`Kg/4O00oKg/2O00OKg/2O003Kg/3
0008Kg/4O038Kg/0075_N`9l03m_N`Al02=_N`03001_Nfmk00Q_N`Al0<Q_N`00/Vmk17`02fmk0W`0
5Vmk00<006mkKg/02Fmk0W`0Gfmk0W`0J6mk002cKg/2O00;Kg/4O00EKg/00`00Kg]_N`1YKg/4O00I
Kg/2O01<Kg/00<1_N`Al01E_N`03001_Nfmk06U_N`Al01Q_N`Al04]_N`00`Fmk0W`05Vmk00<006mk
Kg/06Vmk0W`0CVmk0W`06Fmk17`0Bfmk003IKg/00`00Kg]_N`0IKg/4O01YKg/2O01<Kg/00=U_N`03
001_Nfmk01U_N`Al03E_N`9l081_N`00Dfmk0W`0;Vmk0W`0E6mk00<006mkKg/06Vmk0W`0=Fmk17`0
EVmk0W`09fmk001BKg/4O00/Kg/4O01CKg/00`00Kg]_N`1AKg/4O01EKg/4O00VKg/0059_N`Al02a_
N`Al021_N`9l035_N`03001_Nfmk059_N`9l05I_N`Al02I_N`00Dfmk0W`0;Vmk0W`03fmk0W`03fmk
17`0<6mk00<006mkKg/0Zfmk0W`09fmk002CKg/4O00>Kg/4O00`Kg/00`00Kg]_N`3DKg/009=_N`Al
00m_N`9l02m_N`9l0003001_Nfmk0=A_N`00U6mk0W`0@6mk17`0eVmk003FKg/4O00_Kg/2O02UKg/0
0=M_N`9l0003001_Nfmk02a_N`Al0:A_N`00c6mk1`001Vmk00<006mkKg/0;6mk17`046mk0W`0TVmk
003:Kg/2O003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0]Kg/2O00@Kg/4O02AKg/00<U_N`Al009_N`03
001_Nfmk00M_N`03001_Nfmk00]_N`9l039_N`Al095_N`00K6mk0W`0Ffmk17`00Vmk00<006mkKg/0
1fmk10002Fmk17`0<Vmk0W`0TVmk001[Kg/4O01KKg/2O003Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:
Kg/4O036Kg/006]_N`Al061_N`03001_Nfmk00M_N`03001_Nfmk00]_N`9l05]_N`9l06Y_N`00K6mk
0W`0?Vmk0W`03Fmk0W`04Vmk00<006mkKg/01fmk00<006mkKg/0Ifmk17`0JFmk002[Kg/4O00;Kg/4
O00?Kg/30009Kg/00`00Kg]_N`1WKg/4O01YKg/00:]_N`Al00]_N`Al015_N`03001_Nfmk00M_N`03
001_Nfmk06Q_N`9l06Y_N`00[6mk0W`03Fmk0W`076mk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/0091_N`9l04M_N`03001_Nfmk0=A_N`00Sfmk17`0AVmk00<006mkKg/07Vmk0W`0J6mk0W`0BVmk
002?Kg/4O016Kg/00`00Kg]_N`0MKg/4O01VKg/4O019Kg/003M_N`9l05M_N`9l04M_N`03001_Nfmk
01e_N`Al06I_N`Al04U_N`00=Vmk17`0Wfmk00<006mkKg/07Vmk0W`0J6mk0W`0BVmk000fKg/4O02O
Kg/00`00Kg]_N`3DKg/003M_N`9l0:1_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0[6mk0W`09Vmk
000[Kg/2O01gKg/2O00cKg/00`00Kg]_N`2[Kg/4O00UKg/002Y_N`Al07E_N`Al031_N`9l0003001_
Nfmk055_N`9l05Q_N`Al02E_N`00:Vmk17`0MFmk17`0;fmk17`0DVmk17`0F6mk0W`09Vmk000[Kg/2
O01JKg/2O00KKg/2O00`Kg/4O00gKg/2O00IKg/4O020Kg/007A_N`9l011_N`Al04e_N`9l00<003A_
N`Al01U_N`9l085_N`00Lfmk17`03fmk17`0Cfmk00<006mkKg/0=6mk17`0W6mk001EKg/2O00LKg/4
O00@Kg/2O01@Kg/00`00Kg]_N`0eKg/2O02MKg/005A_N`Al01a_N`9l04]_N`9l01I_N`03001_Nfmk
0=A_N`00E6mk17`0J6mk17`05Fmk00<006mkKg/046mk0W`0`Vmk001EKg/2O01YKg/4O00EKg/00`00
Kg]_N`0?Kg/4O031Kg/00<5_N`9l01I_N`03001_Nfmk00m_N`Al0<5_N`00fFmk00<006mkKg/046mk
0W`0`Vmk003IKg/00`00Kg]_N`1_Kg/2O01SKg/00=U_N`03001_Nfmk06i_N`Al069_N`00fFmk00<0
06mkKg/0KVmk17`0HVmk003IKg/00`00Kg]_N`1_Kg/2O01SKg/00=U_N`03001_Nfmk0=A_N`00ZVmk
0W`0;Fmk00<006mkKg/0e6mk002YKg/4O00/Kg/00`00Kg]_N`3DKg/00:U_N`Al02a_N`03001_Nfmk
0=A_N`00ZVmk0W`0;Fmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_
N`00Sfmk0W`0B6mk0`00e6mk002>Kg/4O017Kg/00`00Kg]_N`3DKg/008i_N`Al04M_N`03001_Nfmk
02Y_N`9l0:Q_N`00Sfmk0W`0@fmk0W`00fmk00<006mkKg/0:Fmk17`0Ifmk0W`0?Vmk003CKg/4O002
Kg/00`00Kg]_N`0YKg/4O01VKg/4O00mKg/00==_N`Al009_N`03001_Nfmk02Y_N`9l06M_N`Al03e_
N`00KVmk0W`0I6mk0W`00fmk00<006mkKg/0BVmk0W`0B6mk0W`0?Vmk001]Kg/4O01XKg/00`00Kg]_
N`19Kg/4O027Kg/006e_N`Al06Q_N`03001_Nfmk04U_N`Al08M_N`00KVmk0W`0C6mk0W`06fmk00<0
06mkKg/04Fmk0W`0=fmk0W`0R6mk002kKg/4O00JKg/00`00Kg]_N`0@Kg/4O030Kg/00;]_N`Al01Y_
N`03001_Nfmk011_N`Al0<1_N`00_6mk0W`06fmk00<006mkKg/04Fmk0W`0`Fmk003IKg/00`00Kg]_
N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_
N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`1/Kg/2O01VKg/004i_N`9l
08U_N`<006]_N`Al06E_N`00CFmk17`0CVmk0W`0>6mk00<006mkKg/0Jfmk17`0IFmk001=Kg/4O01=
Kg/4O00gKg/00`00Kg]_N`1/Kg/2O01VKg/004i_N`9l04i_N`Al03M_N`03001_Nfmk0=A_N`00Wfmk
0W`0>6mk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00fFmk00<0
06mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/007m_N`9l05Q_N`03001_Nfmk0=A_N`00OVmk17`0Efmk
00<006mkKg/0e6mk001nKg/4O01GKg/00`00Kg]_N`3DKg/007m_N`9l05M_N`9l03I_N`9l09i_N`00
efmk17`0=6mk17`0WFmk003GKg/4O00dKg/4O02MKg/00=Q_N`9l03I_N`9l09i_N`00fFmk00<006mk
Kg/0e6mk002kKg/2O00LKg/00`00Kg]_N`3DKg/00;Y_N`Al01]_N`03001_Nfmk01U_N`9l0;U_N`00
^Vmk17`06fmk0`0066mk17`0^6mk002kKg/2O00LKg/00`00Kg]_N`0HKg/4O02hKg/00=U_N`03001_
Nfmk01U_N`9l0;U_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`1BKg/2O020Kg/00=U_N`03
001_Nfmk055_N`Al07m_N`00fFmk00<006mkKg/0DFmk17`0Ofmk003IKg/00`00Kg]_N`1BKg/2O020
Kg/0071_N`9l06M_N`03001_Nfmk0=A_N`00Kfmk17`0IVmk00<006mkKg/0e6mk001_Kg/4O01VKg/0
0`00Kg]_N`3DKg/0071_N`9l06M_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00
Kg]_N`3DKg/00=U_N`03001_Nfmk0=A_N`00Vfmk0W`0?6mk00<006mkKg/0e6mk002JKg/4O00kKg/0
0`00Kg]_N`3DKg/009Y_N`Al02i_N`H000M_N`03001_Nfmk0=A_N`00Vfmk0W`0;fmk00<006mkKg/0
0Vmk00<006mkKg/01Fmk00<006mkKg/0e6mk003=Kg/00`00Kg]_N`09Kg/00`00Kg]_N`3DKg/00<i_
N`03001_Nfmk00Q_N`@00==_N`00cfmk00<006mkKg/01fmk00<006mkKg/0e6mk003@Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`3DKg/00<a_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk0=A_N`00
c6mk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/0e6mk003=Kg/40008Kg/00`00Kg]_N`3D
Kg/00=U_N`03001_Nfmk0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03
001_Nfmk0=A_N`00fFmk00@006mkKg]_N`9l0=5_N`00`fmk0W`056mk00<006mkKg/017`0d6mk0032
Kg/4O00CKg/00`00Kg]_N`04O03@Kg/00<9_N`Al01=_N`04001_NfmkKg/2O03AKg/00<=_N`9l01A_
N`03001_Nfmk00i_N`9l0<A_N`00fFmk00<006mkKg/03Fmk17`0`fmk003IKg/00`00Kg]_N`0=Kg/4
O033Kg/00=U_N`03001_Nfmk00i_N`9l0<A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3D
Kg/00=U_N`<00=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00=U_N`03001_Nfmk
0=A_N`00fFmk00<006mkKg/0e6mk003IKg/00`00Kg]_N`3DKg/00001\
\>"],
  ImageRangeCache->{{{0, 431}, {428.188, 0}} -> {-2.22158, -2.10829, \
0.015301, 0.015301}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["\<\
Once we have the locations of the meshpoints, it is simply a function call to \
generate the meshes.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      the\ Mathematica\ built - 
        in\ function\ *) \)\(\[IndentingNewLine]\)\(PlanarGraphPlot[pp2, 
      LabelPoints \[Rule] False]\)\)\)], "Input",
  CellLabel->"In[107]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.505296 0.226896 0.482847 0.226896 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.012 w
.62787 .03469 Mdot
.39237 .02808 Mdot
.47269 .04431 Mdot
.54567 .05427 Mdot
.3227 .04287 Mdot
.68393 .04849 Mdot
.22687 .08679 Mdot
.2599 .07401 Mdot
.3449 .1146 Mdot
.40519 .1041 Mdot
.47667 .11432 Mdot
.58107 .11371 Mdot
.71162 .11404 Mdot
.82023 .10693 Mdot
.18993 .14032 Mdot
.28838 .14542 Mdot
.42428 .15858 Mdot
.63725 .13111 Mdot
.24625 .1859 Mdot
.54101 .15249 Mdot
.58929 .19404 Mdot
.75052 .15262 Mdot
.35024 .17256 Mdot
.48896 .16901 Mdot
.53326 .20918 Mdot
.67673 .17787 Mdot
.69971 .22507 Mdot
.76821 .19322 Mdot
.85061 .16836 Mdot
.33479 .22351 Mdot
.39215 .19293 Mdot
.44801 .20602 Mdot
.63391 .21663 Mdot
.1117 .19458 Mdot
.29607 .21649 Mdot
.36946 .23913 Mdot
.41479 .2438 Mdot
.4862 .22751 Mdot
.79056 .23224 Mdot
.18076 .22835 Mdot
.23087 .24492 Mdot
.2801 .26075 Mdot
.45195 .262 Mdot
.51089 .26265 Mdot
.63772 .26866 Mdot
.90325 .23276 Mdot
.32212 .28009 Mdot
.36531 .27738 Mdot
.48789 .28385 Mdot
.5544 .24785 Mdot
.7387 .25872 Mdot
.83259 .25481 Mdot
.1859 .30807 Mdot
.40094 .28928 Mdot
.43968 .29688 Mdot
.55053 .29178 Mdot
.59448 .26194 Mdot
.68093 .28025 Mdot
.73799 .30288 Mdot
.79048 .30396 Mdot
.12342 .27293 Mdot
.23415 .29855 Mdot
.28846 .31052 Mdot
.3442 .31712 Mdot
.39803 .32178 Mdot
.48624 .31086 Mdot
.53022 .31202 Mdot
.58256 .3109 Mdot
.61589 .31879 Mdot
.64635 .32484 Mdot
.11167 .33694 Mdot
.2838 .3401 Mdot
.37753 .33596 Mdot
.42274 .3478 Mdot
.4455 .32904 Mdot
.4804 .34115 Mdot
.51697 .34031 Mdot
.58781 .35595 Mdot
.6811 .33442 Mdot
.7193 .33071 Mdot
.86197 .31091 Mdot
.03197 .34679 Mdot
.21583 .36594 Mdot
.25185 .3539 Mdot
.30751 .36275 Mdot
.33754 .35016 Mdot
.46828 .36255 Mdot
.55446 .34537 Mdot
.79166 .34535 Mdot
.93571 .31673 Mdot
.97063 .34423 Mdot
.16609 .37062 Mdot
.28204 .39937 Mdot
.35663 .37661 Mdot
.51096 .36629 Mdot
.54441 .37707 Mdot
.62131 .37075 Mdot
.66285 .37262 Mdot
.7225 .37049 Mdot
.7648 .37126 Mdot
.83491 .36725 Mdot
.89355 .38509 Mdot
.10408 .40324 Mdot
.32471 .39959 Mdot
.37558 .38707 Mdot
.39963 .3708 Mdot
.42209 .39409 Mdot
.44285 .37675 Mdot
.46146 .39855 Mdot
.4825 .39128 Mdot
.50758 .39537 Mdot
.53036 .40237 Mdot
.57393 .38815 Mdot
.83947 .42533 Mdot
.34656 .42437 Mdot
.38295 .41145 Mdot
.4089 .41421 Mdot
.44917 .41686 Mdot
.49144 .42183 Mdot
.53654 .42819 Mdot
.56096 .41657 Mdot
.59994 .40564 Mdot
.63095 .41508 Mdot
.66645 .40932 Mdot
.70317 .40154 Mdot
.17862 .42036 Mdot
.23949 .41296 Mdot
.31882 .43982 Mdot
.37117 .43731 Mdot
.41641 .4373 Mdot
.44055 .43964 Mdot
.47217 .43134 Mdot
.51145 .4328 Mdot
.57785 .43616 Mdot
.73989 .42335 Mdot
.78414 .41062 Mdot
.896 .45791 Mdot
.96424 .4072 Mdot
.03228 .43951 Mdot
.18726 .45789 Mdot
.25018 .44905 Mdot
.28896 .44969 Mdot
.38042 .45975 Mdot
.40715 .46013 Mdot
.47145 .45101 Mdot
.49703 .45331 Mdot
.5241 .45986 Mdot
.54197 .45061 Mdot
.56592 .45728 Mdot
.60437 .44397 Mdot
.65905 .44439 Mdot
.69975 .44718 Mdot
.75941 .4633 Mdot
.80301 .45844 Mdot
.975 .47345 Mdot
.23743 .48397 Mdot
.29845 .48562 Mdot
.34125 .46981 Mdot
.37499 .48867 Mdot
.43627 .4676 Mdot
.45885 .46592 Mdot
.48802 .47358 Mdot
.5122 .47488 Mdot
.55147 .47982 Mdot
.62159 .46187 Mdot
.65433 .47667 Mdot
.72798 .47722 Mdot
.81829 .49403 Mdot
.11389 .46401 Mdot
.26278 .50809 Mdot
.32927 .50426 Mdot
.39676 .49918 Mdot
.4194 .48881 Mdot
.4535 .49382 Mdot
.47395 .48911 Mdot
.49825 .4944 Mdot
.52167 .49132 Mdot
.5383 .49192 Mdot
.58539 .47598 Mdot
.60221 .49866 Mdot
.62923 .49853 Mdot
.68509 .48697 Mdot
.025 .50226 Mdot
.18521 .50465 Mdot
.35617 .51646 Mdot
.39482 .52405 Mdot
.43275 .51091 Mdot
.46055 .51943 Mdot
.48231 .51208 Mdot
.5118 .51312 Mdot
.54658 .51324 Mdot
.57273 .50541 Mdot
.66619 .51922 Mdot
.71703 .51156 Mdot
.86892 .50715 Mdot
.96355 .5376 Mdot
.13134 .51409 Mdot
.21512 .54136 Mdot
.25454 .56928 Mdot
.28661 .53333 Mdot
.35364 .54491 Mdot
.4245 .53585 Mdot
.44885 .54349 Mdot
.49351 .53211 Mdot
.52899 .52564 Mdot
.56599 .53326 Mdot
.60017 .53183 Mdot
.63324 .53021 Mdot
.70886 .53894 Mdot
.76423 .51281 Mdot
.07353 .56089 Mdot
.14885 .57088 Mdot
.31534 .54814 Mdot
.38764 .55511 Mdot
.47404 .54526 Mdot
.51015 .54883 Mdot
.5334 .55438 Mdot
.55626 .55518 Mdot
.73383 .56105 Mdot
.76876 .5742 Mdot
.79584 .54312 Mdot
.83661 .56145 Mdot
.04852 .63449 Mdot
.19501 .59536 Mdot
.30965 .58212 Mdot
.41488 .5617 Mdot
.47322 .56807 Mdot
.49777 .56891 Mdot
.59221 .56031 Mdot
.63573 .56169 Mdot
.67476 .55505 Mdot
.90061 .56578 Mdot
.13462 .64475 Mdot
.27534 .61084 Mdot
.35566 .58091 Mdot
.43441 .57751 Mdot
.45731 .58224 Mdot
.50678 .58554 Mdot
.53001 .58689 Mdot
.55998 .58505 Mdot
.58585 .59669 Mdot
.61422 .58869 Mdot
.63138 .61288 Mdot
.65984 .60474 Mdot
.68293 .58788 Mdot
.71331 .59586 Mdot
.81726 .61231 Mdot
.3373 .61167 Mdot
.38755 .59391 Mdot
.4191 .60292 Mdot
.44712 .62312 Mdot
.47227 .60627 Mdot
.4938 .6089 Mdot
.6786 .6438 Mdot
.72493 .62799 Mdot
.41387 .63606 Mdot
.46534 .64526 Mdot
.50919 .62977 Mdot
.53704 .61706 Mdot
.55576 .63393 Mdot
.58354 .62556 Mdot
.77238 .62297 Mdot
.8784 .62318 Mdot
.2226 .63099 Mdot
.31881 .63955 Mdot
.37695 .62837 Mdot
.49531 .6599 Mdot
.53483 .66421 Mdot
.60293 .65039 Mdot
.63912 .656 Mdot
.1949 .68545 Mdot
.36556 .65701 Mdot
.41849 .66634 Mdot
.45061 .67179 Mdot
.50087 .69757 Mdot
.53798 .71057 Mdot
.5734 .67917 Mdot
.70247 .68312 Mdot
.75874 .6712 Mdot
.90864 .68529 Mdot
.30636 .68567 Mdot
.34697 .69291 Mdot
.38873 .68926 Mdot
.43561 .71925 Mdot
.47042 .70927 Mdot
.75464 .71844 Mdot
.82395 .67347 Mdot
.26555 .6626 Mdot
.40211 .72085 Mdot
.58274 .73389 Mdot
.61604 .7004 Mdot
.66214 .70532 Mdot
.82844 .73314 Mdot
.90998 .74759 Mdot
.25268 .71343 Mdot
.33812 .73076 Mdot
.10299 .74921 Mdot
.13225 .73842 Mdot
.20123 .76362 Mdot
.27317 .75818 Mdot
.38453 .75072 Mdot
.45092 .76535 Mdot
.50188 .75194 Mdot
.63573 .75779 Mdot
.70048 .75145 Mdot
.77036 .77843 Mdot
.31541 .75799 Mdot
.39667 .78938 Mdot
.55071 .76764 Mdot
.68365 .81647 Mdot
.85565 .81002 Mdot
.25727 .81591 Mdot
.33499 .80225 Mdot
.18466 .84963 Mdot
.2982 .86989 Mdot
.37238 .85121 Mdot
.55286 .82326 Mdot
.60971 .80794 Mdot
.76376 .84764 Mdot
.43939 .8249 Mdot
.49531 .8095 Mdot
.26376 .91243 Mdot
.36311 .92697 Mdot
.43624 .88764 Mdot
.63382 .87675 Mdot
.50288 .87802 Mdot
.56997 .89213 Mdot
.70387 .90304 Mdot
.4548 .96564 Mdot
.51481 .96295 Mdot
.54502 .97192 Mdot
.003 w
[ ] 0 setdash
.62787 .03469 m
.39237 .02808 L
s
.62787 .03469 m
.47269 .04431 L
s
.62787 .03469 m
.54567 .05427 L
s
.62787 .03469 m
.68393 .04849 L
s
.62787 .03469 m
.58107 .11371 L
s
.62787 .03469 m
.63725 .13111 L
s
.39237 .02808 m
.47269 .04431 L
s
.39237 .02808 m
.3227 .04287 L
s
.39237 .02808 m
.3449 .1146 L
s
.39237 .02808 m
.40519 .1041 L
s
.47269 .04431 m
.54567 .05427 L
s
.47269 .04431 m
.40519 .1041 L
s
.47269 .04431 m
.47667 .11432 L
s
.54567 .05427 m
.47667 .11432 L
s
.54567 .05427 m
.58107 .11371 L
s
.54567 .05427 m
.54101 .15249 L
s
.3227 .04287 m
.22687 .08679 L
s
.3227 .04287 m
.2599 .07401 L
s
.3227 .04287 m
.3449 .1146 L
s
.68393 .04849 m
.71162 .11404 L
s
.68393 .04849 m
.82023 .10693 L
s
.68393 .04849 m
.63725 .13111 L
s
.22687 .08679 m
.2599 .07401 L
s
.22687 .08679 m
.18993 .14032 L
s
.22687 .08679 m
.28838 .14542 L
s
.22687 .08679 m
.1117 .19458 L
s
.2599 .07401 m
.3449 .1146 L
s
.2599 .07401 m
.28838 .14542 L
s
.3449 .1146 m
.40519 .1041 L
s
.3449 .1146 m
.28838 .14542 L
s
.3449 .1146 m
.35024 .17256 L
s
.40519 .1041 m
.47667 .11432 L
s
.40519 .1041 m
.42428 .15858 L
s
.40519 .1041 m
.35024 .17256 L
s
.47667 .11432 m
.42428 .15858 L
s
.47667 .11432 m
.54101 .15249 L
s
.47667 .11432 m
.48896 .16901 L
s
.58107 .11371 m
.63725 .13111 L
s
.58107 .11371 m
.54101 .15249 L
s
.58107 .11371 m
.58929 .19404 L
s
.71162 .11404 m
.82023 .10693 L
s
.71162 .11404 m
.63725 .13111 L
s
.71162 .11404 m
.75052 .15262 L
s
.71162 .11404 m
.67673 .17787 L
s
.82023 .10693 m
.75052 .15262 L
s
.82023 .10693 m
.85061 .16836 L
s
.82023 .10693 m
.90325 .23276 L
s
.18993 .14032 m
.28838 .14542 L
s
.18993 .14032 m
.24625 .1859 L
s
.18993 .14032 m
.1117 .19458 L
s
.18993 .14032 m
.18076 .22835 L
s
.28838 .14542 m
.24625 .1859 L
s
.28838 .14542 m
.35024 .17256 L
s
.28838 .14542 m
.29607 .21649 L
s
.42428 .15858 m
.35024 .17256 L
s
.42428 .15858 m
.48896 .16901 L
s
.42428 .15858 m
.39215 .19293 L
s
.42428 .15858 m
.44801 .20602 L
s
.63725 .13111 m
.58929 .19404 L
s
.63725 .13111 m
.67673 .17787 L
s
.63725 .13111 m
.63391 .21663 L
s
.24625 .1859 m
.29607 .21649 L
s
.24625 .1859 m
.18076 .22835 L
s
.24625 .1859 m
.23087 .24492 L
s
.54101 .15249 m
.58929 .19404 L
s
.54101 .15249 m
.48896 .16901 L
s
.54101 .15249 m
.53326 .20918 L
s
.58929 .19404 m
.53326 .20918 L
s
.58929 .19404 m
.63391 .21663 L
s
.58929 .19404 m
.5544 .24785 L
s
.58929 .19404 m
.59448 .26194 L
s
.75052 .15262 m
.67673 .17787 L
s
.75052 .15262 m
.69971 .22507 L
s
.75052 .15262 m
.76821 .19322 L
s
.75052 .15262 m
.85061 .16836 L
s
.35024 .17256 m
.33479 .22351 L
s
.35024 .17256 m
.39215 .19293 L
s
.35024 .17256 m
.29607 .21649 L
s
.48896 .16901 m
.53326 .20918 L
s
.48896 .16901 m
.44801 .20602 L
s
.48896 .16901 m
.4862 .22751 L
s
.53326 .20918 m
.4862 .22751 L
s
.53326 .20918 m
.51089 .26265 L
s
.53326 .20918 m
.5544 .24785 L
s
.67673 .17787 m
.69971 .22507 L
s
.67673 .17787 m
.63391 .21663 L
s
.69971 .22507 m
.76821 .19322 L
s
.69971 .22507 m
.63391 .21663 L
s
.69971 .22507 m
.63772 .26866 L
s
.69971 .22507 m
.7387 .25872 L
s
.69971 .22507 m
.68093 .28025 L
s
.76821 .19322 m
.85061 .16836 L
s
.76821 .19322 m
.79056 .23224 L
s
.76821 .19322 m
.7387 .25872 L
s
.85061 .16836 m
.79056 .23224 L
s
.85061 .16836 m
.90325 .23276 L
s
.85061 .16836 m
.83259 .25481 L
s
.33479 .22351 m
.39215 .19293 L
s
.33479 .22351 m
.29607 .21649 L
s
.33479 .22351 m
.36946 .23913 L
s
.33479 .22351 m
.2801 .26075 L
s
.33479 .22351 m
.32212 .28009 L
s
.39215 .19293 m
.44801 .20602 L
s
.39215 .19293 m
.36946 .23913 L
s
.39215 .19293 m
.41479 .2438 L
s
.44801 .20602 m
.41479 .2438 L
s
.44801 .20602 m
.4862 .22751 L
s
.44801 .20602 m
.45195 .262 L
s
.63391 .21663 m
.63772 .26866 L
s
.63391 .21663 m
.59448 .26194 L
s
.1117 .19458 m
.18076 .22835 L
s
.1117 .19458 m
.12342 .27293 L
s
.1117 .19458 m
.03197 .34679 L
s
.29607 .21649 m
.23087 .24492 L
s
.29607 .21649 m
.2801 .26075 L
s
.36946 .23913 m
.41479 .2438 L
s
.36946 .23913 m
.32212 .28009 L
s
.36946 .23913 m
.36531 .27738 L
s
.41479 .2438 m
.45195 .262 L
s
.41479 .2438 m
.36531 .27738 L
s
.41479 .2438 m
.40094 .28928 L
s
.4862 .22751 m
.45195 .262 L
s
.4862 .22751 m
.51089 .26265 L
s
.4862 .22751 m
.48789 .28385 L
s
.79056 .23224 m
.7387 .25872 L
s
.79056 .23224 m
.83259 .25481 L
s
.79056 .23224 m
.79048 .30396 L
s
.18076 .22835 m
.23087 .24492 L
s
.18076 .22835 m
.1859 .30807 L
s
.18076 .22835 m
.12342 .27293 L
s
.23087 .24492 m
.2801 .26075 L
s
.23087 .24492 m
.1859 .30807 L
s
.23087 .24492 m
.23415 .29855 L
s
.2801 .26075 m
.32212 .28009 L
s
.2801 .26075 m
.23415 .29855 L
s
.2801 .26075 m
.28846 .31052 L
s
.45195 .262 m
.48789 .28385 L
s
.45195 .262 m
.40094 .28928 L
s
.45195 .262 m
.43968 .29688 L
s
.51089 .26265 m
.48789 .28385 L
s
.51089 .26265 m
.5544 .24785 L
s
.51089 .26265 m
.55053 .29178 L
s
.51089 .26265 m
.53022 .31202 L
s
.63772 .26866 m
.59448 .26194 L
s
.63772 .26866 m
.68093 .28025 L
s
.63772 .26866 m
.61589 .31879 L
s
.63772 .26866 m
.64635 .32484 L
s
.90325 .23276 m
.83259 .25481 L
s
.90325 .23276 m
.86197 .31091 L
s
.90325 .23276 m
.93571 .31673 L
s
.90325 .23276 m
.97063 .34423 L
s
.32212 .28009 m
.36531 .27738 L
s
.32212 .28009 m
.28846 .31052 L
s
.32212 .28009 m
.3442 .31712 L
s
.36531 .27738 m
.40094 .28928 L
s
.36531 .27738 m
.3442 .31712 L
s
.36531 .27738 m
.39803 .32178 L
s
.36531 .27738 m
.37753 .33596 L
s
.48789 .28385 m
.43968 .29688 L
s
.48789 .28385 m
.48624 .31086 L
s
.48789 .28385 m
.53022 .31202 L
s
.5544 .24785 m
.55053 .29178 L
s
.5544 .24785 m
.59448 .26194 L
s
.7387 .25872 m
.68093 .28025 L
s
.7387 .25872 m
.73799 .30288 L
s
.7387 .25872 m
.79048 .30396 L
s
.83259 .25481 m
.79048 .30396 L
s
.83259 .25481 m
.86197 .31091 L
s
.1859 .30807 m
.12342 .27293 L
s
.1859 .30807 m
.23415 .29855 L
s
.1859 .30807 m
.11167 .33694 L
s
.1859 .30807 m
.21583 .36594 L
s
.1859 .30807 m
.16609 .37062 L
s
.40094 .28928 m
.43968 .29688 L
s
.40094 .28928 m
.39803 .32178 L
s
.43968 .29688 m
.39803 .32178 L
s
.43968 .29688 m
.48624 .31086 L
s
.43968 .29688 m
.4455 .32904 L
s
.55053 .29178 m
.59448 .26194 L
s
.55053 .29178 m
.53022 .31202 L
s
.55053 .29178 m
.58256 .3109 L
s
.59448 .26194 m
.58256 .3109 L
s
.59448 .26194 m
.61589 .31879 L
s
.68093 .28025 m
.73799 .30288 L
s
.68093 .28025 m
.64635 .32484 L
s
.68093 .28025 m
.6811 .33442 L
s
.68093 .28025 m
.7193 .33071 L
s
.73799 .30288 m
.79048 .30396 L
s
.73799 .30288 m
.7193 .33071 L
s
.73799 .30288 m
.79166 .34535 L
s
.79048 .30396 m
.86197 .31091 L
s
.79048 .30396 m
.79166 .34535 L
s
.12342 .27293 m
.11167 .33694 L
s
.12342 .27293 m
.03197 .34679 L
s
.23415 .29855 m
.28846 .31052 L
s
.23415 .29855 m
.2838 .3401 L
s
.23415 .29855 m
.21583 .36594 L
s
.23415 .29855 m
.25185 .3539 L
s
.28846 .31052 m
.3442 .31712 L
s
.28846 .31052 m
.2838 .3401 L
s
.28846 .31052 m
.33754 .35016 L
s
.3442 .31712 m
.37753 .33596 L
s
.3442 .31712 m
.33754 .35016 L
s
.39803 .32178 m
.37753 .33596 L
s
.39803 .32178 m
.42274 .3478 L
s
.39803 .32178 m
.4455 .32904 L
s
.48624 .31086 m
.53022 .31202 L
s
.48624 .31086 m
.4455 .32904 L
s
.48624 .31086 m
.4804 .34115 L
s
.48624 .31086 m
.51697 .34031 L
s
.53022 .31202 m
.58256 .3109 L
s
.53022 .31202 m
.51697 .34031 L
s
.53022 .31202 m
.55446 .34537 L
s
.58256 .3109 m
.61589 .31879 L
s
.58256 .3109 m
.58781 .35595 L
s
.58256 .3109 m
.55446 .34537 L
s
.61589 .31879 m
.64635 .32484 L
s
.61589 .31879 m
.58781 .35595 L
s
.61589 .31879 m
.62131 .37075 L
s
.64635 .32484 m
.6811 .33442 L
s
.64635 .32484 m
.62131 .37075 L
s
.64635 .32484 m
.66285 .37262 L
s
.11167 .33694 m
.03197 .34679 L
s
.11167 .33694 m
.16609 .37062 L
s
.11167 .33694 m
.10408 .40324 L
s
.2838 .3401 m
.25185 .3539 L
s
.2838 .3401 m
.30751 .36275 L
s
.2838 .3401 m
.33754 .35016 L
s
.2838 .3401 m
.28204 .39937 L
s
.37753 .33596 m
.42274 .3478 L
s
.37753 .33596 m
.33754 .35016 L
s
.37753 .33596 m
.35663 .37661 L
s
.37753 .33596 m
.39963 .3708 L
s
.42274 .3478 m
.4455 .32904 L
s
.42274 .3478 m
.39963 .3708 L
s
.42274 .3478 m
.44285 .37675 L
s
.4455 .32904 m
.4804 .34115 L
s
.4455 .32904 m
.46828 .36255 L
s
.4455 .32904 m
.44285 .37675 L
s
.4804 .34115 m
.51697 .34031 L
s
.4804 .34115 m
.46828 .36255 L
s
.4804 .34115 m
.51096 .36629 L
s
.51697 .34031 m
.55446 .34537 L
s
.51697 .34031 m
.51096 .36629 L
s
.51697 .34031 m
.54441 .37707 L
s
.58781 .35595 m
.55446 .34537 L
s
.58781 .35595 m
.62131 .37075 L
s
.58781 .35595 m
.57393 .38815 L
s
.6811 .33442 m
.7193 .33071 L
s
.6811 .33442 m
.66285 .37262 L
s
.6811 .33442 m
.7225 .37049 L
s
.7193 .33071 m
.79166 .34535 L
s
.7193 .33071 m
.7225 .37049 L
s
.7193 .33071 m
.7648 .37126 L
s
.86197 .31091 m
.79166 .34535 L
s
.86197 .31091 m
.93571 .31673 L
s
.86197 .31091 m
.83491 .36725 L
s
.86197 .31091 m
.89355 .38509 L
s
.03197 .34679 m
.10408 .40324 L
s
.03197 .34679 m
.03228 .43951 L
s
.03197 .34679 m
.025 .50226 L
s
.21583 .36594 m
.25185 .3539 L
s
.21583 .36594 m
.16609 .37062 L
s
.21583 .36594 m
.17862 .42036 L
s
.21583 .36594 m
.23949 .41296 L
s
.25185 .3539 m
.28204 .39937 L
s
.25185 .3539 m
.23949 .41296 L
s
.30751 .36275 m
.33754 .35016 L
s
.30751 .36275 m
.28204 .39937 L
s
.30751 .36275 m
.32471 .39959 L
s
.33754 .35016 m
.35663 .37661 L
s
.33754 .35016 m
.32471 .39959 L
s
.46828 .36255 m
.51096 .36629 L
s
.46828 .36255 m
.44285 .37675 L
s
.46828 .36255 m
.46146 .39855 L
s
.46828 .36255 m
.4825 .39128 L
s
.55446 .34537 m
.54441 .37707 L
s
.55446 .34537 m
.57393 .38815 L
s
.79166 .34535 m
.7648 .37126 L
s
.79166 .34535 m
.83491 .36725 L
s
.79166 .34535 m
.78414 .41062 L
s
.93571 .31673 m
.97063 .34423 L
s
.93571 .31673 m
.89355 .38509 L
s
.97063 .34423 m
.89355 .38509 L
s
.97063 .34423 m
.96424 .4072 L
s
.97063 .34423 m
.975 .47345 L
s
.16609 .37062 m
.10408 .40324 L
s
.16609 .37062 m
.17862 .42036 L
s
.28204 .39937 m
.32471 .39959 L
s
.28204 .39937 m
.23949 .41296 L
s
.28204 .39937 m
.31882 .43982 L
s
.28204 .39937 m
.25018 .44905 L
s
.28204 .39937 m
.28896 .44969 L
s
.35663 .37661 m
.32471 .39959 L
s
.35663 .37661 m
.37558 .38707 L
s
.35663 .37661 m
.39963 .3708 L
s
.35663 .37661 m
.34656 .42437 L
s
.51096 .36629 m
.54441 .37707 L
s
.51096 .36629 m
.4825 .39128 L
s
.51096 .36629 m
.50758 .39537 L
s
.51096 .36629 m
.53036 .40237 L
s
.54441 .37707 m
.53036 .40237 L
s
.54441 .37707 m
.57393 .38815 L
s
.54441 .37707 m
.56096 .41657 L
s
.62131 .37075 m
.66285 .37262 L
s
.62131 .37075 m
.57393 .38815 L
s
.62131 .37075 m
.59994 .40564 L
s
.62131 .37075 m
.63095 .41508 L
s
.66285 .37262 m
.7225 .37049 L
s
.66285 .37262 m
.63095 .41508 L
s
.66285 .37262 m
.66645 .40932 L
s
.66285 .37262 m
.70317 .40154 L
s
.7225 .37049 m
.7648 .37126 L
s
.7225 .37049 m
.70317 .40154 L
s
.7225 .37049 m
.73989 .42335 L
s
.7648 .37126 m
.73989 .42335 L
s
.7648 .37126 m
.78414 .41062 L
s
.83491 .36725 m
.89355 .38509 L
s
.83491 .36725 m
.83947 .42533 L
s
.83491 .36725 m
.78414 .41062 L
s
.89355 .38509 m
.83947 .42533 L
s
.89355 .38509 m
.896 .45791 L
s
.89355 .38509 m
.96424 .4072 L
s
.10408 .40324 m
.17862 .42036 L
s
.10408 .40324 m
.03228 .43951 L
s
.10408 .40324 m
.11389 .46401 L
s
.32471 .39959 m
.34656 .42437 L
s
.32471 .39959 m
.31882 .43982 L
s
.37558 .38707 m
.39963 .3708 L
s
.37558 .38707 m
.34656 .42437 L
s
.37558 .38707 m
.38295 .41145 L
s
.39963 .3708 m
.42209 .39409 L
s
.39963 .3708 m
.44285 .37675 L
s
.39963 .3708 m
.38295 .41145 L
s
.39963 .3708 m
.4089 .41421 L
s
.42209 .39409 m
.44285 .37675 L
s
.42209 .39409 m
.46146 .39855 L
s
.42209 .39409 m
.4089 .41421 L
s
.42209 .39409 m
.44917 .41686 L
s
.44285 .37675 m
.46146 .39855 L
s
.46146 .39855 m
.4825 .39128 L
s
.46146 .39855 m
.44917 .41686 L
s
.46146 .39855 m
.49144 .42183 L
s
.46146 .39855 m
.47217 .43134 L
s
.4825 .39128 m
.50758 .39537 L
s
.4825 .39128 m
.49144 .42183 L
s
.50758 .39537 m
.53036 .40237 L
s
.50758 .39537 m
.49144 .42183 L
s
.50758 .39537 m
.51145 .4328 L
s
.53036 .40237 m
.53654 .42819 L
s
.53036 .40237 m
.56096 .41657 L
s
.53036 .40237 m
.51145 .4328 L
s
.57393 .38815 m
.56096 .41657 L
s
.57393 .38815 m
.59994 .40564 L
s
.83947 .42533 m
.78414 .41062 L
s
.83947 .42533 m
.896 .45791 L
s
.83947 .42533 m
.80301 .45844 L
s
.83947 .42533 m
.81829 .49403 L
s
.83947 .42533 m
.86892 .50715 L
s
.34656 .42437 m
.38295 .41145 L
s
.34656 .42437 m
.31882 .43982 L
s
.34656 .42437 m
.37117 .43731 L
s
.34656 .42437 m
.34125 .46981 L
s
.38295 .41145 m
.4089 .41421 L
s
.38295 .41145 m
.37117 .43731 L
s
.38295 .41145 m
.41641 .4373 L
s
.4089 .41421 m
.44917 .41686 L
s
.4089 .41421 m
.41641 .4373 L
s
.44917 .41686 m
.41641 .4373 L
s
.44917 .41686 m
.44055 .43964 L
s
.44917 .41686 m
.47217 .43134 L
s
.49144 .42183 m
.47217 .43134 L
s
.49144 .42183 m
.51145 .4328 L
s
.49144 .42183 m
.49703 .45331 L
s
.53654 .42819 m
.56096 .41657 L
s
.53654 .42819 m
.51145 .4328 L
s
.53654 .42819 m
.5241 .45986 L
s
.53654 .42819 m
.54197 .45061 L
s
.56096 .41657 m
.59994 .40564 L
s
.56096 .41657 m
.57785 .43616 L
s
.56096 .41657 m
.54197 .45061 L
s
.59994 .40564 m
.63095 .41508 L
s
.59994 .40564 m
.57785 .43616 L
s
.59994 .40564 m
.60437 .44397 L
s
.63095 .41508 m
.66645 .40932 L
s
.63095 .41508 m
.60437 .44397 L
s
.63095 .41508 m
.65905 .44439 L
s
.63095 .41508 m
.62159 .46187 L
s
.66645 .40932 m
.70317 .40154 L
s
.66645 .40932 m
.65905 .44439 L
s
.66645 .40932 m
.69975 .44718 L
s
.70317 .40154 m
.73989 .42335 L
s
.70317 .40154 m
.69975 .44718 L
s
.17862 .42036 m
.23949 .41296 L
s
.17862 .42036 m
.18726 .45789 L
s
.17862 .42036 m
.11389 .46401 L
s
.23949 .41296 m
.18726 .45789 L
s
.23949 .41296 m
.25018 .44905 L
s
.31882 .43982 m
.28896 .44969 L
s
.31882 .43982 m
.29845 .48562 L
s
.31882 .43982 m
.34125 .46981 L
s
.37117 .43731 m
.41641 .4373 L
s
.37117 .43731 m
.38042 .45975 L
s
.37117 .43731 m
.34125 .46981 L
s
.41641 .4373 m
.44055 .43964 L
s
.41641 .4373 m
.38042 .45975 L
s
.41641 .4373 m
.40715 .46013 L
s
.41641 .4373 m
.43627 .4676 L
s
.44055 .43964 m
.47217 .43134 L
s
.44055 .43964 m
.47145 .45101 L
s
.44055 .43964 m
.43627 .4676 L
s
.44055 .43964 m
.45885 .46592 L
s
.47217 .43134 m
.47145 .45101 L
s
.47217 .43134 m
.49703 .45331 L
s
.51145 .4328 m
.49703 .45331 L
s
.51145 .4328 m
.5241 .45986 L
s
.57785 .43616 m
.54197 .45061 L
s
.57785 .43616 m
.56592 .45728 L
s
.57785 .43616 m
.60437 .44397 L
s
.73989 .42335 m
.78414 .41062 L
s
.73989 .42335 m
.69975 .44718 L
s
.73989 .42335 m
.75941 .4633 L
s
.73989 .42335 m
.72798 .47722 L
s
.78414 .41062 m
.75941 .4633 L
s
.78414 .41062 m
.80301 .45844 L
s
.896 .45791 m
.96424 .4072 L
s
.896 .45791 m
.975 .47345 L
s
.896 .45791 m
.86892 .50715 L
s
.896 .45791 m
.96355 .5376 L
s
.96424 .4072 m
.975 .47345 L
s
.03228 .43951 m
.11389 .46401 L
s
.03228 .43951 m
.025 .50226 L
s
.18726 .45789 m
.25018 .44905 L
s
.18726 .45789 m
.23743 .48397 L
s
.18726 .45789 m
.11389 .46401 L
s
.18726 .45789 m
.18521 .50465 L
s
.18726 .45789 m
.13134 .51409 L
s
.25018 .44905 m
.28896 .44969 L
s
.25018 .44905 m
.23743 .48397 L
s
.25018 .44905 m
.29845 .48562 L
s
.28896 .44969 m
.29845 .48562 L
s
.38042 .45975 m
.40715 .46013 L
s
.38042 .45975 m
.34125 .46981 L
s
.38042 .45975 m
.37499 .48867 L
s
.40715 .46013 m
.37499 .48867 L
s
.40715 .46013 m
.43627 .4676 L
s
.40715 .46013 m
.39676 .49918 L
s
.40715 .46013 m
.4194 .48881 L
s
.47145 .45101 m
.49703 .45331 L
s
.47145 .45101 m
.45885 .46592 L
s
.47145 .45101 m
.48802 .47358 L
s
.49703 .45331 m
.5241 .45986 L
s
.49703 .45331 m
.48802 .47358 L
s
.49703 .45331 m
.5122 .47488 L
s
.5241 .45986 m
.54197 .45061 L
s
.5241 .45986 m
.5122 .47488 L
s
.5241 .45986 m
.55147 .47982 L
s
.5241 .45986 m
.52167 .49132 L
s
.5241 .45986 m
.5383 .49192 L
s
.54197 .45061 m
.56592 .45728 L
s
.54197 .45061 m
.55147 .47982 L
s
.56592 .45728 m
.60437 .44397 L
s
.56592 .45728 m
.55147 .47982 L
s
.56592 .45728 m
.58539 .47598 L
s
.60437 .44397 m
.62159 .46187 L
s
.60437 .44397 m
.58539 .47598 L
s
.65905 .44439 m
.69975 .44718 L
s
.65905 .44439 m
.62159 .46187 L
s
.65905 .44439 m
.65433 .47667 L
s
.65905 .44439 m
.68509 .48697 L
s
.69975 .44718 m
.72798 .47722 L
s
.69975 .44718 m
.68509 .48697 L
s
.75941 .4633 m
.80301 .45844 L
s
.75941 .4633 m
.72798 .47722 L
s
.75941 .4633 m
.76423 .51281 L
s
.80301 .45844 m
.81829 .49403 L
s
.80301 .45844 m
.76423 .51281 L
s
.975 .47345 m
.96355 .5376 L
s
.23743 .48397 m
.29845 .48562 L
s
.23743 .48397 m
.26278 .50809 L
s
.23743 .48397 m
.18521 .50465 L
s
.23743 .48397 m
.21512 .54136 L
s
.29845 .48562 m
.34125 .46981 L
s
.29845 .48562 m
.26278 .50809 L
s
.29845 .48562 m
.32927 .50426 L
s
.29845 .48562 m
.28661 .53333 L
s
.34125 .46981 m
.37499 .48867 L
s
.34125 .46981 m
.32927 .50426 L
s
.37499 .48867 m
.32927 .50426 L
s
.37499 .48867 m
.39676 .49918 L
s
.37499 .48867 m
.35617 .51646 L
s
.37499 .48867 m
.39482 .52405 L
s
.43627 .4676 m
.45885 .46592 L
s
.43627 .4676 m
.4194 .48881 L
s
.43627 .4676 m
.4535 .49382 L
s
.45885 .46592 m
.48802 .47358 L
s
.45885 .46592 m
.4535 .49382 L
s
.45885 .46592 m
.47395 .48911 L
s
.48802 .47358 m
.5122 .47488 L
s
.48802 .47358 m
.47395 .48911 L
s
.48802 .47358 m
.49825 .4944 L
s
.5122 .47488 m
.49825 .4944 L
s
.5122 .47488 m
.52167 .49132 L
s
.55147 .47982 m
.5383 .49192 L
s
.55147 .47982 m
.58539 .47598 L
s
.55147 .47982 m
.54658 .51324 L
s
.55147 .47982 m
.57273 .50541 L
s
.62159 .46187 m
.65433 .47667 L
s
.62159 .46187 m
.58539 .47598 L
s
.62159 .46187 m
.60221 .49866 L
s
.62159 .46187 m
.62923 .49853 L
s
.65433 .47667 m
.62923 .49853 L
s
.65433 .47667 m
.68509 .48697 L
s
.65433 .47667 m
.66619 .51922 L
s
.72798 .47722 m
.68509 .48697 L
s
.72798 .47722 m
.71703 .51156 L
s
.72798 .47722 m
.76423 .51281 L
s
.81829 .49403 m
.86892 .50715 L
s
.81829 .49403 m
.76423 .51281 L
s
.81829 .49403 m
.79584 .54312 L
s
.81829 .49403 m
.83661 .56145 L
s
.11389 .46401 m
.025 .50226 L
s
.11389 .46401 m
.13134 .51409 L
s
.26278 .50809 m
.21512 .54136 L
s
.26278 .50809 m
.25454 .56928 L
s
.26278 .50809 m
.28661 .53333 L
s
.32927 .50426 m
.35617 .51646 L
s
.32927 .50426 m
.28661 .53333 L
s
.32927 .50426 m
.35364 .54491 L
s
.32927 .50426 m
.31534 .54814 L
s
.39676 .49918 m
.4194 .48881 L
s
.39676 .49918 m
.39482 .52405 L
s
.39676 .49918 m
.43275 .51091 L
s
.4194 .48881 m
.4535 .49382 L
s
.4194 .48881 m
.43275 .51091 L
s
.4535 .49382 m
.47395 .48911 L
s
.4535 .49382 m
.43275 .51091 L
s
.4535 .49382 m
.46055 .51943 L
s
.47395 .48911 m
.49825 .4944 L
s
.47395 .48911 m
.46055 .51943 L
s
.47395 .48911 m
.48231 .51208 L
s
.49825 .4944 m
.52167 .49132 L
s
.49825 .4944 m
.48231 .51208 L
s
.49825 .4944 m
.5118 .51312 L
s
.52167 .49132 m
.5383 .49192 L
s
.52167 .49132 m
.5118 .51312 L
s
.52167 .49132 m
.52899 .52564 L
s
.5383 .49192 m
.54658 .51324 L
s
.5383 .49192 m
.52899 .52564 L
s
.58539 .47598 m
.60221 .49866 L
s
.58539 .47598 m
.57273 .50541 L
s
.60221 .49866 m
.62923 .49853 L
s
.60221 .49866 m
.57273 .50541 L
s
.60221 .49866 m
.60017 .53183 L
s
.62923 .49853 m
.66619 .51922 L
s
.62923 .49853 m
.60017 .53183 L
s
.62923 .49853 m
.63324 .53021 L
s
.68509 .48697 m
.66619 .51922 L
s
.68509 .48697 m
.71703 .51156 L
s
.025 .50226 m
.13134 .51409 L
s
.025 .50226 m
.07353 .56089 L
s
.025 .50226 m
.04852 .63449 L
s
.18521 .50465 m
.13134 .51409 L
s
.18521 .50465 m
.21512 .54136 L
s
.18521 .50465 m
.14885 .57088 L
s
.35617 .51646 m
.39482 .52405 L
s
.35617 .51646 m
.35364 .54491 L
s
.39482 .52405 m
.43275 .51091 L
s
.39482 .52405 m
.35364 .54491 L
s
.39482 .52405 m
.4245 .53585 L
s
.39482 .52405 m
.38764 .55511 L
s
.43275 .51091 m
.46055 .51943 L
s
.43275 .51091 m
.4245 .53585 L
s
.43275 .51091 m
.44885 .54349 L
s
.46055 .51943 m
.48231 .51208 L
s
.46055 .51943 m
.44885 .54349 L
s
.46055 .51943 m
.47404 .54526 L
s
.48231 .51208 m
.5118 .51312 L
s
.48231 .51208 m
.49351 .53211 L
s
.48231 .51208 m
.47404 .54526 L
s
.5118 .51312 m
.49351 .53211 L
s
.5118 .51312 m
.52899 .52564 L
s
.5118 .51312 m
.51015 .54883 L
s
.54658 .51324 m
.57273 .50541 L
s
.54658 .51324 m
.52899 .52564 L
s
.54658 .51324 m
.56599 .53326 L
s
.57273 .50541 m
.56599 .53326 L
s
.57273 .50541 m
.60017 .53183 L
s
.66619 .51922 m
.71703 .51156 L
s
.66619 .51922 m
.63324 .53021 L
s
.66619 .51922 m
.70886 .53894 L
s
.66619 .51922 m
.67476 .55505 L
s
.71703 .51156 m
.70886 .53894 L
s
.71703 .51156 m
.76423 .51281 L
s
.71703 .51156 m
.73383 .56105 L
s
.86892 .50715 m
.96355 .5376 L
s
.86892 .50715 m
.83661 .56145 L
s
.86892 .50715 m
.90061 .56578 L
s
.96355 .5376 m
.90061 .56578 L
s
.96355 .5376 m
.90864 .68529 L
s
.96355 .5376 m
.90998 .74759 L
s
.13134 .51409 m
.07353 .56089 L
s
.13134 .51409 m
.14885 .57088 L
s
.21512 .54136 m
.25454 .56928 L
s
.21512 .54136 m
.14885 .57088 L
s
.21512 .54136 m
.19501 .59536 L
s
.25454 .56928 m
.28661 .53333 L
s
.25454 .56928 m
.19501 .59536 L
s
.25454 .56928 m
.30965 .58212 L
s
.25454 .56928 m
.27534 .61084 L
s
.25454 .56928 m
.2226 .63099 L
s
.28661 .53333 m
.31534 .54814 L
s
.28661 .53333 m
.30965 .58212 L
s
.35364 .54491 m
.31534 .54814 L
s
.35364 .54491 m
.38764 .55511 L
s
.35364 .54491 m
.35566 .58091 L
s
.4245 .53585 m
.44885 .54349 L
s
.4245 .53585 m
.38764 .55511 L
s
.4245 .53585 m
.41488 .5617 L
s
.44885 .54349 m
.47404 .54526 L
s
.44885 .54349 m
.41488 .5617 L
s
.44885 .54349 m
.47322 .56807 L
s
.44885 .54349 m
.43441 .57751 L
s
.44885 .54349 m
.45731 .58224 L
s
.49351 .53211 m
.47404 .54526 L
s
.49351 .53211 m
.51015 .54883 L
s
.52899 .52564 m
.56599 .53326 L
s
.52899 .52564 m
.51015 .54883 L
s
.52899 .52564 m
.5334 .55438 L
s
.52899 .52564 m
.55626 .55518 L
s
.56599 .53326 m
.60017 .53183 L
s
.56599 .53326 m
.55626 .55518 L
s
.56599 .53326 m
.59221 .56031 L
s
.60017 .53183 m
.63324 .53021 L
s
.60017 .53183 m
.59221 .56031 L
s
.60017 .53183 m
.63573 .56169 L
s
.63324 .53021 m
.63573 .56169 L
s
.63324 .53021 m
.67476 .55505 L
s
.70886 .53894 m
.73383 .56105 L
s
.70886 .53894 m
.67476 .55505 L
s
.70886 .53894 m
.68293 .58788 L
s
.70886 .53894 m
.71331 .59586 L
s
.76423 .51281 m
.73383 .56105 L
s
.76423 .51281 m
.76876 .5742 L
s
.76423 .51281 m
.79584 .54312 L
s
.07353 .56089 m
.14885 .57088 L
s
.07353 .56089 m
.04852 .63449 L
s
.07353 .56089 m
.13462 .64475 L
s
.14885 .57088 m
.19501 .59536 L
s
.14885 .57088 m
.13462 .64475 L
s
.31534 .54814 m
.30965 .58212 L
s
.31534 .54814 m
.35566 .58091 L
s
.38764 .55511 m
.41488 .5617 L
s
.38764 .55511 m
.35566 .58091 L
s
.38764 .55511 m
.38755 .59391 L
s
.47404 .54526 m
.51015 .54883 L
s
.47404 .54526 m
.47322 .56807 L
s
.47404 .54526 m
.49777 .56891 L
s
.51015 .54883 m
.5334 .55438 L
s
.51015 .54883 m
.49777 .56891 L
s
.5334 .55438 m
.55626 .55518 L
s
.5334 .55438 m
.49777 .56891 L
s
.5334 .55438 m
.50678 .58554 L
s
.5334 .55438 m
.53001 .58689 L
s
.5334 .55438 m
.55998 .58505 L
s
.55626 .55518 m
.59221 .56031 L
s
.55626 .55518 m
.55998 .58505 L
s
.73383 .56105 m
.76876 .5742 L
s
.73383 .56105 m
.71331 .59586 L
s
.76876 .5742 m
.79584 .54312 L
s
.76876 .5742 m
.83661 .56145 L
s
.76876 .5742 m
.71331 .59586 L
s
.76876 .5742 m
.81726 .61231 L
s
.76876 .5742 m
.77238 .62297 L
s
.79584 .54312 m
.83661 .56145 L
s
.83661 .56145 m
.90061 .56578 L
s
.83661 .56145 m
.81726 .61231 L
s
.83661 .56145 m
.8784 .62318 L
s
.04852 .63449 m
.13462 .64475 L
s
.04852 .63449 m
.10299 .74921 L
s
.19501 .59536 m
.13462 .64475 L
s
.19501 .59536 m
.2226 .63099 L
s
.30965 .58212 m
.27534 .61084 L
s
.30965 .58212 m
.35566 .58091 L
s
.30965 .58212 m
.3373 .61167 L
s
.30965 .58212 m
.31881 .63955 L
s
.41488 .5617 m
.43441 .57751 L
s
.41488 .5617 m
.38755 .59391 L
s
.41488 .5617 m
.4191 .60292 L
s
.47322 .56807 m
.49777 .56891 L
s
.47322 .56807 m
.45731 .58224 L
s
.47322 .56807 m
.50678 .58554 L
s
.47322 .56807 m
.47227 .60627 L
s
.49777 .56891 m
.50678 .58554 L
s
.59221 .56031 m
.63573 .56169 L
s
.59221 .56031 m
.55998 .58505 L
s
.59221 .56031 m
.58585 .59669 L
s
.59221 .56031 m
.61422 .58869 L
s
.63573 .56169 m
.67476 .55505 L
s
.63573 .56169 m
.61422 .58869 L
s
.63573 .56169 m
.65984 .60474 L
s
.63573 .56169 m
.68293 .58788 L
s
.67476 .55505 m
.68293 .58788 L
s
.90061 .56578 m
.8784 .62318 L
s
.90061 .56578 m
.90864 .68529 L
s
.13462 .64475 m
.2226 .63099 L
s
.13462 .64475 m
.1949 .68545 L
s
.13462 .64475 m
.10299 .74921 L
s
.13462 .64475 m
.13225 .73842 L
s
.27534 .61084 m
.2226 .63099 L
s
.27534 .61084 m
.31881 .63955 L
s
.27534 .61084 m
.26555 .6626 L
s
.35566 .58091 m
.3373 .61167 L
s
.35566 .58091 m
.38755 .59391 L
s
.35566 .58091 m
.37695 .62837 L
s
.43441 .57751 m
.45731 .58224 L
s
.43441 .57751 m
.4191 .60292 L
s
.45731 .58224 m
.4191 .60292 L
s
.45731 .58224 m
.44712 .62312 L
s
.45731 .58224 m
.47227 .60627 L
s
.50678 .58554 m
.53001 .58689 L
s
.50678 .58554 m
.47227 .60627 L
s
.50678 .58554 m
.4938 .6089 L
s
.50678 .58554 m
.53704 .61706 L
s
.53001 .58689 m
.55998 .58505 L
s
.53001 .58689 m
.53704 .61706 L
s
.55998 .58505 m
.58585 .59669 L
s
.55998 .58505 m
.53704 .61706 L
s
.55998 .58505 m
.55576 .63393 L
s
.55998 .58505 m
.58354 .62556 L
s
.58585 .59669 m
.61422 .58869 L
s
.58585 .59669 m
.58354 .62556 L
s
.61422 .58869 m
.63138 .61288 L
s
.61422 .58869 m
.65984 .60474 L
s
.61422 .58869 m
.58354 .62556 L
s
.63138 .61288 m
.65984 .60474 L
s
.63138 .61288 m
.58354 .62556 L
s
.63138 .61288 m
.60293 .65039 L
s
.63138 .61288 m
.63912 .656 L
s
.65984 .60474 m
.68293 .58788 L
s
.65984 .60474 m
.6786 .6438 L
s
.65984 .60474 m
.63912 .656 L
s
.68293 .58788 m
.71331 .59586 L
s
.68293 .58788 m
.6786 .6438 L
s
.71331 .59586 m
.6786 .6438 L
s
.71331 .59586 m
.72493 .62799 L
s
.71331 .59586 m
.77238 .62297 L
s
.81726 .61231 m
.77238 .62297 L
s
.81726 .61231 m
.8784 .62318 L
s
.81726 .61231 m
.82395 .67347 L
s
.3373 .61167 m
.31881 .63955 L
s
.3373 .61167 m
.37695 .62837 L
s
.3373 .61167 m
.36556 .65701 L
s
.38755 .59391 m
.4191 .60292 L
s
.38755 .59391 m
.37695 .62837 L
s
.4191 .60292 m
.44712 .62312 L
s
.4191 .60292 m
.41387 .63606 L
s
.4191 .60292 m
.37695 .62837 L
s
.44712 .62312 m
.47227 .60627 L
s
.44712 .62312 m
.41387 .63606 L
s
.44712 .62312 m
.46534 .64526 L
s
.44712 .62312 m
.41849 .66634 L
s
.44712 .62312 m
.45061 .67179 L
s
.47227 .60627 m
.4938 .6089 L
s
.47227 .60627 m
.46534 .64526 L
s
.4938 .6089 m
.46534 .64526 L
s
.4938 .6089 m
.50919 .62977 L
s
.4938 .6089 m
.53704 .61706 L
s
.6786 .6438 m
.72493 .62799 L
s
.6786 .6438 m
.63912 .656 L
s
.6786 .6438 m
.70247 .68312 L
s
.6786 .6438 m
.66214 .70532 L
s
.72493 .62799 m
.77238 .62297 L
s
.72493 .62799 m
.70247 .68312 L
s
.72493 .62799 m
.75874 .6712 L
s
.41387 .63606 m
.37695 .62837 L
s
.41387 .63606 m
.36556 .65701 L
s
.41387 .63606 m
.41849 .66634 L
s
.46534 .64526 m
.50919 .62977 L
s
.46534 .64526 m
.49531 .6599 L
s
.46534 .64526 m
.45061 .67179 L
s
.50919 .62977 m
.53704 .61706 L
s
.50919 .62977 m
.49531 .6599 L
s
.50919 .62977 m
.53483 .66421 L
s
.53704 .61706 m
.55576 .63393 L
s
.53704 .61706 m
.53483 .66421 L
s
.55576 .63393 m
.58354 .62556 L
s
.55576 .63393 m
.53483 .66421 L
s
.55576 .63393 m
.60293 .65039 L
s
.55576 .63393 m
.5734 .67917 L
s
.58354 .62556 m
.60293 .65039 L
s
.77238 .62297 m
.75874 .6712 L
s
.77238 .62297 m
.82395 .67347 L
s
.8784 .62318 m
.90864 .68529 L
s
.8784 .62318 m
.82395 .67347 L
s
.2226 .63099 m
.1949 .68545 L
s
.2226 .63099 m
.26555 .6626 L
s
.31881 .63955 m
.36556 .65701 L
s
.31881 .63955 m
.30636 .68567 L
s
.31881 .63955 m
.34697 .69291 L
s
.31881 .63955 m
.26555 .6626 L
s
.37695 .62837 m
.36556 .65701 L
s
.49531 .6599 m
.53483 .66421 L
s
.49531 .6599 m
.45061 .67179 L
s
.49531 .6599 m
.50087 .69757 L
s
.49531 .6599 m
.47042 .70927 L
s
.53483 .66421 m
.50087 .69757 L
s
.53483 .66421 m
.53798 .71057 L
s
.53483 .66421 m
.5734 .67917 L
s
.60293 .65039 m
.63912 .656 L
s
.60293 .65039 m
.5734 .67917 L
s
.60293 .65039 m
.61604 .7004 L
s
.63912 .656 m
.61604 .7004 L
s
.63912 .656 m
.66214 .70532 L
s
.1949 .68545 m
.26555 .6626 L
s
.1949 .68545 m
.25268 .71343 L
s
.1949 .68545 m
.13225 .73842 L
s
.1949 .68545 m
.20123 .76362 L
s
.36556 .65701 m
.41849 .66634 L
s
.36556 .65701 m
.34697 .69291 L
s
.36556 .65701 m
.38873 .68926 L
s
.41849 .66634 m
.45061 .67179 L
s
.41849 .66634 m
.38873 .68926 L
s
.41849 .66634 m
.43561 .71925 L
s
.41849 .66634 m
.40211 .72085 L
s
.45061 .67179 m
.43561 .71925 L
s
.45061 .67179 m
.47042 .70927 L
s
.50087 .69757 m
.53798 .71057 L
s
.50087 .69757 m
.47042 .70927 L
s
.50087 .69757 m
.50188 .75194 L
s
.53798 .71057 m
.5734 .67917 L
s
.53798 .71057 m
.58274 .73389 L
s
.53798 .71057 m
.50188 .75194 L
s
.53798 .71057 m
.55071 .76764 L
s
.5734 .67917 m
.58274 .73389 L
s
.5734 .67917 m
.61604 .7004 L
s
.70247 .68312 m
.75874 .6712 L
s
.70247 .68312 m
.75464 .71844 L
s
.70247 .68312 m
.66214 .70532 L
s
.70247 .68312 m
.70048 .75145 L
s
.75874 .6712 m
.75464 .71844 L
s
.75874 .6712 m
.82395 .67347 L
s
.90864 .68529 m
.82395 .67347 L
s
.90864 .68529 m
.82844 .73314 L
s
.90864 .68529 m
.90998 .74759 L
s
.30636 .68567 m
.34697 .69291 L
s
.30636 .68567 m
.26555 .6626 L
s
.30636 .68567 m
.25268 .71343 L
s
.30636 .68567 m
.33812 .73076 L
s
.30636 .68567 m
.27317 .75818 L
s
.30636 .68567 m
.31541 .75799 L
s
.34697 .69291 m
.38873 .68926 L
s
.34697 .69291 m
.40211 .72085 L
s
.34697 .69291 m
.33812 .73076 L
s
.38873 .68926 m
.40211 .72085 L
s
.43561 .71925 m
.47042 .70927 L
s
.43561 .71925 m
.40211 .72085 L
s
.43561 .71925 m
.45092 .76535 L
s
.47042 .70927 m
.45092 .76535 L
s
.47042 .70927 m
.50188 .75194 L
s
.75464 .71844 m
.82395 .67347 L
s
.75464 .71844 m
.82844 .73314 L
s
.75464 .71844 m
.70048 .75145 L
s
.75464 .71844 m
.77036 .77843 L
s
.82395 .67347 m
.82844 .73314 L
s
.26555 .6626 m
.25268 .71343 L
s
.40211 .72085 m
.33812 .73076 L
s
.40211 .72085 m
.38453 .75072 L
s
.40211 .72085 m
.45092 .76535 L
s
.58274 .73389 m
.61604 .7004 L
s
.58274 .73389 m
.63573 .75779 L
s
.58274 .73389 m
.55071 .76764 L
s
.58274 .73389 m
.60971 .80794 L
s
.61604 .7004 m
.66214 .70532 L
s
.61604 .7004 m
.63573 .75779 L
s
.66214 .70532 m
.63573 .75779 L
s
.66214 .70532 m
.70048 .75145 L
s
.82844 .73314 m
.90998 .74759 L
s
.82844 .73314 m
.77036 .77843 L
s
.82844 .73314 m
.85565 .81002 L
s
.90998 .74759 m
.85565 .81002 L
s
.25268 .71343 m
.20123 .76362 L
s
.25268 .71343 m
.27317 .75818 L
s
.33812 .73076 m
.38453 .75072 L
s
.33812 .73076 m
.31541 .75799 L
s
.10299 .74921 m
.13225 .73842 L
s
.10299 .74921 m
.18466 .84963 L
s
.13225 .73842 m
.20123 .76362 L
s
.13225 .73842 m
.18466 .84963 L
s
.20123 .76362 m
.27317 .75818 L
s
.20123 .76362 m
.25727 .81591 L
s
.20123 .76362 m
.18466 .84963 L
s
.27317 .75818 m
.31541 .75799 L
s
.27317 .75818 m
.25727 .81591 L
s
.27317 .75818 m
.33499 .80225 L
s
.38453 .75072 m
.45092 .76535 L
s
.38453 .75072 m
.31541 .75799 L
s
.38453 .75072 m
.39667 .78938 L
s
.38453 .75072 m
.33499 .80225 L
s
.45092 .76535 m
.50188 .75194 L
s
.45092 .76535 m
.39667 .78938 L
s
.45092 .76535 m
.43939 .8249 L
s
.45092 .76535 m
.49531 .8095 L
s
.50188 .75194 m
.55071 .76764 L
s
.50188 .75194 m
.49531 .8095 L
s
.63573 .75779 m
.70048 .75145 L
s
.63573 .75779 m
.68365 .81647 L
s
.63573 .75779 m
.60971 .80794 L
s
.70048 .75145 m
.77036 .77843 L
s
.70048 .75145 m
.68365 .81647 L
s
.77036 .77843 m
.68365 .81647 L
s
.77036 .77843 m
.85565 .81002 L
s
.77036 .77843 m
.76376 .84764 L
s
.31541 .75799 m
.33499 .80225 L
s
.39667 .78938 m
.33499 .80225 L
s
.39667 .78938 m
.37238 .85121 L
s
.39667 .78938 m
.43939 .8249 L
s
.55071 .76764 m
.55286 .82326 L
s
.55071 .76764 m
.60971 .80794 L
s
.55071 .76764 m
.49531 .8095 L
s
.68365 .81647 m
.60971 .80794 L
s
.68365 .81647 m
.76376 .84764 L
s
.68365 .81647 m
.63382 .87675 L
s
.68365 .81647 m
.70387 .90304 L
s
.85565 .81002 m
.76376 .84764 L
s
.85565 .81002 m
.70387 .90304 L
s
.25727 .81591 m
.33499 .80225 L
s
.25727 .81591 m
.18466 .84963 L
s
.25727 .81591 m
.2982 .86989 L
s
.25727 .81591 m
.26376 .91243 L
s
.33499 .80225 m
.2982 .86989 L
s
.33499 .80225 m
.37238 .85121 L
s
.18466 .84963 m
.26376 .91243 L
s
.2982 .86989 m
.37238 .85121 L
s
.2982 .86989 m
.26376 .91243 L
s
.2982 .86989 m
.36311 .92697 L
s
.37238 .85121 m
.43939 .8249 L
s
.37238 .85121 m
.36311 .92697 L
s
.37238 .85121 m
.43624 .88764 L
s
.55286 .82326 m
.60971 .80794 L
s
.55286 .82326 m
.49531 .8095 L
s
.55286 .82326 m
.50288 .87802 L
s
.55286 .82326 m
.56997 .89213 L
s
.60971 .80794 m
.63382 .87675 L
s
.60971 .80794 m
.56997 .89213 L
s
.76376 .84764 m
.70387 .90304 L
s
.43939 .8249 m
.49531 .8095 L
s
.43939 .8249 m
.43624 .88764 L
s
.43939 .8249 m
.50288 .87802 L
s
.49531 .8095 m
.50288 .87802 L
s
.26376 .91243 m
.36311 .92697 L
s
.26376 .91243 m
.4548 .96564 L
s
.36311 .92697 m
.43624 .88764 L
s
.36311 .92697 m
.4548 .96564 L
s
.43624 .88764 m
.50288 .87802 L
s
.43624 .88764 m
.4548 .96564 L
s
.63382 .87675 m
.56997 .89213 L
s
.63382 .87675 m
.70387 .90304 L
s
.63382 .87675 m
.54502 .97192 L
s
.50288 .87802 m
.56997 .89213 L
s
.50288 .87802 m
.4548 .96564 L
s
.50288 .87802 m
.51481 .96295 L
s
.56997 .89213 m
.51481 .96295 L
s
.56997 .89213 m
.54502 .97192 L
s
.70387 .90304 m
.54502 .97192 L
s
.4548 .96564 m
.51481 .96295 L
s
.4548 .96564 m
.54502 .97192 L
s
.51481 .96295 m
.54502 .97192 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[107]:=",
  ImageSize->{288, 288},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`0001/1000`40O003h00Oofmk/Fmk003oKg^a
Kg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00
ofmk/Fmk003oKg^aKg/00:Q_N`<00?m_N`I_N`00Yfmk1@00ofmk1Fmk002WKg/L003]Kg/00:9_N`l0
019_Nc8001Q_N`<00:1_N`00WFmk1@001Vmk0`001Vmk1@00?fmk7000Wfmk002HKg/5000:Kg/00`00
Kg/0000<Kg/40010Kg/>00000fmk00000009002LKg/008Y_N`<000I_N`D000m_N`04001_Nfmk000?
Kg/5000^Kg/=000;Kg/40003Kg/50003Kg/4002HKg/008U_N`X001=_N`05001_NfmkKg/0000DKg/5
0006Kg/3000CKg/=000DKg/40007Kg/40008Kg/4002DKg/008U_N`D001Q_N`05001_NfmkKg/0000I
Kg/:0004Kg/>000MKg/4000;Kg/00`00Kg/0000=Kg/40005Kg/30028Kg/008Q_N`H001M_N`03001_
Nfmk009_N`03001_Nfmk01a_N`T002M_N`@000i_N`04001_Nfmk000AKg/90027Kg/008I_N`80009_
N`<001M_N`03001_Nfmk00=_N`03001_Nfmk01a_N`D00003Kg/0000000H001i_N`@0019_N`05001_
NfmkKg/0000DKg/50027Kg/008A_N`8000I_N`03001_Nfmk01E_N`03001_Nfmk00=_N`03001_Nfmk
01a_N`@000Y_N`P000]_N`<000A_N`@001E_N`03001_Nfmk009_N`03001_Nfmk019_N`H008I_N`00
PVmk0P0026mk00<006mkKg/056mk00<006mkKg/01Fmk00<006mkKg/06Fmk0P000Vmk00<006mkKg/0
4Fmk20000Vmk200066mk00<006mkKg/00fmk00<006mkKg/04fmk0`000Vmk0P00Q6mk001oKg/3000:
Kg/00`00Kg]_N`0DKg/00`00Kg]_N`05Kg/00`00Kg]_N`0HKg/00`00Kg]_N`02Kg/00`00Kg]_N`0I
Kg/7000KKg/00`00Kg]_N`03Kg/00`00Kg]_N`0BKg/01000Kg]_N`0016mk0P00PVmk001mKg/3000=
Kg/00`00Kg]_N`0BKg/00`00Kg]_N`06Kg/00`00Kg]_N`0GKg/00`00Kg]_N`03Kg/00`00Kg]_N`0K
Kg/5000JKg/00`00Kg]_N`04Kg/00`00Kg]_N`0BKg/01@00Kg]_Nfmk00001Fmk0`00Ofmk001kKg/3
000?Kg/00`00Kg]_N`0BKg/00`00Kg]_N`06Kg/00`00Kg]_N`0FKg/00`00Kg]_N`04Kg/00`00Kg]_
N`0KKg/4000KKg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/2
001mKg/007U_N`<0015_N`03001_Nfmk015_N`03001_Nfmk00M_N`03001_Nfmk01E_N`03001_Nfmk
00E_N`03001_Nfmk01U_N`80009_N`03001_N`0001U_N`03001_Nfmk00E_N`03001_Nfmk015_N`03
001_Nfmk009_N`03001_Nfmk00Q_N`8007]_N`00Mfmk0`0056mk00<006mkKg/03fmk00<006mkKg/0
26mk00<006mkKg/056mk00<006mkKg/01fmk00<006mkKg/05fmk00<006mkKg/00Vmk00<006mk0000
6Fmk00<006mkKg/01Fmk00<006mkKg/046mk00<006mkKg/016mk00<006mkKg/02Fmk0`00N6mk001d
Kg/4000FKg/00`00Kg]_N`0?Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0BKg/2000:Kg/00`00Kg]_N`0F
Kg/00`00Kg]_N`03Kg/01000Kg]_N`005fmk00<006mkKg/01Vmk00<006mkKg/046mk00<006mkKg/0
16mk00<006mkKg/036mk0P00MVmk001^Kg/300000fmk00000002000HKg/00`00Kg]_N`0>Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0EKg/00`00Kg]_N`04Kg/01000
Kg]_N`005Vmk00<006mkKg/01fmk00<006mkKg/03fmk00<006mkKg/01Vmk00<006mkKg/03Fmk0P00
M6mk001]Kg/7000JKg/00`00Kg]_N`0>Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`0DKg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00005Fmk00<006mkKg/026mk00<006mk
Kg/03Fmk00<006mkKg/01fmk00<006mkKg/03fmk0P00LVmk001]Kg/5000MKg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`0;Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0CKg/00`00Kg]_N`06Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0AKg/00`00Kg]_N`09Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`0@Kg/3001_Kg/006]_N`P001a_N`03001_Nfmk00a_N`03001_Nfmk00]_N`03001_Nfmk
00e_N`03001_Nfmk00e_N`03001_Nfmk019_N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_Nfmk
015_N`03001_Nfmk00U_N`03001_Nfmk00a_N`03001_Nfmk00U_N`03001_Nfmk01=_N`8006e_N`00
JFmk100000=_N`0000000P0000=_N`0000006Vmk00<006mkKg/02fmk00<006mkKg/036mk00<006mk
Kg/036mk00<006mkKg/03Vmk00<006mkKg/046mk0P002Vmk00<006mkKg/00fmk00<006mkKg/03fmk
00<006mkKg/02Vmk00<006mkKg/036mk00<006mkKg/02Fmk00<006mkKg/05Fmk0P00Jfmk001WKg/3
0007Kg/01000Kg]_Nfmk0P006Fmk00<006mkKg/02Vmk00<006mkKg/036mk00<006mkKg/02fmk00<0
06mkKg/03fmk00<006mkKg/03fmk00<006mkKg/02Fmk00<006mkKg/016mk00<006mkKg/03fmk00<0
06mkKg/02Vmk00<006mkKg/02fmk00<006mkKg/02fmk00<006mkKg/05Vmk0P00JFmk001PKg/30002
Kg/3000:Kg/00`00Kg]_N`02Kg/2000GKg/00`00Kg]_N`09Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`08
Kg/2000BKg/00`00Kg]_N`0>Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0HKg/3001VKg/005m_N`H000e_
N`03001_Nfmk00A_N`8001E_N`03001_Nfmk00Q_N`03001_Nfmk00m_N`03001_Nfmk00M_N`03001_
Nfmk019_N`03001_Nfmk00e_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_
Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk00e_N`03001_Nfmk01Y_N`8006A_N`00Gfmk1@003Vmk
00<006mkKg/01Vmk0P0056mk00<006mkKg/01fmk00<006mkKg/03fmk00<006mkKg/01Vmk00<006mk
Kg/04fmk00<006mkKg/036mk00<006mkKg/036mk00<006mkKg/01Vmk00<006mkKg/02fmk00<006mk
Kg/036mk00<006mkKg/02Vmk00<006mkKg/03Fmk00<006mkKg/076mk0P00HVmk001OKg/5000?Kg/0
0`00Kg]_N`07Kg/2000BKg/00`00Kg]_N`06Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`0DKg/00`00Kg]_N`0;Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`0=Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0NKg/2001PKg/005m_N`D000m_N`03
001_Nfmk00U_N`80011_N`03001_Nfmk00I_N`03001_Nfmk011_N`03001_Nfmk00A_N`03001_Nfmk
01E_N`03001_Nfmk00U_N`80011_N`03001_Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk00e_N`03
001_Nfmk00Q_N`03001_Nfmk011_N`03001_Nfmk01m_N`<005e_N`00GVmk0P0016mk00<006mkKg/0
36mk00<006mkKg/02fmk0P003Vmk00<006mkKg/01Fmk00<006mkKg/04Fmk00<006mkKg/00fmk00<0
06mkKg/05Vmk00<006mkKg/026mk00<006mkKg/046mk00<006mkKg/026mk00<006mkKg/01fmk00<0
06mkKg/03Vmk00<006mkKg/026mk00<006mkKg/046mk00<006mkKg/08Vmk0P00Ffmk001MKg/20006
Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0<Kg/2000=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0BKg/00`00
Kg]_N`02000IKg/00`00Kg]_N`07Kg/00`00Kg]_N`0AKg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0SKg/2001IKg/005a_N`03
001_N`0000M_N`03001_Nfmk00]_N`03001_Nfmk00i_N`8000]_N`03001_Nfmk00=_N`03001_Nfmk
019_N`@001a_N`03001_Nfmk00E_N`03001_Nfmk019_N`03001_Nfmk00U_N`03001_Nfmk00E_N`03
001_Nfmk011_N`03001_Nfmk00I_N`03001_Nfmk019_N`03001_Nfmk02E_N`<005I_N`00Ffmk00<0
06mk00002Fmk0P0036mk00<006mkKg/03fmk0P002Fmk00<006mkKg/00Vmk00<006mkKg/04Vmk1@00
76mk00<006mkKg/016mk00<006mkKg/04fmk00<006mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/0
4Fmk00<006mkKg/01Fmk00<006mkKg/056mk00<006mkKg/09fmk0P00E6mk001JKg/00`00Kg/0000<
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0AKg/20008Kg/01@00Kg]_Nfmk000056mk1P006fmk00<006mk
Kg/00fmk00<006mkKg/056mk00<006mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/04Fmk00<006mk
Kg/01Fmk00<006mkKg/056mk00<006mkKg/0:Fmk0P000Vmk0`00CFmk001HKg/200000fmk001_N`0=
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0CKg/20006Kg/01000Kg]_N`0046mk2P0000=_N`0000001000
5Fmk00<006mkKg/00Vmk00<006mkKg/05Fmk00<006mkKg/02fmk00D006mkKg]_N`0001A_N`03001_
Nfmk00A_N`03001_Nfmk01E_N`03001_Nfmk02]_N`H004a_N`00Efmk00D006mkKg]_N`0000m_N`03
001_Nfmk00Q_N`03001_Nfmk01A_N`8000A_N`04001_Nfmk000;Kg/50005Kg/40008Kg/6000?Kg/0
0`00Kg]_N`02000HKg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk000056mk00<006mkKg/016mk00<006mk
Kg/05Vmk00<006mkKg/09Vmk2P00C6mk001FKg/01@00Kg]_Nfmk00004Fmk00<006mkKg/01fmk00<0
06mkKg/05Vmk0P000Vmk0`001Vmk1P002Vmk00@006mkKg/000i_N`H000Q_N`@001Y_N`03001_Nfmk
00a_N`<001E_N`03001_Nfmk00=_N`03001_Nfmk01M_N`<001I_Na0000E_N`D004a_N`00EFmk00D0
06mkKg]_N`0001=_N`03001_Nfmk00M_N`03001_Nfmk01M_N`/000m_N`05001_NfmkKg/0000DKg/6
00000fmk00000003000JKg/00`00Kg]_N`0;Kg/5000DKg/00`00Kg]_N`02Kg/00`00Kg]_N`0GKg/5
0005Kg/@000DKg/00`00Kg/00002001=Kg/005A_N`03001_Nfmk009_N`03001_Nfmk019_N`03001_
Nfmk00I_N`03001_Nfmk01Q_N`D001=_N`03001_Nfmk00=_N`03001_Nfmk01M_N`H001Y_N`03001_
Nfmk00]_N`D001A_N`03001_Nfmk009_N`03001_Nfmk01M_N`X0029_N`8000A_N`8004a_N`00Dfmk
00<006mkKg/00Vmk00<006mkKg/056mk00<006mkKg/01Fmk00<006mkKg/066mk1@004Vmk00<006mk
Kg/016mk00<006mkKg/066mk1@006Vmk00<006mkKg/02fmk20004Fmk00D006mkKg]_N`0001I_N`T0
02E_N`8000M_N`8004]_N`00DVmk00<006mkKg/00Vmk00<006mkKg/05Vmk00<006mkKg/01Fmk00<0
06mkKg/05Fmk0P0000A_N`000000019_N`03001_Nfmk00E_N`03001_Nfmk01M_N`D00003Kg/00000
01Q_N`03001_Nfmk00]_N`@000A_N`<000m_N`04001_Nfmk000AKg/50005Kg/4000TKg/00`00Kg]_
N`07Kg/2001;Kg/0055_N`03001_Nfmk00=_N`03001_Nfmk01M_N`03001_Nfmk00A_N`03001_Nfmk
01=_N`8000A_N`03001_Nfmk015_N`03001_Nfmk00I_N`03001_Nfmk01E_N`03001_Nfmk009_N`04
001_NfmkKg/2000FKg/00`00Kg]_N`0:Kg/01000Kg]_N`0026mk0`0036mk00<006mk00003Vmk1000
2Fmk00<006mkKg/00Vmk00<006mkKg/07fmk0P002fmk0P00BVmk001@Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0IKg/00`00Kg]_N`04Kg/00`00Kg]_N`0@Kg/20006Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`0DKg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0CKg/00`00Kg]_N`09
Kg/01@00Kg]_Nfmk00002fmk100026mk00<006mk00002Fmk1@003Fmk00<006mkKg/00fmk00<006mk
Kg/07Fmk00<006mkKg/02fmk00<006mk0000BFmk001?Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0KKg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0>Kg/20008Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`0CKg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/2000CKg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0=Kg/30004Kg/30005Kg/5000AKg/00`00Kg]_N`05Kg/00`00Kg]_N`0JKg/2000?Kg/2
0019Kg/004i_N`03001_Nfmk00=_N`03001_Nfmk01e_N`03001_Nfmk009_N`03001_Nfmk00e_N`03
001_Nfmk00Q_N`03001_Nfmk00i_N`03001_Nfmk00Y_N`03001_Nfmk015_N`03001_Nfmk00E_N`03
001_Nfmk00I_N`80011_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00m_N``001I_N`03
001_Nfmk00I_N`03001_Nfmk01Q_N`03001_Nfmk00m_N`03001_N`0004Q_N`00CFmk00<006mkKg/0
16mk00<006mkKg/07Vmk0P000fmk00<006mkKg/02Vmk0P0036mk00<006mkKg/036mk00<006mkKg/0
2fmk00<006mkKg/03fmk0P002Fmk00<006mkKg/01fmk0P003Vmk00<006mkKg/01fmk00<006mkKg/0
1Fmk00<006mkKg/04Vmk1@006Fmk00<006mkKg/026mk00<006mkKg/05Fmk0P004fmk00<006mk0000
Afmk001<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0QKg/01000Kg]_N`002Vmk0P003Vmk00<006mkKg/0
36mk00<006mkKg/02fmk00<006mkKg/03Vmk00<006mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/0
2fmk00<006mkKg/01Fmk0P0026mk00<006mkKg/04Vmk1@006Fmk00<006mkKg/02Fmk0P004fmk0P00
5Fmk00<006mk0000Afmk001;Kg/00`00Kg]_N`02Kg/3000UKg/00`00Kg/00008Kg/2000@Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/2000;
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0BKg/5000HKg/00`00Kg]_N`0<Kg/00`00
Kg]_N`0?Kg/00`00Kg]_N`0FKg/00`00Kg/00016Kg/004Y_N`03001_Nfmk009_N`D002E_N`03001_
N`0000E_N`80019_N`03001_Nfmk00Y_N`03001_Nfmk00i_N`03001_Nfmk00]_N`03001_Nfmk00]_
N`03001_Nfmk00a_N`8000U_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk019_N`03001_
N`00009_N`03001_Nfmk01A_N`03001_Nfmk00i_N`03001_Nfmk00a_N`8001U_N`04001_Nfmk0015
Kg/004Q_N`8000E_N`d001i_N`@00003Kg/0000001A_N`03001_Nfmk00U_N`03001_Nfmk00m_N`03
001_Nfmk00Y_N`03001_Nfmk00a_N`03001_Nfmk00i_N`8000M_N`03001_Nfmk009_N`03001_Nfmk
00Y_N`03001_Nfmk015_N`04001_Nfmk0002Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0?Kg/00`00Kg]_
N`0:Kg/00`00Kg]_N`0JKg/00`00Kg/00015Kg/004M_N`03001_Nfmk00E_N`D000Q_NaH000Q_N`D0
01I_N`03001_Nfmk00Q_N`03001_Nfmk015_N`03001_Nfmk00M_N`80011_N`03001_Nfmk00m_N`03
001_Nfmk00A_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`0@Kg/01@00Kg]_Nfmk00000fmk00<006mk
Kg/04Vmk00<006mkKg/04Fmk00<006mkKg/01fmk0P007Fmk00@006mkKg/004A_N`00AVmk00<006mk
Kg/01Fmk00<006mk000010007Fmk3@005Vmk00<006mkKg/026mk00<006mkKg/04Fmk00<006mkKg/0
1Vmk00<006mkKg/046mk00<006mkKg/046mk0P0016mk00@006mkKg/000i_N`03001_Nfmk00m_N`03
001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk015_N`03001_Nfmk019_N`03001_Nfmk00A_N`80
021_N`04001_Nfmk0013Kg/004E_N`03001_Nfmk00A_N`8000=_N`05001_NfmkKg/0000TKg/6000E
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0BKg/00`00Kg]_N`05Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0B
Kg/200000fmk00000002000?Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0?Kg/00`00Kg]_N`0DKg/400000fmk001_N`0QKg/01000Kg]_N`00@fmk0014Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0QKg/40002Kg/2000CKg/00`00Kg]_
N`06Kg/00`00Kg]_N`0DKg/00`00Kg]_N`03Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0DKg/5000?Kg/0
0`00Kg]_N`0>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0DKg/5
000TKg/01000Kg]_N`00@Vmk0013Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`0OKg/01000Kg]_N`001Fmk0P004Fmk00<006mkKg/01Fmk00<006mkKg/05Fmk00<006mk
Kg/00Vmk00<006mkKg/04fmk00<006mkKg/056mk1@003fmk00<006mkKg/03Fmk00<006mkKg/016mk
00<006mkKg/01Fmk00<006mkKg/036mk00<006mkKg/05Fmk1P008fmk00D006mkKg]_N`00045_N`00
@Vmk00<006mkKg/00fmk0P001Vmk00<006mkKg/01Fmk0P007Vmk00D006mkKg]_N`0000M_N`8000m_
N`03001_Nfmk00A_N`03001_Nfmk01I_N`D001M_N`03001_Nfmk015_N`L000m_N`03001_Nfmk00a_
N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_Nfmk01=_N`L00003Kg/00000
00@001i_N`04001_Nfmk0011Kg/0045_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00M_
N`03001_Nfmk01Y_N`03001_Nfmk009_N`03001_Nfmk00M_N`8000e_N`03001_Nfmk00A_N`03001_
Nfmk01E_N`D001Q_N`03001_Nfmk00e_N`@000=_N`@0011_N`03001_Nfmk00Y_N`03001_Nfmk00I_
N`03001_Nfmk00I_N`03001_Nfmk00Y_N`03001_Nfmk015_N`<000=_N`<000Q_N`H001Q_N`05001_
NfmkKg/00010Kg/0041_N`03001_Nfmk009_N`8000U_N`03001_Nfmk00Q_N`03001_Nfmk01Q_N`03
001_Nfmk00A_N`03001_Nfmk00Q_N`<000]_N`03001_Nfmk009_N`03001_Nfmk01I_N`H001M_N`03
001_Nfmk00Y_N`<000Q_N`04001_Nfmk000?Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/30005Kg/01000Kg]_N`003Vmk1P004fmk00D006mk
Kg]_N`0003m_N`00?fmk00<006mkKg/00Vmk00<006mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/0
5Vmk00<006mkKg/01Fmk00<006mkKg/02fmk0P002Fmk00D006mkKg]_N`0001A_N`X00003Kg/00000
00D0011_N`03001_Nfmk00M_N`<000Y_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk00U_
N`03001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk00a_N`<000M_N`03001_
Nfmk009_N`03001_Nfmk015_N`H000e_N`05001_NfmkKg/0000oKg/003i_N`04001_NfmkKg/2000<
Kg/00`00Kg]_N`0:Kg/2000EKg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/20007Kg/01000Kg]_N`00
3fmk1P001Fmk10002Fmk1`002Fmk0`000fmk10003Fmk00<006mkKg/00fmk0P0036mk00<006mkKg/0
26mk00<006mkKg/026mk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/02fmk0P002Vmk00<0
06mkKg/00Vmk00<006mkKg/05fmk1P0026mk0`0000=_N`00Kg/0?Fmk000mKg/01@00Kg]_Nfmk0000
3Vmk00<006mkKg/036mk00<006mkKg/04Fmk00<006mkKg/01fmk00<006mkKg/03fmk0P001Fmk00<0
06mk00002fmk1@002Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk1`0000=_N`0000001@004Fmk00<0
06mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/02Fmk00<006mkKg/02Vmk00<0
06mkKg/016mk00<006mkKg/026mk0`002fmk00<006mkKg/016mk00<006mkKg/076mk1P0000=_N`00
00000`0000=_N`00Kg/0?6mk000lKg/01@00Kg]_Nfmk00003fmk00<006mkKg/03Fmk00<006mkKg/0
3fmk00<006mkKg/026mk00<006mkKg/04Fmk0P000Vmk10001Vmk1@003fmk00<006mkKg/00Vmk00<0
06mkKg/056mk1P004fmk00<006mkKg/01Vmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/0
2Fmk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/01Vmk0`003Fmk00<006mkKg/01Fmk00<0
06mkKg/08Vmk1P0000=_N`00Kg/0?6mk000kKg/00`00Kg]_N`02000@Kg/00`00Kg]_N`0>Kg/00`00
Kg]_N`0=Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0CKg/<000CKg/00`00Kg]_N`04Kg/00`00Kg]_N`0D
Kg/5000CKg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0:Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/3000?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0P
Kg/70002Kg/00`00Kg]_N`0jKg/003Y_N`04001_Nfmk000BKg/00`00Kg]_N`0?Kg/2000<Kg/00`00
Kg]_N`0:Kg/00`00Kg]_N`0DKg/5000HKg/00`00Kg]_N`05Kg/00`00Kg]_N`0DKg/5000CKg/00`00
Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/40003
Kg/3000BKg/00`00Kg]_N`07Kg/00`00Kg]_N`0MKg/30002Kg/50003Kg/00`00Kg]_N`0iKg/003Q_
N`800003Kg/00000019_N`03001_Nfmk019_N`03001_Nfmk00Q_N`03001_Nfmk00]_N`03001_Nfmk
01A_N`H001I_N`03001_Nfmk00M_N`03001_Nfmk019_N`04001_Nfmk0002Kg/00`00Kg]_N`0?Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0=Kg/7
000DKg/00`00Kg]_N`08Kg/00`00Kg]_N`0IKg/40004Kg/00`00Kg/00002Kg/01@00Kg]_Nfmk0000
>fmk000gKg/01000Kg]_N`0056mk00<006mkKg/04fmk00<006mkKg/01Vmk00<006mkKg/036mk00<0
06mkKg/04fmk1@000Vmk0P004fmk00<006mkKg/026mk00<006mkKg/04Fmk00D006mkKg]_N`0000=_
N`03001_Nfmk00i_N`03001_Nfmk00]_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00a_
N`03001_Nfmk00e_N`D001E_N`03001_Nfmk00Y_N`03001_Nfmk01E_N`<000M_N`04001_Nfmk0003
Kg/01@00Kg]_Nfmk0000>Vmk000fKg/01000Kg/000005Fmk00<006mkKg/056mk00<006mkKg/016mk
00<006mkKg/03Fmk00<006mkKg/04Vmk00@006mkKg/000I_N`80011_N`03001_Nfmk00Y_N`03001_
Nfmk00m_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk00a_N`03001_
Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00a_N`03001_Nfmk00e_N`D001E_N`03001_Nfmk00Y_
N`03001_Nfmk019_N`<000U_N`05001_NfmkKg/00004Kg/01@00Kg]_Nfmk0000>Fmk000eKg/00`00
Kg/0000GKg/00`00Kg]_N`0EKg/6000AKg/00`00Kg]_N`0@Kg/01@00Kg]_Nfmk000026mk0P003Fmk
00<006mkKg/02fmk00<006mkKg/03Vmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/036mk
00<006mkKg/03Fmk00<006mkKg/00fmk00D006mkKg]_N`0000m_N`03001_Nfmk00e_N`@001E_N`03
001_Nfmk00a_N`03001_Nfmk00i_N`<000]_N`03001_Nfmk009_N`03001_Nfmk00=_N`04001_Nfmk
000iKg/003A_N`03001_N`0001Q_N`03001_Nfmk01I_N`D0015_N`03001_Nfmk00m_N`03001_Nfmk
009_N`03001_Nfmk00Q_N`8000Y_N`03001_Nfmk00e_N`03001_Nfmk00a_N`03001_Nfmk00A_N`03
001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk00i_N`8000=_N`04001_Nfmk000@Kg/00`00Kg]_
N`0<Kg/01@00Kg]_Nfmk000056mk00<006mkKg/03Fmk00<006mkKg/02fmk0`003Fmk00<006mkKg/0
0Vmk00<006mkKg/01Fmk00@006mkKg/003Q_N`00<fmk0`006Fmk00<006mkKg/05Vmk1@004Fmk00<0
06mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/02fmk0P0026mk00<006mkKg/03Vmk00<006mkKg/0
2Fmk0P001fmk00<006mkKg/01Fmk00<006mkKg/02Vmk00<006mkKg/046mk00H006mkKg/006mk000A
Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0>Kg/00`00Kg]_N`06
Kg/4000@Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/01000Kg]_N`00=fmk000_Kg/5000KKg/00`00
Kg]_N`0FKg/5000AKg/00`00Kg]_N`0<Kg/20005Kg/00`00Kg]_N`0=Kg/200001Vmk00000000Kg/0
015_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk00I_N`8000U_N`03001_Nfmk019_N`D0
015_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk011_N`03001_Nfmk00m_N`<000=_N`<0
01=_N`03001_Nfmk00=_N`03001_Nfmk00I_N`04001_Nfmk000gKg/002i_N`D001a_N`03001_Nfmk
01A_N`800005Kg/00000001_N`02000?Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?
Kg/5000CKg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`0BKg/5000AKg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0?
Kg/7000EKg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/01000Kg]_N`00=Vmk000^Kg/5000LKg/00`00
Kg]_N`0CKg/01@00Kg]_Nfmk00001Fmk00<006mkKg/036mk00<006mkKg/02Vmk00<006mkKg/01Vmk
00<006mkKg/03fmk1P004Vmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/02Fmk00<006mk
Kg/01Fmk00<006mkKg/04Vmk1@004Fmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/03Vmk
00<006mkKg/03fmk1@005Vmk00<006mkKg/01Fmk00<006mkKg/026mk00@006mkKg/003E_N`00;Vmk
1@006fmk00<006mkKg/04Vmk0P0016mk00<006mkKg/016mk0P0036mk00<006mkKg/02Fmk00<006mk
Kg/01Vmk00<006mkKg/046mk1@0000=_N`0000000`003Vmk00<006mkKg/00fmk00<006mkKg/02Vmk
00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/03fmk20004Fmk00<006mkKg/01fmk00<006mk
Kg/02Fmk00<006mkKg/036mk00<006mkKg/03fmk1P005Fmk00<006mkKg/01Fmk00<006mkKg/02Vmk
00<006mk0000=Fmk000_Kg/300000fmk0000000IKg/00`00Kg]_N`0AKg/00`00Kg]_N`04Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0?Kg/60006
Kg/4000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`0<Kg/30004Kg/300000fmk0000000?Kg/00`00Kg]_N`05Kg/2000<Kg/00`00Kg]_N`0;Kg/0
0`00Kg]_N`0>Kg/20002Kg/3000EKg/00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/00`00Kg/0000dKg/0
02i_N`03001_N`0000A_N`8001M_N`03001_Nfmk00m_N`8000I_N`03001_Nfmk00Q_N`8000U_N`03
001_Nfmk00I_N`8000Y_N`03001_Nfmk00e_N`80009_N`04001_Nfmk000:Kg/50006Kg/4000=Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/00`00Kg]_N`09Kg/30006Kg/00`00Kg/00004Kg/2000=Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/20004Kg/01000Kg]_
N`004fmk00<006mkKg/01fmk00<006mkKg/02fmk00@006mkKg/003=_N`00;Vmk00@006mkKg/000E_
N`8001E_N`03001_Nfmk00e_N`8000Q_N`03001_Nfmk00Y_N`8000M_N`03001_Nfmk00E_N`03001_
Nfmk00U_N`03001_Nfmk00a_N`8000A_N`05001_NfmkKg/0000>Kg/:000=Kg/00`00Kg]_N`0>Kg/0
1000Kg]_N`0026mk100026mk00@006mkKg/000I_N`8000]_N`03001_Nfmk00=_N`03001_Nfmk00i_
N`03001_Nfmk00U_N`03001_Nfmk00]_N`8000E_N`05001_NfmkKg/0000BKg/00`00Kg]_N`08Kg/0
0`00Kg]_N`0<Kg/00`00Kg/0000cKg/002e_N`05001_NfmkKg/00007Kg/2000CKg/00`00Kg]_N`0<
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`0:Kg/20005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/5000=Kg/00`00Kg]_N`0?
Kg/40004Kg/3000<Kg/01@00Kg]_Nfmk00001fmk0P002Fmk00<006mkKg/00Vmk00<006mkKg/046mk
00<006mkKg/01fmk00<006mkKg/02Vmk0P001fmk00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mk
Kg/02Fmk00<006mkKg/03Fmk00<006mk0000<Vmk000]Kg/01@00Kg]_Nfmk00002Fmk0P004Fmk00<0
06mkKg/02Vmk0P002Vmk00<006mkKg/03Vmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/02fmk00<0
06mkKg/026mk0P001fmk00<006mkKg/00Vmk00<006mkKg/04Fmk1@003Fmk00<006mkKg/03fmk2000
3Vmk00<006mkKg/00Vmk00<006mkKg/01fmk0P001fmk00D006mkKg]_N`0001=_N`03001_Nfmk00I_
N`03001_Nfmk00U_N`8000Q_N`03001_Nfmk00=_N`03001_Nfmk00e_N`03001_Nfmk00U_N`03001_
Nfmk00m_N`03001_N`00035_N`00;6mk00<006mkKg/00Vmk00<006mkKg/02Fmk0P003fmk00<006mk
Kg/02Fmk00<006mkKg/02Vmk00<006mkKg/046mk00<006mkKg/00Vmk00D006mkKg]_N`0000i_N`03
001_Nfmk00I_N`8000Q_N`03001_Nfmk00A_N`03001_Nfmk011_N`@00003Kg/006mk00]_N`03001_
Nfmk00m_N`D0011_N`03001_Nfmk00=_N`03001_Nfmk00U_N`8000E_N`04001_Nfmk000EKg/00`00
Kg]_N`05Kg/00`00Kg]_N`06Kg/3000:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`0@Kg/2000aKg/002a_N`03001_Nfmk009_N`03001_Nfmk00]_N`8000e_N`03001_
Nfmk00M_N`8000e_N`03001_Nfmk015_N`800003Kg/0000000<000i_N`03001_Nfmk00E_N`8000Y_
N`03001_Nfmk00A_N`03001_Nfmk00m_N`04001_Nfmk0003Kg/2000:Kg/00`00Kg]_N`0>Kg/6000@
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/20002Kg/4000FKg/00`00Kg]_N`04Kg/00`00Kg]_N`05
Kg/2000<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0AKg/2000`
Kg/002]_N`03001_Nfmk00=_N`03001_Nfmk00e_N`8000]_N`03001_Nfmk00E_N`8000m_N`03001_
Nfmk01=_N`D000m_N`03001_Nfmk00=_N`8000]_N`03001_Nfmk00I_N`03001_Nfmk00e_N`05001_
NfmkKg/00005Kg/20008Kg/00`00Kg]_N`0;Kg/30002Kg/3000@Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`0=Kg/6000GKg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/2000>Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0AKg/00`00Kg/0000_Kg/002]_N`03001_Nfmk00=_N`03
001_Nfmk00m_N`8000U_N`03001_Nfmk00A_N`03001_Nfmk00i_N`03001_Nfmk01A_N`D000m_N`04
001_NfmkKg/2000=Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/01@00Kg]_Nfmk00001fmk00<006mk
Kg/01Fmk00<006mkKg/02Fmk0P001Fmk00@006mkKg/000i_N`03001_Nfmk00E_N`03001_Nfmk00i_
N`H001I_N`03001_Nfmk009_N`03001_Nfmk009_N`8000m_N`03001_Nfmk00M_N`03001_Nfmk00M_
N`03001_Nfmk00a_N`03001_Nfmk01=_N`8002m_N`00:Vmk00<006mkKg/01Fmk00<006mkKg/046mk
0P001Vmk00<006mkKg/00fmk0P004Fmk00<006mkKg/04fmk30001fmk0`0000=_N`0000003Vmk00<0
06mkKg/01fmk00<006mkKg/036mk00<006mkKg/00Vmk00<006mkKg/01Vmk0P001Fmk00<006mkKg/0
1Vmk0`001Vmk00D006mkKg]_N`0000i_N`03001_Nfmk00E_N`03001_Nfmk00i_N`D00003Kg/00000
00D0011_N`04001_Nfmk0003Kg/2000AKg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<
Kg/00`00Kg]_N`0DKg/2000^Kg/002Y_N`03001_Nfmk00E_N`03001_Nfmk019_N`8000A_N`03001_
Nfmk009_N`03001_Nfmk015_N`03001_Nfmk015_N`80009_N`<000M_N`/0011_N`03001_Nfmk00Q_
N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00A_
N`8000U_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_Nfmk00I_N`03001_Nfmk00i_N`@000U_
N`L000U_N`<0009_N`80019_N`03001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00e_N`03001_
Nfmk01E_N`8002e_N`00:Fmk00<006mkKg/01Vmk00<006mkKg/056mk0P0000E_N`00000006mk0080
01A_N`03001_Nfmk00i_N`<000A_N`03001_Nfmk00e_N`D000m_N`03001_Nfmk00U_N`03001_Nfmk
00U_N`03001_Nfmk00A_N`03001_Nfmk00U_N`800004Kg/000000002Kg/3000;Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/01000Kg]_N`004Fmk1`0000=_N`00
0000100056mk00<006mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/03Vmk00<006mkKg/05Vmk00<0
06mkKg/0:fmk000YKg/00`00Kg]_N`06Kg/00`00Kg]_N`0FKg/5000EKg/00`00Kg]_N`0=Kg/20007
Kg/00`00Kg]_N`0=Kg/6000>Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0;Kg/6000=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<
Kg/01@00Kg]_Nfmk000066mk1P0056mk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/03fmk
00<006mkKg/05fmk00<006mkKg/0:Vmk000XKg/00`00Kg]_N`07Kg/00`00Kg]_N`0FKg/5000EKg/0
0`00Kg]_N`0;Kg/20008Kg/00`00Kg]_N`0=Kg/00`00Kg/000020002Kg/2000;Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/5000>Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk00006Fmk1@0056mk00<006mk
Kg/036mk10004Fmk00<006mkKg/066mk1000:Fmk000XKg/00`00Kg]_N`07Kg/00`00Kg]_N`0FKg/7
000CKg/00`00Kg]_N`08Kg/3000:Kg/00`00Kg]_N`0;Kg/20002Kg/00`00Kg]_N`04Kg/20009Kg/0
0`00Kg]_N`0<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/5000=Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0FKg/00`00Kg/00004000CKg/00`00Kg]_N`0;Kg/5000AKg/00`00Kg]_N`0HKg/5000XKg/002M_
N`03001_Nfmk00Q_N`03001_Nfmk01E_N`D000=_N`<000m_N`03001_Nfmk00M_N`8000a_N`03001_
Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk00I_N`8000I_N`03001_Nfmk00e_N`03001_Nfmk00=_
N`03001_Nfmk00Q_N`03001_Nfmk00]_N`@000i_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_
Nfmk00Y_N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk01A_N`80009_N`03001_Nfmk009_
N`03001_Nfmk00m_N`03001_Nfmk00a_N`D0015_N`03001_Nfmk01Q_N`D002Q_N`009Vmk00<006mk
Kg/02Vmk00<006mkKg/04fmk00D006mkKg]_N`0000M_N`<000a_N`03001_Nfmk00E_N`8000i_N`03
001_Nfmk00U_N`8000E_N`03001_Nfmk00Q_N`80009_N`<000m_N`03001_Nfmk00=_N`03001_Nfmk
00U_N`03001_Nfmk00U_N`06001_Nfmk001_N`003Fmk00<006mkKg/01fmk00<006mkKg/00fmk00<0
06mkKg/02fmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/04fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00<006mkKg/03Vmk00<006mkKg/036mk1@004Fmk00<006mkKg/05Fmk2000:6mk000V
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0BKg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/40008Kg/00`00
Kg]_N`02Kg/3000@Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/6000?Kg/01@00
Kg]_Nfmk000036mk00<006mkKg/026mk00D006mkKg]_N`00009_N`03001_Nfmk00U_N`03001_Nfmk
00U_N`03001_Nfmk009_N`03001_Nfmk00]_N`03001_Nfmk00M_N`03001_Nfmk00E_N`03001_Nfmk
015_N`8000A_N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_Nfmk00]_N`800005Kg/00000001_
N`02000?Kg/00`00Kg]_N`0BKg/30004Kg/3000YKg/002E_N`03001_Nfmk00]_N`03001_Nfmk015_
N`03001_Nfmk00=_N`03001_Nfmk00a_N`<000=_N`<0009_N`80019_N`03001_Nfmk00M_N`8000M_
N`03001_Nfmk00a_N`L000e_N`@000e_N`03001_Nfmk00M_N`03001_Nfmk009_N`05001_NfmkKg/0
000:Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00003Vmk00<006mkKg/01Vmk00<006mkKg/01Vmk00<0
06mkKg/046mk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/02fmk00<006mkKg/02Fmk0P00
16mk00<006mkKg/00Vmk0P0036mk00<006mkKg/03fmk10001Vmk00<006mkKg/00P00:6mk000UKg/0
0`00Kg]_N`0;Kg/00`00Kg]_N`0?Kg/20007Kg/00`00Kg]_N`0>Kg/8000DKg/00`00Kg]_N`06Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/50002Kg/:0002Kg/5000=Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`03Kg/01@00Kg]_Nfmk00002Vmk00<006mkKg/02Vmk0`003fmk00<006mkKg/01Fmk00<006mkKg/0
1fmk00<006mkKg/03Vmk0P001fmk00<006mkKg/01fmk0P002Vmk00<006mkKg/026mk0P001Vmk00<0
06mkKg/016mk0P002Vmk00<006mkKg/036mk0`002Vmk00D006mkKg]_N`0002Q_N`0096mk00<006mk
Kg/036mk00<006mkKg/03Vmk00<006mkKg/01fmk00<006mkKg/046mk1@005Fmk00<006mkKg/016mk
0P002Vmk00<006mkKg/02fmk1@003Fmk1`003Fmk00<006mkKg/016mk0P001Vmk00<006mkKg/00Vmk
00<006mkKg/01Vmk00<006mkKg/02Vmk1@003Vmk00<006mkKg/016mk00<006mkKg/02Fmk00<006mk
Kg/036mk00<006mkKg/01Vmk00<006mkKg/02Vmk00<006mkKg/01fmk00<006mkKg/01Vmk0P0026mk
00<006mkKg/01Vmk0P0026mk00<006mkKg/02Fmk0`0036mk00<006mkKg/00Vmk0P009fmk000TKg/0
0`00Kg]_N`0<Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0@Kg/7000BKg/00`00Kg]_
N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk000046mk1P0036mk00<006mkKg/0
0fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/02Vmk1@003Vmk00<0
06mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/02Vmk0P002Fmk00<006mkKg/02fmk00<006mkKg/0
1Fmk00<006mkKg/01Fmk0P002Vmk00<006mkKg/026mk0P001Vmk00<006mkKg/01Fmk10003fmk00<0
06mkKg/00Vmk00<006mk00009Vmk000SKg/00`00Kg]_N`0>Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`0AKg/30003Kg/3000?Kg/00`00Kg]_N`02Kg/2000<Kg/00`00Kg]_N`0:Kg/01@00
Kg]_Nfmk000046mk00<006mk00000P000Vmk0P002Vmk00<006mkKg/00Vmk00<006mkKg/01fmk00<0
06mkKg/016mk00<006mkKg/00fmk00<006mkKg/02Vmk200036mk00<006mkKg/00Vmk00<006mkKg/0
2fmk00<006mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/036mk00<006mkKg/016mk00<006mkKg/0
0fmk0P0036mk00<006mkKg/02Vmk0P000Vmk0`0016mk0`004Vmk00<006mkKg/016mk0P009Vmk000S
Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`09Kg/2000<Kg/00`00Kg]_N`0@Kg/00`00Kg/00007Kg/3000;
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<
Kg/20002Kg/00`00Kg]_N`04Kg/20008Kg/01@00Kg]_Nfmk00002Vmk00<006mkKg/016mk00<006mk
Kg/00fmk00<006mkKg/01fmk0`000Vmk0`000fmk0`002Vmk00D006mkKg]_N`0000e_N`03001_Nfmk
00M_N`8000]_N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk009_N`8000i_N`03001_Nfmk
00a_N`T001E_N`03001_Nfmk00A_N`03001_N`0002E_N`008Vmk00<006mkKg/03fmk00<006mkKg/0
26mk00<006mkKg/036mk00<006mkKg/03fmk00@006mkKg/000Y_N`<000Q_N`03001_Nfmk008000m_
N`03001_Nfmk00M_N`8000E_N`03001_Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk00I_N`<000E_
N`04001_Nfmk000;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/20006Kg/00`00
Kg]_N`05Kg/30007Kg/01000Kg]_N`003Vmk00<006mkKg/01Vmk00<006mkKg/02fmk00<006mkKg/0
3fmk1@000Vmk0P0046mk00<006mkKg/03Fmk1@005fmk00<006mkKg/01Fmk00<006mk00009Fmk000R
Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0>Kg/01@00Kg]_Nfmk
00003Fmk0`000fmk0`0000=_N`00Kg/03fmk00<006mkKg/01fmk00<006mkKg/01Fmk00<006mkKg/0
2Fmk0P0016mk00<006mkKg/02Vmk0P000Vmk100036mk00<006mkKg/01Vmk00@006mkKg/000E_N`<0
00Q_N`03001_Nfmk00Q_N`<000=_N`@000m_N`03001_Nfmk00A_N`8000e_N`03001_Nfmk015_N`H0
019_N`03001_Nfmk00e_N`D001M_N`03001_Nfmk00I_N`03001_N`0002A_N`008Fmk00<006mkKg/0
46mk00<006mkKg/01Fmk0P0046mk00<006mkKg/03Vmk00D006mkKg]_N`00011_N`L0015_N`03001_
Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00a_N`H000e_
N`03001_Nfmk00I_N`<0009_N`<000]_N`03001_Nfmk00]_N`L000m_N`03001_Nfmk00=_N`03001_
Nfmk00e_N`03001_Nfmk015_N`D001=_N`03001_Nfmk00e_N`@001M_N`03001_Nfmk00M_N`04001_
Nfmk000SKg/0025_N`03001_Nfmk011_N`03001_Nfmk00A_N`03001_Nfmk011_N`03001_Nfmk00e_
N`03001_Nfmk009_N`03001_Nfmk011_N`D0015_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03001_
Nfmk00I_N`8000M_N`03001_Nfmk00e_N`D000e_N`03001_Nfmk00E_N`H000i_N`03001_Nfmk00e_
N`D000m_N`04001_NfmkKg/2000@Kg/00`00Kg]_N`0?Kg/7000CKg/00`00Kg]_N`0=Kg/01@00Kg]_
Nfmk00005Vmk00<006mkKg/026mk00<006mk00008fmk000PKg/00`00Kg]_N`0AKg/00`00Kg]_N`03
Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/6000@Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0>Kg/5000=
Kg/00`00Kg]_N`05Kg/5000?Kg/00`00Kg]_N`0=Kg/;0008Kg/300000fmk001_N`0@Kg/00`00Kg]_
N`0>Kg/20003Kg/4000CKg/00`00Kg]_N`0<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0CKg/00`00Kg]_
N`09Kg/01000Kg]_N`008Vmk000PKg/00`00Kg]_N`0BKg/01@00Kg]_Nfmk000056mk00<006mkKg/0
36mk00<006mkKg/00fmk00<006mkKg/03fmk1@000Vmk0P003Fmk00<006mkKg/00fmk0P002fmk00<0
06mkKg/00fmk0P002Fmk00<006mkKg/036mk0P0000I_N`00000006mk000<Kg/00`00Kg]_N`05Kg/5
000?Kg/00`00Kg]_N`0<Kg/00`00Kg/000020007Kg/600000fmk00000003000BKg/00`00Kg]_N`0;
Kg/30006Kg/01000Kg]_N`004Vmk00<006mkKg/02fmk00<006mkKg/016mk00<006mkKg/04Vmk00<0
06mkKg/02Fmk00@006mkKg/0029_N`007fmk00<006mkKg/04Vmk1@005Fmk00<006mkKg/02fmk00<0
06mkKg/016mk00<006mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk0P002fmk00<006mkKg/0
0Vmk00<006mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/02Vmk0P000fmk00<0
06mkKg/00Vmk0P002Vmk00<006mkKg/01Fmk100000=_N`00Kg/03Fmk00<006mkKg/02Vmk0P000Vmk
00<006mk00003Fmk1P004Vmk00<006mkKg/026mk0`002Fmk00D006mkKg]_N`00015_N`03001_Nfmk
00Y_N`03001_Nfmk00E_N`03001_Nfmk015_N`03001_Nfmk00]_N`04001_Nfmk000QKg/001i_N`03
001_Nfmk019_N`D001M_N`03001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00e_N`03001_Nfmk
00=_N`03001_Nfmk00A_N`<000Q_N`05001_NfmkKg/0000=Kg/01000Kg]_Nfmk0P0036mk00<006mk
Kg/026mk0P001Fmk00<006mkKg/016mk0P0026mk00<006mkKg/016mk00D006mkKg]_N`00009_N`03
001_Nfmk00Y_N`03001_Nfmk00Y_N`03001_Nfmk009_N`03001_N`0000i_N`P000i_N`03001_Nfmk
00I_N`<000a_N`03001_Nfmk009_N`8000m_N`03001_Nfmk00U_N`03001_Nfmk00M_N`03001_Nfmk
011_N`03001_Nfmk00]_N`05001_NfmkKg/0000PKg/001i_N`03001_Nfmk019_N`D001M_N`03001_
Nfmk00U_N`03001_Nfmk00I_N`03001_Nfmk00]_N`03001_Nfmk00A_N`03001_Nfmk00M_N`8000I_
N`04001_Nfmk000=Kg/300000fmk001_N`0<Kg/00`00Kg]_N`07Kg/20006Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02000:Kg/00`00Kg]_N`08
Kg/20005Kg/01000Kg]_N`003Vmk0`0016mk10002Vmk00<006mkKg/00fmk0`003fmk00<006mkKg/0
16mk00<006mkKg/036mk00<006mkKg/026mk00<006mkKg/026mk00<006mkKg/03fmk00<006mkKg/0
3Fmk00@006mkKg/0021_N`007Fmk00<006mkKg/04fmk1@005fmk00<006mkKg/026mk00<006mkKg/0
1fmk00<006mkKg/02Fmk0P001fmk00<006mkKg/02Fmk0P000Vmk1@003Fmk1@003Vmk00<006mkKg/0
1Vmk00<006mkKg/01Vmk00<006mkKg/026mk0P001Fmk00@006mkKg]_N`8000I_N`03001_Nfmk009_
N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00E_N`04001_Nfmk000>Kg/20009Kg/40004
Kg/30003Kg/2000BKg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0>Kg/01@00Kg]_Nfmk00007fmk000MKg/00`00Kg]_N`0BKg/5
00000fmk0000000EKg/00`00Kg]_N`07Kg/00`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`0;Kg/60007Kg/<000>Kg/00`00Kg]_N`04Kg/20009Kg/00`00Kg]_N`0:Kg/00`00
Kg]_N`02Kg/01000Kg]_N`0026mk00<006mkKg/00fmk0P001fmk00<006mkKg/01Vmk00<006mkKg/0
1Fmk00<006mkKg/00Vmk00<006mkKg/02Vmk00@006mkKg/000a_N`X001A_N`03001_Nfmk00I_N`03
001_Nfmk00Y_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03001_Nfmk00e_N`03001_Nfmk00i_N`05
001_NfmkKg/0000OKg/001a_N`03001_Nfmk019_N`04001_Nfmk0005Kg/2000CKg/00`00Kg]_N`06
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/<0007Kg/7000;
Kg/00`00Kg]_N`03Kg/2000:Kg/00`00Kg]_N`0<Kg/200000fmk00000002000:Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/20008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/01000
Kg]_N`003fmk1@005Vmk00<006mkKg/01fmk00<006mkKg/02Fmk00<006mkKg/01Vmk00<006mkKg/0
36mk00<006mkKg/02fmk00<006mkKg/046mk00D006mkKg]_N`0001i_N`0076mk00<006mkKg/04Fmk
00D006mkKg]_N`0000M_N`80015_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00I_N`03
001_Nfmk00Y_N`03001_Nfmk00]_N`D000m_N`<000=_N`<000Q_N`04001_NfmkKg/2000<Kg/00`00
Kg]_N`0>Kg/5000:Kg/00`00Kg]_N`05Kg/20004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0:Kg/01000Kg]_N`003fmk1P005Fmk00<006mkKg/026mk00<006mkKg/0
26mk00<006mkKg/01Fmk00<006mkKg/03Fmk00<006mkKg/02fmk00<006mkKg/046mk00<006mkKg/0
0Vmk00<006mkKg/06fmk000KKg/00`00Kg]_N`0AKg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`0>Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/2000=Kg/00`00Kg]_N`0;
Kg/4000?Kg/00`00Kg]_N`020005Kg/30003Kg/300000fmk0000000>Kg/00`00Kg]_N`0>Kg/5000:
Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk00000fmk0P002fmk00<006mkKg/00fmk00<006mkKg/026mk
00D006mkKg]_N`0000m_N`D00004Kg/00000000BKg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0BKg/01@00Kg]_Nfmk00007Fmk
000KKg/00`00Kg]_N`0?Kg/20005Kg/00`00Kg]_N`08Kg/2000>Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0<Kg/01P00Kg]_N`00Kg/000M_N`L000m_N`03001_Nfmk00]_N`T000]_N`03001_Nfmk00M_N`03
001_N`0000800003Kg/006mk00]_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`05001_NfmkKg/0000?
Kg/01@00Kg/006mk000016mk0P0046mk00<006mkKg/02Vmk00<006mkKg/01Vmk00<006mkKg/016mk
00<006mkKg/03fmk00<006mkKg/02Fmk00<006mkKg/04Vmk00<006mkKg/00Vmk00<006mkKg/06Vmk
000JKg/00`00Kg]_N`0?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/2000<Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`0;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0;Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01Vmk1@003fmk00<006mkKg/01fmk1000
1Fmk0`0000=_N`00Kg/02Fmk00<006mkKg/026mk1@003Fmk00<006mkKg/016mk00<006mkKg/01fmk
00<006mkKg/00Vmk00<006mkKg/036mk00@006mkKg/0009_N`03001_Nfmk00=_N`<000e_N`03001_
Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk015_N`03001_Nfmk00M_N`03001_
Nfmk01=_N`03001_Nfmk009_N`03001_Nfmk01Y_N`006Vmk00<006mkKg/03Vmk00<006mkKg/01Vmk
00<006mkKg/036mk0P002Vmk00<006mkKg/00fmk00<006mkKg/036mk00D006mkKg]_N`00015_N`03
001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`05001_NfmkKg/00002Kg/00`00Kg]_N`06
Kg/;0009Kg/00`00Kg]_N`03Kg/4000:Kg/01000Kg]_Nfmk0P002Fmk00<006mkKg/01fmk1@003Fmk
00<006mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/02Vmk00D006mkKg]_N`00
00=_N`03001_Nfmk00E_N`8000]_N`03001_Nfmk00a_N`03001_Nfmk00A_N`03001_Nfmk009_N`03
001_Nfmk019_N`03001_Nfmk00M_N`03001_Nfmk01A_N`03001_Nfmk009_N`03001_Nfmk01U_N`00
6Fmk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/03fmk0P0026mk00<006mkKg/00Vmk00<0
06mkKg/036mk1@004fmk00<006mkKg/01Vmk00<006mkKg/01fmk00<006mkKg/026mk00<006mkKg/0
0Vmk00D006mkKg]_N`0000Q_N`<000M_N`H00005Kg/00000001_N`04000>Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`07Kg/5000=Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/30008Kg/0
0`00Kg]_N`0=Kg/20004Kg/01@00Kg]_Nfmk00005Vmk00<006mkKg/01Fmk00<006mkKg/05Fmk00<0
06mkKg/00fmk00<006mkKg/066mk000IKg/00`00Kg]_N`0<Kg/20009Kg/00`00Kg]_N`0AKg/00`00
Kg]_N`06Kg/01@00Kg]_Nfmk00003Fmk1@0056mk00<006mkKg/016mk0P002Vmk00<006mkKg/026mk
00<006mkKg/00fmk00D006mkKg]_N`0000Q_N`03001_Nfmk00a_N`D0019_N`03001_Nfmk00A_N`80
00I_N`03001_Nfmk00M_N`@00003Kg/0000000Y_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_
Nfmk00A_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00U_N`8000I_
N`03001_Nfmk00m_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0EKg/00`00Kg]_N`05Kg/00`00Kg]_
N`0EKg/00`00Kg]_N`03Kg/00`00Kg]_N`0HKg/001Q_N`03001_Nfmk00a_N`03001_Nfmk00U_N`03
001_Nfmk019_N`8000I_N`04001_Nfmk000>Kg/5000DKg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<Kg/7
000?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/20008Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/30002Kg/3000AKg/01P00Kg]_N`00Kg/001U_N`03001_Nfmk
00=_N`03001_Nfmk01M_N`03001_Nfmk00=_N`03001_Nfmk01M_N`0066mk00<006mkKg/02fmk00<0
06mkKg/02Vmk00<006mkKg/056mk0P0016mk00<006mk00002Vmk3`003fmk00<006mkKg/00Vmk00<0
06mkKg/03Fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/01Fmk00<0
06mkKg/02Vmk1`000Vmk10002fmk00<006mkKg/026mk0P0016mk00<006mkKg/016mk00<006mkKg/0
26mk00<006mkKg/01Fmk00<006mkKg/01fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/0
1fmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/036mk1P004Fmk1@006Fmk00<006mkKg/0
0fmk00<006mkKg/05fmk00<006mkKg/016mk00<006mkKg/05Vmk000GKg/00`00Kg]_N`0;Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0FKg/2000016mk000000001Vmk1@001Vmk1@0016mk10002fmk00D006mk
Kg]_N`00011_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03
001_Nfmk00U_N`04001_NfmkKg/30007Kg/30008Kg/00`00Kg]_N`0:Kg/01@00Kg]_Nfmk00001Fmk
00<006mkKg/02Vmk0P001Fmk00<006mkKg/01fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mk
Kg/01Vmk00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/036mk3@002Fmk1@006Vmk00D006mk
Kg]_N`0001]_N`03001_Nfmk00=_N`03001_Nfmk01I_N`005fmk00<006mkKg/02Fmk0P003Fmk00<0
06mkKg/06Fmk2P002fmk00<006mk00000Vmk00<006mkKg/01Fmk1@001Vmk10004Vmk00<006mkKg/0
0fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/00Vmk00<006mkKg/026mk0P001Vmk00<0
06mkKg/026mk0`001Fmk00<006mkKg/02fmk0P000Vmk00D006mkKg]_N`0000m_N`80009_N`03001_
Nfmk00U_N`05001_NfmkKg/00009Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`0<Kg/50008Kg/A000GKg/01@00Kg]_Nfmk00006fmk00<006mkKg/016mk00<006mkKg/0
5Fmk000FKg/00`00Kg]_N`09Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0IKg/5000@Kg/00`00Kg/00003
Kg/00`00Kg]_N`09Kg/:000BKg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/01@00
Kg]_Nfmk00002Fmk00<006mkKg/01Vmk00<006mkKg/02fmk1`003Vmk00<006mk00000`004Vmk1000
2Vmk00D006mkKg]_N`0000U_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_
Nfmk00a_N`D0011_N`D000=_N`X000i_N`<001a_N`03001_Nfmk00A_N`03001_Nfmk01E_N`005Fmk
00<006mkKg/02Fmk00<006mkKg/03Vmk00<006mkKg/066mk1P0046mk00@006mkKg/000=_N`03001_
Nfmk00e_N`H0019_N`05001_NfmkKg/00009Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00001fmk0P00
2Fmk00<006mkKg/03Vmk30001fmk1@002Fmk3P002Vmk00@006mkKg/000U_N`03001_Nfmk00=_N`03
001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00i_N`<0
00i_N`X000=_N`D001a_N`03001_Nfmk00A_N`03001_Nfmk01A_N`005Fmk00<006mkKg/026mk00<0
06mkKg/03fmk00<006mkKg/05Fmk0`000Vmk0`004Fmk00@006mkKg/000A_N`03001_Nfmk00a_N`D0
0003Kg/0000000H000]_N`<000Y_N`03001_Nfmk00E_N`04001_Nfmk0005Kg/2000;Kg/00`00Kg]_
N`0=Kg/60007Kg/E0009Kg/80007Kg/00`00Kg/0000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0GKg/=
000GKg/30005Kg/00`00Kg]_N`0CKg/001A_N`03001_Nfmk00M_N`80019_N`03001_Nfmk01=_N`80
00E_N`04001_Nfmk000?Kg/01@00Kg]_Nfmk00001Fmk0P003Fmk1@0026mk20000Vmk1@002Fmk00<0
06mkKg/01Vmk00<006mk000016mk00<006mkKg/036mk00<006mkKg/02Vmk0P0000=_N`0000000`00
3Vmk1@004Vmk1@000fmk0`0016mk0`002Vmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mkKg/0
2Fmk00<006mkKg/01fmk00<006mkKg/01Vmk0P003Vmk00<006mkKg/06Fmk1P001Fmk40001Vmk1@00
16mk00<006mkKg/04fmk000DKg/00`00Kg]_N`06Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0@Kg/30007
Kg/01000Kg]_N`003fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/02fmk00D006mkKg]_
N`0000m_N`L000U_N`03001_Nfmk00M_N`<00003Kg/0000000m_N`03001_Nfmk00Q_N`8000A_N`<0
0003Kg/006mk00e_N`<0019_N`03001_N`00008000M_N`P000U_N`05001_NfmkKg/0000;Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0GKg/20002
Kg/3000FKg/;0005Kg/00`00Kg]_N`0BKg/001=_N`03001_Nfmk00I_N`03001_Nfmk019_N`03001_
Nfmk00m_N`8000U_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk009_N`03001_Nfmk00E_
N`03001_Nfmk00U_N`03001_Nfmk00=_N`03001_Nfmk00i_N`D000Y_N`03001_Nfmk00E_N`D0015_
N`03001_Nfmk00I_N`8000I_N`03001_Nfmk009_N`03001_Nfmk00Y_N`05001_NfmkKg/0000AKg/0
1000Kg]_N`002fmk1@002Vmk00<006mk000036mk00<006mkKg/02Vmk00<006mkKg/016mk00<006mk
Kg/02fmk00<006mkKg/02Vmk00<006mkKg/05Fmk0P000fmk00@006mkKg/001a_N`D000E_N`03001_
Nfmk019_N`004fmk00<006mkKg/01Fmk00<006mkKg/04fmk00<006mkKg/03Fmk0P002fmk00<006mk
Kg/00Vmk00<006mkKg/036mk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/026mk00<006mk
Kg/016mk00<006mkKg/03Vmk0`0000=_N`00000026mk00<006mkKg/01Fmk1P0046mk00<006mkKg/0
16mk0P0026mk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/00Vmk00<006mkKg/03Fmk00D0
06mkKg]_N`0000]_N`T000E_N`<000e_N`03001_Nfmk00]_N`03001_Nfmk00=_N`03001_Nfmk00a_
N`03001_Nfmk00U_N`03001_Nfmk01=_N`8000E_N`05001_NfmkKg/0000LKg/50005Kg/00`00Kg]_
N`0AKg/0019_N`03001_Nfmk00A_N`8001I_N`03001_Nfmk00Y_N`<000e_N`03001_Nfmk00=_N`03
001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00I_N`8000Q_N`03001_Nfmk00E_N`8000i_N`03
001_Nfmk00=_N`8000I_N`03001_Nfmk00E_N`D00003Kg/0000000D000Q_N`<000=_N`8000Y_N`03
001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk00=_N`03
001_Nfmk00Q_N`@000E_N`T000a_N`03001_Nfmk00a_N`05001_NfmkKg/0000@Kg/20009Kg/00`00
Kg]_N`0AKg/20006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0IKg/00`00Kg]_N`03Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`0@Kg/0019_N`03001_Nfmk00=_N`03001_Nfmk01I_N`03001_Nfmk00Q_N`8000m_
N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00E_
N`03001_Nfmk00M_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00A_
N`03001_N`0000<000Q_N`h000a_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03
001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_N`0000Y_N`D000a_N`03001_Nfmk
00a_N`@001=_N`03001_Nfmk00M_N`03001_Nfmk00i_N`8000Q_N`03001_Nfmk00=_N`03001_Nfmk
01Q_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk011_N`004Fmk00<006mkKg/00fmk00<0
06mkKg/05fmk00<006mkKg/01Fmk0`004Fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/0
16mk00<006mkKg/02Fmk00<006mkKg/016mk00<006mkKg/026mk00<006mkKg/02Vmk00<006mkKg/0
1Vmk0P000fmk00<006mkKg/00Vmk0P001Vmk00<006mkKg/036mk1@003Vmk00<006mkKg/01Vmk00<0
06mkKg/016mk00<006mkKg/01Vmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/01fmk00@0
06mkKg/000Y_N`P000U_N`03001_Nfmk00]_N`D001A_N`03001_Nfmk00I_N`03001_Nfmk00]_N`<0
00U_N`03001_Nfmk00A_N`03001_Nfmk01M_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk
00m_N`004Fmk00<006mkKg/00Vmk00<006mkKg/066mk00<006mkKg/00fmk0P0056mk00<006mkKg/0
1Fmk00<006mkKg/02Fmk00<006mkKg/01Fmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/0
2Fmk00<006mkKg/02Fmk00<006mkKg/026mk0P0000I_N`00000006mk0009Kg/00`00Kg]_N`0;Kg/7
000<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00002fmk0`0016mk100016mk0`002fmk1`0056mk00<0
06mkKg/01Fmk00<006mkKg/02Fmk0P0036mk00<006mkKg/01Fmk00<006mkKg/05Fmk00<006mkKg/0
26mk0P000Vmk00<006mkKg/03fmk000@Kg/01000Kg]_Nfmk0P006Fmk0`000Vmk0`005Fmk00<006mk
Kg/01fmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/02Vmk00D006mkKg]_N`0000e_N`03
001_Nfmk00M_N`03001_Nfmk00]_N`D000]_N`03001_Nfmk00Y_N`D0009_N`<000U_N`03001_Nfmk
00Q_N`05001_NfmkKg/0000:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`07Kg/01000Kg]_N`0026mk20000Vmk200000=_N`0000000`0000=_N`00
00000`0046mk0P001Fmk00<006mkKg/01fmk0P003Fmk00<006mkKg/01Vmk00<006mkKg/05Fmk00<0
06mkKg/02Vmk00@006mkKg/0011_N`0046mk00@006mkKg/001Y_N`H001Q_N`03001_Nfmk00M_N`03
001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00]_N`D000e_N`8000M_N`03001_Nfmk00]_N`D0
00a_N`03001_Nfmk00Q_N`07001_NfmkKg/006mk000016mk0P001Vmk00<006mkKg/02Vmk10002fmk
00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/01fmk
00@006mkKg/000]_N`L000Y_N`<00003Kg/006mk00A_N`D000e_N`03001_Nfmk009_N`03001_Nfmk
00E_N`8000m_N`03001_Nfmk00M_N`03001_Nfmk01=_N`03001_Nfmk00a_N`04001_Nfmk000?Kg/0
00m_N`04001_Nfmk000IKg/7000IKg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`0;Kg/5000>Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/:000:Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`02Kg/00`00Kg/00006Kg/3000016mk0000000036mk1@002fmk00<006mkKg/00Vmk00<0
06mkKg/026mk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/00Vmk00<0
06mkKg/026mk1@003Vmk00@006mkKg/000U_N`H000Q_N`05001_NfmkKg/00005Kg/2000@Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0>Kg/00`00Kg/0000?Kg/000m_N`03001_N`00015_
N`T0009_N`D001Q_N`03001_Nfmk00U_N`03001_Nfmk00I_N`03001_Nfmk00M_N`03001_Nfmk00]_
N`D000m_N`03001_Nfmk00=_N`03001_Nfmk00I_N`<000=_N`<000A_N`@000M_N`03001_Nfmk00A_
N`03001_Nfmk00=_N`04001_Nfmk0008Kg/50006Kg/;000;Kg/4000;Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`09Kg/4000>Kg/01@00Kg]_Nfmk
00003Vmk1@0016mk1@000Vmk0P004Vmk00<006mkKg/026mk00<006mkKg/04Vmk00<006mkKg/03fmk
1@0036mk000<Kg/5000:Kg/8000<Kg/300000fmk0000000FKg/00`00Kg]_N`0:Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0:Kg/<000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/20005
Kg/01@00Kg]_Nfmk00001fmk100016mk1P001Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk2`001Fmk
1@0000=_N`0000001P000Vmk1@002fmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/01Fmk
00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/00Vmk0P0036mk00<006mkKg/00Vmk00<006mk
Kg/046mk2`004fmk00<006mkKg/02Vmk00<006mkKg/046mk00<006mkKg/04Fmk1@002fmk000;Kg/5
0002Kg/9000EKg/00`00Kg]_N`02Kg/00`00Kg]_N`0CKg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`07Kg/20002Kg/40006Kg/60005Kg/50003Kg/30007Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`08Kg/90006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/5000<Kg/3000:Kg/7
000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0DKg/5000DKg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0AKg/5000;Kg/000]_N`L001e_N`03001_Nfmk
00A_N`80019_N`03001_Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00A_N`<0
00E_N`04001_Nfmk000;Kg/=0009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0<Kg/50006Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`05Kg/300000fmk0000000:Kg/01000Kg]_N`002fmk1`002Vmk00@006mkKg/0
00U_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk
00Q_N`03001_Nfmk00A_N`03001_Nfmk01=_N`D001=_N`03001_Nfmk00a_N`03001_Nfmk00i_N`03
001_Nfmk019_N`D000]_N`002fmk1@007fmk00<006mkKg/01Vmk0P0046mk00<006mkKg/036mk00<0
06mkKg/00fmk00<006mkKg/02Fmk0`000Vmk0P0026mk00D006mkKg]_N`00011_N`D000]_N`03001_
Nfmk00A_N`03001_Nfmk00]_N`D000I_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00=_
N`03001_Nfmk00M_N`05001_NfmkKg/0000;Kg/30003Kg/30007Kg/00`00Kg/0000:Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0BKg/400000fmk0000000AKg/00`00Kg]_N`0<Kg/00`00Kg]_N`0=Kg/00`00
Kg]_N`0AKg/2000016mk0000000036mk000<Kg/5000NKg/00`00Kg]_N`08Kg/00`00Kg]_N`0=Kg/0
0`00Kg]_N`0=Kg/01@00Kg]_Nfmk00002fmk1P002Vmk00<006mkKg/00Vmk00<006mkKg/036mk1P00
2Vmk00<006mkKg/01Vmk00<006mkKg/02Vmk10001fmk00<006mkKg/016mk00<006mkKg/00fmk00<0
06mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mk00001Vmk0`00
0fmk0`002fmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/016mk00<006mkKg/02Fmk00<0
06mkKg/01fmk00<006mkKg/01Fmk0P004Fmk00@006mkKg/000A_N`8000i_N`03001_Nfmk00i_N`03
001_Nfmk00a_N`03001_Nfmk00m_N`8000A_N`03001_Nfmk00]_N`003Fmk00D006mkKg]_N`0001e_
N`03001_Nfmk00U_N`8000a_N`03001_Nfmk00i_N`05001_NfmkKg/0000;Kg/5000;Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`09Kg/20002Kg/3000;Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/20006Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`08Kg/01000Kg]_N`0026mk1`002Vmk00<006mkKg/00Vmk00<006mk
Kg/026mk00<006mkKg/016mk00<006mkKg/02Vmk0P001fmk00<006mkKg/01fmk00<006mkKg/03Fmk
00@006mkKg/000M_N`8000a_N`03001_Nfmk00i_N`03001_Nfmk00]_N`03001_Nfmk00i_N`8000I_
N`03001_Nfmk00]_N`003Fmk00<006mkKg/00Vmk00<006mkKg/06Vmk00<006mkKg/02fmk00<006mk
Kg/02Fmk00<006mkKg/03fmk00@006mkKg/000U_N`L000]_N`03001_Nfmk00A_N`03001_Nfmk00I_
N`8000A_N`04001_Nfmk0009Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`05Kg/01@00Kg]_Nfmk00002fmk00<006mkKg/00fmk00<006mkKg/00fmk
00<006mkKg/01fmk00@006mkKg/000Y_N`D000Y_N`05001_NfmkKg/0000<Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk0000
2Fmk00<006mkKg/026mk00<006mkKg/046mk00<006mkKg/02Fmk00<006mkKg/03Fmk0P001fmk0P00
3Fmk000=Kg/00`00Kg]_N`03Kg/2000JKg/00`00Kg]_N`0<Kg/20009Kg/00`00Kg]_N`0?Kg/01000
Kg]_N`001Vmk0`000fmk0`0036mk00<006mkKg/01Fmk10000Vmk0P001Vmk00D006mkKg]_N`0000Q_
N`03001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00I_
N`<000e_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_
Nfmk00M_N`H000Y_N`04001_Nfmk000<Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`09Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/20008Kg/00`00
Kg]_N`0@Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0;Kg/20009Kg/2000=Kg/000e_N`03001_Nfmk00E_
N`03001_Nfmk01M_N`03001_Nfmk00i_N`8000I_N`03001_Nfmk011_N`<000A_N`<000I_N`04001_
Nfmk000;Kg/00`00Kg]_N`05Kg/60008Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/02Vmk00<006mk
Kg/016mk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/01Fmk1@003Fmk1@001fmk00<006mk
Kg/016mk00<006mkKg/00Vmk00<006mkKg/026mk0`000Vmk0P0026mk00<006mk00003Fmk00D006mk
Kg]_N`00019_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03
001_Nfmk00Y_N`8000E_N`03001_Nfmk015_N`03001_Nfmk00Q_N`03001_Nfmk00Y_N`8000]_N`80
00e_N`003Fmk00<006mkKg/01Vmk00<006mkKg/05Fmk00<006mkKg/04Fmk00<006mkKg/00fmk00<0
06mkKg/03fmk20002Fmk00D006mkKg]_N`0000Y_N`03001_Nfmk00E_N`D000Q_N`03001_Nfmk00=_
N`03001_Nfmk00A_N`03001_Nfmk00]_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk009_
N`03001_Nfmk00E_N``000M_N`D000I_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00M_
N`03001_Nfmk00A_N`<000E_N`03001_N`0000i_N`04001_Nfmk000CKg/01@00Kg]_Nfmk00003Fmk
00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/036mk0P0000A_N`00000001A_N`03001_Nfmk
00M_N`03001_Nfmk00Q_N`8000e_N`8000e_N`003Fmk00<006mkKg/01fmk00<006mkKg/056mk00<0
06mkKg/04Vmk0P0000A_N`00000000m_N`L000a_N`05001_NfmkKg/0000:Kg/00`00Kg]_N`05Kg/5
0008Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0=Kg/4000<Kg/01000Kg]_N`0026mk
1@001fmk30001fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/026mk
0P000Vmk0`003fmk00<006mk00005Fmk1@003Fmk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mk
Kg/03Vmk1@004fmk00<006mkKg/01Vmk00<006mkKg/01fmk0P003fmk0P003Fmk000=Kg/00`00Kg]_
N`08Kg/2000DKg/00`00Kg]_N`0DKg/50003Kg/;0002Kg/5000<Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`06Kg/30009Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/5
000=Kg/00`00Kg/00006Kg/2000016mk000000003fmk1`001Vmk00D006mkKg]_N`0000M_N`03001_
Nfmk00E_N`03001_Nfmk00Y_N`H000i_N`<001I_N`D000e_N`D000Q_N`03001_Nfmk00i_N`D001A_
N`03001_Nfmk00A_N`03001_Nfmk00I_N`80015_N`8000e_N`003Fmk00<006mkKg/02Vmk00<006mk
Kg/04Fmk00<006mkKg/056mk20003Vmk100036mk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mk
Kg/01Vmk00@006mkKg/000U_N`03001_Nfmk00E_N`04001_Nfmk000>Kg/6000=Kg/00`00Kg/00004
Kg/20003Kg/00`00Kg/0000?Kg/40003Kg/20005Kg/01000Kg]_N`001fmk00<006mkKg/016mk00<0
06mkKg/036mk2`001fmk1@002fmk5@001fmk1@001fmk00<006mkKg/03fmk20004Fmk00<006mkKg/0
16mk00<006mkKg/016mk0P004fmk0P003Fmk000=Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0@Kg/00`00
Kg]_N`0DKg/5000AKg/01000Kg]_N`002fmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/0
1Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/01fmk0`0026mk1P0000=_N`0000002@00
26mk0`0000=_N`0000001Fmk00@006mkKg/000a_N`80009_N`8000E_N`<0009_N`@000Q_N`03001_
Nfmk00=_N`03001_Nfmk00]_N`H000I_NaL000Y_N`D000I_N``000M_N`03001_Nfmk00i_N`D000A_
N`@000i_N`03001_Nfmk009_N`03001_Nfmk00=_N`8001E_N`8000e_N`0036mk0P003Vmk0P0046mk
00<006mkKg/04Vmk0P0000A_N`000000015_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk
00E_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk
00I_N`D00003Kg/0000000@000I_N`03001_N`0000<000I_N`H00003Kg/0000000<000M_N`04001_
Nfmk000;Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01Fmk1`001fmk00<006mkKg/00fmk00<006mk
Kg/026mk0`000Vmk0`003Vmk1@005Vmk0`003Vmk1@001fmk00<006mkKg/03Fmk00D006mkKg]_N`00
00U_N`<000]_N`05001_NfmkKg/00004Kg/2000GKg/2000=Kg/000a_N`80011_N`03001_Nfmk00e_
N`03001_Nfmk011_N`8000E_N`03001_Nfmk00i_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_
Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_
Nfmk00I_N`H000Y_N`80009_N`05001_N`00Kg/0000;Kg/60007Kg/01@00Kg]_Nfmk00002Fmk00<0
06mkKg/00Vmk00@006mkKg/000U_N`D000Q_N`05001_NfmkKg/00009Kg/20004Kg/01000Kg]_N`00
3Vmk100000=_N`00Kg/04fmk00@006mkKg/000m_N`<000Q_N`03001_Nfmk00a_N`03001_Nfmk009_
N`03001_Nfmk00Y_N`@000Q_N`04001_Nfmk0002Kg/2000HKg/00`00Kg/0000=Kg/000a_N`80015_
N`03001_Nfmk00]_N`03001_Nfmk00m_N`8000M_N`03001_Nfmk00i_N`03001_Nfmk00A_N`03001_
Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`D000U_N`8000=_N`04001_Nfmk0002Kg/00`00Kg]_N`09Kg/50007
Kg/01@00Kg]_Nfmk000026mk00<006mkKg/00fmk00D006mkKg]_N`0000Q_N`H000M_N`05001_Nfmk
Kg/00006Kg/30006Kg/01000Kg]_N`003Vmk00<006mk00000fmk00<006mkKg/04Fmk00@006mkKg/0
00i_N`04001_Nfmk0008Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0>Kg/40004Kg/0
1000Kg/006mk0P006Vmk00@006mkKg/000a_N`0036mk0P004Vmk0P002fmk00<006mkKg/03Fmk0P00
2Fmk00<006mkKg/03Fmk00<006mkKg/01Fmk00<006mkKg/01fmk00<006mkKg/01fmk00<006mkKg/0
0Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mk0000
0P0000=_N`0000000Vmk0`0000=_N`00Kg/016mk00@006mkKg/0009_N`03001_Nfmk00Q_N`H000I_
N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00A_N`05001_NfmkKg/00009Kg/30002Kg/3
0005Kg/00`00Kg/00005Kg/20008Kg/01@00Kg]_Nfmk00003Fmk00@006mkKg/000A_N`80011_N`03
001_Nfmk009_N`03001_Nfmk00]_N`05001_NfmkKg/00007Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0BKg/8000LKg/01000Kg]_N`0036mk000<Kg/2000DKg/00`00Kg]_N`08Kg/00`00
Kg]_N`0;Kg/2000;Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05
Kg/01000Kg]_N`001Fmk1P001Vmk00@006mkKg/000=_N`03001_Nfmk00I_N`03001_Nfmk00A_N`03
001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk009_N`8000M_N`03001_Nfmk009_N`03001_Nfmk
00E_N`04001_Nfmk0005Kg/30002Kg/30002Kg/30009Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0:Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/20008Kg/00`00Kg]_N`0DKg/5000LKg/0
1000Kg]_N`0036mk000<Kg/2000EKg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/2000>Kg/00`00Kg]_
N`0;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00000fmk00<0
06mkKg/026mk00<006mkKg/00Vmk00<006mkKg/00fmk0P000fmk00<006mkKg/016mk1@001Fmk00D0
06mkKg]_N`0000A_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00A_
N`@000U_N`03001_Nfmk009_N`03001_Nfmk00E_N`05001_NfmkKg/00007Kg/7000<Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`08Kg/00`00Kg]_N`0DKg/7000JKg/01000Kg]_N`0036mk000<Kg/2000FKg/00`00Kg]_N`06Kg/0
0`00Kg]_N`07Kg/2000@Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`09Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`0:Kg/01000Kg]_N`000Vmk00<006mkKg/02Vmk00@006mkKg/000E_N`03001_Nfmk00=_N`03001_
Nfmk00A_N`D000E_N`03001_Nfmk009_N`03001_Nfmk009_N`H000U_N`03001_Nfmk009_N`03001_
Nfmk00=_N`D000Q_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00I_
N`D000a_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`03001_Nfmk00E_N`8000Y_
N`03001_Nfmk00A_N`03001_Nfmk00U_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00M_
N`03001_Nfmk00U_N`03001_Nfmk01=_N`H0009_N`<001M_N`04001_Nfmk000<Kg/000a_N`8001M_
N`8000I_N`03001_Nfmk00E_N`80019_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`03001_Nfmk00A_
N`03001_Nfmk00Y_N`04001_Nfmk0002Kg/00`00Kg]_N`0:Kg/01000Kg]_N`000fmk0P001Vmk00<0
06mkKg/016mk10001Fmk00<006mkKg/00fmk00<006mkKg/00Vmk1@002fmk00D006mkKg]_N`0000E_
N`D000M_N`<000E_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00I_N`D000a_N`03001_
Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_
Nfmk00E_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_
Nfmk00Y_N`03001_Nfmk019_N`03001_Nfmk00<000I_N`<001A_N`04001_Nfmk000<Kg/000a_N`80
01U_N`03001_Nfmk00=_N`03001_Nfmk00=_N`8001A_N`03001_Nfmk00Q_N`03001_Nfmk00a_N`03
001_Nfmk00=_N`03001_Nfmk00]_N`05001_N`00Kg/0000>Kg/00`00Kg/00002Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`04Kg/01000Kg]_N`001Fmk00<006mkKg/00fmk00<006mkKg/00Vmk1`002Vmk1000
0fmk4P001Fmk00D006mkKg]_N`0000I_N`03001_Nfmk00I_N`<00003Kg/006mk00U_N`03001_Nfmk
00E_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`8000I_N`03001_Nfmk00I_N`03
001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00A_N`8000e_N`03001_Nfmk
015_N`03001_Nfmk009_N`03001_Nfmk00Q_N`<0015_N`04001_Nfmk000<Kg/000a_N`8001Y_N`05
001_NfmkKg/00004Kg/2000FKg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0=Kg/3000?Kg/300000fmk001_N`07Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk00001Fmk00<0
06mkKg/00fmk00<006mkKg/00Vmk1@000Vmk20000Vmk1`000fmk0`001fmk1@001Fmk00D006mkKg]_
N`0000I_N`03001_Nfmk00E_N`03001_Nfmk00=_N`8000M_N`03001_Nfmk00I_N`03001_Nfmk00E_
N`03001_Nfmk00I_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00M_
N`03001_Nfmk00M_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0?Kg/20005Kg/0
0`00Kg]_N`0;Kg/3000>Kg/01000Kg]_N`0036mk000<Kg/2000KKg/500000fmk0000000IKg/00`00
Kg]_N`06Kg/00`00Kg]_N`0>Kg/01@00Kg]_Nfmk00003Vmk1@003Fmk1@002Fmk00<006mkKg/00fmk
00<006mkKg/00fmk00D006mkKg]_N`0000M_N`03001_Nfmk009_N`@000Y_N`L000M_N`03001_Nfmk
00E_N`L000A_N`<000Q_N`03001_Nfmk00A_N`03001_Nfmk00E_N`8000E_N`03001_Nfmk00M_N`03
001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00]_N`03001_N`00008000Y_N`03001_Nfmk00E_
N`03001_Nfmk00Q_N`05001_NfmkKg/00004Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0>Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0>Kg/3000:Kg/01@00Kg]_Nfmk000036mk000<Kg/2000LKg/5000KKg/00`00
Kg]_N`05Kg/00`00Kg]_N`0?Kg/01@00Kg]_Nfmk00003Vmk5`002Fmk00<006mkKg/00Vmk00<006mk
Kg/016mk00D006mkKg]_N`0000M_N`05001_NfmkKg/00004Kg/2000:Kg/50007Kg/00`00Kg]_N`06
Kg/30003Kg/80007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg/00002000:Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/50009Kg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/0
1000Kg]_N`000fmk00<006mkKg/03fmk00<006mkKg/03Fmk00<006mkKg/01Vmk00<006mkKg/04Fmk
0`001fmk00D006mkKg]_N`0000a_N`0036mk0P0076mk1@006fmk00<006mkKg/01Fmk00<006mkKg/0
46mk00@006mkKg/000]_N`P000e_N`D000U_N`03001_Nfmk009_N`03001_Nfmk00E_N`04001_Nfmk
0007Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/026mk1@001fmk00<006mkKg/016mk00<006mk0000
1fmk1@0026mk00<006mkKg/00Vmk00<006mkKg/02Fmk1@002Fmk00<006mkKg/00Vmk00<006mkKg/0
2Fmk00<006mkKg/02fmk1@002Fmk00<006mkKg/016mk00<006mkKg/02Vmk00<006mk00000fmk00<0
06mkKg/046mk00<006mkKg/02fmk0P002Fmk00<006mkKg/056mk0`000fmk0`000Vmk00<006mkKg/0
2Vmk000<Kg/2000LKg/8000HKg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/01000Kg]_N`0026mk0`00
16mk10003Vmk10002Fmk00D006mkKg]_N`0000Q_N`03001_N`0000Q_N`04001_Nfmk0008Kg/00`00
Kg]_N`06Kg/01000Kg]_N`000Vmk00<006mkKg/016mk00<006mkKg/00fmk00@006mkKg/000M_N`H0
00M_N`05001_NfmkKg/0000<Kg/50009Kg/01@00Kg]_Nfmk00002fmk0`001fmk2P002Vmk00<006mk
Kg/00fmk00<006mkKg/02fmk0P0000=_N`0000004fmk00<006mkKg/02Vmk00<006mkKg/02Fmk00<0
06mkKg/05fmk1`0000=_N`00Kg/02fmk000<Kg/2000JKg/2000016mk0000000016mk10005Fmk00<0
06mkKg/00Vmk00<006mkKg/04fmk0P001Fmk10001Vmk00<006mk00000Vmk00<006mkKg/036mk00@0
06mkKg/000M_N`05001_NfmkKg/00008Kg/40008Kg/01000Kg]_N`002Fmk00<006mkKg/016mk00D0
06mkKg]_N`0000=_N`03001_Nfmk00=_N`03001_Nfmk00=_N`05001_NfmkKg/00007Kg/30002Kg/2
0005Kg/01@00Kg]_Nfmk00002Fmk2P001fmk00@006mkKg/000]_N`/000I_N`<00003Kg/0000000Q_
N`03001_Nfmk009_N`03001_Nfmk00a_N`<001E_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`03001_
Nfmk01U_N`D00003Kg/006mk00]_N`0036mk0P0066mk0P001Fmk00<006mkKg/01Vmk10004Fmk00<0
06mkKg/00Vmk00<006mkKg/04fmk1`002Fmk00D006mkKg]_N`00009_N`03001_Nfmk00]_N`05001_
NfmkKg/00006Kg/01000Kg]_N`0026mk1@0026mk0`002fmk00<006mkKg/00fmk00<006mkKg/00Vmk
00@006mkKg]_N`8000=_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00A_N`04001_Nfmk
0004Kg/20004Kg/00`00Kg/00007Kg/30004Kg/30003Kg/40003Kg/4000:Kg/6000=Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/5000DKg/00`00Kg]_N`07Kg/2
000=Kg/00`00Kg]_N`0IKg/500000fmk001_N`0;Kg/000a_N`8001I_N`8000M_N`03001_Nfmk00Y_
N`@000e_N`05001_NfmkKg/0000DKg/6000<Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/02Fmk00<0
06mkKg/00fmk00<006mkKg/00fmk00@006mkKg/000Q_N`T000=_N`D000]_N`D000E_N`03001_Nfmk
00=_N`05001_NfmkKg/00003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/01000Kg]_N`001Vmk0P00
0Vmk0`0016mk0`001Vmk00<006mk000026mk1`000Vmk200000=_N`0000000`003Fmk00<006mkKg/0
0fmk0P001Fmk00D006mkKg]_N`0000a_N`X0019_N`03001_Nfmk00E_N`03001_Nfmk00e_N`03001_
Nfmk01Q_N`D0009_N`03001_Nfmk00Y_N`0036mk0P0056mk0P002Fmk00<006mkKg/03Vmk10002Fmk
00@006mkKg/000i_N`L00003Kg/0000000<000]_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_N`0000Q_N`H000A_N`h000I_N`D000A_
N`03001_Nfmk00A_N`04001_Nfmk0002Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
000026mk2@0026mk00@006mkKg/000Y_N`L000Y_N`@000a_N`03001_Nfmk00I_N`8000A_N`04001_
Nfmk0009Kg/30002Kg/50003Kg/3000?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0G
Kg/00`00Kg]_N`02Kg/01000Kg]_N`0036mk000<Kg/2000BKg/2000;Kg/00`00Kg]_N`0BKg/40005
Kg/30009Kg/60008Kg/5000:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`05Kg/01000Kg]_Nfmk0P001Vmk0`000Vmk0`0000=_N`0000001Fmk1@001Vmk2`001Fmk00<0
06mkKg/016mk1@001Vmk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/01Vmk1@002fmk00D0
06mkKg]_N`0000U_N`D000a_N`05001_NfmkKg/0000;Kg/00`00Kg]_N`08Kg/01`00Kg]_Nfmk001_
N`0000I_N`@000I_N`<000M_N`<000a_N`03001_Nfmk009_N`80015_N`03001_Nfmk01I_N`03001_
Nfmk00=_N`04001_Nfmk000<Kg/000a_N`80011_N`8000e_N`03001_Nfmk01I_N`T00003Kg/00000
00D000a_N`800004Kg/00000000;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`06Kg/40003Kg/40005Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/3000=Kg/50005Kg/0
0`00Kg]_N`05Kg/50005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/5000:Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`07Kg/5000<Kg/01@00Kg]_Nfmk00002fmk00<006mkKg/02Fmk0P00
00A_N`00000000=_N`<000U_N`05001_NfmkKg/00009Kg/40008Kg/01@00Kg]_Nfmk00004fmk00<0
06mkKg/056mk0P001Vmk00@006mkKg/000a_N`0036mk0P003Vmk0P0046mk00<006mkKg/06Fmk1P00
4Vmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/0
1Vmk00<006mkKg/01Vmk1`002Fmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/02Vmk00<0
06mk00000P0000=_N`00000016mk00<006mkKg/016mk1@001Fmk00D006mkKg]_N`0000I_N`03001_
Nfmk00A_N`800003Kg/00000008000U_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_N`0000=_
N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk00]_N`L000a_N`05001_
NfmkKg/0000=Kg/30004Kg/300000fmk001_N`0CKg/00`00Kg]_N`0CKg/00`00Kg]_N`06Kg/01000
Kg]_N`0036mk000<Kg/2000<Kg/2000BKg/00`00Kg]_N`0IKg/5000BKg/00`00Kg]_N`04Kg/00`00
Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/5000:
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/20002Kg/00`00Kg]_N`03Kg/01@00
Kg]_Nfmk00001Vmk1@001Fmk00@006mkKg/000M_N`<0009_N`80009_N`03001_Nfmk009_N`03001_
Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_N`0000A_N`03001_Nfmk00Q_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00]_N`D000e_N`03001_Nfmk00=_N`03001_Nfmk00e_
N`P001I_N`03001_Nfmk015_N`03001_Nfmk00M_N`04001_Nfmk000<Kg/000]_N`03001_N`0000Y_
N`8001A_N`03001_Nfmk01Q_N`03001_N`000080019_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03
001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00I_N`D000Y_N`03001_Nfmk
00M_N`8000=_N`03001_Nfmk00M_N`05001_NfmkKg/00007Kg/2000016mk000000000Vmk0P0000E_
N`00000006mk008000A_N`03001_N`0000I_N`H000A_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03
001_Nfmk00A_N`03001_Nfmk00E_N`04001_Nfmk0005Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0;Kg/5000=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/5000FKg/0
0`00Kg]_N`0?Kg/2000:Kg/01000Kg]_N`0036mk000;Kg/00`00Kg/00008Kg/2000FKg/00`00Kg]_
N`0FKg/20004Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/200001Fmk00000000Kg/00P001fmk00<0
06mkKg/02Vmk00D006mkKg]_N`0000I_N`8000A_N`03001_Nfmk00M_N`H000E_N`04001_NfmkKg/2
000016mk000000001fmk1@0016mk00<006mkKg/01Fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<0
06mkKg/016mk00D006mkKg]_N`0000I_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk00E_
N`03001_Nfmk00U_N`800004Kg/00000000>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/5000FKg/0
0`00Kg]_N`0>Kg/00`00Kg]_N`0;Kg/00`00Kg/0000<Kg/000]_N`03001_N`0000I_N`8001Q_N`03
001_Nfmk01E_N`03001_Nfmk00A_N`03001_Nfmk00i_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03
001_Nfmk00Q_N`03001_Nfmk00M_N`05001_NfmkKg/00006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0016mk0P001Vmk00<006mkKg/01fmk1@00
1Vmk00<006mkKg/00fmk400016mk00<006mkKg/01Vmk00@006mkKg/000Q_N`03001_Nfmk00=_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03
001_Nfmk00Q_N`05001_NfmkKg/00002Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?
Kg/400000fmk0000000DKg/00`00Kg]_N`0=Kg/00`00Kg]_N`0<Kg/00`00Kg/0000<Kg/000]_N`03
001_N`0000A_N`8001Y_N`03001_Nfmk01=_N`8000M_N`03001_Nfmk00e_N`03001_Nfmk00U_N`03
001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00Q_N`04001_Nfmk0004Kg/20005Kg/00`00Kg]_
N`03Kg/2000016mk000000003fmk1@0000=_N`00Kg/01Vmk00<006mkKg/01Fmk20001Vmk00<006mk
Kg/00fmk1@001fmk0`0016mk00<006mkKg/01fmk100026mk00<006mkKg/00Vmk00<006mkKg/00Vmk
00<006mkKg/01fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/01Vmk
0P0016mk00@006mkKg/000a_N`03001_Nfmk00E_N`03001_Nfmk00i_N`05001_N`00Kg/00003Kg/2
000BKg/00`00Kg]_N`0;Kg/2000?Kg/00`00Kg/0000<Kg/000]_N`@00003Kg/0000001e_N`03001_
Nfmk015_N`03001_Nfmk00M_N`03001_Nfmk00]_N`8000a_N`03001_Nfmk00=_N`03001_Nfmk00U_
N`03001_Nfmk00U_N`@00003Kg/0000000I_N`03001_Nfmk00I_N`D000m_N`D000I_N`<000A_N`<0
00A_N`@000I_N`03001_Nfmk00=_N`D000M_N`03001_N`0000A_N`03001_Nfmk00I_N`D000U_N`04
001_Nfmk0005Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`04Kg/20006Kg/01@00Kg]_Nfmk00002Vmk00<006mkKg/01fmk00<006mkKg/036mk00H0
06mkKg/006mk0005Kg/2000@Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg/0000<Kg/000]_
N`D001m_N`03001_Nfmk00m_N`8000]_N`03001_Nfmk00U_N`03001_Nfmk00e_N`05001_NfmkKg/0
000<Kg/00`00Kg]_N`09Kg/50008Kg/00`00Kg]_N`06Kg/K0003Kg/80008Kg/01000Kg]_N`001Fmk
00<006mkKg/016mk0`001fmk00@006mkKg/000=_N`03001_Nfmk00M_N`P000I_N`04001_Nfmk0005
Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00002fmk00D006mkKg]_N`0000E_N`8000Q_N`05001_Nfmk
Kg/0000:Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/01000Kg]_N`000fmk00<006mkKg/016mk00<0
06mkKg/03Fmk00<006mkKg/02Fmk00<006mkKg/046mk00<006mk000036mk000;Kg/5000OKg/00`00
Kg]_N`0>Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0>Kg/01@00Kg]_Nfmk000036mk
00<006mkKg/02Fmk1@0026mk00<006mkKg/01Vmk1@003fmk1@000Vmk20002fmk00D006mkKg]_N`00
00E_N`03001_Nfmk009_N`04001_Nfmk0007Kg/01000Kg]_N`000fmk00<006mkKg/01Fmk1`000fmk
0P000fmk10001Vmk00<006mkKg/02Vmk0`003Fmk00@006mkKg/000A_N`03001_Nfmk00M_N`03001_
Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00U_N`05001_NfmkKg/00003Kg/0
0`00Kg]_N`05Kg/2000=Kg/00`00Kg]_N`07Kg/2000CKg/00`00Kg/0000<Kg/000]_N`P001a_N`03
001_Nfmk00a_N`8000i_N`03001_Nfmk00M_N`03001_Nfmk00m_N`04001_Nfmk000>Kg/00`00Kg]_
N`06Kg/70008Kg/00`00Kg]_N`06Kg/4000?Kg/00`00Kg/000020006Kg/70009Kg/00`00Kg]_N`02
Kg/20003Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00fmk00D006mkKg]_N`00009_N`03001_Nfmk
00A_N`8000=_N`<000I_N`L000I_N`03001_Nfmk00U_N`D000e_N`@00003Kg/0000000Y_N`03001_
Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03001_Nfmk00M_N`8000A_N`03001_Nfmk009_
N`03001_Nfmk00I_N`8000]_N`03001_Nfmk00I_N`03001_Nfmk01A_N`8000a_N`002fmk100016mk
0`006Fmk00<006mkKg/02fmk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/046mk0`003Vmk
0`000fmk10000fmk100026mk00<006mkKg/01Fmk00D006mkKg]_N`0000e_N`80009_N`04001_Nfmk
0006Kg/30003Kg/20007Kg/00`00Kg]_N`04Kg/01000Kg]_N`000fmk00<006mkKg/00Vmk00<006mk
Kg/00fmk00D006mkKg]_N`00009_N`04001_NfmkKg/30005Kg/00`00Kg]_N`08Kg/50006Kg/00`00
Kg]_N`09Kg/<0006Kg/5000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/20009Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0EKg/00`00Kg/0000;Kg/000]_N`03001_N`0000Q_N`@001I_N`03001_Nfmk00Q_
N`80019_N`03001_Nfmk00A_N`03001_Nfmk011_N`D000a_N`L000M_N`04001_Nfmk0008Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/20003Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04
Kg/00`00Kg/00004Kg/30003Kg/30006Kg/00`00Kg/00002Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03
Kg/01000Kg]_Nfmk0`000Vmk0P001fmk00<006mkKg/01fmk1`001Fmk00<006mkKg/02Vmk1@001fmk
2`0036mk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/02fmk00<006mkKg/016mk00<006mk
Kg/016mk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/01Vmk00<006mkKg/00fmk0P0066mk
00<006mk00002fmk000;Kg/00`00Kg/0000<Kg/4000BKg/00`00Kg]_N`07Kg/00`00Kg]_N`0BKg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/G0008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`04Kg/01000Kg]_N`001Vmk1`001Vmk10001fmk00D006mkKg]_N`0000=_N`H000Q_N`03001_Nfmk
00E_N`<000=_N`@000E_N`03001_Nfmk00Q_N`800003Kg/00000008000e_N`D000a_N`03001_Nfmk
00E_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk
00A_N`03001_Nfmk00Y_N`8000I_N`03001_Nfmk009_N`03001_Nfmk01Q_N`03001_N`0000]_N`00
2fmk0P004Fmk0`003fmk00<006mkKg/01Fmk0P005Fmk00@006mkKg]_N`8000a_N`L00003Kg/00000
00<000a_N`D000Q_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00A_
N`03001_Nfmk00E_N`8000I_N`03001_Nfmk00=_N`03001_Nfmk00=_N`05001_NfmkKg/00007Kg/8
0003Kg/50006Kg/01@00Kg]_Nfmk00000fmk1@002Fmk00<006mkKg/00fmk0P001Fmk00<006mkKg/0
0Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk0P001Fmk00<006mk00003Fmk10002fmk00<006mkKg/0
1Vmk00<006mkKg/00Vmk00<006mkKg/03Fmk00D006mkKg]_N`0000Q_N`03001_Nfmk00A_N`03001_
Nfmk00a_N`8000A_N`05001_NfmkKg/0000KKg/00`00Kg/0000;Kg/000]_N`8001A_N`@000]_N`03
001_Nfmk00A_N`03001_Nfmk01E_N`@000Q_N`H000U_N`D000a_N`<000Q_N`03001_Nfmk00E_N`03
001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03
001_Nfmk00E_N`05001_NfmkKg/00004Kg/00`00Kg]_N`05Kg/50003Kg/80007Kg/00`00Kg/00004
Kg/70004Kg/30003Kg/30007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/20006
Kg/01000Kg]_N`003Fmk00D006mkKg]_N`0000Y_N`03001_Nfmk00M_N`05001_NfmkKg/0000?Kg/4
0008Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0>Kg/200000fmk00000003000LKg/00`00Kg/0000;Kg/0
00]_N`8001Q_N`<000Q_N`03001_Nfmk009_N`8001M_N`D00003Kg/0000000D000m_N`03001_Nfmk
009_N`03001_Nfmk00]_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00=_N`05001_Nfmk
Kg/00009Kg/300000fmk00000006Kg/30008Kg/01000Kg]_N`001Fmk00<006mkKg/016mk10001fmk
200016mk0`000Vmk0P0000A_N`00000000=_N`X000U_N`03001_Nfmk00A_N`05001_NfmkKg/00004
Kg/20008Kg/01@00Kg]_Nfmk000036mk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mkKg/01fmk
00@006mkKg/000m_N`D000Q_N`03001_Nfmk00I_N`03001_Nfmk00m_N`D001i_N`8000]_N`002fmk
0P006fmk10001Fmk00@006mkKg/001A_N`/001I_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_
Nfmk00E_N`03001_Nfmk00M_N`05001_NfmkKg/00003Kg/00`00Kg]_N`07Kg/50007Kg/50007Kg/0
1000Kg]_N`001Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk0`0016mk2@001Fmk
00<006mkKg/016mk1@002fmk00<006mkKg/01Fmk10000Vmk0P002Vmk00<006mkKg/00Vmk00<006mk
Kg/026mk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/026mk0`003Fmk1`0026mk00<006mk
Kg/01Vmk00<006mkKg/03fmk1@007Vmk0P002fmk000;Kg/2000OKg/80005Kg/@0005Kg/5000FKg/0
0`00Kg]_N`05Kg/2000:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/01000Kg]_N`000Vmk00<006mk
Kg/026mk4@0026mk00<006mk00001fmk10001Vmk00<006mkKg/016mk00@006mkKg/000I_N`D000I_
N`03001_Nfmk00A_N`D000Y_N`03001_Nfmk00I_N`H000a_N`03001_Nfmk009_N`03001_Nfmk00Q_
N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00M_N`D0009_N`X0009_N`D000M_N`03001_
Nfmk00Q_N`03001_Nfmk00i_N`X001U_N`8000]_N`002fmk0P008Vmk2P005Fmk100000=_N`000000
56mk00<006mkKg/01fmk00<006mkKg/01fmk00<006mkKg/016mk00<006mkKg/02Vmk00<006mk0000
0Vmk00<006mkKg/01Fmk20001fmk2@0016mk0`001Vmk1@001Vmk00<006mkKg/00fmk00<006mkKg/0
0Vmk00<006mkKg/00fmk1@001fmk00<006mkKg/016mk10002Fmk00<006mkKg/01fmk1@003Fmk00<0
06mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/026mk1`00
3Fmk0`0026mk00<006mkKg/026mk00<006mkKg/03fmk10001Fmk1@0056mk0P002fmk000;Kg/2000Q
Kg/6000IKg/01000Kg]_N`0016mk0P004Vmk00<006mkKg/026mk00<006mkKg/01fmk00<006mkKg/0
0fmk00<006mkKg/02Vmk1@0016mk100016mk0`0026mk10001Fmk20000fmk1`001fmk00<006mkKg/0
0Vmk00<006mkKg/00Vmk00<006mkKg/00fmk100000=_N`00Kg/01Fmk00<006mkKg/00fmk00<006mk
Kg/00Vmk00<006mkKg/01Vmk00<006mkKg/01Vmk1`0036mk00<006mkKg/00fmk00<006mkKg/01Vmk
00<006mkKg/01fmk00<006mkKg/00fmk00<006mkKg/01fmk1P003Vmk00@006mkKg/000Q_N`03001_
Nfmk00Q_N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk00M_N`@0011_N`8000]_N`002fmk
0P007fmk0P0000=_N`0000000`0066mk00D006mkKg]_N`0000I_N`8000m_N`03001_Nfmk00Y_N`80
00M_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`T000Q_N`03001_Nfmk00I_N`800004Kg/006mk0008
Kg/80002Kg/70006Kg/01000Kg]_N`001Vmk00D006mkKg]_N`00009_N`80009_N`8000A_N`03001_
Nfmk009_N`03001_Nfmk00A_N`8000E_N`03001_Nfmk00A_N`<0009_N`<0009_N`<000U_N`03001_
Nfmk00A_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00E_N`80009_
N`<000i_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk00e_N`03001_
Nfmk009_N`03001_Nfmk00]_N`D000]_N`8000]_N`002fmk0P0076mk0`0016mk0`0066mk00<006mk
Kg/00Vmk00<006mkKg/01Vmk0P003Fmk00<006mkKg/036mk00<006mkKg/016mk00<006mkKg/00Vmk
00<006mkKg/02fmk1@0036mk00<006mkKg/01Fmk00D006mkKg]_N`00009_N`03001_Nfmk00E_N`D0
00I_N`<000=_N`@000=_N`<000M_N`@0009_N`03001_N`0000=_N`03001_Nfmk009_N`05001_Nfmk
Kg/00008Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/20004Kg/01000Kg]_N`001Fmk0P001Vmk00<0
06mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/02Vmk00D006mkKg]_N`0000A_N`<000E_N`03001_
Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk00a_N`03001_
Nfmk00A_N`03001_Nfmk00m_N`D000I_N`<000Y_N`002fmk00<006mkKg/06Fmk0P002Fmk00<006mk
Kg/05Fmk00<006mkKg/00fmk00<006mkKg/026mk0P002fmk00<006mkKg/03Fmk00<006mkKg/00fmk
00<006mkKg/00Vmk00<006mkKg/02Fmk1`0036mk00<006mkKg/016mk00<006mkKg/00Vmk00@006mk
Kg/000Q_N`@000I_N`04001_Nfmk0006Kg/70005Kg/50002Kg/00`00Kg/00004Kg/20002Kg/01000
Kg]_N`002Vmk10000Vmk0`001Vmk00@006mkKg/000M_N`<00004Kg/000000008Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`0;Kg/40002Kg/20008Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0CKg/:0009Kg/000]_
N`03001_Nfmk01M_N`8000a_N`03001_Nfmk01=_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`8000Q_
N`03001_Nfmk00m_N`8000A_N`04001_Nfmk000:Kg/20003Kg/300000fmk0000000:Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`03Kg/01000Kg]_N`001fmk00<006mkKg/00Vmk00<006mkKg/00fmk00D006mk
Kg]_N`0000M_N`l0009_N`04001_Nfmk0005Kg/00`00Kg/00002000;Kg/60008Kg/01@00Kg]_Nfmk
00002Vmk1@0026mk00<006mkKg/00Vmk00<006mkKg/02fmk1P002Vmk00<006mkKg/02fmk00<006mk
Kg/01Fmk00<006mkKg/00Vmk00<006mkKg/036mk00<006mkKg/02Vmk00<006mkKg/01fmk00<006mk
Kg/05fmk1@002Fmk000:Kg/2000GKg/2000>Kg/00`00Kg]_N`0BKg/00`00Kg]_N`05Kg/00`00Kg]_
N`0<Kg/20006Kg/00`00Kg]_N`0AKg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01Fmk0`001Fmk00<0
06mkKg/00fmk0P0026mk00<006mkKg/00Vmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/0
0fmk00<006mkKg/016mk00<006mkKg/00Vmk00D006mkKg]_N`0000M_N`D000E_N`D00003Kg/006mk
009_N`03001_Nfmk00A_N`D000E_N`X000U_N`03001_Nfmk009_N`03001_Nfmk00M_N`D000U_N`04
001_Nfmk000>Kg/5000<Kg/00`00Kg]_N`09Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`09Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0FKg/50009Kg/000Y_N`8001A_N`<0
011_N`03001_Nfmk015_N`03001_Nfmk00I_N`03001_Nfmk00i_N`80009_N`<001A_N`06001_Nfmk
001_N`001Fmk0`001fmk00<006mkKg/01Vmk00<006mkKg/01Fmk00D006mkKg]_N`0000I_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_
Nfmk00A_N`@000M_N`<0009_N`03001_Nfmk009_N`03001_Nfmk00=_N`X000E_N`D000Q_N`03001_
Nfmk00=_N`03001_Nfmk00M_N`P000I_N`04001_Nfmk000:Kg/9000<Kg/00`00Kg]_N`09Kg/00`00
Kg]_N`07Kg/01@00Kg]_Nfmk00003fmk00<006mkKg/026mk00<006mkKg/02Vmk00<006mkKg/05Vmk
0`002Vmk000:Kg/2000BKg/2000DKg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0AKg/6
000DKg/50003Kg/2000:Kg/00`00Kg]_N`07Kg/20004Kg/00`00Kg]_N`020007Kg/00`00Kg]_N`03
Kg/01@00Kg]_Nfmk000026mk00D006mkKg]_N`0000E_N`03001_Nfmk009_N`05001_NfmkKg/00006
Kg/01`00Kg]_Nfmk001_N`0000A_N`03001_Nfmk00=_N`D000]_N`@000Q_N`03001_Nfmk00=_N`03
001_Nfmk00M_N`D000=_N`@000=_N`<000E_N`D000E_N`@000a_N`03001_Nfmk00Q_N`03001_Nfmk
00Q_N`05001_NfmkKg/0000?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0EKg/00`00
Kg]_N`0:Kg/000Y_N`80011_N`8001I_N`03001_Nfmk00i_N`03001_Nfmk00M_N`03001_Nfmk019_
N`l000]_N`L000a_N`03001_Nfmk00U_N`800003Kg/00000008000U_N`03001_Nfmk00=_N`@000U_
N`05001_NfmkKg/00006Kg/40005Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg/00005Kg/0
0`00Kg]_N`02Kg/5000:Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/016mk00<006mkKg/01Vmk00<0
06mkKg/00Vmk00<006mkKg/01Fmk2`002Vmk00D006mkKg]_N`0000]_N`03001_Nfmk00M_N`03001_
Nfmk00U_N`04001_Nfmk000@Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0EKg/00`00
Kg]_N`0:Kg/000Y_N`8000e_N`<001Q_N`03001_Nfmk00e_N`03001_Nfmk00Q_N`03001_Nfmk015_
N`H000Y_Na0000e_N`03001_Nfmk00a_N`D000Q_N`03001_Nfmk00=_N`D000Y_N`03001_N`0000I_
N`D000E_N`03001_Nfmk009_N`03001_Nfmk00=_N`<000A_N`05001_NfmkKg/00002Kg/00`00Kg/0
000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`07Kg/5000>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0;Kg/00`00Kg/0000AKg/00`00Kg]_N`05Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0DKg/0
0`00Kg]_N`0:Kg/000Y_N`8000]_N`8001]_N`03001_Nfmk00a_N`03001_Nfmk00U_N`03001_Nfmk
00i_N`<0009_N`@001E_N`D000e_N`03001_Nfmk00a_N`D000Q_N`03001_Nfmk00=_N`H000Y_N`<0
00E_N`D000I_N`04001_Nfmk0005Kg/50003Kg/3000016mk001_N`000fmk00<006mkKg/01Vmk00<0
06mkKg/016mk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/016mk00<0
06mkKg/01fmk1@003Vmk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/0
2fmk0`004Fmk00<006mkKg/01Fmk00<006mkKg/03fmk00<006mkKg/04fmk00<006mkKg/02Vmk000:
Kg/20009Kg/2000NKg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/20005Kg/01@00
Kg]_Nfmk00004Vmk0P0000E_N`00000006mk008000Y_N`03001_Nfmk00]_N`L000Q_N`03001_Nfmk
00=_N`D00003Kg/0000000H00003Kg/0000000h000A_N`<000I_N`H00003Kg/0000000<0009_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk00E_N`05001_NfmkKg/00008Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/5000<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`0;Kg/5000@Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0B
Kg/00`00Kg]_N`0:Kg/000Y_N`03001_Nfmk00I_N`80021_N`03001_Nfmk00U_N`03001_Nfmk00]_
N`03001_Nfmk00U_N`<000I_N`03001_Nfmk00=_N`03001_Nfmk00i_N`05001_NfmkKg/00005Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`08Kg/30003Kg/300000fmk00000006Kg/01000Kg]_Nfmk0P0000A_
N`00000000Y_N`H000E_N`<000=_Na800003Kg/0000000@0009_N`03001_Nfmk00=_N`03001_Nfmk
00=_N`03001_Nfmk00I_N`@000U_N`D000U_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk
00U_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00a_N`D0015_N`03
001_Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk015_N`03001_Nfmk00Y_N`002Vmk00<006mkKg/0
0fmk0`008Vmk00<006mkKg/026mk00<006mkKg/036mk00<006mkKg/01Vmk0`002Fmk00<006mkKg/0
16mk0P0036mk0P0016mk00<006mkKg/016mk0P001fmk00<006mkKg/01Vmk0P001Fmk00D006mkKg]_
N`00009_N`800004Kg/000000002Kg/20006Kg/00`00Kg]_N`08Kg/50005Kg/00`00Kg/00006Kg/5
0006Kg/30003Kg/50002Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/50007Kg/5
000:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/9000>Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0DKg/0
0`00Kg]_N`0?Kg/00`00Kg]_N`0;Kg/000U_N`<0009_N`8002I_N`03001_Nfmk00I_N`03001_Nfmk
00e_N`03001_Nfmk00A_N`8000a_N`03001_Nfmk00I_N`03001_Nfmk00M_N`8000I_N`03001_Nfmk
00I_N`03001_Nfmk00=_N`03001_Nfmk00A_N`<000I_N`03001_Nfmk009_N`03001_Nfmk009_N`H0
00Q_N`03001_Nfmk00Q_N`@000E_N`04001_Nfmk0006Kg/50006Kg/00`00Kg/00004Kg/40002Kg/0
0`00Kg]_N`05Kg/01000Kg]_N`002Fmk4@002Vmk00<006mkKg/01Fmk00<006mkKg/01Vmk00<006mk
Kg/01fmk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/02Fmk0`000Vmk
0`0016mk10002fmk00@006mkKg/001M_N`03001_Nfmk00m_N`03001_Nfmk00]_N`0026mk1P00:6mk
00<006mkKg/01Fmk00<006mkKg/03Fmk0`000Vmk0`003Fmk00<006mkKg/026mk00<006mkKg/01Fmk
00<006mkKg/01Fmk00<006mkKg/026mk0P0000A_N`00000000=_N`<000U_N`03001_Nfmk00=_N`04
001_NfmkKg/5000:Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk00001Fmk00@006mkKg/000I_N`@000I_
N`04001_Nfmk0005Kg/00`00Kg/00002Kg/00`00Kg]_N`05Kg/40005Kg/90007Kg/5000;Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`07Kg/20006Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`08Kg/20005Kg/00`00Kg/00008Kg/30008Kg/01000Kg]_N`0066mk00<006mkKg/0
3Vmk00<006mkKg/02fmk0008Kg/7000WKg/00`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/6000@Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`02Kg/20008Kg/00`00Kg]_N`0:Kg/7000;Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`080008Kg/00`00Kg]_N`03Kg/20004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/01000Kg]_N`001Fmk00<006mk00000Vmk00<006mk
Kg/01Fmk2@001Fmk0`0026mk100000=_N`0000002Fmk00<006mkKg/00fmk00<006mkKg/02Vmk00<0
06mkKg/00fmk00<006mkKg/02fmk00<006mkKg/00Vmk00D006mkKg]_N`0000M_N`<000I_N`04001_
Nfmk000;Kg/40004Kg/3000JKg/00`00Kg]_N`0=Kg/00`00Kg]_N`0;Kg/000Q_N`D0009_N`T001m_
N`03001_Nfmk009_N`03001_Nfmk00i_N`D0011_N`03001_Nfmk00]_N`@000Y_N`03001_Nfmk00Y_
N`D000a_N`03001_Nfmk00I_N`04001_NfmkKg/30004Kg/30005Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00001Vmk00<006mkKg/00Vmk00@0
06mkKg/000A_N`07001_NfmkKg/006mk00001fmk1@002Vmk00<006mkKg/01Vmk00@006mkKg/000A_
N`8000M_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk009_N`03001_Nfmk00a_N`05001_
NfmkKg/00002Kg/00`00Kg]_N`03Kg/30009Kg/01000Kg]_N`003fmk20006Vmk00<006mkKg/036mk
00<006mkKg/02fmk0009Kg/4000;Kg/9000FKg/01@00Kg]_Nfmk00002fmk2`0046mk00<006mkKg/0
2Vmk1@002Vmk00<006mkKg/02Vmk1P002fmk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/0
1Fmk0`000fmk100026mk00@006mkKg/000E_N`@000Q_N`04001_Nfmk0003Kg/00`00Kg]_N`02Kg/0
1000Kg]_Nfmk0P001Vmk1`002Vmk00<006mkKg/01Vmk00@006mkKg/000I_N`03001_Nfmk00E_N`05
001_NfmkKg/0000?Kg/5000?Kg/01P00Kg]_N`00Kg/000A_N`8000a_N`05001_NfmkKg/0000AKg/5
000KKg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/000]_N`03001_N`0001=_N`X000a_N`@000I_N`H0
00M_N`@0011_N`03001_Nfmk00Y_N`D000U_N`03001_Nfmk00Y_N`03001_N`000080009_N`8000Q_
N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00Q_N`L000Q_N`04001_Nfmk0004Kg/50008
Kg/40004Kg/01000Kg]_N`0016mk0`000fmk0P000fmk10002Vmk00<006mkKg/01Fmk00D006mkKg]_
N`0000M_N`8000E_N`04001_Nfmk000@Kg/5000@Kg/40002Kg/3000=Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0?Kg/7000JKg/00`00Kg]_N`09Kg/00`00Kg]_N`0<Kg/000]_N`03001_N`0001e_N`T0009_
N`/000a_N`05001_NfmkKg/0000?Kg/00`00Kg]_N`0:Kg/60009Kg/00`00Kg]_N`08Kg/20002Kg/0
1000Kg]_N`000fmk0`000Vmk0`0036mk00@006mkKg/000e_N`D000Q_N`03001_N`0000E_N`T000A_
N`D000=_N`04001_Nfmk0003Kg/70005Kg/01@00Kg]_Nfmk00002Fmk00<006mkKg/016mk00<006mk
Kg/00Vmk00<006mkKg/01fmk0P000fmk00@006mkKg/0011_N`d000Q_N`H0011_N`03001_Nfmk009_
N`03001_Nfmk011_N`<000=_N`<001Q_N`03001_Nfmk00Q_N`03001_Nfmk00a_N`002fmk00@006mk
Kg/002E_N`L0019_N`03001_Nfmk009_N`03001_Nfmk00a_N`03001_Nfmk00U_N`03001_Nfmk00<0
0003Kg/006mk00M_N`03001_Nfmk00M_N`03001_Nfmk009_N`05001_NfmkKg/00005Kg/6000<Kg/0
0`00Kg/0000;Kg/:0005Kg/30003Kg/70004Kg/90003Kg/01000Kg]_N`000fmk1@001fmk00<006mk
Kg/00Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/02Fmk0P0000A_
N`00000000Y_N``000Q_N`d0011_N`03001_Nfmk00=_N`03001_Nfmk00m_N`05001_NfmkKg/00005
Kg/4000DKg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/000]_N`05001_NfmkKg/0000VKg/5000AKg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`08Kg/20003Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`05Kg/20004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/5000<Kg/00`00Kg/0
0008Kg/30003Kg/30004Kg/;0003Kg/30009Kg/50003Kg/00`00Kg/00004Kg/50007Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/500000fmk
000000060008Kg/4000@Kg/5000@Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/01@00Kg]_Nfmk0000
2Fmk0`004Vmk00<006mkKg/01fmk00<006mkKg/036mk000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0R
Kg/5000BKg/00`00Kg]_N`05Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`03Kg/;0007Kg/30003Kg/40006Kg/00`00Kg/00008Kg/50005Kg/01000Kg]_N`0026mk1000
00M_N`00Kg]_N`00Kg/00003Kg/00`00Kg/000030006Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0:Kg/6000AKg/00`00Kg/0000AKg/4000?Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/3000@Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0=Kg/000]_N`03001_Nfmk00=_N`03001_Nfmk021_N`03001_Nfmk009_N`03
001_Nfmk00m_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00E_N`8000I_N`03001_Nfmk
00=_N`03001_Nfmk00=_N`03001_Nfmk00=_N`8000M_N`03001_Nfmk00A_N`03001_Nfmk00=_N`<0
00M_N`d000U_N`05001_NfmkKg/00007Kg/50005Kg/01000Kg]_N`001fmk00@006mkKg/000=_N`03
001_N`0000800003Kg/0000000I_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk009_N`05
001_NfmkKg/00009Kg/00`00Kg]_N`08Kg/7000BKg/00`00Kg/0000@Kg/00`00Kg/00002Kg/00`00
Kg]_N`0<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/3000>
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/000a_N`03001_Nfmk00=_N`03001_Nfmk01i_N`03001_
Nfmk00=_N`03001_Nfmk00m_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00E_N`03001_
Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_
Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00a_N`D000]_N`05001_NfmkKg/00008Kg/30006Kg/0
1@00Kg]_Nfmk00001Fmk00D006mkKg]_N`0000A_N`D000U_N`03001_Nfmk009_N`03001_Nfmk00M_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`08Kg/00`00Kg]_N`05Kg/30003Kg/300000fmk0000000?
Kg/01@00Kg]_Nfmk00003Vmk00@006mkKg/000=_N`03001_Nfmk00]_N`03001_Nfmk00I_N`03001_
Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00i_N`<000a_N`03001_Nfmk00=_N`03001_Nfmk00e_
N`0036mk00<006mkKg/00fmk00<006mkKg/07Fmk00<006mkKg/01Fmk00<006mkKg/03Fmk00<006mk
Kg/02Fmk00<006mkKg/01Vmk00<006mkKg/016mk00<006mkKg/01fmk00<006mkKg/01Fmk00D006mk
Kg]_N`00009_N`8000U_N`03001_Nfmk00I_N`03001_Nfmk00=_N`03001_Nfmk00a_N`H000Y_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_N`0000I_N`05001_NfmkKg/00004Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`02Kg/5000:Kg/01@00Kg]_Nfmk00002Vmk00@006mkKg/0009_N`03001_Nfmk00M_
N`<000=_N`<000Q_N`04001_NfmkKg/2000=Kg/01@00Kg]_Nfmk00003Vmk00@006mkKg/000A_N`03
001_Nfmk00U_N`03001_Nfmk00M_N`03001_Nfmk00Y_N`03001_Nfmk00I_N`03001_Nfmk015_N`<0
00Y_N`03001_Nfmk009_N`03001_Nfmk00e_N`0036mk00<006mkKg/016mk00<006mkKg/06Vmk0P00
26mk00<006mkKg/03Fmk00<006mkKg/02Vmk00<006mkKg/016mk00<006mkKg/00fmk0P002Vmk00<0
06mkKg/01Vmk100000=_N`00Kg/02Vmk00<006mkKg/01Vmk00<006mkKg/00fmk00<006mkKg/02Vmk
0P0000A_N`000000009_N`8000M_N`03001_Nfmk00=_N`03001_Nfmk00A_N`05001_NfmkKg/00005
Kg/00`00Kg]_N`02Kg/40005Kg/00`00Kg]_N`02Kg/:0006Kg/4000;Kg/50009Kg/7000;Kg/00`00
Kg]_N`03Kg/2000;Kg/01@00Kg]_Nfmk00003Fmk00D006mkKg]_N`0000E_N`03001_Nfmk00Q_N`03
001_Nfmk00M_N`03001_Nfmk00Y_N`03001_Nfmk00M_N`03001_Nfmk01=_N`<000Q_N`05001_Nfmk
Kg/0000?Kg/000a_N`03001_Nfmk00E_N`03001_Nfmk01Q_N`03001_Nfmk00Q_N`03001_Nfmk00a_
N`03001_Nfmk00a_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_Nfmk00Y_N`03001_Nfmk00I_
N`D000a_N`03001_Nfmk00M_N`05001_NfmkKg/0000;Kg/20003Kg/00`00Kg]_N`04Kg/30004Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00Vmk1@001Fmk00<0
06mkKg/00Vmk1@001Fmk2`002Vmk1@001Fmk2@003Fmk00<006mkKg/01Fmk0P0026mk00<006mkKg/0
0fmk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/00fmk0P001fmk00<006mkKg/026mk00<0
06mkKg/02Fmk00<006mkKg/02Fmk00<006mkKg/05Fmk100016mk00D006mkKg]_N`0000m_N`0036mk
00<006mkKg/01Vmk00<006mkKg/05Vmk00<006mkKg/02Vmk00<006mkKg/02fmk00<006mkKg/03Fmk
00<006mkKg/00Vmk00<006mkKg/00P0036mk00<006mkKg/01fmk1@002fmk00<006mkKg/02Fmk00@0
06mkKg/000U_N`8000E_N`03001_Nfmk00M_N`D000I_N`03001_Nfmk009_N`03001_Nfmk00=_N`05
001_NfmkKg/00004Kg/50004Kg/00`00Kg]_N`03Kg/00`00Kg/00002Kg/00`00Kg]_N`08Kg/I0004
Kg/5000=Kg/00`00Kg]_N`07Kg/20006Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`0IKg/30002Kg/4000?Kg/000a_N`03001_Nfmk00M_N`03001_Nfmk01A_N`03001_
Nfmk00]_N`03001_Nfmk00Y_N`03001_Nfmk00m_N`04001_Nfmk0002Kg/00`00Kg]_N`0<Kg/00`00
Kg]_N`07Kg/5000;Kg/00`00Kg]_N`09Kg/01000Kg]_N`001fmk0P001fmk00<006mkKg/026mk1@00
1Vmk00D006mkKg]_N`0000E_N`05001_NfmkKg/00004Kg/50004Kg/00`00Kg]_N`02Kg/01@00Kg]_
Nfmk00000Vmk00<006mkKg/01fmk1@002Vmk1@002Vmk0`0000=_N`0000002fmk00<006mkKg/02Fmk
0P000Vmk0`001Fmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/00fmk
00<006mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/02fmk00<006mkKg/06fmk1`003Vmk000=Kg/0
0`00Kg]_N`07Kg/00`00Kg]_N`0AKg/2000>Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/400000fmk
001_N`0>Kg/00`00Kg]_N`07Kg/400000fmk00000009Kg/00`00Kg]_N`0:Kg/00`00Kg/00005Kg/2
0009Kg/00`00Kg]_N`08Kg/70004Kg/01000Kg]_N`001fmk00@006mkKg/000=_N`H000A_N`05001_
NfmkKg/00004Kg/01@00Kg]_Nfmk00002Fmk10002fmk1@002Vmk00<006mkKg/00Vmk00<006mkKg/0
26mk00<006mkKg/02fmk1P001Fmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/01fmk00D0
06mkKg]_N`0000a_N`03001_Nfmk00I_N`03001_Nfmk00a_N`03001_Nfmk01e_N`D000i_N`003Fmk
00<006mkKg/01fmk00<006mkKg/046mk00<006mkKg/03fmk00<006mkKg/026mk00<006mkKg/046mk
1@0046mk00<006mkKg/01Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00E_N`03001_Nfmk00a_N`<0
009_N`8000Y_N`03001_Nfmk00M_N`L0009_N`8000=_N`<000M_N`04001_Nfmk0002Kg/00`00Kg]_
N`04Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/00fmk00<006mkKg/00Vmk00<006mkKg/01Vmk00D0
06mkKg]_N`0000Y_N`03001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk009_N`8000U_N`03001_
Nfmk00]_N`D000E_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`@000e_N`03001_
Nfmk00A_N`03001_Nfmk00i_N`03001_Nfmk01]_N`H000i_N`003Fmk00<006mkKg/026mk00<006mk
Kg/03Vmk00<006mkKg/046mk00<006mkKg/026mk00<006mkKg/046mk1@0046mk00<006mkKg/01Fmk
00<006mkKg/00fmk00@006mkKg]_N`8000E_N`03001_Nfmk00]_N`H000a_N`03001_Nfmk00I_N`04
001_NfmkKg/30005Kg/70007Kg/300000fmk001_N`07Kg/01P00Kg]_N`00Kg/000I_N`03001_Nfmk
009_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00=_N`03001_Nfmk
00M_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`H000E_N`03001_Nfmk00E_N`03
001_Nfmk00I_N`03001_Nfmk00M_N`D000e_N`03001_Nfmk00A_N`03001_Nfmk00i_N`03001_Nfmk
01U_N`80009_N`<000m_N`003Fmk00<006mkKg/02Fmk00<006mkKg/036mk00<006mkKg/04Fmk00<0
06mkKg/01fmk00<006mkKg/046mk1P0046mk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/0
0fmk0P0000A_N`00000000]_N`L000e_N`03001_Nfmk00A_N`8000A_N`03001_Nfmk00M_N`P000=_
N`D000Y_N`D000I_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00I_
N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk00E_N`8000I_N`03001_Nfmk00Q_N`80009_
N`D000E_N`03001_Nfmk00A_N`03001_Nfmk00I_N`03001_Nfmk00M_N`D000e_N`03001_Nfmk00=_
N`03001_Nfmk011_N`03001_Nfmk01I_N`8000A_N`03001_Nfmk00m_N`003Fmk00<006mkKg/02Vmk
00<006mkKg/02Fmk0P0056mk00<006mkKg/01fmk00<006mkKg/03Vmk0P000Vmk0`0000=_N`00Kg/0
3Fmk00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/016mk1@000Vmk20000Vmk1`002fmk00<0
06mkKg/00Vmk0P001Fmk00<006mkKg/026mk1@000fmk3@001Fmk1@001Vmk00<006mkKg/016mk00<0
06mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/01Fmk00<0
06mkKg/01fmk0P0016mk00<006mkKg/01Vmk0P000fmk00<006mk00000fmk00<006mkKg/00Vmk00<0
06mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01fmk1`002fmk00<006mkKg/00fmk00<006mkKg/0
4Fmk00<006mkKg/04Vmk0`001Fmk0P004Fmk000>Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`0EKg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/20004Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/7000;Kg/30003Kg/30008Kg/01@00
Kg]_Nfmk00001fmk00<006mkKg/01Vmk0P0000=_N`0000000P001Vmk1@001Fmk2P001Vmk0`001Fmk
00D006mkKg]_N`0000U_N`03001_Nfmk00=_N`03001_Nfmk00M_N`8000E_N`03001_Nfmk00U_N`05
001_NfmkKg/00006Kg/20005Kg/00`00Kg/00004Kg/01@00Kg]_Nfmk000016mk00<006mkKg/026mk
00<006mkKg/026mk0`000fmk0`002Fmk00D006mkKg]_N`0001A_N`03001_Nfmk011_N`8000Q_N`80
015_N`003Vmk00<006mkKg/02fmk00<006mkKg/01Fmk00<006mkKg/05Vmk00<006mkKg/01Fmk00<0
06mkKg/02fmk0P001Vmk00<006mkKg/00fmk0P002fmk00<006mkKg/00fmk00<006mkKg/026mk00<0
06mkKg/00fmk1@003Vmk00<006mkKg/01Fmk0`000fmk0`0000=_N`00000026mk00<006mkKg/016mk
0P000fmk00D006mk001_N`0000I_N`@000Y_N`l000E_N`@000Y_N`03001_Nfmk009_N`03001_Nfmk
00U_N`03001_Nfmk009_N`03001_Nfmk00Y_N`800004Kg/000000002Kg/20006Kg/01000Kg]_N`00
1Fmk00D006mkKg]_N`0000=_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk00M_N`8000M_
N`04001_Nfmk000FKg/00`00Kg]_N`0=Kg/2000:Kg/00`00Kg]_N`0@Kg/000i_N`03001_Nfmk00]_
N`03001_Nfmk00A_N`03001_Nfmk01M_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`8000M_N`03001_
Nfmk00I_N`03001_Nfmk00Q_N`03001_Nfmk009_N`03001_Nfmk00U_N`03001_Nfmk00A_N`D000e_
N`03001_Nfmk00Q_N`L000U_N`03001_Nfmk00=_N`8000A_N`04001_Nfmk0002Kg/00`00Kg]_N`04
Kg/01000Kg]_N`002Vmk0`001Vmk1`000fmk1@002Vmk00D006mkKg]_N`0000a_N`05001_NfmkKg/0
000>Kg/60008Kg/01000Kg]_N`001Vmk00@006mkKg/0009_N`03001_Nfmk00U_N`03001_Nfmk00I_
N`03001_Nfmk00Y_N`8000E_N`04001_Nfmk000FKg/00`00Kg]_N`0;Kg/2000;Kg/2000BKg/000i_
N`03001_Nfmk00a_N`H001]_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`8000U_N`03001_Nfmk00M_
N`8000Q_N`05001_NfmkKg/0000=Kg/00`00Kg]_N`04Kg/01@00Kg]_Nfmk000036mk00<006mkKg/0
2Vmk1@002Fmk00@006mkKg]_N`8000I_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/01@00Kg]_Nfmk
000026mk00<006mkKg/01Vmk1P000Vmk2@002Vmk10003Fmk00D006mkKg]_N`0000e_N`D000Q_N`03
001_Nfmk009_N`03001_Nfmk00A_N`D000a_N`03001_Nfmk00E_N`03001_Nfmk00e_N`<0009_N`03
001_N`0001Q_N`03001_Nfmk00M_N`<000e_N`80019_N`003Vmk00<006mkKg/036mk1@0076mk00<0
06mkKg/00Vmk00<006mkKg/01Vmk0`002fmk00<006mkKg/02Fmk00<006mkKg/01Fmk00@006mkKg/0
00i_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00Y_N`P000A_N`<0
0003Kg/0000000M_N`05001_NfmkKg/00004Kg/01@00Kg]_Nfmk00001Fmk00<006mkKg/01Fmk00<0
06mkKg/016mk0P0000=_N`0000000`001Fmk1@0000=_N`0000001P000Vmk1@003Fmk100026mk2P00
26mk00<006mkKg/00Vmk00<006mkKg/01Fmk1@002fmk00<006mkKg/016mk00<006mkKg/04Fmk1@00
66mk00<006mkKg/01Fmk0P0046mk0P004Vmk000>Kg/00`00Kg]_N`0<Kg/6000KKg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/2000=Kg/00`00Kg]_N`0;Kg/20005Kg/00`00Kg/0000@Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/20009Kg/00`00Kg]_N`09Kg/50004Kg/80009Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`02Kg/01000Kg]_N`001Vmk00<006mkKg/00fmk00<006mkKg/00fmk0P000fmk00<006mk0000
0Vmk00<006mkKg/00fmk0`002Vmk3P001Vmk1@0000=_N`00000010001Vmk0`0026mk00<006mkKg/0
0fmk00<006mkKg/01Fmk1@0036mk00<006mkKg/00fmk00<006mkKg/04Vmk2@0056mk0`000Vmk0P00
4Fmk0P004fmk000?Kg/00`00Kg]_N`0;Kg/500000fmk00000004000FKg/01000Kg]_N`001Fmk0P00
3fmk00<006mkKg/03Fmk00D006mkKg]_N`00009_N`03001_Nfmk00i_N`03001_Nfmk009_N`03001_
Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00Q_N`05001_NfmkKg/00008Kg/50009Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`03Kg/40006Kg/00`00Kg]_N`02Kg/01000Kg]_Nfmk0P0016mk00@006mkKg/0
009_N`03001_Nfmk00A_N`03001_Nfmk00]_N`D000M_N``000i_N`03001_Nfmk00I_N`03001_Nfmk
00=_N`03001_Nfmk00E_N`H000]_N`03001_Nfmk009_N`03001_Nfmk00i_N`X000A_N`h000E_N`H0
01=_N`8001=_N`003fmk00<006mkKg/036mk0`0026mk1`003fmk00@006mkKg/000=_N`80015_N`03
001_Nfmk00i_N`03001_N`0000<0019_N`05001_NfmkKg/00009Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/50008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/5
0006Kg/40002Kg/20005Kg/01@00Kg]_Nfmk00000fmk00<006mkKg/016mk00<006mkKg/02Fmk1@00
3Vmk1P003Vmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/01Vmk0`000Vmk0`0026mk00D0
06mkKg]_N`0000a_N`D000E_N`D0019_N`X001=_N`03001_N`0001=_N`003fmk00<006mkKg/036mk
00@006mkKg/000i_N`L000Q_N`<0009_N`80019_N`03001_Nfmk011_N`D0019_N`05001_NfmkKg/0
000:Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/400000fmk
001_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/80003Kg/60006Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/01000Kg]_N`000Vmk00<006mkKg/036mk1000
00=_N`00000036mk00<006mkKg/01Fmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/01Vmk
0P001Vmk00@006mkKg/000U_N`@000]_N`@001M_N`D001=_N`03001_N`0001=_N`003fmk00<006mk
Kg/036mk00D006mkKg]_N`0001A_N`H00003Kg/0000000@001A_N`03001_Nfmk011_N`D001=_N`04
001_Nfmk000;Kg/20005Kg/00`00Kg]_N`03Kg/20006Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk
0P0016mk00<006mkKg/01Fmk00<006mkKg/00Vmk1@000fmk20001Vmk00<006mkKg/00Vmk00<006mk
Kg/016mk00<006mkKg/00Vmk00<006mkKg/01fmk00D006mkKg]_N`0000=_N`03001_Nfmk00Y_N`03
001_Nfmk009_N`03001_Nfmk008000]_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00E_
N`03001_Nfmk00Q_N`<0009_N`@000E_N`D000m_N`05001_NfmkKg/0000GKg/3000DKg/2000DKg/0
00m_N`03001_Nfmk00]_N`03001_Nfmk00=_N`03001_Nfmk01M_N`H001A_N`03001_Nfmk011_N`/0
00i_N`04001_Nfmk000=Kg/00`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_
N`05Kg/01000Kg]_N`001Fmk00<006mk00000P001fmk00<006mkKg/00Vmk100000=_N`00000016mk
1@001Vmk00<006mkKg/00Vmk00<006mkKg/01Fmk00D006mkKg]_N`0000Q_N`03001_Nfmk009_N`03
001_Nfmk009_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`03001_Nfmk009_N`8000U_N`03001_Nfmk
00=_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00a_N`/001=_N`03001_Nfmk009_N`03
001_Nfmk01E_N`8001A_N`03001_N`0001A_N`003fmk00<006mkKg/02fmk00<006mkKg/00fmk00<0
06mkKg/066mk1@0056mk00<006mkKg/03Vmk0P000Vmk0`001Vmk10002fmk0P003fmk00D006mkKg]_
N`0000=_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk00=_N`D000I_
N`05001_NfmkKg/00002Kg/00`00Kg]_N`02Kg/20003Kg/30006Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`06Kg/01000Kg]_N`001Vmk0P001Fmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mkKg/01Fmk
00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/00fmk
00<006mkKg/03Vmk1@0066mk00<006mkKg/00fmk00<006mkKg/04fmk00<006mk000056mk00<006mk
000056mk000@Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0HKg/300000fmk0000000B
Kg/00`00Kg]_N`0<Kg/20003Kg/01000Kg]_N`002Vmk1@001Vmk0`003fmk1`002Vmk00<006mkKg/0
0fmk00<006mkKg/00fmk00<006mkKg/00fmk1@001Vmk00@006mkKg/000=_N`03001_Nfmk00A_N`80
00A_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_N`0000E_N`03001_Nfmk
00E_N`03001_Nfmk00=_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00A_N`8000M_N`05
001_NfmkKg/00008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0=Kg/6000GKg/00`00Kg]_N`05Kg/00`00
Kg]_N`0BKg/00`00Kg/0000DKg/00`00Kg/0000DKg/0011_N`03001_Nfmk00U_N`03001_Nfmk00I_
N`03001_Nfmk01M_N`03001_Nfmk00=_N`8000m_N`03001_Nfmk00Y_N`<000E_N`05001_NfmkKg/0
000>Kg/:000?Kg/5000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/:000016mk
0000000016mk00<006mkKg/01Vmk0P000Vmk00D006mkKg]_N`0000M_N`03001_Nfmk00M_N`04001_
Nfmk0003Kg/00`00Kg]_N`05Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`05Kg/20005Kg/01000Kg]_N`002Fmk00<006mkKg/00Vmk00<006mkKg/02fmk0`000Vmk1@00
5Vmk00<006mkKg/01Fmk00<006mkKg/04Vmk00<006mk00004fmk00<006mk00005Fmk000@Kg/00`00
Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0FKg/00`00Kg]_N`05Kg/2000=Kg/00`00Kg]_N`08
Kg/20007Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/I000;Kg/01@00Kg]_Nfmk00001fmk00<006mk
Kg/016mk0`001Vmk1@000fmk00<006mkKg/026mk0P0000=_N`0000000P001fmk00<006mkKg/026mk
1P0026mk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/026mk00<006mkKg/01fmk0P000fmk
00@006mkKg/000U_N`03001_Nfmk009_N`03001_Nfmk00Q_N`<000I_N`05001_NfmkKg/0000EKg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0@Kg/01000Kg]_N`004fmk00<006mk00005Fmk000@Kg/00`00Kg]_
N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0FKg/00`00Kg]_N`07Kg/2000;Kg/00`00Kg]_N`06Kg/2
0009Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/5000?Kg/70009Kg/01000Kg]_N`0026mk00<006mk
Kg/00fmk00<006mkKg/01fmk1@000fmk00<006mkKg/02Vmk1@001Vmk0`002Fmk1@002Fmk00<006mk
Kg/01Vmk1@0036mk00<006mkKg/026mk0P0000A_N`00000000]_N`04001_Nfmk0009Kg/20009Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0AKg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/01000Kg]_N`004Vmk
00@006mkKg/001E_N`0046mk00<006mkKg/026mk00<006mkKg/02Fmk00<006mkKg/05Fmk00<006mk
Kg/02Fmk0P0026mk00<006mkKg/016mk0`002Vmk00<006mkKg/016mk00<006mkKg/046mk1@0046mk
0`000fmk0P001fmk00@006mkKg/000Q_N`03001_Nfmk009_N`03001_Nfmk00I_N`L000=_N`03001_
Nfmk00Y_Na`000U_N`03001_Nfmk00I_N`D000e_N`03001_Nfmk00U_N`D000Y_N`03001_N`0000M_
N`<000]_N`03001_Nfmk00=_N`80015_N`03001_Nfmk00Q_N`03001_Nfmk00i_N`03001_Nfmk009_
N`03001_Nfmk00m_N`04001_Nfmk000EKg/0011_N`03001_Nfmk00Q_N`03001_Nfmk00Y_N`03001_
Nfmk01A_N`03001_Nfmk00]_N`8000I_N`03001_Nfmk009_N`8000e_N`03001_Nfmk00E_N`03001_
Nfmk00e_N`80009_N`04001_Nfmk000>Kg/01000Kg]_N`001Fmk0`0016mk00<006mk00002Fmk00<0
06mkKg/00Vmk00<006mkKg/016mk0P000fmk10000fmk00<006mkKg/02Vmk1@001Fmk1@0026mk1P00
26mk00<006mkKg/01Vmk1@003Fmk00<006mkKg/02Fmk1@002Vmk00<006mk000016mk0`003Vmk00<0
06mkKg/01Fmk00<006mkKg/03Vmk00<006mkKg/02Fmk00<006mkKg/03Fmk00<006mkKg/00Vmk00<0
06mkKg/03fmk00<006mk00005Vmk000AKg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0B
Kg/00`00Kg]_N`0>Kg/200000fmk000000020002Kg/2000>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<
Kg/00`00Kg]_N`03Kg/01000Kg]_N`003Fmk00D006mkKg]_N`0000M_N`H000Y_N`05001_NfmkKg/0
0005Kg/20005Kg/01000Kg]_N`000fmk00<006mkKg/026mk0P0000=_N`0000000P001Fmk1@0026mk
10000Vmk0P001Vmk00<006mkKg/016mk2@0036mk00<006mkKg/026mk2@001Fmk0`000fmk0P004Fmk
00<006mkKg/01Vmk00<006mkKg/036mk00<006mkKg/02fmk00<006mkKg/036mk00<006mkKg/00Vmk
00<006mkKg/03Vmk00@006mkKg/001I_N`004Fmk00<006mkKg/01Vmk00<006mkKg/036mk00<006mk
Kg/04Vmk00<006mkKg/046mk1`0046mk00<006mkKg/01fmk00<006mkKg/02Vmk00<006mkKg/016mk
00D006mkKg]_N`0000]_N`03001_Nfmk009_N`03001_Nfmk00I_N`D000]_N`04001_Nfmk0003Kg/2
0007Kg/01@00Kg]_Nfmk00000Vmk00<006mkKg/01fmk00@006mkKg/000A_N`03001_Nfmk00=_N`<0
00U_N`05001_N`00Kg/00003Kg/20002Kg/30003Kg/30002Kg/40003Kg/30009Kg/00`00Kg]_N`07
Kg/00`00Kg/000020005Kg/;000CKg/00`00Kg]_N`07Kg/2000<Kg/00`00Kg]_N`0;Kg/00`00Kg]_
N`0;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0>Kg/01000Kg]_N`005Vmk000AKg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0@Kg/5000AKg/00`00Kg]_N`08Kg/00`00Kg]_
N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_
N`05Kg/80008Kg/00`00Kg/00002Kg/20008Kg/00`00Kg]_N`02Kg/01000Kg]_N`001fmk0P000fmk
00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/01Vmk00H006mkKg/006mk0005Kg/80005Kg/0
1@00Kg]_Nfmk00001Fmk0P0026mk00<006mkKg/01Fmk00D006mkKg]_N`0000Y_N`D001E_N`03001_
Nfmk00U_N`03001_Nfmk00U_N`03001_Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_
Nfmk00i_N`04001_Nfmk000FKg/0015_N`03001_Nfmk00E_N`03001_Nfmk00m_N`03001_Nfmk011_
N`03001_Nfmk011_N`D0015_N`03001_Nfmk00U_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_
Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00E_N`D000=_N`@000=_N`<00003
Kg/0000000Y_N`03001_Nfmk00=_N`03001_N`0000E_N`8000A_N`03001_Nfmk00E_N`03001_Nfmk
00=_N`03001_Nfmk00E_N`05001_NfmkKg/00002Kg/00`00Kg]_N`03Kg/50006Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`04Kg/30005Kg/00`00Kg]_N`03Kg/20004Kg/00`00Kg]_N`08Kg/6000DKg/00`00
Kg]_N`0:Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`0=Kg/01000Kg]_N`005fmk000AKg/00`00Kg]_N`05Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`0?
Kg/00`00Kg]_N`0@Kg/5000@Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/30008Kg/7000<Kg/00`00
Kg]_N`03Kg/00`00Kg/00004Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`04Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00Vmk1@001Fmk00<006mkKg/01Fmk00<006mk
Kg/01Vmk0`000fmk0`0000=_N`00Kg/01Fmk00<006mkKg/02Fmk0`000Vmk0P004fmk00<006mkKg/0
2Vmk0P001fmk00<006mkKg/03Vmk00<006mkKg/026mk00<006mkKg/016mk00<006mkKg/03Fmk00@0
06mkKg/001M_N`004Vmk00<006mkKg/016mk00<006mkKg/046mk00<006mkKg/03Vmk00<006mkKg/0
46mk00<006mkKg/00fmk00<006mkKg/036mk00<006mkKg/036mk00<006mkKg/016mk00<006mkKg/0
26mk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/0
2Fmk1@002fmk00<006mkKg/01Fmk0`0000=_N`0000001Vmk00<006mkKg/026mk00<006mkKg/00Vmk
00<006mkKg/00fmk00D006mkKg]_N`0000A_N`03001_Nfmk00=_N`<000E_N`03001_Nfmk00I_N`03
001_Nfmk00U_N`L000I_N`03001_Nfmk00U_N`04001_Nfmk0004Kg/2000AKg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/0
1@00Kg]_Nfmk00005fmk000BKg/00`00Kg]_N`03Kg/00`00Kg]_N`0BKg/00`00Kg]_N`0=Kg/00`00
Kg]_N`0?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`02Kg/2000<
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:
Kg/5000;Kg/00`00Kg]_N`04Kg/50005Kg/3000<Kg/01@00Kg]_Nfmk000016mk00<006mkKg/00Vmk
00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/02Vmk
1@001Vmk00<006mkKg/026mk00D006mkKg]_N`0000I_N`8000m_N`03001_Nfmk00e_N`03001_Nfmk
009_N`03001_Nfmk015_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00a_N`05001_Nfmk
Kg/0000GKg/0019_N`03001_Nfmk00=_N`03001_Nfmk01=_N`03001_Nfmk00a_N`03001_Nfmk00i_
N`03001_Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk00i_N`@000i_N`03001_Nfmk00E_N`@000]_
N`03001_Nfmk00A_N`03001_Nfmk00Q_N`800003Kg/0000000<000Y_N`03001_Nfmk00A_N`L0009_
N`D000a_N`04001_Nfmk0003Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`07Kg/70006Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`05Kg/2000=Kg/00`00Kg]_N`0>Kg/5000CKg/00`00Kg]_N`05Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0<Kg/01000Kg]_N`0066mk000BKg/00`00Kg]_N`03Kg/00`00Kg]_N`0DKg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0<Kg/2000:Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0=Kg/5000>Kg/00`00
Kg]_N`05Kg/5000:Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk
00002Fmk00<006mkKg/016mk1@000Vmk200036mk00<006mk00000Vmk00<006mkKg/016mk00<006mk
Kg/016mk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/02fmk0`000fmk0`000fmk0`001fmk
00<006mkKg/01fmk00<006mkKg/00fmk00<006mkKg/01fmk0P002fmk00<006mkKg/03fmk1@004fmk
00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/02fmk00D006mkKg]_N`0001Q_N`004Vmk00<0
06mkKg/00Vmk00<006mkKg/05Fmk00<006mkKg/02fmk00<006mkKg/02fmk00<006mkKg/02fmk00<0
06mkKg/01fmk00<006mkKg/03Vmk1@003Vmk00<006mkKg/01Fmk1@002fmk00<006mkKg/00Vmk00<0
06mkKg/01Vmk0P0016mk00<006mkKg/00fmk00<006mkKg/01Fmk00<006mkKg/016mk00<006mk0000
0P001Fmk1@0000=_N`00000010001fmk00D006mk001_N`0000I_N`03001_Nfmk00A_N`05001_Nfmk
Kg/00004Kg/00`00Kg]_N`0;Kg/70006Kg/00`00Kg/00007Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`09Kg/20009Kg/00`00Kg]_N`0?Kg/5000DKg/00`00Kg]_N`02Kg/00`00Kg]_N`06
Kg/00`00Kg]_N`0;Kg/01@00Kg]_Nfmk000066mk000BKg/00`00Kg]_N`02Kg/00`00Kg]_N`0FKg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/7
000>Kg/00`00Kg]_N`05Kg/6000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`04Kg/20005Kg/00`00Kg]_N`02Kg/20002Kg/00`00Kg]_N`05Kg/50007Kg/60002Kg/3
0007Kg/00`00Kg]_N`05Kg/01000Kg]_N`000fmk00<006mkKg/036mk1@001fmk00D006mkKg]_N`00
00I_N`03001_Nfmk00E_N`03001_Nfmk00I_N`03001_Nfmk00Y_N`8000M_N`03001_Nfmk00a_N`d0
00m_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_Nfmk00]_N`05001_NfmkKg/0000HKg/001=_
N`05001_NfmkKg/0000IKg/00`00Kg]_N`08Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0?Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`0:Kg/30003Kg/300000fmk001_N`0<Kg/00`00Kg]_N`06Kg/30002Kg/30008
Kg/01@00Kg]_Nfmk00001Fmk0P001fmk00<006mkKg/01Vmk00<006mkKg/00Vmk00<006mkKg/00P00
16mk00<006mkKg/01Fmk00D006mkKg]_N`0000e_N`H000I_N`03001_Nfmk00I_N`03001_N`00009_
N`03001_Nfmk00U_N`T000M_N`05001_NfmkKg/00006Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0<Kg/20005Kg/00`00Kg]_N`08Kg/40004Kg/30006Kg/5000;Kg/01000Kg]_N`002Fmk
00<006mkKg/02Vmk00D006mkKg]_N`0001U_N`004fmk00@006mkKg/001]_N`03001_Nfmk00M_N`03
001_Nfmk00U_N`03001_Nfmk011_N`03001_Nfmk00A_N`03001_Nfmk00M_N`<000I_N`03001_Nfmk
009_N`8000a_N`03001_Nfmk00A_N`05001_NfmkKg/00004Kg/20006Kg/01000Kg]_N`0016mk0P00
2Fmk00<006mkKg/01fmk00<006mk00000P0000=_N`00Kg/01Fmk00<006mkKg/016mk00<006mkKg/0
0fmk00<006mkKg/02fmk1@001Vmk00<006mkKg/01Vmk00D006mk001_N`0000Q_N`@000A_N`@000Q_
N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00e_
N`80009_N`<000E_N`@000U_N`03001_Nfmk00Y_N`H000I_N`<000U_N`03001_Nfmk00Y_N`05001_
NfmkKg/0000IKg/001=_N`04001_Nfmk000KKg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/2000DKg/0
0`00Kg]_N`02Kg/00`00Kg]_N`06Kg/20009Kg/00`00Kg]_N`04Kg/2000:Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`04Kg/20005Kg/00`00Kg/00003Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`08Kg/50007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/70006Kg/00`00Kg]_
N`07Kg/40004Kg/40008Kg/00`00Kg/00008Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`03Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0?Kg/:000=Kg/00`00Kg]_N`0@Kg/:0008Kg/00`00Kg]_
N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0GKg/001=_N`04001_Nfmk000LKg/00`00Kg]_N`06Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`0EKg/01@00Kg]_Nfmk00001Fmk0`002fmk00<006mkKg/01Vmk00<0
06mkKg/01fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/01Fmk0`000Vmk0`0000=_N`00
000036mk00<006mkKg/026mk1@001fmk00<006mkKg/00Vmk00<006mkKg/01fmk00<006mkKg/01Fmk
0P000fmk0`0000=_N`00Kg/00fmk00<006mkKg/01fmk2@002fmk00D006mkKg]_N`0000M_N`03001_
Nfmk00A_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00Y_N`<000i_N`L0019_N`03001_
Nfmk01A_N`D000Q_N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk01M_N`004fmk00<006mk
00007Vmk00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/05fmk00<006mk00000fmk0`003Vmk
00<006mkKg/01fmk0P001fmk00<006mkKg/00Vmk00<006mkKg/01Fmk00<006mkKg/01fmk1P003Vmk
00<006mkKg/01fmk1P001fmk00<006mkKg/00Vmk00<006mkKg/01fmk10000Vmk0P001Vmk00D006mk
Kg]_N`0000=_N`03001_Nfmk00M_N`D000i_N`03001_Nfmk009_N`03001_Nfmk00A_N`03001_Nfmk
00E_N`03001_Nfmk009_N`03001_Nfmk009_N`03001_Nfmk00U_N`D000=_N`X0009_N`D0019_N`03
001_Nfmk01A_N`D000Q_N`03001_Nfmk00U_N`05001_NfmkKg/0000JKg/001=_N`03001_N`0001m_
N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk01Q_N`H0015_N`03001_Nfmk00U_N`03001_
Nfmk00A_N`05001_NfmkKg/00008Kg/00`00Kg]_N`08Kg/5000>Kg/00`00Kg]_N`05Kg/20002Kg/4
0006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/60008Kg/00`00Kg]_N`02Kg/01000Kg]_N`001fmk
1`003Fmk00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/01Vmk00D006mkKg]_N`0000=_N`03
001_Nfmk00Y_N`P000e_N`@0019_N`03001_Nfmk01A_N`@000Y_N`03001_Nfmk00M_N`03001_Nfmk
009_N`03001_Nfmk01Q_N`004fmk0`007fmk00<006mkKg/00fmk00<006mkKg/00fmk0P006Fmk1P00
4fmk00<006mkKg/02Vmk0P0016mk00D006mkKg]_N`0000U_N`03001_Nfmk00M_N`P000Y_N`03001_
Nfmk00=_N`<000=_N`05001_N`00Kg/00006Kg/01@00Kg]_Nfmk00002fmk1@002Fmk00<006mkKg/0
0fmk10000fmk0`000fmk0`003Fmk00<006mkKg/016mk00<006mkKg/00fmk00<006mkKg/01fmk00@0
06mkKg/000=_N`03001_Nfmk00U_N`L0011_N`05001_NfmkKg/0000AKg/00`00Kg]_N`0CKg/01@00
Kg]_Nfmk00002Vmk00<006mkKg/01fmk00<006mkKg/00Vmk00<006mkKg/066mk000BKg/5000OKg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0CKg/600000fmk00000003000BKg/00`00Kg]_
N`0=Kg/20003Kg/00`00Kg/0000:Kg/00`00Kg]_N`08Kg/30004Kg/40005Kg/30002Kg/20005Kg/0
1000Kg]_N`000Vmk00<006mkKg/00fmk00@006mkKg/000Y_N`L000U_N`03001_Nfmk00=_N`L000U_
N`03001_Nfmk00U_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_N`0000=_
N`03001_Nfmk00I_N`<000=_N`@0011_N`03001_Nfmk009_N`03001_Nfmk00i_N`03001_Nfmk019_
N`03001_Nfmk00=_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk009_N`03001_Nfmk01Q_
N`004Vmk1`007Vmk00D006mkKg]_N`0000=_N`03001_Nfmk00i_N`H000M_N`H0015_N`03001_Nfmk
00m_N`03001_N`00008000a_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`X000M_N`04001_Nfmk0003
Kg/00`00Kg]_N`02Kg/01000Kg]_N`0026mk0P000fmk0`002Vmk00<006mkKg/00fmk1@0036mk00<0
06mkKg/026mk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mk00000Vmk00<0
06mkKg/01Fmk0P001Vmk00@006mkKg/0011_N`03001_Nfmk00=_N`03001_Nfmk00e_N`03001_Nfmk
015_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk
01U_N`004Vmk1@000Vmk2P005Fmk00@006mkKg/0009_N`03001_Nfmk00U_N`H000i_N`<0009_N`03
001_Nfmk00i_N`03001_Nfmk011_N`D000a_N`03001_Nfmk00E_N`03001_Nfmk00e_N`D000M_N`03
001_Nfmk009_N`05001_NfmkKg/00003Kg/00`00Kg/00006Kg/30005Kg/01000Kg]_N`002Fmk00<0
06mkKg/00fmk1`002fmk00<006mkKg/01Vmk00<006mkKg/01fmk00D006mkKg]_N`0000a_N`800003
Kg/006mk00A_N`<000M_N`03001_Nfmk009_N`03001_Nfmk00e_N`03001_Nfmk00A_N`03001_Nfmk
00a_N`03001_Nfmk011_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk
009_N`03001_Nfmk01U_N`004fmk0`003Fmk2@0036mk0`0000=_N`0000001Vmk1P004fmk00<006mk
Kg/016mk0P003Vmk00<006mkKg/046mk1@0036mk00<006mkKg/01Fmk00<006mkKg/036mk1P001fmk
00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/00P0016mk0`001fmk00<006mkKg/00Vmk00<0
06mkKg/01Vmk00<006mkKg/016mk0`000fmk0`0026mk00<006mkKg/01Fmk00<006mkKg/026mk00D0
06mkKg]_N`0000a_N`<000=_N`<000Y_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00I_
N`03001_Nfmk00]_N`03001_Nfmk00m_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00E_
N`03001_Nfmk00=_N`03001_Nfmk01U_N`005Fmk00<006mkKg/056mk2P0000=_N`0000000`000Vmk
1P006Fmk00<006mkKg/01Vmk00<006mkKg/02fmk00<006mkKg/03fmk1`0036mk00<006mkKg/016mk
00<006mkKg/02Vmk0P000Vmk0`001fmk00<006mkKg/00fmk00<006mkKg/00Vmk10000fmk0P002Vmk
00<006mkKg/00fmk00<006mkKg/016mk00<006mkKg/016mk00@006mkKg/000I_N`8000M_N`03001_
Nfmk00=_N`03001_Nfmk00U_N`04001_Nfmk000<Kg/7000<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0IKg/001I_N`03001_Nfmk01e_N`P001i_
N`03001_Nfmk00Q_N`03001_Nfmk00U_N`03001_Nfmk00i_N`80009_N`<0009_N`<000U_N`03001_
Nfmk00=_N`03001_Nfmk00Q_N`<000E_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk009_
N`L000]_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk009_N`03001_
Nfmk00E_N`<000E_N`05001_NfmkKg/0000<Kg/01000Kg]_N`0036mk1@003Vmk00<006mkKg/01Vmk
00<006mkKg/02Fmk00<006mkKg/026mk00<006mkKg/02Vmk00<006mkKg/036mk00<006mkKg/02Vmk
00<006mkKg/01Fmk00<006mkKg/01Fmk00<006mkKg/00Vmk00<006mkKg/06Vmk000FKg/00`00Kg]_
N`0NKg/6000OKg/00`00Kg]_N`09Kg/20009Kg/00`00Kg]_N`0;Kg/30004Kg/01000Kg]_N`0016mk
0P0026mk00<006mkKg/00Vmk00<006mkKg/01Vmk0P002Fmk00<006mkKg/016mk00<006mkKg/016mk
00<006mkKg/00Vmk1@003Fmk00<006mkKg/01Fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mk
Kg/00Vmk00<006mkKg/026mk0`000fmk100036mk00@006mkKg/000U_N`P000i_N`03001_Nfmk00I_
N`03001_Nfmk00U_N`03001_Nfmk00U_N`03001_Nfmk00U_N`03001_Nfmk00]_N`03001_Nfmk00a_
N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk01Y_N`005fmk00<006mk
Kg/07Vmk0`000Vmk00<006mkKg/06fmk00<006mkKg/036mk00<006mkKg/01Vmk00<006mkKg/02Fmk
0P001fmk00@006mkKg/000I_N`<000I_N`05001_NfmkKg/00006Kg/2000;Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`02Kg/6000;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/7000<Kg/00`00Kg/00007Kg/30004Kg/3000>Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/20009Kg/00`00Kg]_N`09Kg/2000?Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0JKg/001M_N`03001_Nfmk
01m_N`8000=_N`8001]_N`03001_Nfmk00e_N`03001_Nfmk00E_N`03001_Nfmk00M_N`8000U_N`05
001_NfmkKg/00008Kg/20004Kg/01000Kg]_N`0016mk0`003Fmk00<006mkKg/00Vmk00<006mkKg/0
1Vmk00<006mkKg/00fmk0`000Vmk0P002Fmk00<006mkKg/026mk00D006mkKg]_N`0000=_N`03001_
Nfmk00E_N`03001_Nfmk00a_N`H000]_N`<000A_N`<000M_N`04001_Nfmk000=Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0@
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0JKg/001Q_N`03001_
Nfmk01i_N`8000E_N`03001_Nfmk01M_N`03001_Nfmk00m_N`8000E_N`03001_Nfmk00E_N`8000Y_
N`03001_Nfmk009_N`03001_Nfmk00Q_N`<0009_N`<0009_N`80011_N`03001_Nfmk009_N`03001_
Nfmk00I_N`03001_Nfmk009_N`03001_Nfmk00E_N`8000I_N`03001_Nfmk00U_N`05001_NfmkKg/0
0002Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/500000fmk000000060002Kg/8000:Kg/01000Kg]_
N`0036mk00<006mkKg/02fmk00<006mkKg/01Fmk00<006mkKg/03Vmk00<006mkKg/01Fmk00<006mk
Kg/01fmk00<006mkKg/04Fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mk
Kg/06fmk000HKg/00`00Kg]_N`0MKg/00`00Kg/00006Kg/00`00Kg]_N`0FKg/00`00Kg]_N`0AKg/0
0`00Kg]_N`02Kg/00`00Kg]_N`02Kg/3000<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/7000BKg/0
1@00Kg]_Nfmk00002Fmk00<006mkKg/00Vmk00<006mkKg/01fmk0P000Vmk0`0036mk00@006mkKg/0
009_N`03001_Nfmk00M_N`03001_Nfmk00]_N`@000Y_N`L000e_N`05001_NfmkKg/0000;Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`0CKg/00`00Kg]_N`02Kg/00`00Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0KKg/001U_
N`03001_Nfmk01a_N`03001_N`0000M_N`8001E_N`03001_Nfmk01=_N`03001_N`000080009_N`80
00m_N`03001_Nfmk00=_N`03001_Nfmk00]_N`D001=_N`05001_NfmkKg/00009Kg/01@00Kg]_Nfmk
000036mk1P0036mk00D006mk001_N`0000Y_N`03001_Nfmk00Y_N`05001_NfmkKg/0000<Kg/5000<
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0A
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0DKg/00`00Kg]_N`02Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0KKg/001U_N`03001_Nfmk01a_N`03001_N`0000U_N`03001_
Nfmk019_N`03001_Nfmk01A_N`H0015_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`/000i_N`03001_
N`0000]_N`04001_Nfmk000=Kg/7000;Kg/3000<Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0;Kg/3000=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`02
Kg/00`00Kg]_N`0BKg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0FKg/01@00Kg]_Nfmk
000016mk00<006mkKg/016mk00<006mkKg/06fmk000JKg/00`00Kg]_N`0KKg/00`00Kg/0000:Kg/2
000BKg/00`00Kg]_N`0DKg/5000AKg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/30007Kg/60007Kg/3
000<Kg/00`00Kg/0000;Kg/80002Kg/80002Kg/5000;Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0:Kg/01000Kg]_N`003Fmk00<006mkKg/016mk00<006mkKg/01Vmk00<006mkKg/03fmk
00D006mkKg]_N`0001E_N`05001_NfmkKg/00005Kg/00`00Kg]_N`0GKg/01@00Kg]_Nfmk000016mk
00<006mkKg/00fmk00<006mkKg/076mk000JKg/00`00Kg]_N`0JKg/01000Kg]_N`0036mk00<006mk
Kg/03Vmk00<006mkKg/04fmk1`004Fmk00<006mkKg/01Vmk00<006mkKg/02Fmk00D006mkKg]_N`00
00a_N`/000]_N`03001_N`0000M_N`@000A_N`<000]_N`L000]_N`03001_Nfmk00I_N`03001_Nfmk
00E_N`03001_Nfmk00U_N`05001_NfmkKg/0000<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0AKg/01000Kg]_N`005Vmk00D006mkKg]_N`0000=_N`03001_Nfmk01U_N`04001_Nfmk0003
Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0LKg/001]_N`03001_Nfmk01U_N`04001_Nfmk000=Kg/2000>
Kg/00`00Kg]_N`0@Kg/30003Kg/300000fmk0000000?Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`02Kg/00`00Kg]_N`0?Kg/60009Kg/30004Kg/40007Kg/00`00Kg/0000>Kg/7000:Kg/0
0`00Kg]_N`04Kg/00`00Kg]_N`06Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0AKg/3000HKg/01000Kg]_N`000Vmk00<006mk
Kg/06Vmk00D006mkKg]_N`00009_N`03001_Nfmk00A_N`03001_Nfmk01a_N`006fmk00<006mkKg/0
6Fmk00@006mkKg/000m_N`03001_Nfmk00Y_N`03001_Nfmk00i_N`<000I_N`03001_Nfmk00=_N`80
00e_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00A_N`03001_Nfmk00i_N`D00003Kg/0
000000D00003Kg/0000000H000]_N`03001_N`0000i_N`@000=_N`<000M_N`03001_Nfmk00=_N`03
001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`03
001_Nfmk00=_N`03001_Nfmk015_N`D001Q_N`D001i_N`04001_Nfmk0002Kg/00`00Kg]_N`04Kg/0
0`00Kg]_N`0LKg/001a_N`03001_Nfmk01M_N`05001_NfmkKg/0000@Kg/2000:Kg/00`00Kg]_N`0;
Kg/30009Kg/00`00Kg]_N`05Kg/2000:Kg/00`00Kg]_N`08Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0=Kg/50009Kg/6000=Kg/01@00Kg]_Nfmk000036mk00@006mkKg/000M_N`8000I_
N`05001_NfmkKg/0000;Kg/00`00Kg]_N`06Kg/00`00Kg]_N`04Kg/00`00Kg]_N`08Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0AKg/A000<Kg/5000NKg/01P00Kg]_N`00Kg/000I_N`03
001_Nfmk01e_N`0076mk00<006mkKg/05fmk00D006mkKg]_N`00019_N`03001_Nfmk00I_N`03001_
Nfmk00U_N`<000a_N`03001_Nfmk00M_N`03001_Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk00E_
N`03001_Nfmk00I_N`03001_Nfmk00]_N`06001_Nfmk001_N`002Vmk1@003Fmk00D006mkKg]_N`00
00]_N`05001_NfmkKg/00009Kg/30003Kg/4000<Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`09Kg/01@00Kg]_Nfmk00003fmk2@0036mk4P007Vmk00D006mk001_N`00
00I_N`03001_Nfmk01e_N`007Fmk00<006mkKg/05Vmk00D006mkKg]_N`0001=_N`03001_Nfmk00E_
N`03001_Nfmk00I_N`<000i_N`03001_Nfmk00U_N`8000M_N`03001_Nfmk00U_N`03001_Nfmk00E_
N`03001_Nfmk00M_N`03001_Nfmk00U_N`07001_NfmkKg/006mk00002fmk0`003Fmk00<006mkKg/0
0Vmk00<006mkKg/026mk00<006mkKg/00Vmk00<006mkKg/02Vmk1`0036mk00<006mkKg/01Fmk00<0
06mkKg/01Vmk00<006mkKg/01Vmk00<006mkKg/02Fmk00@006mkKg/000]_N`D000E_N`<001U_N`D0
0003Kg/0000000D001M_N`04001_N`000007Kg/00`00Kg]_N`0MKg/001e_N`03001_Nfmk01E_N`03
001_Nfmk009_N`03001_Nfmk019_N`8000A_N`03001_Nfmk00A_N`<0015_N`03001_Nfmk00]_N`80
00E_N`03001_Nfmk00Y_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`8000=_N`05
001_NfmkKg/0000:Kg/00`00Kg/0000=Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`03
Kg/00`00Kg]_N`0<Kg/5000<Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00
Kg]_N`0:Kg/30006Kg/5000<Kg/00`00Kg]_N`0FKg/00`00Kg/000020009Kg/7000AKg/30007Kg/0
0`00Kg]_N`0MKg/001i_N`03001_Nfmk01A_N`03001_Nfmk009_N`03001_Nfmk01A_N`D000=_N`<0
01A_N`03001_Nfmk00e_N`D000e_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00E_N`03
001_Nfmk00=_N`05001_NfmkKg/0000:Kg/01000Kg]_N`002fmk00<006mkKg/00fmk00<006mkKg/0
1Fmk0P001Vmk00<006mkKg/036mk1@003Fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/0
1Fmk00<006mkKg/02Fmk2P004Fmk00<006mkKg/056mk0P000fmk00<006mkKg/03fmk20002Fmk0`00
1Vmk00<006mkKg/07Vmk000NKg/00`00Kg]_N`0DKg/00`00Kg]_N`02Kg/00`00Kg]_N`0DKg/8000G
Kg/00`00Kg]_N`0>Kg/5000=Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/00fmk00<006mkKg/016mk
00D006mkKg]_N`0000U_N`05001_NfmkKg/0000;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`06Kg/00`00Kg]_N`0<Kg/400000fmk0000000;Kg/00`00Kg]_N`03Kg/00`00Kg]_N`09Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/5000EKg/00`00Kg]_N`0CKg/20005Kg/00`00Kg]_N`0GKg/7
00000fmk000000030005Kg/00`00Kg]_N`0NKg/001m_N`03001_Nfmk019_N`03001_Nfmk00=_N`03
001_Nfmk01A_N`D001U_N`03001_Nfmk00m_N`H000a_N`05001_NfmkKg/0000>Kg/50007Kg/00`00
Kg]_N`02Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/01000Kg]_N`0016mk0P002Fmk00<006mkKg/0
0Vmk00<006mkKg/02Vmk00<006mkKg/00fmk00<006mkKg/02Vmk1@005Fmk00<006mkKg/04Vmk00<0
06mkKg/01Fmk00<006mkKg/07Vmk1P001Fmk00<006mkKg/07Vmk000OKg/00`00Kg]_N`0BKg/00`00
Kg]_N`03Kg/00`00Kg]_N`0DKg/6000HKg/00`00Kg]_N`0?Kg/500000fmk000000040007Kg/3000>
Kg/50007Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`02Kg/00`00Kg]_N`07Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/20004Kg/00`00Kg]_N`03
Kg/20008Kg/01@00Kg]_Nfmk00003Fmk00<006mkKg/00Vmk00<006mkKg/026mk0P0000I_N`000000
06mk000DKg/00`00Kg]_N`0@Kg/20008Kg/00`00Kg]_N`0OKg/50005Kg/00`00Kg]_N`0NKg/0021_
N`03001_Nfmk015_N`03001_Nfmk00=_N`03001_Nfmk01E_N`<0009_N`8001I_N`03001_Nfmk00i_
N`H000M_N`/000M_N`/000M_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_
Nfmk00E_N`03001_Nfmk00I_N`04001_Nfmk000<Kg/00`00Kg]_N`07Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`05Kg/20006Kg/01000Kg]_N`003Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk0P0016mk00@0
06mkKg]_N`80019_N`03001_Nfmk00m_N`03001_Nfmk00U_N`03001_Nfmk01a_N`800004Kg/00000
0005Kg/00`00Kg]_N`0OKg/0021_N`03001_Nfmk011_N`03001_Nfmk00=_N`03001_Nfmk01A_N`80
009_N`03001_Nfmk009_N`8001=_N`03001_Nfmk00e_N`8000=_N`800003Kg/006mk00]_N``000I_
N`D000M_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_Nfmk00A_N`03001_Nfmk00E_N`03001_
Nfmk00E_N`@000e_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03001_Nfmk00M_N`8000A_N`04001_
Nfmk000?Kg/01000Kg]_N`001fmk0P001Vmk00<006mkKg/00fmk00<006mkKg/03fmk00<006mkKg/0
3Fmk0P0036mk00<006mkKg/06fmk00<006mkKg/00Vmk00<006mkKg/016mk00<006mkKg/07fmk000Q
Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0CKg/00`00Kg]_N`02Kg/00`00Kg]_N`04
Kg/2000AKg/00`00Kg]_N`0;Kg/20004Kg/00`00Kg/00002Kg/00`00Kg]_N`09Kg/5000>Kg/30007
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05
Kg/5000=Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/00`00Kg]_N`09Kg/20002Kg/3000@Kg/01000
Kg]_N`001Fmk0P0026mk00<006mkKg/016mk0P003fmk00<006mkKg/036mk00<006mkKg/036mk00<0
06mkKg/06Fmk0P001Fmk00<006mkKg/016mk00<006mkKg/07fmk000QKg/00`00Kg]_N`0?Kg/00`00
Kg]_N`03Kg/00`00Kg]_N`0BKg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/2000?Kg/00`00Kg]_N`09
Kg/20006Kg/00`00Kg/00002Kg/00`00Kg]_N`0:Kg/300000fmk0000000>Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/00`00Kg]_N`03Kg/00`00Kg]_N`05Kg/5
000=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0;Kg/6000@Kg/00`00Kg/00003Kg/2
000:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0:Kg/2000?Kg/00`00Kg]_N`0GKg/2
0007Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0OKg/0029_N`03001_Nfmk00i_N`03001_Nfmk00=_N`03
001_Nfmk015_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`8000e_N`03001_Nfmk00M_N`8000M_N`05
001_NfmkKg/00002Kg/00`00Kg]_N`09Kg/00`00Kg]_N`03Kg/2000=Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`05Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/01@00Kg]_Nfmk00001fmk1`0036mk00<006mk
Kg/00fmk00<006mkKg/026mk00<006mkKg/036mk1`003Vmk00@006mk001_N`8000a_N`03001_Nfmk
00M_N`8000a_N`03001_Nfmk00Q_N`80015_N`03001_Nfmk01E_N`8000U_N`03001_Nfmk00=_N`03
001_Nfmk021_N`008Vmk00<006mkKg/03Fmk00<006mkKg/016mk00<006mkKg/046mk00<006mkKg/0
1Fmk00<006mkKg/02Vmk0P002Vmk00<006mkKg/01Vmk0P002Fmk00D006mkKg]_N`0000=_N`03001_
Nfmk00Q_N`03001_Nfmk00E_N`8000]_N`03001_Nfmk00=_N`03001_Nfmk00M_N`05001_NfmkKg/0
000:Kg/01@00Kg]_Nfmk000016mk0`000Vmk0`000Vmk0`002Fmk00<006mkKg/00Vmk00<006mkKg/0
2Vmk00<006mkKg/02fmk1@000Vmk2P0016mk10003Vmk00<006mkKg/02Fmk0P002Vmk00<006mkKg/0
1fmk00<006mkKg/04Fmk00<006mkKg/056mk00<006mkKg/02Fmk00<006mkKg/00fmk00<006mkKg/0
86mk000SKg/00`00Kg]_N`0<Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`06Kg/00`00
Kg]_N`0<Kg/20008Kg/00`00Kg]_N`04Kg/2000:Kg/00`00Kg]_N`02Kg/01@00Kg]_Nfmk00002Vmk
00<006mkKg/01fmk0P002Vmk00<006mkKg/00Vmk00<006mkKg/01fmk00D006mkKg]_N`0000]_N`<0
009_N`<000I_N`03001_Nfmk00A_N`<000I_N`03001_Nfmk008000e_N`03001_Nfmk00]_N`@000e_
N`P000i_N`03001_Nfmk00]_N`03001_Nfmk00M_N`03001_Nfmk00E_N`8001A_N`03001_Nfmk019_
N`8000a_N`03001_Nfmk00=_N`03001_Nfmk021_N`008fmk00<006mkKg/036mk00<006mkKg/016mk
00<006mkKg/03Fmk0P002Vmk00<006mkKg/03Fmk0P001Vmk00<006mkKg/00Vmk0P0036mk00<006mk
Kg/00Vmk00<006mkKg/00Vmk00<006mkKg/01Vmk00<006mkKg/02Vmk0P0026mk00<006mkKg/00Vmk
00<006mkKg/01fmk00D006mkKg]_N`0000Y_N`H000U_N`03001_Nfmk00M_N`8000=_N`@000m_N`03
001_Nfmk00Y_N`05001_NfmkKg/0000@Kg/5000>Kg/00`00Kg]_N`0<Kg/20006Kg/00`00Kg]_N`05
Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0@Kg/2000>Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0PKg/002A_
N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk00m_
N`80009_N`<0009_N`8000e_N`03001_Nfmk00=_N`03001_Nfmk00=_N`03001_Nfmk00E_N`03001_
Nfmk00a_N`8000M_N`05001_NfmkKg/0000:Kg/00`00Kg/0000;Kg/5000:Kg/00`00Kg]_N`09Kg/7
000?Kg/00`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0>Kg/5000>Kg/00`00Kg]_N`0>Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`03Kg/2000GKg/00`00Kg]_N`0?Kg/00`00Kg]_N`0>Kg/00`00Kg]_
N`02Kg/00`00Kg]_N`0QKg/002A_N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk00]_N`03
001_Nfmk00]_N`03001_Nfmk015_N`L000m_N`03001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk
00A_N`03001_Nfmk00i_N`8000E_N`04001_Nfmk000;Kg/00`00Kg/00008Kg/8000:Kg/00`00Kg]_
N`0;Kg/5000?Kg/00`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0>Kg/4000>Kg/00`00Kg]_
N`0?Kg/20003Kg/01000Kg]_Nfmk0P006Fmk00<006mkKg/03Fmk0P004Fmk00<006mkKg/00Vmk00<0
06mkKg/08Fmk000UKg/00`00Kg]_N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<
Kg/00`00Kg]_N`0BKg/5000?Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00
Kg]_N`0@Kg/20004Kg/00`00Kg/0000;Kg/00`00Kg/00004Kg/40004Kg/3000;Kg/00`00Kg]_N`0;
Kg/5000?Kg/00`00Kg]_N`07Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`02Kg/00`00
Kg]_N`0;Kg/00`00Kg]_N`0AKg/00`00Kg/0000200000fmk001_N`0JKg/00`00Kg]_N`0;Kg/2000C
Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0QKg/002E_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`03001_
Nfmk00U_N`03001_Nfmk00e_N`03001_Nfmk019_N`D000m_N`03001_Nfmk00A_N`03001_Nfmk00E_
N`03001_Nfmk009_N`03001_Nfmk01=_N`80009_N`<000]_N`L000Q_N`04001_Nfmk000:Kg/00`00
Kg]_N`0;Kg/400000fmk0000000>Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/0
0`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0BKg/5000LKg/00`00Kg]_N`0:Kg/00`00Kg]_
N`0CKg/00`00Kg]_N`02Kg/00`00Kg]_N`0QKg/002I_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03
001_Nfmk00M_N`80011_N`03001_Nfmk019_N`@000m_N`03001_Nfmk00E_N`03001_Nfmk00I_N`05
001_NfmkKg/0000GKg/60005Kg/9000;Kg/01@00Kg]_Nfmk00002Fmk00<006mkKg/02Vmk00D006mk
Kg]_N`0000=_N`8000a_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03001_Nfmk00]_N`03001_Nfmk
00E_N`03001_Nfmk00Q_N`03001_Nfmk01=_N`D001e_N`03001_Nfmk00M_N`8001M_N`04001_Nfmk
000TKg/002I_N`03001_Nfmk00M_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk011_N`03
001_Nfmk015_N`05001_NfmkKg/0000?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`06Kg/01@00Kg]_Nfmk
00005fmk2`0016mk1@002Vmk00<006mkKg/00fmk00<006mkKg/01Vmk00<006mkKg/02Vmk00D006mk
Kg]_N`0000E_N`8000Y_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk00]_N`03001_Nfmk
00I_N`03001_Nfmk00M_N`03001_Nfmk01=_N`X001Q_N`03001_Nfmk00E_N`8001U_N`04001_Nfmk
000TKg/002M_N`03001_Nfmk00E_N`03001_Nfmk00M_N`03001_Nfmk00E_N`03001_Nfmk015_N`03
001_Nfmk011_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00M_N`03001_Nfmk00I_N`04
001_Nfmk000@Kg/700000fmk000000030009Kg/5000:Kg/00`00Kg]_N`03Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`09Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/20008Kg/00`00Kg]_N`03Kg/00`00Kg]_
N`0:Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0AKg/2000016mk
000000001Vmk1P004Vmk00<006mkKg/00fmk0P006fmk00@006mkKg/002A_N`009fmk00<006mkKg/0
1Fmk00<006mkKg/01fmk00<006mkKg/016mk00<006mkKg/04Vmk00<006mkKg/03fmk00<006mkKg/0
16mk00<006mkKg/02fmk00<006mkKg/01fmk00<006mkKg/01fmk0P002Vmk1`002Fmk10002Vmk0`00
2fmk00<006mkKg/016mk00<006mkKg/01Fmk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/0
1fmk0P001Vmk00<006mkKg/00Vmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mkKg/026mk00<0
06mkKg/01Vmk00<006mkKg/046mk00<006mkKg/00fmk00<006mkKg/02Vmk1@003Fmk00<006mkKg/0
0Vmk00<006mkKg/06fmk00@006mkKg/002A_N`00:6mk00<006mkKg/016mk00<006mkKg/01fmk00<0
06mkKg/00fmk00<006mkKg/04fmk00<006mkKg/03Vmk00<006mkKg/01Vmk00<006mkKg/02Fmk00<0
06mkKg/026mk00<006mkKg/01fmk0`000Vmk1`003fmk00<006mkKg/00Vmk00<006mkKg/02Fmk00<0
06mkKg/026mk00<006mkKg/01Vmk00<006mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/01Fmk00<0
06mkKg/026mk0P0016mk00D006mkKg]_N`0000i_N`03001_Nfmk00Q_N`03001_Nfmk00Y_N`03001_
Nfmk00E_N`03001_Nfmk00i_N`8000I_N`03001_Nfmk00m_N`D000Q_N`03001_Nfmk008001i_N`03
001_N`0002E_N`00:6mk00<006mkKg/00fmk00<006mkKg/026mk00<006mkKg/00Vmk00<006mkKg/0
56mk00<006mkKg/03Fmk00<006mkKg/01fmk00<006mkKg/02Fmk00<006mkKg/026mk00<006mkKg/0
1Vmk1P005Vmk00<006mkKg/00fmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mkKg/01fmk00<0
06mkKg/016mk00<006mkKg/01Fmk00<006mkKg/01Vmk00<006mkKg/02Vmk0P000Vmk100046mk00<0
06mkKg/01fmk00<006mkKg/02fmk00<006mkKg/016mk00<006mkKg/036mk0P0026mk00<006mkKg/0
56mk2`0086mk00<006mk00009Fmk000YKg/00`00Kg]_N`02Kg/00`00Kg]_N`08Kg/00`00Kg]_N`02
000GKg/00`00Kg]_N`0<Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_
N`06Kg/6000EKg/00`00Kg]_N`05Kg/20009Kg/00`00Kg]_N`07Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/6000@Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0=Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/2000;Kg/00`00Kg]_N`0HKg/6000PKg/0
0`00Kg/0000UKg/002U_N`03001_Nfmk009_N`03001_Nfmk00I_N`<00003Kg/006mk01Q_N`03001_
Nfmk00]_N`03001_Nfmk00Y_N`03001_Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk00I_N`D00003
Kg/00000019_N`03001_Nfmk00Q_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk00U_N`03
001_Nfmk00=_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00e_N`D0011_N`03001_Nfmk
00I_N`03001_Nfmk00e_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00]_N`03001_Nfmk
01Q_N`D00003Kg/0000000<001]_N`03001_N`0002E_N`00:Vmk00D006mkKg]_N`0000M_N`D001Y_
N`03001_Nfmk00Y_N`03001_Nfmk00a_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`03001_Nfmk00E_
N`03001_N`00008000A_N`80011_N`03001_Nfmk00U_N`03001_Nfmk00I_N`03001_Nfmk00E_N`03
001_Nfmk00Y_N`03001_Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03001_Nfmk00a_N`H0
011_N`03001_Nfmk00A_N`03001_Nfmk00m_N`03001_Nfmk009_N`03001_Nfmk00M_N`8000i_N`03
001_Nfmk01Q_N`D000I_N`D001I_N`8002I_N`00:Vmk00@006mkKg/000Q_N`D001Y_N`03001_Nfmk
00U_N`03001_Nfmk00e_N`03001_Nfmk00E_N`03001_Nfmk00Y_N`03001_Nfmk00E_N`03001_Nfmk
00Q_N`8000e_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk00E_N`03001_Nfmk00]_N`05
001_NfmkKg/00004Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/40002Kg/2000>Kg/00`00Kg]_N`04
Kg/00`00Kg]_N`0@Kg/01@00Kg]_Nfmk00001fmk0P0046mk00<006mkKg/05fmk00<006mk00000`00
2fmk1@004Fmk0P009Vmk000[Kg/00`00Kg/00007Kg/8000HKg/00`00Kg]_N`08Kg/00`00Kg]_N`0?
Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0;Kg/30009Kg/00`00
Kg]_N`0=Kg/00`00Kg]_N`04Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/01@00Kg]_Nfmk00000fmk
00<006mkKg/02fmk00<006mkKg/02fmk00D006mkKg]_N`0000A_N`<000]_N`03001_Nfmk00=_N`03
001_Nfmk019_N`04001_Nfmk0006Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0EKg/00`00Kg]_N`03Kg/0
0`00Kg]_N`0>Kg/5000<Kg/2000VKg/002]_N`<000=_N`@0009_N`@0009_N`<001E_N`03001_Nfmk
00M_N`03001_Nfmk011_N`03001_Nfmk00=_N`03001_Nfmk00]_N`03001_Nfmk00=_N`03001_Nfmk
00m_N`8000M_N`03001_Nfmk00i_N`03001_Nfmk00A_N`03001_Nfmk00=_N`03001_Nfmk00e_N`04
001_Nfmk0002Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`05Kg/2
000:Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0CKg/00`00Kg/00004Kg/2000DKg/00`00Kg]_N`0DKg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0BKg/50006Kg/3000VKg/002Y_N`L000U_N`03001_Nfmk00=_N`<0
01=_N`03001_Nfmk00E_N`03001_Nfmk019_N`05001_NfmkKg/0000?Kg/01@00Kg]_Nfmk000056mk
0P000Vmk0`004Vmk00<006mkKg/00fmk00<006mkKg/00fmk00<006mkKg/03Vmk00D006mk001_N`00
011_N`03001_Nfmk00Q_N`03001_Nfmk00A_N`03001_Nfmk00I_N`8000Q_N`05001_NfmkKg/0000F
Kg/400000fmk0000000FKg/00`00Kg]_N`0BKg/20008Kg/00`00Kg]_N`0GKg/:000UKg/002Y_N`D0
00a_N`03001_Nfmk00E_N`80015_N`03001_Nfmk00A_N`03001_Nfmk01=_N`05001_NfmkKg/0000?
Kg/01000Kg]_N`005fmk1P004Vmk00<006mkKg/00fmk00D006mkKg]_N`00019_N`@0011_N`03001_
Nfmk00M_N`03001_Nfmk00E_N`03001_Nfmk00Q_N`8000M_N`04001_Nfmk000FKg/5000HKg/00`00
Kg]_N`0AKg/00`00Kg]_N`08Kg/00`00Kg]_N`0LKg/5000UKg/002Y_N`D000a_N`03001_Nfmk00M_
N`<000i_N`03001_Nfmk00=_N`03001_Nfmk01E_N`03001_N`00011_N`03001_N`0001M_N`L001=_
N`03001_Nfmk009_N`05001_NfmkKg/0000AKg/5000@Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/0
0`00Kg]_N`0:Kg/30004Kg/00`00Kg/0000EKg/7000IKg/00`00Kg]_N`0?Kg/00`00Kg]_N`0:Kg/0
0`00Kg]_N`0KKg/5000UKg/002]_N`@000e_N`03001_Nfmk00U_N`<000]_N`03001_Nfmk009_N`03
001_Nfmk01I_N`<000m_N`@000e_N`X0009_N`X000m_N`80009_N`05001_NfmkKg/0000AKg/5000@
Kg/00`00Kg]_N`05Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0<Kg/200000fmk00000002000<Kg/90002
Kg/6000HKg/00`00Kg]_N`0>Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0KKg/4000VKg/002i_N`03001_
Nfmk00]_N`03001_Nfmk00a_N`8000U_N`05001_NfmkKg/0000HKg/5000=Kg/50003Kg/:000<Kg/4
0006Kg/5000<Kg/01P00Kg]_N`00Kg/000i_N``000i_N`03001_Nfmk00=_N`03001_Nfmk00U_N`03
001_Nfmk00i_N`D000=_N`T000a_N`<0009_N`<001E_N`03001_Nfmk00a_N`8000i_N`03001_Nfmk
01Y_N`03001_Nfmk02Q_N`00;fmk00<006mkKg/02fmk00<006mkKg/03Fmk0`001Vmk00@006mkKg/0
01I_Nad001E_N`05001_NfmkKg/0000;Kg/40009Kg/01@00Kg/006mk00002Vmk10001Fmk0`0016mk
0`002fmk00<006mkKg/00Vmk00<006mkKg/02Vmk00<006mkKg/03Vmk20005Fmk00<006mkKg/01Fmk
0`004fmk00<006mkKg/02Vmk00<006mkKg/03fmk00<006mkKg/066mk00<006mkKg/0:Fmk000`Kg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`0@Kg/30002Kg/4000=Kg/:0003Kg/5000=Kg/5000GKg/00`00Kg]_
N`02Kg/00`00Kg]_N`0=Kg/50005Kg/40005Kg/5000:Kg/00`00Kg]_N`06Kg/40007Kg/01@00Kg]_
Nfmk00003Vmk00<006mkKg/03Fmk1@0066mk00<006mkKg/026mk0P004Fmk00<006mkKg/02Fmk00<0
06mkKg/046mk00<006mkKg/066mk00<006mkKg/0:Fmk000aKg/00`00Kg]_N`0:Kg/00`00Kg]_N`0B
Kg/60003Kg/:000>Kg/300000fmk001_N`0<Kg/3000GKg/00`00Kg]_N`03Kg/00`00Kg]_N`0BKg/>
000>Kg/00`00Kg]_N`0;Kg/30004Kg/4000?Kg/00`00Kg]_N`0>Kg/300000fmk001_N`0FKg/00`00
Kg]_N`0:Kg/3000>Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0AKg/00`00Kg]_N`0GKg/00`00Kg]_N`0Z
Kg/0039_N`03001_Nfmk00U_N`03001_Nfmk01=_N`P001Q_N`03001_Nfmk009_N`03001_Nfmk00a_
N`03001_Nfmk01A_N`03001_Nfmk00E_N`03001_Nfmk01I_N`D0019_N`03001_Nfmk00i_N`P000m_
N`03001_Nfmk00i_N`05001_NfmkKg/0000FKg/00`00Kg]_N`0>Kg/2000<Kg/00`00Kg]_N`06Kg/2
000EKg/00`00Kg]_N`0EKg/00`00Kg]_N`0[Kg/0039_N`03001_Nfmk00U_N`03001_Nfmk01=_N`D0
01]_N`03001_Nfmk00=_N`8000e_N`03001_Nfmk019_N`03001_Nfmk00I_N`03001_Nfmk01E_N`H0
019_N`03001_Nfmk015_N`D0011_N`03001_Nfmk00e_N`03001_Nfmk009_N`03001_Nfmk01=_N`03
001_Nfmk011_N`<000Y_N`03001_Nfmk00A_N`03001_Nfmk01E_N`03001_Nfmk01A_N`03001_Nfmk
02a_N`00<fmk00<006mkKg/02Fmk00<006mkKg/04fmk10006fmk00<006mkKg/01Fmk00<006mkKg/0
2Vmk00<006mkKg/04Fmk00<006mkKg/01fmk00<006mkKg/04fmk0P000Vmk10004Vmk00<006mkKg/0
4Fmk1@0046mk00<006mkKg/036mk00<006mkKg/016mk00<006mkKg/04Vmk00<006mkKg/04fmk0P00
26mk00<006mkKg/00fmk00<006mkKg/05Vmk00<006mkKg/04fmk00<006mkKg/0;Fmk000dKg/00`00
Kg]_N`08Kg/00`00Kg]_N`0CKg/01@00Kg]_Nfmk00006Fmk00<006mkKg/01fmk0P002fmk00<006mk
Kg/03fmk00<006mkKg/02Fmk00<006mkKg/046mk0P0016mk00D006mkKg]_N`00015_N`03001_Nfmk
011_N`D00003Kg/006mk00i_N`03001_Nfmk00a_N`03001_Nfmk00E_N`03001_Nfmk015_N`03001_
Nfmk01E_N`<000E_N`03001_Nfmk009_N`03001_Nfmk01M_N`03001_Nfmk019_N`03001_Nfmk02i_
N`00=Fmk00<006mkKg/026mk00<006mkKg/04Vmk00<006mkKg/00Vmk00<006mkKg/05Vmk00<006mk
Kg/02Fmk00<006mkKg/026mk00<006mkKg/03Vmk00<006mkKg/02Vmk00<006mkKg/03Vmk0P001Vmk
00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/03fmk00D006mkKg]_N`0000=_N`03001_Nfmk
00e_N`03001_Nfmk00Y_N`03001_Nfmk00M_N`03001_Nfmk00m_N`03001_Nfmk01U_N`<00005Kg/0
0000001_N`02000KKg/00`00Kg]_N`0@Kg/00`00Kg]_N`0_Kg/003I_N`03001_Nfmk00M_N`03001_
Nfmk019_N`03001_Nfmk00=_N`03001_Nfmk01E_N`03001_Nfmk00Y_N`8000U_N`03001_Nfmk00a_
N`03001_Nfmk00]_N`03001_Nfmk00a_N`8000Q_N`03001_Nfmk00=_N`03001_Nfmk00e_N`03001_
Nfmk00i_N`03001_Nfmk009_N`03001_Nfmk009_N`8000e_N`03001_Nfmk00Y_N`03001_Nfmk00M_
N`03001_Nfmk00m_N`03001_Nfmk01a_N`D001e_N`03001_Nfmk00m_N`03001_Nfmk031_N`00=Vmk
00<006mkKg/026mk00<006mkKg/04Fmk00<006mkKg/016mk0P0056mk00<006mkKg/03Fmk00<006mk
Kg/01Vmk00<006mkKg/036mk00<006mkKg/036mk00<006mkKg/026mk0`002Vmk00<006mkKg/016mk
00<006mkKg/036mk00<006mkKg/036mk0P001Fmk00<006mkKg/016mk00<006mkKg/02fmk00<006mk
Kg/026mk00<006mkKg/02Fmk00<006mkKg/03Vmk00<006mkKg/076mk1@007Fmk00<006mkKg/03Vmk
00<006mkKg/0<Fmk000gKg/00`00Kg]_N`07Kg/00`00Kg]_N`0AKg/00`00Kg]_N`06Kg/00`00Kg]_
N`0AKg/00`00Kg]_N`0>Kg/00`00Kg]_N`06Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0=Kg/00`00Kg]_
N`06Kg/2000=Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`05Kg/0
0`00Kg]_N`05Kg/2000;Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0=Kg/00`00Kg]_
N`0LKg/7000LKg/00`00Kg]_N`0=Kg/00`00Kg]_N`0aKg/003Q_N`03001_Nfmk00M_N`03001_Nfmk
00m_N`03001_Nfmk00Q_N`03001_Nfmk011_N`03001_Nfmk00m_N`8000I_N`03001_Nfmk00U_N`03
001_Nfmk00i_N`03001_Nfmk00A_N`8000i_N`03001_Nfmk00M_N`03001_Nfmk00U_N`03001_Nfmk
00]_N`03001_Nfmk00I_N`03001_Nfmk00M_N`03001_Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk
00a_N`03001_Nfmk00]_N`03001_Nfmk01]_N`800004Kg/000000003Kg/3000IKg/00`00Kg]_N`0<
Kg/00`00Kg]_N`0bKg/003U_N`03001_Nfmk00I_N`03001_Nfmk00m_N`03001_Nfmk00U_N`03001_
Nfmk00m_N`03001_Nfmk015_N`03001_Nfmk00A_N`03001_Nfmk00M_N`03001_Nfmk00m_N`<0009_
N`80011_N`03001_Nfmk00Q_N`03001_Nfmk00Q_N`03001_Nfmk00U_N`8000U_N`03001_Nfmk00Q_
N`03001_Nfmk00Q_N`03001_Nfmk00E_N`03001_Nfmk00i_N`03001_Nfmk00Y_N`03001_Nfmk01Q_
N`<000E_N`03001_Nfmk00A_N`8001M_N`03001_Nfmk00]_N`03001_Nfmk03=_N`00>Vmk00<006mk
Kg/01Vmk00<006mkKg/03Vmk00<006mkKg/02Vmk00<006mkKg/03Fmk00<006mkKg/04fmk0P0016mk
00<006mkKg/01Vmk00<006mkKg/03fmk1P004Vmk00<006mkKg/02Fmk00<006mkKg/01fmk00<006mk
Kg/026mk00<006mkKg/02Fmk00<006mkKg/02Fmk0P0026mk00<006mkKg/01Fmk00<006mkKg/03Vmk
00<006mkKg/02Vmk00<006mkKg/05Vmk0P0026mk00<006mkKg/01Vmk0`005Fmk00<006mkKg/02Fmk
00<006mkKg/0=6mk000jKg/00`00Kg]_N`06Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0;Kg/00`00Kg]_
N`0<Kg/00`00Kg]_N`0EKg/00`00Kg]_N`02Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0@Kg/5000CKg/0
0`00Kg]_N`0:Kg/00`00Kg]_N`06Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0CKg/3
0009Kg/00`00Kg]_N`0:Kg/3000BKg/00`00Kg]_N`08Kg/00`00Kg]_N`0eKg/003]_N`03001_Nfmk
00I_N`03001_Nfmk00e_N`03001_Nfmk00a_N`03001_Nfmk00]_N`03001_Nfmk01I_N`80009_N`03
001_Nfmk00=_N`03001_Nfmk00a_N`X001=_N`03001_Nfmk00]_N`03001_Nfmk00E_N`03001_Nfmk
00E_N`8000e_N`03001_Nfmk00a_N`03001_Nfmk00E_N`03001_Nfmk00=_N`03001_Nfmk015_N`03
001_Nfmk00M_N`03001_Nfmk019_N`8000a_N`03001_Nfmk00e_N`80011_N`03001_Nfmk00M_N`03
001_Nfmk03I_N`00?6mk00<006mkKg/01Fmk00<006mkKg/03Fmk00<006mkKg/03Fmk00<006mkKg/0
2Vmk00<006mkKg/066mk00@006mkKg/000=_N`03001_Nfmk00Q_N`D000I_N`D0015_N`03001_Nfmk
00e_N`03001_Nfmk00A_N`03001_Nfmk00A_N`03001_Nfmk00e_N`03001_Nfmk00e_N`8000E_N`03
001_Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk00I_N`03001_Nfmk011_N`8000i_N`03001_Nfmk
00m_N`<000i_N`03001_Nfmk00E_N`03001_Nfmk03M_N`00?Fmk00<006mkKg/016mk00<006mkKg/0
36mk00<006mkKg/03fmk00<006mkKg/026mk00<006mkKg/06Vmk00<006mk00000`001Fmk1P002fmk
00<006mkKg/00Vmk00<006mkKg/03Vmk00<006mkKg/03Vmk00<006mkKg/00fmk00<006mkKg/00fmk
00<006mkKg/03fmk00<006mkKg/03Vmk00<006mkKg/00Vmk00<006mkKg/00Vmk00<006mkKg/056mk
00<006mkKg/01Fmk00<006mkKg/03Fmk0`0046mk00<006mkKg/04Vmk0P0036mk00<006mkKg/016mk
00<006mkKg/0>6mk000mKg/00`00Kg]_N`05Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0@Kg/00`00Kg]_
N`07Kg/00`00Kg]_N`0KKg/:000@Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`0?Kg/0
1@00Kg]_Nfmk000016mk0P004Vmk00<006mkKg/03fmk0P000fmk00@006mkKg/001M_N`03001_Nfmk
00E_N`03001_Nfmk00]_N`8001=_N`03001_Nfmk01A_N`<000U_N`03001_Nfmk00=_N`03001_Nfmk
03U_N`00?Vmk00<006mkKg/016mk00<006mkKg/02fmk00<006mkKg/04Fmk00<006mkKg/01Vmk00<0
06mkKg/06fmk1@005Fmk00<006mkKg/01Fmk00<006mkKg/036mk00<006mkKg/046mk00@006mkKg/0
00=_N`03001_Nfmk019_N`03001_Nfmk015_N`04001_Nfmk0002Kg/00`00Kg]_N`0FKg/00`00Kg]_
N`03Kg/00`00Kg]_N`0:Kg/2000EKg/00`00Kg]_N`0GKg/20008Kg/00`00Kg]_N`02Kg/00`00Kg]_
N`0iKg/003m_N`03001_Nfmk00A_N`03001_Nfmk00Y_N`03001_Nfmk019_N`8000E_N`03001_Nfmk
01I_N`/001E_N`03001_Nfmk00I_N`8000a_N`03001_Nfmk015_N`@00003Kg/006mk01A_N`03001_
Nfmk019_N`03001_N`00008001Y_N`03001_Nfmk009_N`03001_Nfmk00M_N`<001M_N`03001_Nfmk
01U_N`<000E_N`05001_NfmkKg/0000lKg/0041_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_
Nfmk01A_N`03001_Nfmk009_N`03001_Nfmk011_N`H000M_N`@001A_N`03001_Nfmk00U_N`03001_
Nfmk00U_N`03001_Nfmk015_N`D001I_N`03001_Nfmk01=_N`D001Y_N`05001_NfmkKg/00007Kg/2
000JKg/00`00Kg]_N`0LKg/30002Kg/4000mKg/0045_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03
001_Nfmk01I_N`05001_NfmkKg/0000=Kg/5000<Kg/01@00Kg]_Nfmk000056mk00<006mkKg/02Vmk
00<006mkKg/01fmk00<006mkKg/04Vmk1@005Vmk00<006mkKg/04fmk200066mk00@006mkKg/000A_
N`<001a_N`03001_Nfmk01m_N`H003e_N`00@Fmk00<006mkKg/00fmk00<006mkKg/026mk00<006mk
Kg/05fmk10001fmk1P004Fmk00<006mkKg/00Vmk00<006mkKg/04Fmk00<006mkKg/02fmk0P001fmk
00<006mkKg/03fmk30004Vmk00<006mkKg/046mk20000fmk2P003Vmk10000Vmk0P007fmk00<006mk
Kg/086mk1@00?Fmk0012Kg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0GKg/;000FKg/0
0`00Kg]_N`04Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0<Kg/3
0004Kg/30005Kg/4000>Kg/00`00Kg]_N`0<Kg/40004Kg/3000>Kg/;0003Kg/6000PKg/00`00Kg]_
N`0PKg/6000mKg/004=_N`03001_Nfmk009_N`03001_Nfmk00M_N`03001_Nfmk01M_N`D001a_N`03
001_Nfmk00E_N`03001_Nfmk00i_N`03001_Nfmk00m_N`03001_Nfmk00=_N`03001_Nfmk00U_N`<0
00Q_N`03001_Nfmk00Q_N`@000Y_N`03001_Nfmk00Q_N`@000Q_N`03001_N`0001U_N`P0025_N`03
001_Nfmk01e_N`@00004Kg/00000000nKg/004A_N`03001_Nfmk009_N`03001_Nfmk00I_N`03001_
Nfmk01I_N`H001]_N`03001_Nfmk00I_N`03001_Nfmk00e_N`03001_Nfmk015_N`03001_Nfmk009_
N`03001_Nfmk00E_N`@000]_N`03001_Nfmk00a_N`@000E_N`<000E_N`@000]_N`05001_NfmkKg/0
000KKg/6000PKg/00`00Kg]_N`0KKg/200000fmk001_N`13Kg/004E_N`05001_NfmkKg/00007Kg/0
0`00Kg]_N`0EKg/20002Kg/4000KKg/00`00Kg]_N`07Kg/00`00Kg]_N`0<Kg/00`00Kg]_N`0BKg/5
0004Kg/3000?Kg/00`00Kg]_N`0@Kg/=000?Kg/01@00Kg]_Nfmk00006fmk10000Vmk0`007Fmk00<0
06mkKg/06Fmk0P0000=_N`000000AFmk0015Kg/01@00Kg]_Nfmk00001fmk00<006mkKg/04fmk0P00
1Fmk00<006mk00006Vmk00<006mkKg/02Fmk00<006mkKg/02fmk00<006mkKg/04fmk20004fmk00<0
06mkKg/04fmk1@004Vmk00<006mkKg/00Vmk00<006mkKg/06Fmk00@006mkKg/000E_N`8001]_N`03
001_Nfmk01I_N`<0009_N`03001_Nfmk04E_N`00AVmk00D006mkKg]_N`0000I_N`03001_Nfmk015_
N`8000M_N`04001_Nfmk000HKg/00`00Kg]_N`0;Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0DKg/5000F
Kg/00`00Kg]_N`0CKg/5000BKg/00`00Kg]_N`03Kg/00`00Kg]_N`0GKg/01@00Kg]_Nfmk00001fmk
0`0066mk00<006mkKg/056mk0P000fmk0P00B6mk0017Kg/01000Kg]_N`001Vmk00<006mkKg/03fmk
0P002Fmk00D006mkKg]_N`0001M_N`03001_Nfmk00]_N`03001_Nfmk00U_N`03001_Nfmk01=_N`H0
01I_N`03001_Nfmk01=_N`@0019_N`03001_Nfmk00A_N`03001_Nfmk01I_N`03001_Nfmk009_N`03
001_Nfmk00Q_N`8001I_N`03001_Nfmk015_N`<000=_N`8004Y_N`00B6mk00@006mkKg/000E_N`03
001_Nfmk00e_N`8000]_N`03001_Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk00e_N`03001_Nfmk
00M_N`03001_Nfmk015_N`<0009_N`@001I_N`03001_Nfmk019_N`05001_NfmkKg/0000BKg/00`00
Kg]_N`04Kg/00`00Kg]_N`0EKg/00`00Kg]_N`03Kg/00`00Kg]_N`0:Kg/3000CKg/00`00Kg]_N`0?
Kg/20005Kg/00`00Kg]_N`1:Kg/004U_N`03001_N`0000E_N`03001_Nfmk00]_N`8000e_N`03001_
Nfmk009_N`03001_Nfmk01=_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk00i_N`<000I_
N`03001_Nfmk008001A_N`03001_Nfmk015_N`03001_Nfmk009_N`03001_Nfmk00m_N`03001_Nfmk
00I_N`03001_Nfmk01=_N`03001_Nfmk00E_N`03001_Nfmk00a_N`80015_N`03001_Nfmk00a_N`<0
00E_N`8004e_N`00BFmk00@006mkKg/000=_N`03001_Nfmk00Y_N`80011_N`03001_Nfmk009_N`03
001_Nfmk015_N`03001_Nfmk011_N`03001_Nfmk00E_N`03001_Nfmk00a_N`8000U_N`03001_Nfmk
009_N`03001_Nfmk015_N`03001_Nfmk011_N`03001_Nfmk00=_N`03001_Nfmk00m_N`03001_Nfmk
00I_N`03001_Nfmk01=_N`03001_Nfmk00E_N`03001_Nfmk00i_N`<000i_N`03001_Nfmk00Y_N`80
00I_N`8004m_N`00BVmk00<006mk00000fmk00<006mkKg/026mk0P004Vmk00<006mkKg/00fmk00<0
06mkKg/046mk00<006mkKg/046mk00<006mkKg/016mk00<006mkKg/02Vmk0`002fmk00<006mkKg/0
0fmk00<006mkKg/046mk00<006mkKg/03fmk00<006mkKg/016mk00<006mkKg/03Vmk00<006mkKg/0
26mk00<006mkKg/04Fmk00<006mkKg/01Vmk00<006mkKg/04Fmk0P002fmk00<006mkKg/026mk0`00
1fmk00<006mkKg/0Cfmk001;Kg/00`00Kg/00002Kg/00`00Kg]_N`06Kg/2000DKg/00`00Kg]_N`04
Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`0BKg/00`00Kg]_N`03Kg/00`00Kg]_N`07Kg/3000>Kg/00`00
Kg]_N`04Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0=Kg/00`00
Kg]_N`08Kg/00`00Kg]_N`0@Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0CKg/30008Kg/00`00Kg]_N`06
Kg/20008Kg/2001BKg/004a_N`80009_N`03001_Nfmk00A_N`8001I_N`03001_Nfmk00E_N`03001_
Nfmk00e_N`03001_Nfmk01=_N`03001_Nfmk009_N`03001_Nfmk00E_N`80015_N`03001_Nfmk00E_
N`03001_Nfmk00i_N`03001_Nfmk00i_N`03001_Nfmk00I_N`03001_Nfmk00a_N`03001_Nfmk00U_
N`03001_Nfmk00m_N`03001_Nfmk00U_N`03001_Nfmk01E_N`8000I_N`03001_Nfmk00A_N`8000U_
N`03001_Nfmk059_N`00CFmk0P0000=_N`00Kg/00fmk0P0066mk00<006mkKg/01Fmk00<006mkKg/0
36mk00<006mkKg/05Fmk00@006mkKg/000E_N`<001=_N`03001_Nfmk00I_N`03001_Nfmk00e_N`03
001_Nfmk00e_N`03001_Nfmk00M_N`03001_Nfmk00a_N`03001_Nfmk00Y_N`03001_Nfmk00e_N`03
001_Nfmk00Y_N`03001_Nfmk01M_N`<0009_N`<0009_N`<000U_N`8005E_N`00CFmk10000Vmk0P00
6Vmk00<006mkKg/01Vmk00<006mkKg/02fmk00<006mkKg/05Fmk10000Vmk0`005Vmk00<006mkKg/0
1fmk0P003Vmk00<006mkKg/02fmk00<006mkKg/026mk00<006mkKg/02fmk00<006mkKg/02fmk00<0
06mkKg/036mk00<006mkKg/02fmk00<006mkKg/06Vmk1`002Vmk0P00Efmk001=Kg/6000LKg/00`00
Kg]_N`07Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0FKg/6000IKg/00`00Kg]_N`09Kg/00`00Kg]_N`0;
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0<
Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0KKg/5000:Kg/00`00Kg]_N`1GKg/004e_N`D001e_N`03001_
Nfmk00Q_N`03001_Nfmk00M_N`03001_Nfmk01M_N`D001Y_N`03001_Nfmk00Y_N`03001_Nfmk00Y_
N`03001_Nfmk00U_N`03001_Nfmk00]_N`03001_Nfmk00U_N`03001_Nfmk00e_N`03001_Nfmk00Y_
N`03001_Nfmk00e_N`03001_Nfmk01Y_N`D000Q_N`8005Y_N`00CFmk1@007Fmk00<006mkKg/02Fmk
00<006mkKg/01Vmk00<006mkKg/056mk20006Vmk00<006mkKg/02fmk00<006mkKg/02Fmk00<006mk
Kg/026mk00<006mkKg/036mk00<006mkKg/02Fmk00<006mkKg/03Fmk00<006mkKg/02Fmk00<006mk
Kg/03Vmk00<006mkKg/06Vmk10001fmk0P00G6mk001>Kg/5000LKg/00`00Kg]_N`09Kg/00`00Kg]_
N`05Kg/00`00Kg]_N`0AKg/40004Kg/300000fmk0000000HKg/00`00Kg]_N`0<Kg/00`00Kg]_N`08
Kg/00`00Kg]_N`07Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0>Kg/00`00Kg]_N`07
Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`0IKg/00`00Kg]_N`08Kg/00`00Kg]_N`1LKg/005=_N`03001_
Nfmk01U_N`03001_Nfmk00Y_N`03001_Nfmk00A_N`03001_Nfmk00e_N`@000U_N`03001_Nfmk009_
N`8001E_N`03001_Nfmk00i_N`8000Q_N`03001_Nfmk00I_N`03001_Nfmk00i_N`03001_Nfmk00Q_
N`03001_Nfmk00m_N`03001_Nfmk00I_N`03001_Nfmk011_N`03001_Nfmk01Q_N`03001_Nfmk00M_
N`8005m_N`00E6mk00<006mkKg/066mk00<006mkKg/02fmk00<006mkKg/00Vmk00<006mkKg/02Vmk
10003Fmk00<006mkKg/016mk00<006mkKg/04Vmk00<006mkKg/046mk00<006mkKg/01Fmk00<006mk
Kg/01Fmk00<006mkKg/046mk00<006mkKg/01fmk00<006mkKg/03fmk00<006mkKg/01Vmk00<006mk
Kg/046mk00<006mkKg/05fmk00<006mkKg/01fmk00<006mkKg/0Gfmk001EKg/00`00Kg]_N`0GKg/0
0`00Kg]_N`0<Kg/01@00Kg]_Nfmk000026mk100046mk00<006mkKg/01Vmk0P004Vmk00<006mkKg/0
4Fmk00<006mkKg/016mk00<006mkKg/016mk00<006mkKg/04Fmk00<006mkKg/01Vmk00<006mkKg/0
4Fmk00<006mkKg/016mk00<006mkKg/04Vmk00<006mkKg/056mk0P0026mk0P00HVmk001FKg/2000G
Kg/00`00Kg]_N`0<Kg/40005Kg/4000DKg/00`00Kg]_N`08Kg/2000@Kg/00`00Kg]_N`0BKg/00`00
Kg]_N`03Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0BKg/00`00Kg]_N`06Kg/00`00Kg]_N`0AKg/00`00
Kg]_N`03Kg/00`00Kg]_N`0CKg/00`00Kg]_N`0CKg/00`00Kg]_N`06Kg/2001TKg/005Q_N`03001_
Nfmk01E_N`03001_Nfmk00]_N`T001Q_N`03001_Nfmk00Y_N`8000i_N`03001_Nfmk01=_N`03001_
Nfmk009_N`03001_Nfmk00=_N`03001_Nfmk019_N`03001_Nfmk00E_N`03001_Nfmk019_N`03001_
Nfmk009_N`03001_Nfmk01A_N`03001_Nfmk019_N`03001_Nfmk00I_N`03001_Nfmk06A_N`00FFmk
00<006mkKg/056mk00<006mkKg/02fmk1@0076mk00<006mkKg/036mk00<006mkKg/02fmk00<006mk
Kg/056mk00<006mkKg/00Vmk00D006mkKg]_N`0001I_N`03001_Nfmk00A_N`03001_Nfmk01=_N`04
001_Nfmk000GKg/00`00Kg]_N`0AKg/00`00Kg]_N`05Kg/2001WKg/005Y_N`03001_Nfmk01=_N`03
001_Nfmk00]_N`D001a_N`03001_Nfmk00e_N`8000]_N`03001_Nfmk01E_N`80009_N`04001_Nfmk
000GKg/00`00Kg]_N`03Kg/00`00Kg]_N`0DKg/4000HKg/00`00Kg]_N`0?Kg/00`00Kg]_N`04Kg/2
001YKg/005]_N`8001=_N`03001_Nfmk00]_N`D001a_N`03001_Nfmk00m_N`8000U_N`03001_Nfmk
01M_N`D001Q_N`03001_Nfmk00=_N`03001_Nfmk01=_N`D001Q_N`03001_Nfmk00i_N`03001_Nfmk
00A_N`03001_Nfmk06U_N`00GFmk00<006mkKg/046mk00<006mkKg/02fmk00<006mkKg/00Vmk00<0
06mkKg/06Fmk00<006mkKg/04Fmk0P001fmk00<006mkKg/05fmk1@0066mk00<006mkKg/00Vmk00<0
06mkKg/056mk1@0066mk00<006mkKg/03Fmk00<006mkKg/00fmk0P00K6mk001NKg/00`00Kg]_N`0?
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`04Kg/2000IKg/00`00Kg]_N`0CKg/00`00Kg]_N`04Kg/00`00
Kg]_N`0FKg/6000IKg/01@00Kg]_Nfmk00004fmk2@005fmk00<006mkKg/036mk00<006mkKg/00fmk
00<006mkKg/0K6mk001OKg/00`00Kg]_N`0>Kg/00`00Kg]_N`09Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`0EKg/00`00Kg]_N`0EKg/20004Kg/00`00Kg]_N`0?Kg/700000fmk00000008000DKg/01000Kg]_
N`0046mk10000fmk10000Vmk0`005Fmk00<006mkKg/02Vmk00<006mkKg/00Vmk0P00Kfmk001PKg/2
000>Kg/00`00Kg]_N`08Kg/00`00Kg]_N`09Kg/00`00Kg]_N`0DKg/00`00Kg]_N`0GKg/5000:Kg/7
0009Kg/30006Kg/5000?Kg/01000Kg]_N`0036mk10001Vmk00<006mkKg/01fmk0P004fmk00<006mk
Kg/02Fmk00@006mkKg]_N`80075_N`00HVmk00<006mkKg/02fmk00<006mkKg/01fmk00<006mkKg/0
2fmk00<006mkKg/04fmk00<006mkKg/066mk1@000Vmk1`003fmk00<006mk000036mk10002fmk00<0
06mk00002Fmk10002Fmk00<006mkKg/02Vmk0`0046mk00<006mkKg/026mk00D006mkKg]_N`0007=_
N`00Hfmk00<006mkKg/02Vmk00<006mkKg/01fmk00<006mkKg/036mk00<006mkKg/04Vmk00<006mk
Kg/066mk1`005Vmk00@006mkKg/000m_N`D000I_N`<000E_N`@000a_N`03001_Nfmk00i_N`8000i_
N`03001_Nfmk00M_N`03001_Nfmk008007A_N`00I6mk0P002Vmk00<006mkKg/01Vmk00<006mkKg/0
3Vmk00<006mkKg/04Fmk00<006mkKg/066mk1@005fmk00D006mkKg]_N`0001A_N`h000m_N`03001_
Nfmk015_N`<000a_N`03001_Nfmk00A_N`800003Kg/0000007I_N`00IVmk00<006mkKg/01fmk00<0
06mkKg/01Fmk00<006mkKg/046mk00<006mkKg/046mk00<006mkKg/05fmk1@0066mk00D006mkKg]_
N`0001U_N`D0019_N`03001_Nfmk01E_N`8000Y_N`03001_Nfmk00=_N`04001_Nfmk001hKg/006M_
N`03001_Nfmk00I_N`03001_Nfmk00A_N`03001_Nfmk019_N`03001_Nfmk00m_N`03001_Nfmk01E_
N`8000E_N`03001_Nfmk01A_N`03001_Nfmk009_N`03001_Nfmk01M_N`D0015_N`03001_Nfmk01Q_
N`<000M_N`03001_Nfmk009_N`04001_N`00001iKg/006Q_N`03001_Nfmk00E_N`03001_Nfmk00A_
N`03001_Nfmk01=_N`03001_Nfmk00i_N`03001_Nfmk01=_N`8000M_N`03001_Nfmk01A_N`03001_
Nfmk009_N`03001_Nfmk01M_N`@0015_N`03001_Nfmk01a_N`8000E_N`07001_NfmkKg/006mk0000
Nfmk001YKg/20006Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0EKg/2000=Kg/00`00Kg]_N`0BKg/20009
Kg/00`00Kg]_N`0CKg/00`00Kg]_N`03Kg/00`00Kg]_N`0GKg/2000BKg/00`00Kg]_N`0OKg/30002
Kg/6001lKg/006]_N`03001_Nfmk00=_N`05001_NfmkKg/0000JKg/00`00Kg]_N`0:Kg/00`00Kg]_
N`0@Kg/2000;Kg/00`00Kg]_N`0CKg/00`00Kg]_N`03Kg/00`00Kg]_N`0FKg/00`00Kg/0000BKg/0
0`00Kg]_N`0RKg/6001nKg/006a_N`03001_Nfmk009_N`04001_Nfmk000LKg/00`00Kg]_N`09Kg/0
0`00Kg]_N`0>Kg/2000>Kg/00`00Kg]_N`0AKg/00`00Kg]_N`04Kg/00`00Kg]_N`0EKg/00`00Kg/0
000BKg/00`00Kg]_N`0TKg/5001nKg/006e_N`07001_NfmkKg/006mk00007Vmk00<006mkKg/026mk
00<006mkKg/03Fmk00<006mkKg/03Vmk00<006mkKg/04Fmk00<006mkKg/01Fmk00<006mkKg/04fmk
00@006mkKg/0015_N`03001_Nfmk02A_N`H007i_N`00KVmk1P007fmk00<006mkKg/01fmk00<006mk
Kg/02fmk0P004Fmk00<006mkKg/046mk00<006mkKg/01Vmk00<006mkKg/04fmk00@006mkKg/0011_
N`03001_Nfmk02=_N`80009_N`<007m_N`00Kfmk1@0086mk00<006mkKg/01Vmk00<006mkKg/02Fmk
0P004fmk00<006mkKg/046mk00<006mkKg/01Vmk00<006mkKg/04Vmk00@006mkKg/0011_N`03001_
Nfmk025_N`<008I_N`00Kfmk1P0086mk00<006mkKg/01Fmk00<006mkKg/01fmk0P005Vmk00<006mk
Kg/03Vmk00<006mkKg/01fmk00<006mkKg/04Fmk00D006mkKg]_N`0000m_N`03001_Nfmk021_N`80
08U_N`00Kfmk3@006Vmk00<006mkKg/016mk00<006mkKg/01Fmk0P0066mk00<006mkKg/03Vmk00<0
06mkKg/01fmk00<006mkKg/046mk00<006mkKg/00Vmk00<006mkKg/036mk00<006mkKg/07Vmk0`00
Rfmk001`Kg/30004Kg/400000fmk00000005000DKg/20003Kg/00`00Kg]_N`04Kg/2000JKg/00`00
Kg]_N`0=Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0<Kg/00`00
Kg]_N`0MKg/2002>Kg/007]_N`<000E_N`P000i_N`04001_Nfmk0004Kg/2000LKg/00`00Kg]_N`0=
Kg/00`00Kg]_N`08Kg/00`00Kg]_N`0?Kg/00`00Kg]_N`02Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0L
Kg/2002@Kg/007i_N`@000U_N`L000Q_N`@00003Kg/0000001m_N`03001_Nfmk00]_N`03001_Nfmk
00Y_N`03001_Nfmk00e_N`03001_Nfmk00=_N`03001_Nfmk00Y_N`03001_Nfmk01Y_N`<0099_N`00
PVmk0`003Fmk1`0000=_N`0000000`008Fmk00<006mkKg/02Vmk00<006mkKg/02fmk00<006mkKg/0
36mk00<006mkKg/00fmk00<006mkKg/02Vmk00<006mkKg/06Fmk0P00UFmk0025Kg/4000@Kg/6000Q
Kg/00`00Kg]_N`0:Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`0;Kg/00`00Kg]_N`04Kg/00`00Kg]_N`09
Kg/00`00Kg]_N`0HKg/2002GKg/008U_N`@000e_N`H0021_N`03001_Nfmk00U_N`03001_Nfmk00a_
N`03001_Nfmk00]_N`03001_Nfmk00A_N`03001_Nfmk00Q_N`03001_Nfmk01I_N`<009U_N`00SFmk
0`002fmk0`000Vmk0P007Vmk00<006mkKg/02Fmk00<006mkKg/036mk00<006mkKg/02Vmk00<006mk
Kg/016mk00<006mkKg/026mk00<006mkKg/05Fmk0P00W6mk002@Kg/4000>Kg/3000LKg/00`00Kg]_
N`07Kg/00`00Kg]_N`0=Kg/00`00Kg]_N`09Kg/00`00Kg]_N`05Kg/00`00Kg]_N`07Kg/00`00Kg]_
N`0CKg/3002NKg/009A_N`<000i_N`8001Y_N`03001_Nfmk00M_N`03001_Nfmk00e_N`03001_Nfmk
00Q_N`03001_Nfmk00I_N`03001_Nfmk00I_N`03001_Nfmk019_N`800:5_N`00Ufmk100036mk0P00
66mk00<006mkKg/01Vmk00<006mkKg/03fmk00<006mkKg/01fmk00<006mkKg/01Vmk00<006mkKg/0
1Fmk00<006mkKg/04Fmk0P00Xfmk002KKg/4000:Kg/3000EKg/00`00Kg]_N`06Kg/00`00Kg]_N`0?
Kg/00`00Kg]_N`06Kg/00`00Kg]_N`06Kg/00`00Kg]_N`05Kg/00`00Kg]_N`0?Kg/3002UKg/009m_
N`<000Y_N`8001A_N`03001_Nfmk00A_N`03001_Nfmk011_N`03001_Nfmk00E_N`03001_Nfmk00M_
N`03001_Nfmk00A_N`03001_Nfmk00i_N`800:Q_N`00XVmk100026mk0P004Vmk00<006mkKg/016mk
00<006mkKg/046mk00<006mkKg/016mk00<006mkKg/026mk00<006mkKg/00fmk00<006mkKg/036mk
0`00ZVmk002VKg/30007Kg/3000?Kg/00`00Kg]_N`03Kg/00`00Kg]_N`0AKg/00`00Kg]_N`03Kg/0
0`00Kg]_N`08Kg/00`00Kg]_N`04Kg/00`00Kg]_N`0:Kg/2002]Kg/00:U_N`@000I_N`8000e_N`03
001_Nfmk00=_N`03001_Nfmk015_N`03001_Nfmk00=_N`03001_Nfmk00Q_N`03001_Nfmk00=_N`03
001_Nfmk00U_N`800:m_N`00[Fmk100016mk0`002fmk00D006mkKg]_N`0001A_N`03001_Nfmk009_
N`03001_Nfmk00U_N`03001_Nfmk009_N`03001_Nfmk00M_N`<00;5_N`00/Fmk0`0016mk0P002Fmk
00D006mkKg]_N`0001A_N`05001_NfmkKg/0000;Kg/00`00Kg]_N`02Kg/00`00Kg]_N`06Kg/2002d
Kg/00;A_N`@0009_N`8000M_N`04001_Nfmk000FKg/00`00Kg/0000<Kg/01@00Kg]_Nfmk00001fmk
0P00]Vmk002hKg/3000016mk0000000016mk00@006mkKg/001E_N`@000a_N`04001_Nfmk0005Kg/3
002hKg/00;]_N`H00003Kg/00000008001E_N`D000]_N`04001_Nfmk0004Kg/2002kKg/00;m_N`L0
00]_N`l000]_N`03001_N`00009_N`<00;e_N`00`Fmk40002Vmk2@001Fmk100000=_N`000000`6mk
0031Kg/50008Kg/C0003Kg/:0032Kg/00<9_N`<001a_N``00<=_N`00j6mk1@00`fmk003YKg/30034
Kg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00
ofmk/Fmk003oKg^aKg/00?m_Nk5_N`00\
\>"],
  ImageRangeCache->{{{0, 431}, {431, 0}} -> {-2.22702, -2.12808, 0.0153388, \
0.0153388}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[107]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Good Enough?", "Section"],

Cell["\<\
There are many ways to define and combine the termination criteria. \
\>", "Text"],

Cell[TextData[{
  "A convenient way for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " would be, i.e. if two latest iterations output nearly equal locations, \
the program doesn't go any further. (Like ",
  StyleBox["step 8",
    FontSlant->"Italic"],
  " in the paper, we only choose interior meshpoints to compare.)"
}], "Text"],

Cell[BoxData[
    \(goodEnough[p1_, p2_, eps_] := 
      Max[Norm /@ \((Extract[\((p2 - p1)\), 
                Position[p2, _?\((d[#] < 0 &)\)]])\)] < eps\)], "Input",
  CellLabel->"In[108]:="],

Cell["\<\
Now we can assembly the whole program as predicted in the \"overview\" \
section. (It may take a while to run depending on the speed of your \
computer.)\
\>", "Text"],

Cell[BoxData[
    \(\(pp2 = 
        NestWhile[forcemove, p2, \(! \((goodEnough[#1, #2, 0.02])\)\) &, 2, 
          50];\)\)], "Input",
  CellLabel->"In[109]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[pp2, AspectRatio \[Rule] Automatic, \ 
      PlotStyle \[Rule] {PointSize[0.02], RGBColor[1, 0, 0]}]\)], "Input",
  CellLabel->"In[111]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99054 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500043 0.218785 0.487486 0.218785 [
[.06247 .47499 -6 -9 ]
[.06247 .47499 6 0 ]
[.28126 .47499 -6 -9 ]
[.28126 .47499 6 0 ]
[.71883 .47499 -3 -9 ]
[.71883 .47499 3 0 ]
[.93761 .47499 -3 -9 ]
[.93761 .47499 3 0 ]
[.48754 .04992 -12 -4.5 ]
[.48754 .04992 0 4.5 ]
[.48754 .2687 -12 -4.5 ]
[.48754 .2687 0 4.5 ]
[.48754 .70627 -6 -4.5 ]
[.48754 .70627 0 4.5 ]
[.48754 .92506 -6 -4.5 ]
[.48754 .92506 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99054 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06247 .48749 m
.06247 .49374 L
s
[(-2)] .06247 .47499 0 1 Mshowa
.28126 .48749 m
.28126 .49374 L
s
[(-1)] .28126 .47499 0 1 Mshowa
.71883 .48749 m
.71883 .49374 L
s
[(1)] .71883 .47499 0 1 Mshowa
.93761 .48749 m
.93761 .49374 L
s
[(2)] .93761 .47499 0 1 Mshowa
.125 Mabswid
.10623 .48749 m
.10623 .49124 L
s
.14999 .48749 m
.14999 .49124 L
s
.19374 .48749 m
.19374 .49124 L
s
.2375 .48749 m
.2375 .49124 L
s
.32502 .48749 m
.32502 .49124 L
s
.36877 .48749 m
.36877 .49124 L
s
.41253 .48749 m
.41253 .49124 L
s
.45629 .48749 m
.45629 .49124 L
s
.5438 .48749 m
.5438 .49124 L
s
.58756 .48749 m
.58756 .49124 L
s
.63131 .48749 m
.63131 .49124 L
s
.67507 .48749 m
.67507 .49124 L
s
.76258 .48749 m
.76258 .49124 L
s
.80634 .48749 m
.80634 .49124 L
s
.8501 .48749 m
.8501 .49124 L
s
.89386 .48749 m
.89386 .49124 L
s
.01872 .48749 m
.01872 .49124 L
s
.98137 .48749 m
.98137 .49124 L
s
.25 Mabswid
0 .48749 m
1 .48749 L
s
.50004 .04992 m
.50629 .04992 L
s
[(-2)] .48754 .04992 1 0 Mshowa
.50004 .2687 m
.50629 .2687 L
s
[(-1)] .48754 .2687 1 0 Mshowa
.50004 .70627 m
.50629 .70627 L
s
[(1)] .48754 .70627 1 0 Mshowa
.50004 .92506 m
.50629 .92506 L
s
[(2)] .48754 .92506 1 0 Mshowa
.125 Mabswid
.50004 .09367 m
.50379 .09367 L
s
.50004 .13743 m
.50379 .13743 L
s
.50004 .18119 m
.50379 .18119 L
s
.50004 .22494 m
.50379 .22494 L
s
.50004 .31246 m
.50379 .31246 L
s
.50004 .35621 m
.50379 .35621 L
s
.50004 .39997 m
.50379 .39997 L
s
.50004 .44373 m
.50379 .44373 L
s
.50004 .53124 m
.50379 .53124 L
s
.50004 .575 m
.50379 .575 L
s
.50004 .61876 m
.50379 .61876 L
s
.50004 .66251 m
.50379 .66251 L
s
.50004 .75003 m
.50379 .75003 L
s
.50004 .79378 m
.50379 .79378 L
s
.50004 .83754 m
.50379 .83754 L
s
.50004 .8813 m
.50379 .8813 L
s
.50004 .00616 m
.50379 .00616 L
s
.50004 .96881 m
.50379 .96881 L
s
.25 Mabswid
.50004 0 m
.50004 .99054 L
s
0 0 m
1 0 L
1 .99054 L
0 .99054 L
closepath
clip
newpath
1 0 0 r
.02 w
.6311 .04607 Mdot
.38162 .02358 Mdot
.45899 .02455 Mdot
.53423 .03725 Mdot
.31842 .04636 Mdot
.66622 .05507 Mdot
.22286 .09779 Mdot
.25635 .0755 Mdot
.33528 .08298 Mdot
.40914 .08914 Mdot
.48562 .10319 Mdot
.57442 .10361 Mdot
.69412 .08741 Mdot
.80677 .12305 Mdot
.17581 .13722 Mdot
.27716 .13233 Mdot
.42355 .14965 Mdot
.63089 .13813 Mdot
.21297 .1721 Mdot
.53702 .15077 Mdot
.58688 .18686 Mdot
.76735 .12329 Mdot
.34635 .16031 Mdot
.48159 .17098 Mdot
.53016 .20812 Mdot
.68449 .1685 Mdot
.68255 .23306 Mdot
.74351 .19421 Mdot
.84045 .16689 Mdot
.33087 .22409 Mdot
.39174 .19588 Mdot
.44316 .21103 Mdot
.62918 .21872 Mdot
.11508 .20691 Mdot
.28056 .2047 Mdot
.37386 .24236 Mdot
.41568 .25317 Mdot
.4877 .23123 Mdot
.79442 .23154 Mdot
.141 .21585 Mdot
.21312 .24524 Mdot
.26894 .26338 Mdot
.4555 .26635 Mdot
.51746 .26543 Mdot
.63598 .27739 Mdot
.90335 .23936 Mdot
.31942 .27289 Mdot
.36518 .28794 Mdot
.48761 .28821 Mdot
.56327 .24166 Mdot
.73369 .2609 Mdot
.86879 .23882 Mdot
.16154 .29699 Mdot
.405 .29367 Mdot
.44084 .30461 Mdot
.54897 .29176 Mdot
.59443 .26985 Mdot
.67993 .29019 Mdot
.74026 .31087 Mdot
.8014 .29205 Mdot
.09165 .25942 Mdot
.22627 .31065 Mdot
.28741 .31358 Mdot
.33612 .32092 Mdot
.39842 .3283 Mdot
.48231 .31963 Mdot
.52253 .31803 Mdot
.57232 .31774 Mdot
.60432 .32256 Mdot
.63465 .33056 Mdot
.07699 .31621 Mdot
.2792 .3479 Mdot
.37489 .34396 Mdot
.42203 .35667 Mdot
.44492 .33693 Mdot
.48345 .35002 Mdot
.5179 .35017 Mdot
.58528 .36235 Mdot
.6684 .33921 Mdot
.7092 .33763 Mdot
.86747 .31735 Mdot
.04247 .35534 Mdot
.19596 .36367 Mdot
.24419 .36976 Mdot
.30497 .37101 Mdot
.33673 .35767 Mdot
.4659 .36945 Mdot
.55269 .34949 Mdot
.78734 .3468 Mdot
.94596 .3186 Mdot
.9581 .34882 Mdot
.13669 .36155 Mdot
.27258 .40877 Mdot
.35068 .38764 Mdot
.50774 .37761 Mdot
.54057 .38259 Mdot
.6165 .37484 Mdot
.65275 .37794 Mdot
.69961 .38161 Mdot
.74666 .37602 Mdot
.8345 .37804 Mdot
.90827 .38211 Mdot
.07101 .39985 Mdot
.31605 .40786 Mdot
.37664 .39263 Mdot
.39814 .37736 Mdot
.42146 .39979 Mdot
.44265 .38286 Mdot
.46139 .40868 Mdot
.48116 .39384 Mdot
.50665 .40829 Mdot
.53024 .4094 Mdot
.56736 .39255 Mdot
.85021 .44032 Mdot
.34559 .42967 Mdot
.38307 .41976 Mdot
.40825 .42341 Mdot
.4431 .42271 Mdot
.48938 .42734 Mdot
.53095 .43591 Mdot
.55565 .42159 Mdot
.59284 .40639 Mdot
.62033 .41947 Mdot
.65293 .4112 Mdot
.69115 .41679 Mdot
.15494 .41874 Mdot
.21797 .41989 Mdot
.31723 .45113 Mdot
.36991 .44648 Mdot
.4127 .44701 Mdot
.43821 .44765 Mdot
.46897 .43773 Mdot
.50964 .44122 Mdot
.57237 .43795 Mdot
.73459 .42696 Mdot
.78532 .41261 Mdot
.92304 .45764 Mdot
.9697 .41464 Mdot
.02381 .44817 Mdot
.17825 .46844 Mdot
.24425 .45795 Mdot
.28356 .45101 Mdot
.37984 .46816 Mdot
.40582 .46647 Mdot
.47296 .45734 Mdot
.49568 .45785 Mdot
.52228 .46843 Mdot
.53918 .45567 Mdot
.56155 .4606 Mdot
.59855 .44417 Mdot
.64522 .44807 Mdot
.68265 .45201 Mdot
.75429 .47327 Mdot
.79253 .46046 Mdot
.97619 .48472 Mdot
.2237 .49403 Mdot
.28909 .49334 Mdot
.33681 .47639 Mdot
.36724 .49251 Mdot
.43586 .47725 Mdot
.45711 .46767 Mdot
.48557 .47957 Mdot
.50684 .47939 Mdot
.54846 .48406 Mdot
.61155 .46672 Mdot
.64298 .48008 Mdot
.71383 .4709 Mdot
.8174 .50312 Mdot
.10655 .46514 Mdot
.25682 .51896 Mdot
.32175 .50985 Mdot
.39533 .50503 Mdot
.41367 .49139 Mdot
.44861 .49865 Mdot
.4676 .49095 Mdot
.49351 .50011 Mdot
.51545 .49754 Mdot
.5323 .49598 Mdot
.58144 .47622 Mdot
.59387 .50239 Mdot
.62172 .50305 Mdot
.67195 .49351 Mdot
.02694 .50569 Mdot
.16755 .52455 Mdot
.35607 .52009 Mdot
.3909 .52831 Mdot
.42944 .51388 Mdot
.45691 .52211 Mdot
.47836 .51255 Mdot
.50904 .51794 Mdot
.54193 .51739 Mdot
.5652 .50368 Mdot
.65492 .52358 Mdot
.70822 .50981 Mdot
.8782 .51009 Mdot
.96538 .52751 Mdot
.10486 .52544 Mdot
.21166 .5507 Mdot
.24394 .58353 Mdot
.27796 .54824 Mdot
.3503 .55078 Mdot
.42094 .53644 Mdot
.44334 .54866 Mdot
.49125 .53246 Mdot
.5258 .53065 Mdot
.56061 .53325 Mdot
.58944 .53152 Mdot
.6193 .53638 Mdot
.69491 .5431 Mdot
.75459 .5181 Mdot
.04473 .57899 Mdot
.12716 .58414 Mdot
.31613 .54593 Mdot
.38387 .55625 Mdot
.47011 .543 Mdot
.50517 .5513 Mdot
.529 .55662 Mdot
.55495 .55707 Mdot
.72896 .56068 Mdot
.76532 .58346 Mdot
.79413 .55014 Mdot
.85116 .56893 Mdot
.04951 .63199 Mdot
.18113 .60263 Mdot
.30413 .58679 Mdot
.40878 .5651 Mdot
.47079 .56761 Mdot
.4933 .56853 Mdot
.58679 .56101 Mdot
.63014 .56861 Mdot
.66039 .55827 Mdot
.93087 .56735 Mdot
.11507 .65394 Mdot
.27285 .61632 Mdot
.35208 .5834 Mdot
.43455 .57778 Mdot
.45741 .5855 Mdot
.50354 .58915 Mdot
.5279 .58501 Mdot
.55512 .58657 Mdot
.57616 .59915 Mdot
.60686 .5864 Mdot
.61945 .62082 Mdot
.65076 .60978 Mdot
.67723 .5899 Mdot
.70997 .60095 Mdot
.81831 .61898 Mdot
.33393 .61351 Mdot
.38386 .59587 Mdot
.41638 .60238 Mdot
.44019 .62525 Mdot
.46655 .60853 Mdot
.49094 .61071 Mdot
.6705 .64808 Mdot
.71265 .64302 Mdot
.40912 .63881 Mdot
.46232 .64726 Mdot
.50654 .6323 Mdot
.53472 .61748 Mdot
.55345 .64082 Mdot
.58152 .62662 Mdot
.76347 .6297 Mdot
.89008 .63784 Mdot
.21298 .64206 Mdot
.309 .64864 Mdot
.3767 .62932 Mdot
.49093 .66332 Mdot
.53315 .66744 Mdot
.59569 .66065 Mdot
.63587 .66451 Mdot
.17501 .69473 Mdot
.35721 .65577 Mdot
.41558 .66944 Mdot
.44799 .68044 Mdot
.50398 .6977 Mdot
.53865 .72366 Mdot
.56709 .69 Mdot
.70466 .69611 Mdot
.76212 .67821 Mdot
.9056 .71602 Mdot
.2901 .70526 Mdot
.3397 .69244 Mdot
.38751 .68868 Mdot
.43446 .72624 Mdot
.47287 .71759 Mdot
.76304 .73273 Mdot
.82736 .68544 Mdot
.2568 .6648 Mdot
.39938 .72532 Mdot
.58545 .7479 Mdot
.61005 .70891 Mdot
.65814 .71036 Mdot
.83642 .76062 Mdot
.8982 .74394 Mdot
.2303 .7182 Mdot
.34481 .73387 Mdot
.11003 .74561 Mdot
.10744 .74017 Mdot
.1761 .77873 Mdot
.25402 .77398 Mdot
.37923 .76617 Mdot
.44414 .77626 Mdot
.49813 .75633 Mdot
.64072 .76485 Mdot
.70121 .759 Mdot
.76313 .80148 Mdot
.30942 .76296 Mdot
.38868 .80919 Mdot
.54881 .7829 Mdot
.68415 .82498 Mdot
.84431 .8143 Mdot
.23816 .84687 Mdot
.31705 .82196 Mdot
.18629 .84495 Mdot
.29052 .8997 Mdot
.36875 .87365 Mdot
.5568 .84875 Mdot
.60956 .81264 Mdot
.75028 .8803 Mdot
.43897 .84523 Mdot
.49599 .81388 Mdot
.26714 .90171 Mdot
.35385 .94189 Mdot
.42573 .92716 Mdot
.6334 .8843 Mdot
.49513 .88471 Mdot
.56349 .92828 Mdot
.71372 .9034 Mdot
.4527 .96045 Mdot
.50987 .96696 Mdot
.53797 .96102 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[111]:=",
  ImageSize->{267.5, 264.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0001SA000`40O003h00Ob6mk00<006mkKg/0
aVmk0038Kg/00`00Kg]_N`36Kg/00<Q_N`03001_Nfmk0<I_N`00b6mk0P00afmk0038Kg/00`00Kg]_
N`36Kg/00<Q_N`03001_Nfmk0<I_N`00V6mk0W`07Fmk0W`03fmk00<006mkKg/0aVmk002FKg/6O00I
Kg/6O00=Kg/00`00Kg]_N`36Kg/009I_N`Il01U_N`Il00e_N`03001_Nfmk0<I_N`00UFmk27`05fmk
27`036mk00<006mkKg/0aVmk002EKg/8O00GKg/8O00<Kg/00`00Kg]_N`36Kg/009I_N`Il01U_N`Il
00e_N`03001_Nfmk0<I_N`00UVmk1W`06Fmk1W`03Fmk00<006mkKg/02Vmk0W`0^Vmk002HKg/2O00M
Kg/2O00?Kg/00`00Kg]_N`08Kg/6O02hKg/00<Q_N`03001_Nfmk00Q_N`Il0;Q_N`00OVmk0W`0B6mk
00<006mkKg/01fmk27`08Vmk0W`0Tfmk001lKg/6O016Kg/00`00Kg]_N`07Kg/8O00PKg/6O02AKg/0
07a_N`Il03U_N`H000M_N`03001_Nfmk00Q_N`Il025_N`Il095_N`00Nfmk27`0>6mk00<006mkKg/0
0Vmk00<006mkKg/01Fmk00<006mkKg/026mk1W`086mk27`0T6mk001kKg/8O00iKg/00`00Kg]_N`09
Kg/00`00Kg]_N`0:Kg/2O00RKg/8O009Kg/2O025Kg/007a_N`Il03]_N`03001_Nfmk00Q_N`<002m_
N`Il00Q_N`Il08=_N`00O6mk1W`0<6mk1P001Vmk00<006mkKg/01fmk00<006mkKg/0;fmk1W`026mk
1W`0Pfmk001nKg/2O00oKg/00`00Kg]_N`06Kg/00`00Kg]_N`0aKg/2O009Kg/8O022Kg/00;]_N`03
001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk03a_N`Ql089_N`00^fmk00<006mkKg/00Vmk00<0
06mkKg/01Fmk00<006mkKg/0?Fmk1W`0Pfmk002lKg/40008Kg/00`00Kg]_N`0mKg/6O023Kg/00<Q_
N`03001_Nfmk03m_N`9l08E_N`00IVmk0W`0H6mk00<006mkKg/0aVmk001TKg/6O01NKg/00`00Kg]_
N`36Kg/006A_N`Il05i_N`03001_Nfmk0<I_N`00Hfmk27`06Vmk0W`0@Fmk00<006mkKg/0aVmk001S
Kg/8O00HKg/6O00oKg/00`00Kg]_N`36Kg/006A_N`Il01U_N`Il01Y_N`9l02=_N`03001_Nfmk04Y_
N`9l07Y_N`00I6mk1W`066mk27`05fmk1W`08Fmk00<006mkKg/0B6mk1W`0N6mk001VKg/2O00JKg/8
O00GKg/6O00QKg/00`00Kg]_N`18Kg/6O01hKg/008=_N`Il01M_N`Ql021_N`03001_Nfmk04M_N`Ql
07M_N`00F6mk0W`0:Fmk1W`05fmk27`086mk00<006mkKg/0Afmk27`0Mfmk001FKg/6O00YKg/2O00J
Kg/6O00QKg/00`00Kg]_N`18Kg/6O01hKg/005I_N`Il04E_N`Il01Y_N`9l00E_N`8001]_N`9l02a_
N`Il07Q_N`00EFmk27`0AVmk0W`06Vmk1W`00fmk00<006mkKg/066mk1W`0;6mk0W`0NVmk001EKg/8
O01RKg/6O003Kg/00`00Kg]_N`0HKg/6O02XKg/005I_N`Il069_N`Ql009_N`03001_Nfmk01M_N`Ql
0:M_N`00EVmk1W`0HVmk27`00Vmk00<006mkKg/05fmk27`0Yfmk001HKg/2O01UKg/6O003Kg/00`00
Kg]_N`0HKg/6O02XKg/00;m_N`Il00=_N`03001_Nfmk01Q_N`Il0:Q_N`00`Fmk0W`01Fmk00<006mk
Kg/06Vmk0W`0ZVmk0038Kg/00`00Kg]_N`1WKg/2O00>Kg/2O01=Kg/00<Q_N`03001_Nfmk06E_N`Il
00Y_N`Il04]_N`00b6mk00<006mkKg/0IFmk1W`02Vmk1W`0Bfmk0038Kg/00`00Kg]_N`1TKg/8O008
Kg/8O01:Kg/006i_N`9l05Q_N`03001_Nfmk06A_N`Ql00Q_N`Ql04Y_N`00K6mk1W`0EVmk00<006mk
Kg/0IFmk1W`02Vmk1W`0Bfmk0015Kg/2O00UKg/6O01FKg/00`00Kg]_N`0aKg/2O00bKg/6O00:Kg/6
O01;Kg/004=_N`Il029_N`Ql05E_N`03001_Nfmk02m_N`Il039_N`9l00i_N`9l04e_N`00@fmk1W`0
8Vmk27`0EFmk00<006mkKg/0;fmk1W`0TFmk0012Kg/8O00RKg/6O01FKg/2000_Kg/8O02@Kg/0049_
N`Ql029_N`Il05I_N`03001_Nfmk02i_N`Ql091_N`00@fmk1W`09Fmk0W`0>Fmk0W`07Fmk00<006mk
Kg/02fmk0W`08Vmk1W`0TFmk0013Kg/6O01NKg/6O00KKg/00`00Kg]_N`09Kg/6O00PKg/6O02AKg/0
04E_N`9l061_N`Il01]_N`03001_Nfmk00U_N`Il029_N`9l09=_N`00YVmk27`06Vmk00<006mkKg/0
26mk27`0]Vmk002:Kg/2O00JKg/8O00JKg/00`00Kg]_N`08Kg/8O02fKg/008Q_N`Il01U_N`Il01]_
N`03001_Nfmk00U_N`Il0;M_N`00R6mk1W`06Fmk1W`06fmk00<006mkKg/02Fmk1W`0MFmk0W`0@6mk
0027Kg/8O00JKg/2O00MKg/00`00Kg]_N`0;Kg/2O00iKg/2O00jKg/6O00nKg/005A_N`9l035_N`Ql
035_N`9l00I_N`03001_Nfmk04A_N`Il03Q_N`Il03i_N`00DVmk1W`0<6mk1W`0<6mk1W`016mk00<0
06mkKg/0A6mk1W`0=fmk27`0?Fmk001BKg/6O00`Kg/6O00`Kg/6O004Kg/00`00Kg]_N`13Kg/8O00f
Kg/8O00mKg/0055_N`Ql035_N`9l035_N`Ql00=_N`03001_Nfmk04=_N`Ql03M_N`Il03i_N`00DFmk
27`0I6mk27`00fmk00<006mkKg/0A6mk1W`0>6mk1W`0?Vmk001BKg/6O01VKg/6O004Kg/00`00Kg]_
N`14Kg/6O00jKg/2O010Kg/0059_N`Il06I_N`Il00A_N`03001_Nfmk01m_N`9l02E_N`9l07i_N`00
E6mk0W`0JVmk0W`01Vmk00<006mkKg/07Fmk1W`0Xfmk0038Kg/2000NKg/6O02SKg/00<Q_N`03001_
Nfmk01a_N`Ql03Y_N`9l06I_N`00W6mk0W`0:Vmk00<006mkKg/076mk27`0>6mk1W`0I6mk002JKg/6
O00XKg/00`00Kg]_N`0MKg/6O00iKg/6O01TKg/009Y_N`Il02Q_N`03001_Nfmk01e_N`Il03Q_N`Ql
06=_N`00VFmk27`09fmk00<006mkKg/07fmk0W`0>Vmk27`0Hfmk000]Kg/2O010Kg/2O00XKg/8O00W
Kg/00`00Kg]_N`1LKg/6O01TKg/002]_N`Il03a_N`Il02M_N`Il02Q_N`03001_Nfmk00Q_N`9l059_
N`Il06A_N`00:fmk1W`0?6mk1W`09fmk1W`046mk0W`05Vmk00<006mkKg/01Vmk1W`0DVmk0W`0IVmk
000ZKg/8O00jKg/8O00XKg/2O00@Kg/6O00DKg/00`00Kg]_N`06Kg/6O02jKg/002Y_N`Ql00E_N`9l
03=_N`Ql03Y_N`Il01A_N`03001_Nfmk00E_N`Ql0;U_N`00:fmk1W`016mk1W`0<Vmk1W`0>Vmk27`0
4fmk00<006mkKg/01Fmk27`08fmk0W`0U6mk000[Kg/6O004Kg/6O00bKg/6O00jKg/8O00CKg/00`00
Kg]_N`06Kg/6O00RKg/6O02BKg/002e_N`9l00E_N`Ql03=_N`9l019_N`9l02U_N`Il01A_N`03001_
Nfmk00I_N`Il029_N`Il099_N`00=6mk27`0AFmk1W`09fmk1W`056mk00<006mkKg/026mk0W`08fmk
27`0TFmk000eKg/6O016Kg/6O00YKg/2O00FKg/00`00Kg]_N`0]Kg/8O02AKg/003E_N`Il04E_N`Ql
03Y_N`9l00A_N`03001_Nfmk02i_N`Il03i_N`9l059_N`00=fmk0W`0Afmk27`0>6mk1W`00Vmk0P00
;fmk1W`04Fmk0W`0:Fmk1W`0D6mk0021Kg/6O00iKg/6O002Kg/00`00Kg]_N`0`Kg/2O00AKg/6O00W
Kg/6O01@Kg/0085_N`Il03Q_N`Ql0003Kg/006mk04A_N`Il02I_N`Ql01U_N`9l00a_N`9l02I_N`00
Pfmk0W`0>Vmk27`000=_N`00Kg/05Vmk0W`0:fmk27`09Fmk27`05fmk1W`026mk1W`096mk002EKg/2
O00YKg/6O002Kg/00`00Kg]_N`0CKg/6O00YKg/8O00VKg/6O00HKg/6O008Kg/6O00TKg/005A_N`9l
03e_N`Il02M_N`Il009_N`03001_Nfmk01=_N`Il02Y_N`Il02M_N`Il01M_N`Ql00I_N`Ql02=_N`00
DVmk1W`0>fmk1W`0:Fmk0W`016mk00<006mkKg/04Vmk27`0:Fmk1W`0:Fmk0W`06Fmk27`01Vmk27`0
8fmk001BKg/6O00jKg/8O00^Kg/00`00Kg]_N`0BKg/8O00[Kg/2O017Kg/6O008Kg/6O00TKg/0055_
N`Ql03U_N`Ql00]_N`9l025_N`03001_Nfmk01=_N`Il07E_N`Il00Q_N`Il02A_N`00DFmk27`0>Vmk
1W`02Vmk1W`07fmk00<006mkKg/04fmk1W`0Mfmk0W`036mk0W`09Vmk000TKg/2O00/Kg/6O00kKg/6
O00:Kg/6O00OKg/00`00Kg]_N`0EKg/2O02_Kg/0029_N`Il02Y_N`Il03e_N`9l00]_N`Ql01i_N`03
001_Nfmk05Y_N`9l06Y_N`008Vmk1W`0;6mk0W`05Fmk0W`0=Fmk27`07Vmk00<006mkKg/0F6mk1W`0
J6mk000QKg/8O010Kg/6O00dKg/6O00<Kg/2O00AKg/00`00Kg]_N`03Kg/2O01CKg/6O01XKg/0025_
N`Ql041_N`Il03A_N`Il00Y_N`Il009_N`L000I_N`04001_NfmkKg/6O01@Kg/8O01WKg/0029_N`Il
041_N`Ql03E_N`9l00a_N`Il00E_N`03001_Nfmk00M_N`04001_NfmkKg/6O00KKg/2O00cKg/8O01W
Kg/0029_N`Il041_N`Ql00m_N`9l035_N`Ql00A_N`03001_Nfmk00M_N`03001_Nfmk00Ql01Q_N`Il
039_N`Il06Q_N`0096mk0W`0@fmk1W`03Vmk1W`0;fmk27`016mk00<006mkKg/01fmk00<006mkKg/0
27`066mk1W`0<Vmk1W`0J6mk001YKg/6O00>Kg/6O00_Kg/00`00O01l0004O005Kg/00`00Kg]_N`07
Kg/300000fmkO01l0004O00HKg/8O00<Kg/2O00UKg/2O01ZKg/006]_N`9l00m_N`Ql02m_N`Il00E_
N`03001_Nfmk00M_N`04001_NfmkKg/6O00HKg/8O00:Kg/6O02?Kg/007a_N`Ql035_N`9l00M_N`03
001_Nfmk00M_N`03001_Nfmk00=_N`9l01]_N`Il00]_N`Il08m_N`00OFmk1W`0>Fmk0`002Fmk00<0
06mkKg/086mk1W`02Vmk27`0SVmk001mKg/6O00>Kg/2O00[Kg/01000Kg]_Nfmk0W`016mk00<006mk
Kg/08Vmk0W`036mk27`0SVmk001oKg/2O00>Kg/6O00[Kg/6O002Kg/00`00Kg]_N`0@Kg/2O00OKg/6
O00=Kg/2O00_Kg/2O01?Kg/008m_N`Il00a_N`9l01e_N`Il009_N`03001_Nfmk00i_N`Il01e_N`Il
00]_N`Il02]_N`Il04e_N`00@6mk0W`0C6mk27`02Fmk1W`06Vmk27`000=_N`00Kg/03fmk1W`07fmk
0W`03Fmk1W`0:fmk1W`0CFmk000nKg/6O01:Kg/8O009Kg/6O00JKg/8O0000fmk001_N`0>Kg/8O00/
Kg/8O00YKg/8O01<Kg/003i_N`Il04]_N`Il00U_N`Ql01Y_N`Il009_N`03001_Nfmk00e_N`Ql02a_
N`Ql02U_N`Ql04a_N`00?Fmk27`0BVmk1W`02Fmk27`06Vmk1W`00Vmk00<006mkKg/03Vmk1W`0;Vmk
1W`0:fmk1W`0CFmk000mKg/8O01<Kg/2O00<Kg/6O00:Kg/2O00AKg/2O004Kg/00`00Kg]_N`0>Kg/6
O00^Kg/6O00[Kg/6O01=Kg/003i_N`Il05]_N`Il00Q_N`Il01E_N`03001_Nfmk011_N`9l039_N`9l
02m_N`9l04m_N`00?Vmk1W`05Vmk0W`0AFmk0W`02Vmk1W`05Fmk00<006mkKg/0G6mk0W`0J6mk0010
Kg/2O00FKg/6O00DKg/2O00hKg/8O00DKg/00`00Kg]_N`1JKg/6O01VKg/001i_N`9l03Q_N`Il019_
N`Il03I_N`Ql01A_N`03001_Nfmk05Y_N`Il06I_N`0076mk1W`0=Fmk27`04Fmk1W`0=fmk1W`05Fmk
00<006mkKg/01Fmk0W`04Vmk0W`0?Vmk27`0;Vmk0W`07Vmk0W`05Fmk000LKg/6O00eKg/8O00@Kg/8
O00?Kg/2O00UKg/6O00=Kg/2O006Kg/20004Kg/6O00>Kg/6O00lKg/8O00/Kg/6O00JKg/6O00CKg/0
01]_N`Ql03E_N`Il015_N`Ql00e_N`Il02E_N`9l00e_N`Il00A_N`03001_Nfmk00=_N`Il00i_N`Il
00U_N`9l039_N`Il02e_N`Il01Y_N`Il01=_N`006fmk27`0=Fmk1W`04Vmk1W`03Vmk1W`0=6mk1W`0
16mk00<006mkKg/00Vmk27`036mk27`01Vmk1W`0<6mk1W`0;6mk27`066mk27`04Vmk000LKg/6O00h
Kg/2O00DKg/6O00=Kg/8O00CKg/2O00MKg/8O003Kg/00`00Kg]_N`02Kg/8O00<Kg/8O006Kg/6O00b
Kg/2O00^Kg/8O00HKg/8O00BKg/001a_N`Il051_N`9l00m_N`Ql015_N`Il01]_N`Ql00=_N`03001_
Nfmk00=_N`Il00i_N`Il00I_N`Ql00M_N`9l05U_N`Il01Y_N`Il01=_N`007Vmk0W`0I6mk1W`04Vmk
1W`076mk1W`016mk00<006mkKg/00fmk1W`03Vmk1W`01Vmk27`01Fmk1W`0Efmk1W`06Vmk1W`04fmk
0024Kg/6O00AKg/8O00>Kg/2O00;Kg/6O004Kg/00`00Kg]_N`05Kg/2O00BKg/2O009Kg/6O006Kg/6
O01IKg/2O00NKg/2O00EKg/008I_N`9l01=_N`Ql00a_N`Il00]_N`9l00I_N`03001_Nfmk02A_N`Il
00E_N`Ql00U_N`9l00i_N`9l07A_N`00W6mk1W`03Fmk1W`04fmk00<006mkKg/09Vmk0W`01fmk27`0
1fmk1W`02Vmk1W`0LVmk002EKg/2O005Kg/6O00<Kg/8O00BKg/00`00Kg]_N`0`Kg/6O008Kg/6O00:
Kg/6O01bKg/009=_N`Il00E_N`9l00i_N`Ql019_N`03001_Nfmk031_N`Il00M_N`Ql00Q_N`Ql01Y_
N`9l05E_N`00Kfmk0W`08Vmk1W`05Vmk1W`04fmk00<006mkKg/04Fmk0W`07fmk0W`02Fmk27`026mk
27`066mk1W`0@6mk0W`04Fmk001]Kg/6O00OKg/8O00EKg/6O00<Kg/2O005Kg/00`00Kg]_N`03Kg/2
O00:Kg/6O00YKg/6O00:Kg/6O00IKg/6O00nKg/6O00?Kg/006e_N`Il01m_N`Ql01M_N`9l00a_N`Il
00=_N`04001_NfmkKg/6O008Kg/6O00YKg/6O00:Kg/6O00HKg/8O00mKg/6O00?Kg/0011_N`9l05Y_
N`Ql01m_N`Il00m_N`9l01E_N`Il00=_N`04001_NfmkKg/6O007Kg/8O00ZKg/2O00>Kg/2O00JKg/8
O00lKg/8O00>Kg/000i_N`Il05Q_N`Ql019_N`9l00]_N`Il00e_N`Il019_N`Ql009_N`03001_Nfmk
00Ql00I_N`Ql05M_N`Il03e_N`Ql00i_N`003Vmk1W`08Vmk0W`0=Fmk1W`04Fmk1W`02fmk0W`03fmk
1W`04Vmk27`00Vmk00<006mkKg/027`01fmk1W`0F6mk1W`0?Vmk1W`03fmk000=Kg/8O00OKg/6O00C
Kg/2O00NKg/6O00AKg/6O00KKg/8O00BKg/6O003Kg/01000Kg]_Nfmk1W`026mk1W`02Fmk0W`0Cfmk
0W`0@6mk1W`03fmk000=Kg/8O00OKg/6O00AKg/6O00NKg/2O00BKg/8O00JKg/8O00BKg/6O003Kg/2
0002Kg/6O00:Kg/2O009Kg/6O02AKg/2O00AKg/000i_N`Il01m_N`Ql011_N`Il039_N`Ql01]_N`Il
00e_N`9l00I_N`9l00E_N`03001_Nfmk00=_N`9l01M_N`Il0:A_N`003Vmk1W`07fmk27`03fmk27`0
3fmk0W`05Vmk0W`02Fmk1W`076mk1W`02fmk1W`02fmk00<006mkKg/06fmk27`0Xfmk000@Kg/2O00R
Kg/6O00@Kg/8O00=Kg/6O00BKg/6O007Kg/6O00NKg/2O00=Kg/6O00;Kg/00`00Kg]_N`0KKg/8O02S
Kg/003A_N`Il015_N`Il00i_N`Il019_N`Il00U_N`9l02i_N`Ql00Y_N`03001_Nfmk01a_N`Il00U_
N`9l039_N`9l06E_N`00=Vmk0W`04fmk1W`03Fmk27`046mk27`086mk0W`05Vmk27`02Vmk00@006mk
O01l01]_N`Il00M_N`Il00Y_N`9l029_N`Il01m_N`9l049_N`00CFmk0W`03fmk27`046mk27`07Vmk
1W`05Fmk1W`02fmk1W`06fmk0W`02Fmk1W`026mk1W`03fmk0W`03fmk1W`07Fmk1W`0@6mk001OKg/6
O00BKg/6O00OKg/6O00>Kg/2O005Kg/6O00;Kg/6O009Kg/2O00JKg/8O007Kg/6O00=Kg/6O00<Kg/8
O00LKg/6O00IKg/2O00UKg/005m_N`Il019_N`Il01i_N`Ql00]_N`Il00E_N`9l00a_N`Ql00I_N`Il
01Q_N`Ql00I_N`Ql00a_N`Il00a_N`Ql01]_N`Ql01I_N`Il02=_N`00HFmk0W`05Vmk0W`046mk0W`0
3Vmk27`02fmk1W`04fmk27`01Vmk1W`06Fmk1W`01fmk27`02fmk27`036mk1W`076mk27`05Vmk1W`0
8fmk0029Kg/6O00=Kg/6O00;Kg/8O00CKg/6O006Kg/8O00HKg/6O008Kg/6O00<Kg/8O00<Kg/6O00M
Kg/6O00FKg/8O00RKg/008U_N`Il00M_N`9l00A_N`Il00]_N`Ql00]_N`9l00I_N`Il00I_N`Ql00I_
N`9l019_N`9l00Y_N`Il00e_N`Il00m_N`9l01m_N`Il01I_N`Ql029_N`00R6mk27`016mk1W`016mk
0W`03Vmk1W`02Vmk1W`016mk00@006mkO01l00U_N`Il00E_N`Il01i_N`9l00m_N`Il039_N`9l01U_
N`Il02=_N`00R6mk27`016mk1W`056mk1W`02Vmk1W`016mk00<006mkKg/02Vmk1W`01Fmk1W`0<Fmk
0W`0Cfmk1W`08fmk000KKg/2O01/Kg/6O004Kg/8O00=Kg/2O006Kg/2O00;Kg/8O003Kg/00`00Kg]_
N`0<Kg/2O006Kg/8O023Kg/2O00UKg/001U_N`Il06Y_N`Il00A_N`Ql00]_N`Il015_N`Ql00=_N`03
001_Nfmk01A_N`Ql0:Y_N`006Fmk1W`0K6mk0W`01fmk1W`036mk1W`04Vmk1W`016mk00<006mkKg/0
5Fmk1W`01Vmk0W`0Xfmk000HKg/8O01<Kg/2O00@Kg/2O00DKg/6O00;Kg/8O00;Kg/2O004Kg/6O004
Kg/20002O007Kg/2O00;Kg/6O004Kg/6O02QKg/001Q_N`Ql04Y_N`Il00a_N`Il01A_N`9l00e_N`Ql
00U_N`Il00A_N`9l00I_N`Il00=_N`Il00]_N`9l00I_N`Il01A_N`9l08]_N`006Fmk1W`0Bfmk1W`0
36mk1W`096mk1W`02Vmk1W`036mk1W`00fmk1W`04Vmk27`04Fmk1W`0<Fmk0W`0EVmk000IKg/6O01:
Kg/8O00:Kg/8O00SKg/6O009Kg/8O00:Kg/8O0000fmkO01l0006O00AKg/8O00AKg/6O00<Kg/2O00Q
Kg/6O016Kg/2O00<Kg/001]_N`9l021_N`9l02Y_N`Ql00Y_N`Ql02E_N`9l00]_N`Ql00Y_N`Ql0003
Kg]l07`000Il019_N`Il00M_N`9l00Q_N`Ql00U_N`Il01m_N`Il04A_N`Il00Y_N`00>fmk1W`05Fmk
0W`04Vmk1W`036mk1W`05Vmk0W`076mk1W`036mk1W`00fmk1W`01Vmk0W`02fmk1W`01Fmk1W`01Vmk
27`02Fmk1W`07Vmk27`0@fmk1W`02Vmk000kKg/6O00CKg/6O00@Kg/6O00<Kg/6O00DKg/6O006Kg/2
O00<Kg/2O004Kg/6O00<Kg/6O003Kg/6O004Kg/6O00;Kg/2O007Kg/6O007Kg/6O009Kg/8O00MKg/8
O012Kg/8O009Kg/003Y_N`Ql019_N`Il019_N`9l011_N`9l01I_N`Il00A_N`Il00Q_N`Il00A_N`9l
00i_N`04001_Ng`0O007Kg/2O006Kg/6O00CKg/8O006Kg/6O009Kg/8O00<Kg/2O00@Kg/6O013Kg/8
O009Kg/003Y_N`Ql015_N`Ql03Y_N`Ql00=_N`Il00Q_N`Il00m_N`9l00=_N`03001_Nfmk00m_N`Ql
019_N`Ql00Q_N`9l00a_N`Il00]_N`Il00i_N`Il04A_N`Il00Y_N`00>fmk1W`04Vmk27`0;Vmk0W`0
2Vmk27`00Vmk27`01Vmk27`036mk1W`000=_N`00Kg/046mk27`04fmk1W`05fmk1W`02fmk1W`046mk
0W`0AVmk1W`02Vmk000kKg/6O00CKg/6O00]Kg/6O009Kg/6O003Kg/8O006Kg/8O00<Kg/6O0000fmk
001_N`0AKg/6O00DKg/6O00IKg/2O00<Kg/8O01IKg/2O00<Kg/003e_N`9l01E_N`Il02e_N`Il00U_
N`Il00A_N`Il00Q_N`Il00a_N`Ql0003001_Nfmk00U_N`9l00E_N`Il01I_N`9l02U_N`Ql06M_N`00
EVmk0W`0;Vmk27`02Vmk0W`01Vmk1W`026mk1W`01fmk0W`00fmk27`000<006mkKg/01fmk1W`01Fmk
0W`01Fmk0W`0?Fmk1W`0J6mk0026Kg/8O00DKg/2O00<Kg/2O007Kg/6O002Kg/6O00016mk001_Nfmk
0W`01Fmk1W`02Vmk1W`0>fmk1W`0:Vmk0W`0?6mk0027Kg/6O00/Kg/6O002Kg/6O0000fmk001l0005
O002Kg/8O009Kg/6O007Kg/2O00dKg/2O00ZKg/6O00jKg/008M_N`Il00I_N`9l00m_N`9l019_N`Ql
00=_N`9l00=_N`03001l07`000Al009_N`Ql00Q_N`Ql00A_N`Il05i_N`Il03Y_N`002Fmk0W`0OVmk
0W`01Vmk1W`02fmk1W`01Vmk0W`026mk27`026mk27`00Vmk1W`02Fmk27`016mk1W`03Vmk0W`0CFmk
27`0>Fmk0007Kg/6O01TKg/2O00;Kg/2O00AKg/6O00;Kg/6O004Kg/6O007Kg/6O009Kg/8O002Kg/6
O00:Kg/6O004Kg/8O00;Kg/6O00;Kg/2O00nKg/8O00iKg/000M_N`Il00e_N`H004m_N`Il00<000A_
N`Il00i_N`Ql00U_N`Ql00=_N`Il00M_N`Il00U_N`03001l07`000Al00E_N`9l00a_N`Il00A_N`Ql
00]_N`Il00U_N`Il00Q_N`L002i_N`Il01a_N`H001Q_N`001Vmk27`036mk00<006mkKg/00Vmk00<0
06mkKg/0CFmk1W`01fmk1W`03Vmk27`02Fmk27`00Vmk27`026mk0W`02fmk00<007`0O00017`026mk
0W`02fmk0W`01fmk1W`02fmk27`026mk1W`02fmk00<006mkKg/0;fmk1W`076mk00<006mkKg/00Vmk
00<006mkKg/05Vmk0006Kg/8O00=Kg/00`00Kg]_N`13Kg/2O00;Kg/8O005Kg/8O00>Kg/6O00;Kg/6
O003Kg/8O009Kg/2O007Kg/2O00016mk001_Nfmk0W`026mk1W`04Vmk1W`02fmk27`01fmk27`02Vmk
00<006mkKg/0<Fmk0W`06fmk0W`00Vmk00<006mkKg/06Vmk0007Kg/6O00?Kg/00`00Kg]_N`10Kg/6
O009Kg/8O005Kg/8O00>Kg/6O00;Kg/6O004Kg/6O008Kg/6O003Kg/6O00<Kg/6O005Kg/2O00=Kg/2
O00>Kg/6O008Kg/8O00:Kg/00`00Kg]_N`0JKg/2O00`Kg/6O0000fmk001_N`0JKg/000M_N`Il00A_
N`H000I_N`03001_Nfmk03m_N`Il00=_N`H00003Kg]l07`000Al00M_N`Il015_N`9l00m_N`9l00I_
N`Il00Q_N`Il00=_N`Il00]_N`Ql009_N`Il01]_N`Il00U_N`Il00]_N`03001_Nfmk01Q_N`Il02i_
N`Il009_N`03001_Nfmk01Q_N`002Fmk0W`04fmk00<006mkKg/02Fmk0W`0<Vmk27`02Fmk1W`01fmk
1W`07fmk0W`02fmk0W`02Fmk27`000=_Ng`0O0001W`02Vmk27`00Vmk1W`046mk0W`02fmk0W`02fmk
1W`02fmk00<006mkKg/066mk1W`0;Fmk27`00Vmk00<006mkKg/05fmk000JKg/00`00Kg]_N`02Kg/0
0`00Kg]_N`06Kg/6O00HKg/2O00FKg/8O00;Kg/2O0000fmk001_N`08Kg/2O00GKg/2O006Kg/6O00A
Kg/2O0000fmkO01l0006O0000fmkO01l0006O006Kg/2O003Kg/6O002Kg/8O00=Kg/6O00HKg/2O00=
Kg/00`00Kg]_N`0GKg/8O00/Kg/8O003Kg/00`00Kg]_N`0FKg/001Y_N`03001_Nfmk009_N`03001_
Nfmk00I_N`Il01I_N`Il01E_N`Il00e_N`<0021_N`Il00A_N`Il00m_N`al00=_N`Il00E_N`Il0003
Kg]l07`000Al009_N`Ql00e_N`Il02E_N`9l0003001_Nfmk01M_N`Ql02e_N`Il00A_N`03001_Nfmk
01I_N`006fmk100026mk27`05Fmk1W`05Fmk1W`03fmk00<006mkKg/07Vmk1W`00fmk27`03Vmk37`0
0fmk1W`01Fmk1W`00fmk0W`01Fmk1W`03Fmk27`08Vmk1W`036mk0W`02fmk1W`0;Vmk1W`010006Fmk
000WKg/8O00DKg/8O00FKg/2O00SKg/2O00<Kg/8O002Kg/8O00=Kg/8O0000fmkO01l0007Kg/2O000
0fmk001_N`03Kg/8O009Kg/6O004Kg/2O007Kg/8O00RKg/6O00:Kg/6O009Kg/6O00`Kg/2O00OKg/0
02Q_N`Il01E_N`Ql03U_N`Il00Y_N`Ql00=_N`Il00Q_N`9l00A_N`Ql00e_N`05001_Ng`0O01_N`08
O00;Kg/2O004Kg/6O006Kg/6O00RKg/8O009Kg/6O00;Kg/2O01CKg/002Q_N`Il01I_N`Il03Y_N`Il
00]_N`Il00A_N`Il00I_N`Il00=_N`Il00M_N`9l00E_N`al019_N`Il00I_N`Il00Q_N`9l01Q_N`Ql
00Q_N`Ql05m_N`00:Vmk0W`066mk1W`0>Fmk27`02Vmk1W`01Vmk0W`026mk1W`00fmk1W`01Fmk1W`0
0fmk37`01fmk0W`026mk27`01fmk0W`026mk1W`05fmk1W`02Fmk27`0Gfmk0016Kg/2O00kKg/8O00<
Kg/2O00AKg/8O004Kg/2O007Kg/6O002Kg/8O0000fmkO01l0007Kg/6O006Kg/8O00AKg/6O00GKg/6
O00:Kg/6O01EKg/2O009Kg/008A_N`Il021_N`Ql00a_N`Ql0003Kg]l07`000Il00Y_N`Il00M_N`Il
015_N`Ql01Q_N`9l00a_N`Il05=_N`Il00M_N`00Q6mk1W`06fmk0W`016mk1W`02Fmk0W`00Vmk27`0
0Vmk1W`02Vmk27`01Vmk1W`04Fmk27`0:6mk0W`0EFmk1W`01fmk001IKg/2O00HKg/2O00AKg/2O00:
Kg/2O00?Kg/6O002Kg/6O007Kg/6O0000fmkO01l0004O003Kg/6O00:Kg/8O008Kg/2O00DKg/6O008
Kg/2O01eKg/8O006Kg/005L000Il01@000Il01T000Il00d000Il00@0009l00T000Il0003001l07`0
00Al00D0009l00P0009l00<000Il01l000Il00H000Il07<000Ql00H000001fmk00<006mkKg/03fmk
00<006mkKg/03Vmk00<006mkKg/03fmk00<006mkKg/03Vmk00<006mkKg/01fmk1W`00Vmk00<006mk
Kg/03Vmk00<007`0O00017`02fmk00<006mkKg/02fmk1W`036mk27`02Fmk0W`000=_N`00O0001g`0
0Vmk0W`01Fmk00<006mkKg/00Vmk0W`00fmk1W`000=_Ng`0O00017`036mk00<006mkKg/03Vmk00@0
06mkKg]_N`9l00Q_N`Il00m_N`03001_Nfmk00m_N`03001_Nfmk00i_N`03001_Nfmk00m_N`03001_
Nfmk00i_N`03001_Nfmk00m_N`03001_Nfmk00Y_N`Il00M_N`001fmk00<006mkKg/03fmk00<006mk
Kg/03Vmk00<006mkKg/03fmk00<006mkKg/03Vmk00<006mkKg/01Vmk27`000=_N`00Kg/03fmk27`0
2Vmk00<006mkKg/02Vmk27`02fmk27`01fmk3W`01Vmk0W`000A_N`00Kg]_N`Il0003Kg]l07`000Al
0003Kg/006mk009l00i_N`03001_Nfmk00i_N`03001_Nfmk00Y_N`Ql00i_N`03001_Nfmk00m_N`03
001_Nfmk00i_N`03001_Nfmk00m_N`03001_Nfmk00i_N`03001_Nfmk00m_N`03001_Nfmk00Y_N`Il
00M_N`006Fmk00<006mkKg/0>Vmk27`04Vmk27`05fmk27`036mk1W`026mk1W`000=_Ng`0O00017`0
1Fmk1W`00Vmk3W`026mk0W`02Vmk0W`02Fmk0W`03fmk27`03Vmk00<006mkKg/096mk0W`0;fmk00<0
06mkKg/036mk0W`02Fmk000:Kg/2O01;Kg/6O00DKg/6O00IKg/6O007Kg/2O004Kg/6O007Kg/>O005
Kg/6O0000fmkO01l000=O006Kg/6O006Kg/6O005Kg/6O00>Kg/6O00dKg/6O017Kg/000Q_N`Il04U_
N`Il01A_N`Il01U_N`Il00E_N`Il00A_N`9l00U_N`Ql009_N`9l00I_NaIl00M_N`Il00I_N`Il00E_
N`Il00i_N`Il03A_N`Il04M_N`0026mk1W`0Bfmk0W`066mk0W`02fmk0W`046mk0W`01fmk1W`046mk
1W`02fmk27`000=_Ng`0O00017`000=_Ng`0O00017`01Vmk27`016mk27`00fmk27`03fmk0W`036mk
0W`09fmk27`04fmk0W`0<Fmk0007Kg/8O01_Kg/6O00FKg/8O009Kg/2O004Kg/6O007Kg/2O003Kg/6
O002Kg/6O003Kg/2O008Kg/8O004Kg/8O003Kg/8O00KKg/6O00UKg/8O00AKg/6O00_Kg/000M_N`Ql
06m_N`Il01I_N`Ql00M_N`Il00A_N`9l00M_N`Il0003Kg]l07`000Al00A_N`9l011_N`Il00I_N`Il
00E_N`Il01a_N`Il02I_N`Il019_N`Il02m_N`0026mk1W`0F6mk0W`05Fmk27`05Vmk1W`026mk1W`0
3Fmk1W`00fmk0W`000A_N`00Kg]_N`9l00]_N`9l00E_N`Il00I_N`Il00E_N`Il01]_N`Ql00i_N`9l
01E_N`Il015_N`Ql02i_N`0026mk1W`0EVmk1W`04fmk27`02Fmk0W`02fmk1W`01fmk27`02fmk27`0
1Fmk00<007`0O00017`01fmk1W`01Fmk0W`02Vmk0W`02Fmk0W`07Fmk27`036mk1W`05Fmk0W`04fmk
27`0;Vmk000:Kg/2O01HKg/6O00DKg/6O008Kg/6O00;Kg/2O009Kg/8O006Kg/2O003Kg/8O005Kg/0
0`00O01l0004O007Kg/6O00YKg/2O00AKg/6O00=Kg/6O00[Kg/6O00_Kg/002U_N`9l01M_N`9l01m_
N`Ql01=_N`Il00Q_N`Il01M_N`Il00E_N`Il009_N`Il00I_N`Ql00E_N`Ql02I_N`Il00m_N`Il00a_
N`Ql02Y_N`Il02m_N`009fmk1W`04fmk1W`07Fmk27`05Fmk0W`02Fmk27`026mk0W`036mk1W`01Fmk
1W`00Vmk1W`01Vmk27`01Fmk27`09Vmk1W`04Fmk0W`03Vmk27`0;6mk0W`08Fmk0W`03Vmk000WKg/6
O00CKg/6O00NKg/6O00QKg/8O006Kg/6O00<Kg/2O006Kg/8O003Kg/2O008Kg/00`00O01l0004O002
Kg/2O003Kg/6O00?Kg/2O00EKg/8O00QKg/6O01>Kg/6O00<Kg/002I_N`Ql015_N`Ql01e_N`Il029_
N`Il00M_N`Il01A_N`Ql00U_N`9l009_N`03001l07`000Yl0003Kg]l07`000Al00=_N`9l00Q_N`Il
01=_N`Ql025_N`Il04i_N`Il00a_N`009Vmk27`04Fmk27`07fmk0W`096mk1W`01Vmk27`01fmk0W`0
2fmk1W`026mk1W`000<006mkKg/00W`00Vmk1W`00fmk0W`00fmk1W`01Vmk1W`026mk0W`02Vmk1W`0
96mk0W`0Cfmk27`02fmk000WKg/6O00CKg/6O018Kg/2O008Kg/8O005Kg/6O009Kg/6O008Kg/6O000
0`00Kg]_N`03Kg/8O007Kg/6O005Kg/8O005Kg/6O008Kg/6O01eKg/8O00;Kg/002M_N`Il01=_N`Il
05=_N`Il00I_N`Il00]_N`9l00U_N`Ql0003001_Nfmk009_N`Ql00I_N`Ql00A_N`Ql00E_N`Il00Y_
N`9l07Q_N`Il00a_N`00:Fmk0W`05fmk0W`0EFmk1W`01Fmk27`03fmk0W`016mk27`01Vmk1W`01fmk
27`01Fmk1W`01Fmk27`06Fmk0W`0J6mk1W`036mk001nKg/2O00KKg/2O007Kg/8O00=Kg/6O003Kg/6
O0000`00Kg]_N`04Kg/6O008Kg/6O006Kg/6O005Kg/8O00GKg/6O01XKg/2O00>Kg/006i_N`9l00a_
N`Il02=_N`Il00E_N`9l00M_N`Il00=_N`Il0003001_Nfmk00I_N`9l00Y_N`Il00Q_N`9l00Q_N`Il
01Q_N`Il07Q_N`00E6mk0W`05Vmk1W`02Vmk1W`02Fmk0W`066mk1W`00fmk1W`016mk27`016mk0W`0
0Vmk00<007`0O00056mk0W`056mk1W`05fmk27`08fmk0W`0DVmk001BKg/6O00DKg/6O009Kg/8O006
Kg/6O00HKg/2O005Kg/6O004Kg/8O007Kg/6O00ZKg/2O00IKg/8O00QKg/6O01@Kg/0059_N`Il01=_
N`Ql00Q_N`Ql00I_N`Il00Y_N`9l019_N`Ql00A_N`Il00Q_N`Il00I_N`9l03i_N`Il029_N`Il051_
N`00DFmk27`04Vmk27`02Fmk1W`01Vmk27`01fmk1W`046mk27`016mk1W`01fmk27`00fmk1W`01Vmk
0W`0:6mk0W`02Vmk1W`08Fmk27`0Cfmk001AKg/8O00CKg/6O00:Kg/6O006Kg/8O007Kg/6O00AKg/6
O007Kg/2O009Kg/8O003Kg/6O004Kg/6O009Kg/2O00IKg/6O00:Kg/2O00<Kg/2O00EKg/8O01?Kg/0
059_N`Il01A_N`Il00a_N`9l00U_N`Il00M_N`Ql011_N`Il01=_N`Il00=_N`Ql00=_N`Il00M_N`Il
01M_N`Il01I_N`Il01A_N`Il051_N`00DVmk1W`05Vmk0W`06Fmk1W`01fmk27`01Fmk0W`02fmk0W`0
5Fmk1W`00fmk27`00Vmk27`01Vmk1W`05Vmk27`05Fmk1W`056mk1W`0D6mk001DKg/2O00eKg/2O00:
Kg/6O004Kg/6O00DKg/2O007Kg/2O002Kg/00`00O01l0006Kg/6O003Kg/8O005Kg/8O00<Kg/2O007
Kg/8O00DKg/8O00EKg/2O00EKg/2O00NKg/2O00KKg/009M_N`Il00A_N`Il019_N`Il00=_N`Il0003
001_Nfmk00I_N`Il00A_N`Il00I_N`Ql00Y_N`Il00I_N`Il01E_N`Ql02Y_N`Il01Y_N`Il01U_N`00
VFmk0W`01Fmk27`04Fmk1W`00fmk1W`000<006mkKg/026mk0W`01Vmk1W`01fmk1W`02fmk1W`01Vmk
1W`05Vmk1W`0:fmk1W`06Vmk1W`06Fmk002PKg/8O00@Kg/8O0000fmkO01l0006O00DKg/2O009Kg/6
O00:Kg/8O007Kg/2O00HKg/6O00ZKg/8O00HKg/8O00HKg/0015_N`9l08i_N`Il00I_N`9l00U_N`Ql
0003Kg]l07`000Il025_N`9l00a_N`Ql02=_N`9l02a_N`Ql01Q_N`Ql01Q_N`003fmk1W`0S6mk1W`0
16mk1W`026mk1W`00fmk1W`000<006mkKg/0;Vmk1W`0Dfmk1W`06Vmk1W`06Fmk000?Kg/6O00MKg/2
O00]Kg/2O00YKg/2O00EKg/2O006Kg/6O008Kg/6O003Kg/6O002000_Kg/6O00bKg/2O00OKg/6O00J
Kg/6O00IKg/000i_N`Ql01Y_N`Il02U_N`Il01A_N`9l00m_N`Il01Y_N`Ql00A_N`9l00=_N`9l00M_
N`9l009_N`03001_Nfmk00M_N`9l00U_N`9l01=_N`9l00M_N`9l039_N`Il01m_N`9l01i_N`9l01]_
N`003Vmk27`06Vmk1W`0:Fmk1W`04Vmk1W`03Fmk1W`06Vmk27`00Vmk1W`03Vmk00<007`0O0001Fmk
1W`01Fmk1W`03fmk1W`0>Fmk1W`0G6mk000?Kg/6O00JKg/8O00WKg/8O00AKg/6O00<Kg/8O00JKg/6
O003Kg/6O00=Kg/6O003Kg/6O005Kg/6O00?Kg/6O00HKg/2O00NKg/8O01KKg/000m_N`Il01Y_N`Ql
02M_N`Ql011_N`Ql00]_N`Ql01Y_N`Il009_N`Ql00a_N`Il009_N`Ql00=_N`Ql00e_N`Ql01E_N`Il
01a_N`Ql05]_N`004Fmk0W`07Fmk1W`0:Fmk1W`04Fmk27`036mk1W`02Fmk0W`04Vmk0W`016mk27`0
2fmk27`000=_Ng`0O0001W`00fmk27`03Fmk27`05Fmk1W`07Fmk1W`0G6mk000`Kg/6O00YKg/6O00B
Kg/6O00=Kg/6O007Kg/6O00GKg/6O00<Kg/8O002Kg/6O005Kg/6O005Kg/2O008Kg/6O00EKg/8O00L
Kg/6O01LKg/0039_N`9l02e_N`9l01A_N`Il00m_N`9l00U_N`Il01M_N`Il00e_N`Il00=_N`Il00E_
N`Il00=_N`Il00I_N`Il01E_N`Ql00Q_N`9l01A_N`9l05i_N`00B6mk0W`0;fmk0W`06fmk27`026mk
0W`03Vmk0W`03fmk1W`01Fmk0W`02Fmk0W`01Fmk1W`026mk0W`066mk1W`01fmk1W`0LVmk0016Kg/6
O01:Kg/8O006Kg/6O00NKg/00`00O01l000HKg/8O00QKg/6O007Kg/6O01bKg/004I_N`Il04]_N`Il
00M_N`Il011_N`9l00a_N`03001_Nfmk01Q_N`Ql02=_N`9l00Q_N`Ql075_N`00AFmk27`0BVmk1W`0
1Vmk27`03Fmk1W`01Vmk0W`00Vmk00<006mkKg/06Fmk1W`06Fmk0W`04fmk27`0LFmk0015Kg/8O00h
Kg/2O00BKg/2O008Kg/8O00=Kg/6O004Kg/6O0000`00Kg]_N`0IKg/6O00GKg/6O00BKg/6O01bKg/0
04I_N`Il021_N`9l01E_N`Il01]_N`Il00e_N`Ql00=_N`Il0003001_Nfmk01]_N`9l01U_N`Il019_
N`Il079_N`00AVmk1W`07Vmk1W`04fmk1W`06fmk1W`03Fmk27`00Vmk27`036mk0W`0:Fmk27`04fmk
0W`0:Vmk0W`0B6mk0018Kg/2O00PKg/6O00BKg/8O00LKg/2O00@Kg/6O003Kg/8O00:Kg/6O00NKg/2
O007Kg/8O00mKg/6O016Kg/006U_N`Ql015_N`Ql02i_N`Il00A_N`Il0003001_Nfmk00Q_N`Il01a_
N`Il00I_N`Il03i_N`Il04I_N`00JFmk27`04Vmk1W`09Vmk0W`02Fmk0W`01Vmk1W`000<006mkKg/0
1fmk27`03Vmk0W`02fmk1W`01Vmk1W`0?Fmk27`0AFmk001ZKg/6O00CKg/6O00=Kg/2O00EKg/6O00A
Kg/2O002Kg/20008Kg/8O00<Kg/6O008Kg/8O007Kg/2O00oKg/8O015Kg/006Y_N`Il01E_N`9l00e_
N`Il01=_N`Il01E_N`03001_Nfmk00Q_N`Il00e_N`Il00Q_N`Ql03E_N`9l019_N`Il04I_N`004fmk
0W`0Efmk0W`09Vmk1W`04Vmk27`056mk00@006mkO01l00M_N`Il00a_N`Ql00Q_N`Il03A_N`Il011_
N`Il04I_N`004Fmk1W`0O6mk27`04Fmk27`056mk1W`01fmk0W`03Vmk27`026mk1W`0=6mk1W`04Vmk
0W`0B6mk000AKg/6O01lKg/8O008Kg/2O008Kg/6O00EKg/6O00HKg/6O00;Kg/2O00eKg/8O00]Kg/2
O00/Kg/0011_N`Ql07a_N`Il00M_N`Il00I_N`Il01A_N`Ql00i_N`9l00M_N`Il049_N`Ql02]_N`Il
02Y_N`0046mk27`0?6mk0W`0?Vmk1W`01fmk1W`026mk0W`05Vmk27`036mk1W`01fmk0W`0<Vmk0W`0
4Fmk1W`0;6mk1W`0:Vmk000AKg/6O00kKg/6O00nKg/2O008Kg/8O00PKg/6O00=Kg/6O00iKg/6O00?
Kg/6O00[Kg/8O00YKg/0015_N`Il03]_N`Il02=_N`9l02=_N`Ql011_N`9l00i_N`Il00a_N`Ql02U_
N`9l00e_N`Il015_N`9l02e_N`Ql02U_N`004fmk0W`0?6mk27`086mk1W`08Vmk1W`03fmk1W`036mk
00@006mkO01l00i_N`Ql02M_N`Il00Y_N`Ql041_N`Il02Y_N`00;Fmk0W`08Vmk27`086mk1W`08Vmk
1W`03fmk1W`036mk00<006mkKg/046mk1W`0:6mk1W`02Vmk27`0@6mk1W`0:Vmk000[Kg/6O00QKg/6
O00PKg/8O00>Kg/2O00CKg/2O00@Kg/8O00;Kg/00`00Kg]_N`0@Kg/6O00WKg/8O00:Kg/6O013Kg/2
O00/Kg/002]_N`Il025_N`Il021_N`Ql00a_N`Il02=_N`Ql00]_N`03001_Nfmk019_N`9l02U_N`Ql
00Y_N`Il075_N`00:Vmk27`08Vmk0W`08fmk1W`03Fmk1W`096mk1W`036mk00<006mkKg/08Vmk0W`0
6Vmk1W`03Fmk0W`0Lfmk000ZKg/8O017Kg/6O00<Kg/8O00SKg/6O007Kg/2O003Kg/00`00Kg]_N`0P
Kg/6O00HKg/6O022Kg/002]_N`Il03E_N`9l01=_N`9l00i_N`Ql02E_N`9l00M_N`Il0003Kg/006mk
025_N`Il00a_N`9l00a_N`9l08A_N`00:fmk1W`0<fmk1W`08Vmk1W`0;fmk1W`000=_N`00Kg/02Vmk
0W`056mk27`02Fmk1W`0T6mk000]Kg/2O00eKg/6O00RKg/6O00CKg/2O00IKg/8O0020008Kg/6O00B
Kg/8O009Kg/6O02@Kg/006=_N`Ql02=_N`9l01=_N`Il01M_N`Ql0003001_Nfmk00M_N`Il01=_N`Il
00U_N`Ql08m_N`00Hfmk27`0>6mk1W`066mk1W`000=_N`00Kg/01fmk27`04Vmk1W`02Fmk27`0Sfmk
001TKg/6O00hKg/8O00GKg/6O0000fmk001_N`07Kg/8O00DKg/2O00<Kg/6O00_Kg/2O01OKg/006A_
N`Il03Q_N`Ql00Q_N`9l00m_N`9l00=_N`03001_Nfmk00M_N`Il02=_N`Il02e_N`Il05e_N`00IVmk
0W`0>fmk1W`01fmk1W`04Vmk00<006mkKg/01fmk1W`09Fmk0W`0;fmk1W`0GFmk002SKg/6O007Kg/6
O00BKg/00`00Kg]_N`09Kg/2O01GKg/8O00EKg/2O015Kg/009Y_N`9l00U_N`9l00Q_N`Ql015_N`03
001_Nfmk069_N`Ql01=_N`Il04=_N`00V6mk1W`04Fmk27`04Fmk00<006mkKg/05fmk0W`0BVmk1W`0
56mk1W`0@fmk0027Kg/2O00?Kg/6O00BKg/6O00BKg/00`00Kg]_N`0EKg/6O018Kg/6O00CKg/8O012
Kg/004E_N`9l03i_N`Il00a_N`Ql015_N`Il019_N`03001_Nfmk01E_N`Il03=_N`9l01E_N`9l01E_
N`Ql049_N`00@fmk1W`0?6mk1W`036mk27`04fmk0W`056mk00<007`0O00056mk27`0<6mk1W`0:fmk
1W`0@fmk0013Kg/6O00kKg/8O00<Kg/6O00YKg/6O00BKg/8O00`Kg/6O00[Kg/6O013Kg/0049_N`Ql
03Y_N`Ql00a_N`Il02U_N`Il01=_N`Il031_N`Ql02a_N`9l04E_N`00@Vmk27`0:Fmk0W`046mk1W`0
3fmk0W`07fmk1`0016mk27`04Vmk1W`0<6mk27`0Lfmk0013Kg/6O00XKg/6O00>Kg/6O00cKg/00`00
Kg]_N`05Kg/8O00DKg/2O00?Kg/2O00RKg/6O01dKg/004=_N`Il02Q_N`Il011_N`9l03E_N`03001_
Nfmk00I_N`Il02A_N`Il00m_N`9l00m_N`Il07A_N`00AFmk0W`0:Fmk27`0AVmk00<006mkKg/01Vmk
1W`096mk1W`03Fmk1W`03fmk0W`0MVmk001`Kg/8O016Kg/00`00Kg]_N`07Kg/00`00O01l000UKg/8
O00<Kg/6O01OKg/2O00VKg/005]_N`9l01A_N`Il04E_N`9l0003001_Nfmk00M_N`03001_Nfmk02E_
N`Ql00]_N`Ql05a_N`Il02A_N`00FFmk1W`04Vmk1W`0@fmk1W`026mk00<006mkKg/09Vmk1W`036mk
27`0G6mk1W`096mk001IKg/6O00DKg/2O015Kg/6O008Kg/00`00Kg]_N`0<Kg/2O00HKg/6O00=Kg/6
O01LKg/8O00SKg/005Q_N`Ql03m_N`9l00a_N`9l00Y_N`Ql00M_N`03001_Nfmk00Y_N`Il01Q_N`9l
00m_N`Il05a_N`Ql02=_N`00F6mk27`0?Fmk1W`026mk1W`026mk27`01fmk00<006mkKg/02Vmk1W`0
:fmk0W`0Gfmk1W`096mk001IKg/6O00nKg/6O008Kg/6O009Kg/6O008Kg/00`00Kg]_N`09Kg/8O02;
Kg/6O00TKg/005U_N`Il02Y_N`9l015_N`Ql00I_N`Ql00Q_N`Il00Q_N`03001_Nfmk00U_N`Ql05A_
N`9l03M_N`9l02I_N`00Ffmk0W`0:Vmk1W`03fmk27`01Vmk27`02Vmk0W`02Vmk00<006mkKg/02Vmk
1W`0Dfmk1W`0GFmk0027Kg/6O00@Kg/6O008Kg/6O00GKg/00`00Kg]_N`0:Kg/6O01CKg/6O01MKg/0
02Y_N`9l05Y_N`Ql00m_N`Il00Q_N`Il01M_N`03001_Nfmk00a_N`9l05A_N`Ql05a_N`00:6mk1W`0
F6mk27`04Fmk0W`036mk0W`06Fmk00<006mkKg/0HVmk27`0<Fmk0W`0:Fmk000XKg/6O01IKg/6O00k
Kg/00`00Kg]_N`1SKg/6O00`Kg/6O00WKg/002M_N`Ql05Q_N`Il03]_N`03001_Nfmk01i_N`9l04=_
N`Il031_N`Il02M_N`009fmk27`0FVmk0W`0?Fmk00<006mkKg/076mk1W`0@fmk0W`0<Fmk27`09Vmk
000XKg/8O02HKg/00`00Kg]_N`0LKg/6O01fKg/8O00VKg/002Q_N`Ql09I_N`9l0003001_Nfmk01]_
N`Ql07I_N`Il02M_N`00:Fmk1W`0UFmk1W`076mk27`0:Vmk0W`0BVmk1W`09fmk000YKg/6O02EKg/6
O00MKg/6O00YKg/6O00bKg/2O00FKg/2O00YKg/002]_N`9l04i_N`9l04I_N`Ql01a_N`Il02U_N`Il
031_N`Il03m_N`00NFmk1W`066mk0W`0:Vmk27`07Vmk0W`056mk0W`056mk27`0;fmk1W`0?fmk001i
Kg/6O00FKg/6O00YKg/6O00cKg/6O00BKg/8O00^Kg/8O00nKg/007Q_N`Ql01E_N`Il02U_N`Il03=_
N`Il01=_N`Il02m_N`Ql03i_N`00IFmk0W`04Fmk27`056mk27`0:Vmk0W`000<006mkKg/0<Fmk27`0
4Vmk1W`0<6mk1W`0?fmk001SKg/6O00@Kg/6O00EKg/8O00EKg/2O00EKg/00`00Kg]_N`0aKg/8O00D
Kg/2O00bKg/6O00oKg/004I_N`9l01]_N`Il011_N`Il01I_N`Il01A_N`Il01=_N`03001_Nfmk039_
N`Il04]_N`9l045_N`00A6mk1W`066mk27`04Fmk0W`066mk1W`056mk1W`04fmk00<006mkKg/0<Vmk
1W`0SVmk0014Kg/6O00HKg/8O00]Kg/2O00EKg/8O00BKg/00`00Kg]_N`0@Kg/2O00RKg/2O02@Kg/0
04=_N`Ql01Q_N`Il04E_N`Ql019_N`03001_Nfmk00i_N`Il0;9_N`00@fmk27`066mk1W`0AVmk1W`0
4fmk00<006mkKg/03Vmk1W`0/Vmk0014Kg/6O00KKg/2O018Kg/6O00CKg/00`00Kg]_N`0=Kg/8O02a
Kg/004A_N`Il06M_N`9l01E_N`03001_Nfmk00e_N`Ql0;5_N`00AVmk0W`0P6mk00<006mkKg/03Vmk
1W`0/Vmk0038Kg/00`00Kg]_N`0>Kg/6O02bKg/00<Q_N`03001_Nfmk011_N`9l05=_N`9l05m_N`00
b6mk0P00I6mk1W`0GFmk0038Kg/00`00Kg]_N`1SKg/6O01MKg/009]_N`9l02]_N`03001_Nfmk069_
N`Ql05a_N`00VFmk1W`0:Fmk00<006mkKg/0HVmk27`0G6mk002IKg/6O00WKg/2O0000`00Kg]_N`0X
Kg/2O00iKg/6O00MKg/2O00nKg/009Q_N`Ql02A_N`Il02M_N`Il03M_N`Il01]_N`Il03a_N`00V6mk
27`096mk1W`09fmk1W`0>Fmk0W`07Fmk1W`0?6mk002IKg/6O00TKg/8O00UKg/8O01FKg/8O00kKg/0
07i_N`9l01U_N`Il02A_N`Ql02E_N`Ql05I_N`Ql03]_N`00O6mk1W`06Fmk0W`09fmk1W`09fmk1W`0
6Vmk0W`0?6mk1W`0?6mk001lKg/6O012Kg/6O00WKg/6O00HKg/6O00jKg/6O00lKg/007]_N`Ql04=_
N`9l0003001_Nfmk02Q_N`9l01Y_N`Il03a_N`9l03i_N`00Nfmk27`0AFmk00<006mkKg/0@fmk27`0
Nfmk001lKg/6O016Kg/00`00Kg]_N`13Kg/8O01kKg/007a_N`Il04I_N`03001_Nfmk04A_N`Il07a_
N`00OVmk0W`0B6mk00<006mkKg/0A6mk1W`0O6mk0038Kg/00`00Kg]_N`16Kg/2O01nKg/004Y_N`9l
06=_N`9l01M_N`800<M_N`00B6mk1W`046mk0W`0CFmk1W`05Fmk00<006mkKg/04fmk0W`0/Fmk0018
Kg/6O00>Kg/6O01;Kg/6O00EKg/00`00Kg]_N`0AKg/6O02_Kg/004M_N`Ql00e_N`Il04Y_N`Ql01A_
N`03001_Nfmk015_N`Il0:m_N`00Afmk27`036mk27`0BFmk27`056mk00<006mkKg/046mk27`0[Vmk
0018Kg/6O00=Kg/8O01:Kg/6O00EKg/00`00Kg]_N`0@Kg/8O02^Kg/004Q_N`Il00i_N`Il04]_N`Il
01E_N`03001_Nfmk015_N`Il0:m_N`00BVmk0W`046mk1W`0CFmk0W`05fmk00<006mkKg/04Fmk1W`0
[fmk001NKg/2O01XKg/00`00Kg]_N`0CKg/2O02aKg/00<Q_N`03001_Nfmk0<I_N`00b6mk00<006mk
Kg/0aVmk002CKg/2O00cKg/00`00Kg]_N`36Kg/0095_N`Il035_N`03001_Nfmk0<I_N`00TFmk1W`0
<Fmk00<006mkKg/0aVmk002@Kg/8O00`Kg/00`00Kg]_N`1PKg/2O01TKg/0091_N`Ql031_N`03001_
Nfmk039_N`9l02Y_N`Il069_N`00TFmk1W`0;Vmk0W`000=_N`00Kg/0<Fmk1W`0:6mk1W`0HVmk002A
Kg/6O00/Kg/6O00bKg/6O00WKg/8O01QKg/009=_N`9l02i_N`Il0003001_Nfmk02i_N`Ql02I_N`Ql
065_N`00`Vmk27`0<6mk27`09fmk1W`0HVmk0032Kg/8O00aKg/6O00XKg/6O01RKg/00<=_N`Il039_
N`Il02Y_N`9l06A_N`00JVmk0W`01fmk0W`0CVmk1W`0=6mk0W`0TVmk001XKg/6O003Kg/6O01>Kg/2
O0000fmk001_N`1CKg/2O01bKg/006Q_N`Il00=_N`Il055_N`03001_Nfmk051_N`Il071_N`00Ifmk
27`000=_Ng`0O0001W`0D6mk00<006mkKg/0D6mk1W`0L6mk001WKg/8O0000fmkO01l0006O01@Kg/0
0`00Kg]_N`1?Kg/8O01_Kg/006Q_N`Il00=_N`Il055_N`03001_Nfmk04m_N`Ql06m_N`00J6mk1W`0
0fmk1W`0DFmk00<006mkKg/0D6mk1W`0L6mk001ZKg/2O007Kg/2O01CKg/00`00Kg]_N`1@Kg/6O01`
Kg/00<Q_N`03001_Nfmk059_N`9l079_N`00b6mk00<006mkKg/0aVmk002kKg/60007Kg/00`00Kg]_
N`36Kg/00:U_N`9l011_N`03001_Nfmk009_N`03001_Nfmk00E_N`03001_Nfmk01I_N`9l0:i_N`00
Yfmk1W`03fmk00<006mkKg/02Fmk00<006mkKg/056mk1W`0[6mk002WKg/6O00@Kg/00`00Kg]_N`08
Kg/3000DKg/6O02/Kg/00:I_N`Ql011_N`03001_Nfmk00M_N`03001_Nfmk01=_N`Ql0:]_N`00YVmk
27`04Fmk00<006mkKg/01Vmk00<006mkKg/04fmk27`0Zfmk002WKg/6O00>Kg/00`00Kg]_N`02Kg/0
0`00Kg]_N`05Kg/00`00Kg]_N`0DKg/6O02/Kg/008e_N`9l01Q_N`Il00i_N`03001_Nfmk009_N`03
001_Nfmk00E_N`03001_Nfmk01A_N`Il0:a_N`00Rfmk1W`066mk0W`04Fmk100026mk00<006mkKg/0
5Vmk0W`0[Vmk002;Kg/6O00gKg/00`00Kg]_N`36Kg/008Y_N`Ql03I_N`03001_Nfmk0<I_N`00RVmk
27`0=Vmk00<006mkKg/0aVmk002;Kg/6O00gKg/00`00Kg]_N`36Kg/008]_N`Il03M_N`03001_Nfmk
0<I_N`00SFmk0W`09Fmk0W`04Vmk00<006mkKg/02fmk0W`0^Fmk002bKg/6O00@Kg/00`00Kg]_N`09
Kg/6O02gKg/00;9_N`Il011_N`03001_Nfmk00U_N`Il0;M_N`00/Fmk27`03fmk00<006mkKg/00W`0
1Vmk27`0]Vmk002aKg/8O00?Kg/00`00O01l0004O004Kg/8O02fKg/00;9_N`Il011_N`03001l07`0
00Al00E_N`Il0;M_N`00/Vmk1W`046mk27`016mk1W`0]fmk002dKg/2O00BKg/8O006Kg/2O02iKg/0
0<Q_N`03001l07`000Al0<9_N`00b6mk00<007`0O00017`0`Vmk0038Kg/00`00Kg]_N`02O034Kg/0
0<Q_N`03001_Nfmk0<I_N`00b6mk00<006mkKg/0aVmk0038Kg/00`00Kg]_N`36Kg/00<Q_N`03001_
Nfmk0<I_N`00b6mk00<006mkKg/0aVmk0000\
\>"],
  ImageRangeCache->{{{0, 400.25}, {396.375, 0}} -> {-2.28608, -2.22817, \
0.0171334, 0.0171334}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["\<\
The boundary looks rough above. To complete the algorithm, we need to add the \
section that brings points outside onto the boundary.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Mesh Generator as a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Package"
}], "Section"],

Cell[TextData[{
  "All the previous sections have taken the original code pieces apart so \
that we can experiment with each component of the algorithm. To assemble them \
together, we can put it into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package (.m) file and fasten some screws along the way. The package \
effectively hides the details of the algorithm so that end users can simply \
load the package and use the functions available. "
}], "Text"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package is in a separate file (",
  StyleBox["meshgenerator.m",
    FontFamily->"Courier"],
  "). To construct the package, I basically copy and paste the cells from \
these previous sections into it. This could become tedious when the functions \
are numerous. However there is no reason why an automatic process (maybe \
called ",
  StyleBox["MathematicaTangle",
    FontFamily->"Courier"],
  StyleBox[") can't be used for larger package constructions. Each code piece \
in an input cell can be tagged by a section name. And by using ",
    FontFamily->"Times New Roman"],
  StyleBox["AuthorTools",
    FontFamily->"Courier"],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  StyleBox["NotebookFind",
    FontFamily->"Courier"],
  StyleBox[", ",
    FontFamily->"Times New Roman"],
  StyleBox["NotebookWrite",
    FontFamily->"Courier"],
  StyleBox[" functions, etc., one can extract and assemble the pieces into a \
new notebook. The whole notebook cell can then be marked as a initialization \
cell and saved as ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " package file."
}], "Text"],

Cell["Here is an example of using the package: ", "Text"],

Cell[BoxData[
    \(\(\( (*\ 
      clear\ everything\ defined\ \
before*) \)\(\[IndentingNewLine]\)\(Remove["\<Global`*\>"]\)\)\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(\(\( (*\ 
      set\ the\ current\ directory\ to\ where\ the\ package\ file\ is\ stored\
\ and\ read\ in\ the\ package\ \
*) \)\(\[IndentingNewLine]\)\(SetDirectory["\<c:\\\>"]; << 
      meshgenerator`\)\)\)], "Input",
  CellLabel->"In[113]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?generateMesh\)\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \("generateMesh[d_,h_,h0_,{x1_,y1_,x2_,y2_}] generates a mesh for a \
region defined by the distance function d(x,y) and size function h(x,y). The \
mesh sise is h0 and an initial rectangle region is defined by (x1,y1) and \
(x2,y2)."\)], "Print",
  CellTags->"Info3309581561-6542075"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[generateMesh]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \({Fscale \[Rule] 1.2`, DeltaT \[Rule] 0.2`, Eps \[Rule] 0.2`, 
      MaxSteps \[Rule] 50}\)], "Output",
  CellLabel->"Out[115]="]
}, Open  ]],

Cell[BoxData[{
    \(\(d[{x_, y_}] := 
        ddiff[dcircle[{x, y}, {0, 0, 4}], 
          dcircle[{x, y}, {0, 2, 1}]];\)\), "\[IndentingNewLine]", 
    \(\(h[{x_, y_}] := 0.1 + 0.4 \@\( x\^2 + \((y - 2)\)\^2\);\)\)}], "Input",\

  CellLabel->"In[49]:="],

Cell[BoxData[
    \(\(\( (*\ 
      It\ may\ take\ quite\ a\ while\ to\ run\ \
*) \)\(\[IndentingNewLine]\)\(p2 = 
        generateMesh[d, h, 0.1, {\(-10\), \(-10\), 10, 10}];\)\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[p2, AspectRatio \[Rule] Automatic]\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .99122 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.498999 0.119667 0.491271 0.119667 [
[.02033 .47877 -6 -9 ]
[.02033 .47877 6 0 ]
[.25967 .47877 -6 -9 ]
[.25967 .47877 6 0 ]
[.73833 .47877 -3 -9 ]
[.73833 .47877 3 0 ]
[.97767 .47877 -3 -9 ]
[.97767 .47877 3 0 ]
[.4865 .0126 -12 -4.5 ]
[.4865 .0126 0 4.5 ]
[.4865 .25194 -12 -4.5 ]
[.4865 .25194 0 4.5 ]
[.4865 .7306 -6 -4.5 ]
[.4865 .7306 0 4.5 ]
[.4865 .96994 -6 -4.5 ]
[.4865 .96994 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .99122 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02033 .49127 m
.02033 .49752 L
s
[(-4)] .02033 .47877 0 1 Mshowa
.25967 .49127 m
.25967 .49752 L
s
[(-2)] .25967 .47877 0 1 Mshowa
.73833 .49127 m
.73833 .49752 L
s
[(2)] .73833 .47877 0 1 Mshowa
.97767 .49127 m
.97767 .49752 L
s
[(4)] .97767 .47877 0 1 Mshowa
.125 Mabswid
.08017 .49127 m
.08017 .49502 L
s
.14 .49127 m
.14 .49502 L
s
.19983 .49127 m
.19983 .49502 L
s
.3195 .49127 m
.3195 .49502 L
s
.37933 .49127 m
.37933 .49502 L
s
.43917 .49127 m
.43917 .49502 L
s
.55883 .49127 m
.55883 .49502 L
s
.61867 .49127 m
.61867 .49502 L
s
.6785 .49127 m
.6785 .49502 L
s
.79817 .49127 m
.79817 .49502 L
s
.858 .49127 m
.858 .49502 L
s
.91783 .49127 m
.91783 .49502 L
s
.25 Mabswid
0 .49127 m
1 .49127 L
s
.499 .0126 m
.50525 .0126 L
s
[(-4)] .4865 .0126 1 0 Mshowa
.499 .25194 m
.50525 .25194 L
s
[(-2)] .4865 .25194 1 0 Mshowa
.499 .7306 m
.50525 .7306 L
s
[(2)] .4865 .7306 1 0 Mshowa
.499 .96994 m
.50525 .96994 L
s
[(4)] .4865 .96994 1 0 Mshowa
.125 Mabswid
.499 .07244 m
.50275 .07244 L
s
.499 .13227 m
.50275 .13227 L
s
.499 .1921 m
.50275 .1921 L
s
.499 .31177 m
.50275 .31177 L
s
.499 .3716 m
.50275 .3716 L
s
.499 .43144 m
.50275 .43144 L
s
.499 .5511 m
.50275 .5511 L
s
.499 .61094 m
.50275 .61094 L
s
.499 .67077 m
.50275 .67077 L
s
.499 .79044 m
.50275 .79044 L
s
.499 .85027 m
.50275 .85027 L
s
.499 .9101 m
.50275 .9101 L
s
.25 Mabswid
.499 0 m
.499 .99122 L
s
0 0 m
1 0 L
1 .99122 L
0 .99122 L
closepath
clip
newpath
.008 w
.39699 .0236 Mdot
.41497 .0484 Mdot
.61033 .02573 Mdot
.29129 .06002 Mdot
.50498 .0615 Mdot
.67456 .06398 Mdot
.71842 .06586 Mdot
.61434 .0786 Mdot
.42837 .08441 Mdot
.59742 .11114 Mdot
.76615 .09409 Mdot
.35457 .09475 Mdot
.29427 .10892 Mdot
.42384 .11409 Mdot
.66995 .11848 Mdot
.2728 .13874 Mdot
.7322 .13745 Mdot
.47744 .13806 Mdot
.80345 .1409 Mdot
.16701 .14644 Mdot
.33815 .15549 Mdot
.38726 .1505 Mdot
.43587 .1536 Mdot
.51571 .14571 Mdot
.5775 .15717 Mdot
.71578 .15936 Mdot
.29402 .17548 Mdot
.369 .1858 Mdot
.43485 .18175 Mdot
.51166 .18259 Mdot
.68599 .16438 Mdot
.19815 .18635 Mdot
.65174 .17986 Mdot
.82325 .18318 Mdot
.12676 .19034 Mdot
.60938 .18772 Mdot
.7093 .20517 Mdot
.55017 .20034 Mdot
.67849 .22252 Mdot
.85307 .19438 Mdot
.11184 .20979 Mdot
.15625 .20906 Mdot
.25627 .20564 Mdot
.31255 .21741 Mdot
.43316 .21248 Mdot
.47166 .21439 Mdot
.74794 .21799 Mdot
.86658 .21964 Mdot
.12959 .23559 Mdot
.24403 .22399 Mdot
.35428 .21527 Mdot
.49855 .21498 Mdot
.5661 .22744 Mdot
.62858 .22619 Mdot
.17408 .25297 Mdot
.39496 .2329 Mdot
.44217 .24688 Mdot
.60163 .24458 Mdot
.10832 .26799 Mdot
.24914 .24922 Mdot
.37333 .25259 Mdot
.49187 .24945 Mdot
.52116 .23409 Mdot
.54675 .24235 Mdot
.65452 .25406 Mdot
.85083 .26632 Mdot
.29059 .26594 Mdot
.34897 .26316 Mdot
.41971 .26554 Mdot
.50611 .26725 Mdot
.54031 .26092 Mdot
.50989 .28617 Mdot
.58699 .26891 Mdot
.72571 .2722 Mdot
.77399 .26868 Mdot
.30774 .28127 Mdot
.54448 .28807 Mdot
.07387 .2713 Mdot
.22611 .2846 Mdot
.5678 .2942 Mdot
.67288 .28668 Mdot
.17677 .29504 Mdot
.20554 .29775 Mdot
.24897 .30071 Mdot
.34351 .29406 Mdot
.38485 .2952 Mdot
.08061 .29945 Mdot
.42593 .31073 Mdot
.61481 .30987 Mdot
.80682 .30313 Mdot
.88879 .304 Mdot
.05372 .32966 Mdot
.27896 .31402 Mdot
.34283 .31905 Mdot
.38435 .31955 Mdot
.4925 .31578 Mdot
.51499 .31574 Mdot
.56384 .31515 Mdot
.67674 .31997 Mdot
.079 .352 Mdot
.31401 .33479 Mdot
.52631 .33478 Mdot
.551 .33412 Mdot
.1866 .35049 Mdot
.2316 .34412 Mdot
.27821 .33325 Mdot
.34194 .34808 Mdot
.79964 .33168 Mdot
.25427 .35787 Mdot
.28601 .35229 Mdot
.35785 .35437 Mdot
.3917 .34984 Mdot
.44043 .3469 Mdot
.4668 .3442 Mdot
.49973 .34943 Mdot
.5724 .34613 Mdot
.59588 .3386 Mdot
.6968 .34438 Mdot
.78302 .35401 Mdot
.12812 .35376 Mdot
.29419 .3734 Mdot
.47395 .36107 Mdot
.5839 .36606 Mdot
.60921 .35508 Mdot
.68104 .37138 Mdot
.72083 .36383 Mdot
.75058 .3587 Mdot
.81886 .3677 Mdot
.85609 .36114 Mdot
.89749 .35593 Mdot
.38284 .37172 Mdot
.43865 .37438 Mdot
.48158 .37302 Mdot
.55398 .37221 Mdot
.59442 .38078 Mdot
.63345 .3689 Mdot
.90792 .37768 Mdot
.23493 .37946 Mdot
.32737 .38392 Mdot
.39145 .38068 Mdot
.51274 .38321 Mdot
.52354 .38336 Mdot
.53487 .38232 Mdot
.54395 .38488 Mdot
.57202 .38782 Mdot
.62155 .3942 Mdot
.13929 .3929 Mdot
.41551 .39318 Mdot
.46407 .39608 Mdot
.48182 .38896 Mdot
.73952 .39309 Mdot
.83857 .38558 Mdot
.19215 .40028 Mdot
.23969 .40597 Mdot
.35529 .40496 Mdot
.38828 .40956 Mdot
.42709 .4065 Mdot
.4476 .40467 Mdot
.49136 .40542 Mdot
.58377 .40891 Mdot
.66011 .3858 Mdot
.79306 .39802 Mdot
.91178 .3868 Mdot
.96814 .39625 Mdot
.05523 .40404 Mdot
.12235 .41684 Mdot
.48571 .42176 Mdot
.67241 .41405 Mdot
.70104 .40806 Mdot
.75534 .41254 Mdot
.77932 .41104 Mdot
.8181 .41255 Mdot
.9264 .40949 Mdot
.06939 .4327 Mdot
.45666 .41983 Mdot
.53771 .42106 Mdot
.64648 .42517 Mdot
.66258 .43195 Mdot
.83027 .43605 Mdot
.9143 .43362 Mdot
.20606 .43789 Mdot
.24753 .42808 Mdot
.33325 .43077 Mdot
.41571 .43051 Mdot
.46688 .43295 Mdot
.49135 .43187 Mdot
.59204 .43185 Mdot
.78891 .44449 Mdot
.87156 .43483 Mdot
.11049 .44393 Mdot
.25613 .44602 Mdot
.27945 .43715 Mdot
.34281 .44445 Mdot
.38665 .4418 Mdot
.411 .44533 Mdot
.44337 .44146 Mdot
.47677 .44756 Mdot
.50698 .44586 Mdot
.52511 .44439 Mdot
.58579 .44337 Mdot
.62904 .44337 Mdot
.67666 .44604 Mdot
.70005 .4432 Mdot
.71784 .44247 Mdot
.73672 .44048 Mdot
.93617 .44748 Mdot
.29562 .45053 Mdot
.36309 .44911 Mdot
.38246 .45269 Mdot
.48526 .45798 Mdot
.55887 .45368 Mdot
.57937 .45994 Mdot
.66577 .46072 Mdot
.75959 .45377 Mdot
.78645 .45974 Mdot
.94801 .46301 Mdot
.12488 .46875 Mdot
.15739 .46443 Mdot
.1877 .4621 Mdot
.25392 .4734 Mdot
.28471 .47426 Mdot
.33614 .47012 Mdot
.35337 .46672 Mdot
.37652 .46533 Mdot
.40025 .46758 Mdot
.43286 .46512 Mdot
.45121 .46516 Mdot
.46286 .46503 Mdot
.53497 .46277 Mdot
.75143 .47179 Mdot
.91228 .47821 Mdot
.31444 .47441 Mdot
.38703 .48132 Mdot
.46576 .47316 Mdot
.49825 .47418 Mdot
.52556 .47699 Mdot
.55444 .47552 Mdot
.60758 .4753 Mdot
.62671 .47677 Mdot
.64873 .47714 Mdot
.68676 .47585 Mdot
.06895 .48323 Mdot
.21355 .48129 Mdot
.36501 .48642 Mdot
.43396 .485 Mdot
.45967 .48772 Mdot
.47732 .483 Mdot
.49332 .4856 Mdot
.5598 .48589 Mdot
.67653 .49025 Mdot
.70984 .47911 Mdot
.72713 .48377 Mdot
.74184 .48053 Mdot
.87755 .48711 Mdot
.17757 .49401 Mdot
.24511 .49214 Mdot
.32761 .49392 Mdot
.35968 .49428 Mdot
.4021 .49488 Mdot
.41868 .49645 Mdot
.4458 .49914 Mdot
.45533 .50059 Mdot
.46716 .50062 Mdot
.48512 .4972 Mdot
.51113 .49411 Mdot
.53166 .49393 Mdot
.57798 .48939 Mdot
.58984 .49093 Mdot
.71651 .50478 Mdot
.7704 .48984 Mdot
.79473 .49532 Mdot
.82019 .49548 Mdot
.12743 .50254 Mdot
.23537 .51247 Mdot
.28286 .50043 Mdot
.30156 .5008 Mdot
.35411 .50359 Mdot
.37774 .50912 Mdot
.39306 .50867 Mdot
.47378 .51402 Mdot
.49114 .51185 Mdot
.52288 .5102 Mdot
.54396 .50324 Mdot
.55666 .50412 Mdot
.57269 .50395 Mdot
.59399 .50463 Mdot
.62092 .50392 Mdot
.66667 .50332 Mdot
.70151 .5062 Mdot
.73606 .51124 Mdot
.76168 .50907 Mdot
.02381 .51836 Mdot
.18441 .51562 Mdot
.21178 .51843 Mdot
.26306 .51814 Mdot
.31112 .51326 Mdot
.33368 .51533 Mdot
.34621 .52148 Mdot
.36556 .52535 Mdot
.43495 .51299 Mdot
.50284 .51824 Mdot
.53797 .51826 Mdot
.55274 .51791 Mdot
.56469 .51791 Mdot
.57863 .51678 Mdot
.5915 .52061 Mdot
.61272 .51674 Mdot
.63705 .51708 Mdot
.65631 .51422 Mdot
.76978 .52742 Mdot
.08577 .52668 Mdot
.15186 .52201 Mdot
.1726 .53161 Mdot
.28234 .53098 Mdot
.30387 .52775 Mdot
.32218 .53241 Mdot
.39237 .52556 Mdot
.41042 .52544 Mdot
.42375 .52806 Mdot
.44518 .52806 Mdot
.46192 .52475 Mdot
.52288 .52583 Mdot
.54304 .53037 Mdot
.5604 .5312 Mdot
.57209 .53343 Mdot
.58441 .53346 Mdot
.6075 .52953 Mdot
.66648 .52783 Mdot
.68242 .52766 Mdot
.68701 .52663 Mdot
.70305 .52735 Mdot
.8457 .52927 Mdot
.89037 .52454 Mdot
.11881 .53486 Mdot
.29962 .54014 Mdot
.33035 .5421 Mdot
.38235 .53565 Mdot
.43569 .54241 Mdot
.47132 .537 Mdot
.4918 .53706 Mdot
.51463 .53886 Mdot
.52959 .53891 Mdot
.55321 .54317 Mdot
.61426 .54201 Mdot
.64583 .53355 Mdot
.71187 .54086 Mdot
.73446 .53509 Mdot
.77955 .53868 Mdot
.91642 .53812 Mdot
.97619 .52882 Mdot
.14216 .54707 Mdot
.20968 .5464 Mdot
.22689 .54715 Mdot
.23491 .54254 Mdot
.26411 .54523 Mdot
.30422 .55568 Mdot
.33502 .55082 Mdot
.35546 .54622 Mdot
.39101 .55002 Mdot
.40187 .54648 Mdot
.41616 .54502 Mdot
.46115 .54878 Mdot
.5118 .54847 Mdot
.53527 .54705 Mdot
.5939 .54877 Mdot
.62468 .54806 Mdot
.63839 .54875 Mdot
.65644 .54518 Mdot
.66953 .55095 Mdot
.68124 .55065 Mdot
.73857 .55033 Mdot
.80261 .55104 Mdot
.1505 .56849 Mdot
.17856 .55848 Mdot
.25576 .55846 Mdot
.37389 .55641 Mdot
.38585 .56164 Mdot
.40633 .55933 Mdot
.4229 .55673 Mdot
.4344 .5562 Mdot
.44667 .5551 Mdot
.4679 .55812 Mdot
.4823 .557 Mdot
.49106 .55782 Mdot
.50722 .55865 Mdot
.5261 .56318 Mdot
.5423 .55853 Mdot
.56255 .5548 Mdot
.57884 .55665 Mdot
.64987 .56269 Mdot
.66377 .5663 Mdot
.70948 .56166 Mdot
.75787 .55855 Mdot
.94172 .55571 Mdot
.05838 .56176 Mdot
.09711 .57039 Mdot
.1171 .57597 Mdot
.21304 .57648 Mdot
.24363 .56839 Mdot
.31782 .56672 Mdot
.35042 .5662 Mdot
.36795 .56586 Mdot
.40073 .57265 Mdot
.41409 .57202 Mdot
.42738 .56971 Mdot
.43932 .56972 Mdot
.45252 .56753 Mdot
.46262 .56881 Mdot
.47742 .56974 Mdot
.499 .56974 Mdot
.54564 .5675 Mdot
.5593 .56997 Mdot
.57171 .57121 Mdot
.59385 .56934 Mdot
.60897 .56843 Mdot
.62669 .57002 Mdot
.64233 .57017 Mdot
.68827 .57096 Mdot
.87888 .56411 Mdot
.9571 .58204 Mdot
.04923 .57517 Mdot
.19392 .57735 Mdot
.27233 .58078 Mdot
.32625 .57652 Mdot
.34546 .57733 Mdot
.36168 .57999 Mdot
.37521 .57726 Mdot
.38959 .58009 Mdot
.42027 .58376 Mdot
.43223 .58203 Mdot
.4453 .58008 Mdot
.45723 .58009 Mdot
.46917 .5801 Mdot
.48218 .57877 Mdot
.49196 .57876 Mdot
.50793 .57869 Mdot
.53772 .57867 Mdot
.5546 .57986 Mdot
.57722 .57826 Mdot
.75904 .57643 Mdot
.24577 .58274 Mdot
.26636 .59259 Mdot
.2923 .58933 Mdot
.31556 .58911 Mdot
.33594 .59026 Mdot
.35238 .59034 Mdot
.36911 .59285 Mdot
.38096 .59179 Mdot
.4045 .58946 Mdot
.43648 .59193 Mdot
.45127 .59045 Mdot
.46321 .59046 Mdot
.47514 .59046 Mdot
.48707 .59047 Mdot
.499 .59047 Mdot
.51271 .59025 Mdot
.52197 .58875 Mdot
.5338 .58875 Mdot
.54672 .59045 Mdot
.55976 .58853 Mdot
.56986 .58934 Mdot
.58479 .59041 Mdot
.59379 .58863 Mdot
.60666 .58704 Mdot
.61834 .58639 Mdot
.63026 .58803 Mdot
.64079 .58892 Mdot
.65961 .58576 Mdot
.70109 .59201 Mdot
.72405 .58921 Mdot
.74556 .58687 Mdot
.87869 .58655 Mdot
.03062 .58996 Mdot
.16934 .5973 Mdot
.19602 .59971 Mdot
.22175 .59871 Mdot
.24198 .60038 Mdot
.26216 .60729 Mdot
.30989 .60492 Mdot
.32688 .60599 Mdot
.34725 .60023 Mdot
.3638 .60219 Mdot
.38461 .59848 Mdot
.3993 .59899 Mdot
.42258 .59941 Mdot
.4443 .6022 Mdot
.45647 .60217 Mdot
.46918 .60082 Mdot
.48111 .60083 Mdot
.49304 .60083 Mdot
.50648 .60083 Mdot
.52726 .60082 Mdot
.54153 .60217 Mdot
.55187 .6022 Mdot
.56462 .60079 Mdot
.57798 .60088 Mdot
.59933 .60274 Mdot
.61219 .60366 Mdot
.62589 .60296 Mdot
.65064 .60077 Mdot
.77236 .59827 Mdot
.82196 .59258 Mdot
.85564 .59592 Mdot
.91931 .59974 Mdot
.04613 .6082 Mdot
.09117 .61018 Mdot
.11368 .61376 Mdot
.2073 .61382 Mdot
.23377 .61838 Mdot
.33877 .61049 Mdot
.35851 .61104 Mdot
.37728 .6089 Mdot
.39159 .61109 Mdot
.40435 .60941 Mdot
.41628 .60935 Mdot
.43841 .60974 Mdot
.46178 .61336 Mdot
.47514 .61325 Mdot
.4869 .61155 Mdot
.499 .61094 Mdot
.51167 .61161 Mdot
.52215 .61201 Mdot
.53622 .61336 Mdot
.5571 .61115 Mdot
.57141 .61258 Mdot
.58266 .61087 Mdot
.59501 .6095 Mdot
.62991 .61217 Mdot
.63943 .6109 Mdot
.65739 .61242 Mdot
.66796 .60949 Mdot
.68072 .60899 Mdot
.74599 .61081 Mdot
.76299 .61456 Mdot
.79021 .6096 Mdot
.83299 .61463 Mdot
.04086 .62994 Mdot
.05801 .62673 Mdot
.15662 .61375 Mdot
.1945 .62685 Mdot
.34816 .62278 Mdot
.36117 .62261 Mdot
.3732 .62098 Mdot
.38456 .62328 Mdot
.39758 .62144 Mdot
.40953 .62146 Mdot
.4223 .62004 Mdot
.43326 .62125 Mdot
.44725 .62238 Mdot
.55075 .62238 Mdot
.56546 .62262 Mdot
.58678 .62146 Mdot
.60244 .62129 Mdot
.61193 .6219 Mdot
.62426 .62127 Mdot
.64949 .62399 Mdot
.69224 .61696 Mdot
.70814 .61441 Mdot
.72366 .61459 Mdot
.80293 .62579 Mdot
.88369 .62074 Mdot
.90701 .62488 Mdot
.14616 .63371 Mdot
.23817 .63079 Mdot
.34067 .63282 Mdot
.36779 .63123 Mdot
.38995 .63198 Mdot
.40357 .6318 Mdot
.41619 .63299 Mdot
.42858 .63385 Mdot
.57009 .63268 Mdot
.58103 .63165 Mdot
.59606 .63189 Mdot
.62906 .63376 Mdot
.64117 .63044 Mdot
.66748 .62914 Mdot
.70025 .63502 Mdot
.71502 .63613 Mdot
.72758 .62807 Mdot
.76666 .6336 Mdot
.84525 .63184 Mdot
.07755 .65224 Mdot
.23025 .64442 Mdot
.28775 .64077 Mdot
.31486 .64039 Mdot
.3464 .64284 Mdot
.36162 .64186 Mdot
.3741 .64167 Mdot
.38497 .64058 Mdot
.39761 .64214 Mdot
.4115 .64326 Mdot
.58719 .64445 Mdot
.60226 .6419 Mdot
.6483 .64111 Mdot
.65822 .64147 Mdot
.67718 .64134 Mdot
.6942 .64724 Mdot
.72993 .63809 Mdot
.74826 .63772 Mdot
.15993 .65274 Mdot
.1892 .64715 Mdot
.21616 .64995 Mdot
.35487 .65249 Mdot
.37776 .65245 Mdot
.39165 .65247 Mdot
.40545 .65354 Mdot
.60744 .65099 Mdot
.62838 .64919 Mdot
.6435 .65111 Mdot
.66676 .65425 Mdot
.72062 .65464 Mdot
.73799 .65738 Mdot
.75466 .64961 Mdot
.86103 .65351 Mdot
.89352 .65759 Mdot
.94577 .65081 Mdot
.16432 .66197 Mdot
.19738 .66375 Mdot
.30266 .66152 Mdot
.325 .65977 Mdot
.3469 .66443 Mdot
.36176 .66279 Mdot
.37304 .66145 Mdot
.38569 .6628 Mdot
.39943 .66385 Mdot
.5979 .6627 Mdot
.61315 .66134 Mdot
.62336 .66122 Mdot
.63727 .66458 Mdot
.6483 .66276 Mdot
.66251 .66313 Mdot
.68296 .66113 Mdot
.75925 .66327 Mdot
.79038 .65648 Mdot
.81211 .65303 Mdot
.84211 .6639 Mdot
.24199 .66882 Mdot
.26627 .66892 Mdot
.2956 .67288 Mdot
.33299 .67223 Mdot
.36686 .67449 Mdot
.37966 .67576 Mdot
.3928 .67532 Mdot
.60454 .67417 Mdot
.61827 .67313 Mdot
.63292 .6746 Mdot
.65443 .67309 Mdot
.68827 .67492 Mdot
.70174 .669 Mdot
.71326 .67004 Mdot
.72404 .67176 Mdot
.73901 .67111 Mdot
.75216 .67713 Mdot
.7817 .67271 Mdot
.82348 .67498 Mdot
.13216 .68003 Mdot
.16592 .68525 Mdot
.18086 .68574 Mdot
.20804 .68294 Mdot
.22536 .68184 Mdot
.25299 .68893 Mdot
.28783 .6846 Mdot
.32284 .6844 Mdot
.34723 .68217 Mdot
.36254 .68172 Mdot
.61047 .68453 Mdot
.62598 .68346 Mdot
.6444 .6839 Mdot
.66397 .68199 Mdot
.70682 .6834 Mdot
.73741 .68342 Mdot
.81846 .6875 Mdot
.91348 .68527 Mdot
.19803 .6986 Mdot
.33106 .69495 Mdot
.35399 .69677 Mdot
.36775 .69385 Mdot
.38157 .69244 Mdot
.61636 .6949 Mdot
.63276 .69233 Mdot
.65226 .69365 Mdot
.67007 .6915 Mdot
.69763 .6991 Mdot
.71224 .69681 Mdot
.72206 .6937 Mdot
.74006 .69251 Mdot
.75762 .6938 Mdot
.78204 .69491 Mdot
.80988 .69269 Mdot
.85915 .69262 Mdot
.10591 .70477 Mdot
.26947 .70104 Mdot
.28926 .70286 Mdot
.33804 .70614 Mdot
.37349 .70412 Mdot
.62222 .7053 Mdot
.63691 .70263 Mdot
.6482 .70395 Mdot
.66019 .70755 Mdot
.67628 .70539 Mdot
.72987 .71197 Mdot
.74746 .70949 Mdot
.15177 .71716 Mdot
.18685 .71532 Mdot
.22165 .71357 Mdot
.23503 .71267 Mdot
.24353 .70963 Mdot
.26324 .71288 Mdot
.29565 .71454 Mdot
.3531 .71309 Mdot
.36697 .71302 Mdot
.38046 .7142 Mdot
.62878 .71445 Mdot
.64416 .71444 Mdot
.80306 .71311 Mdot
.82663 .71472 Mdot
.89977 .71229 Mdot
.25392 .72471 Mdot
.30106 .72353 Mdot
.35999 .72478 Mdot
.37504 .72478 Mdot
.62229 .72362 Mdot
.63618 .72478 Mdot
.64918 .72324 Mdot
.66134 .72343 Mdot
.67367 .7222 Mdot
.69901 .72074 Mdot
.75732 .72526 Mdot
.77953 .7243 Mdot
.83381 .729 Mdot
.85822 .72081 Mdot
.18461 .73235 Mdot
.21487 .7294 Mdot
.24597 .73997 Mdot
.27485 .73557 Mdot
.30749 .73579 Mdot
.32226 .73301 Mdot
.34096 .73304 Mdot
.35577 .73507 Mdot
.36774 .73778 Mdot
.37947 .73636 Mdot
.61858 .73522 Mdot
.63101 .73651 Mdot
.64224 .73829 Mdot
.65434 .7365 Mdot
.67601 .7347 Mdot
.68897 .73438 Mdot
.73697 .73412 Mdot
.88977 .73621 Mdot
.12077 .74691 Mdot
.17531 .7441 Mdot
.20349 .74463 Mdot
.22621 .74345 Mdot
.2543 .75222 Mdot
.28822 .7472 Mdot
.3272 .74669 Mdot
.34948 .74865 Mdot
.6245 .74543 Mdot
.65915 .74341 Mdot
.67449 .74617 Mdot
.69725 .74606 Mdot
.71113 .74625 Mdot
.72191 .74653 Mdot
.80267 .74469 Mdot
.82052 .74954 Mdot
.85968 .74585 Mdot
.21199 .76013 Mdot
.30673 .75824 Mdot
.38004 .75463 Mdot
.61598 .75584 Mdot
.6327 .7543 Mdot
.65107 .75436 Mdot
.66835 .75578 Mdot
.69034 .7592 Mdot
.74966 .75729 Mdot
.78436 .75175 Mdot
.15491 .76214 Mdot
.1924 .76784 Mdot
.23424 .76808 Mdot
.32604 .76686 Mdot
.34755 .76283 Mdot
.36173 .76304 Mdot
.37437 .76475 Mdot
.62211 .76738 Mdot
.63711 .76451 Mdot
.64833 .76633 Mdot
.65974 .76947 Mdot
.67398 .76659 Mdot
.77515 .76014 Mdot
.84061 .76787 Mdot
.88637 .76764 Mdot
.18601 .77937 Mdot
.25938 .77417 Mdot
.34087 .77811 Mdot
.35476 .77827 Mdot
.36778 .77643 Mdot
.38173 .77525 Mdot
.62863 .77643 Mdot
.64501 .77849 Mdot
.67911 .77419 Mdot
.76436 .77789 Mdot
.78582 .77642 Mdot
.81046 .77895 Mdot
.87094 .78579 Mdot
.2219 .78079 Mdot
.27726 .78681 Mdot
.29965 .7811 Mdot
.31678 .7835 Mdot
.35905 .78834 Mdot
.37375 .78676 Mdot
.38765 .78562 Mdot
.61184 .78571 Mdot
.62353 .78842 Mdot
.63798 .78971 Mdot
.66896 .78421 Mdot
.68675 .78611 Mdot
.69561 .78297 Mdot
.70921 .7826 Mdot
.72381 .78461 Mdot
.7968 .79571 Mdot
.14463 .79488 Mdot
.16815 .79406 Mdot
.19407 .79792 Mdot
.20786 .79554 Mdot
.22662 .79383 Mdot
.25031 .79397 Mdot
.29283 .7982 Mdot
.30997 .80055 Mdot
.33122 .7955 Mdot
.34524 .79555 Mdot
.36504 .79837 Mdot
.37971 .79709 Mdot
.39361 .79595 Mdot
.60593 .79595 Mdot
.65333 .79557 Mdot
.6656 .7982 Mdot
.68028 .79985 Mdot
.70235 .79931 Mdot
.75034 .79563 Mdot
.22976 .80918 Mdot
.2589 .81142 Mdot
.32448 .80659 Mdot
.35088 .80842 Mdot
.37167 .80744 Mdot
.38568 .80742 Mdot
.39961 .80627 Mdot
.59839 .80627 Mdot
.61496 .80597 Mdot
.63409 .8081 Mdot
.64815 .80972 Mdot
.69576 .81193 Mdot
.72038 .80602 Mdot
.77856 .81083 Mdot
.15192 .8209 Mdot
.17942 .82308 Mdot
.20764 .82197 Mdot
.22718 .8254 Mdot
.27938 .81699 Mdot
.29794 .81629 Mdot
.31531 .81775 Mdot
.33435 .81533 Mdot
.36481 .81647 Mdot
.38058 .81908 Mdot
.39071 .81935 Mdot
.40426 .81656 Mdot
.41576 .81658 Mdot
.58131 .81747 Mdot
.59373 .81656 Mdot
.60728 .81935 Mdot
.62018 .81755 Mdot
.66273 .81694 Mdot
.68178 .8174 Mdot
.72616 .82005 Mdot
.74383 .8212 Mdot
.8398 .81138 Mdot
.32288 .82774 Mdot
.33923 .82574 Mdot
.35063 .82495 Mdot
.36054 .82606 Mdot
.37579 .82812 Mdot
.39508 .82966 Mdot
.40954 .82807 Mdot
.42339 .82698 Mdot
.58698 .82807 Mdot
.60292 .82966 Mdot
.62619 .8279 Mdot
.67306 .83068 Mdot
.70536 .83042 Mdot
.79603 .82501 Mdot
.83287 .83183 Mdot
.22409 .83528 Mdot
.2809 .83871 Mdot
.29597 .8362 Mdot
.31008 .83514 Mdot
.32897 .84063 Mdot
.34225 .84117 Mdot
.35636 .84043 Mdot
.36639 .84075 Mdot
.38341 .83887 Mdot
.40251 .83975 Mdot
.4146 .83998 Mdot
.4289 .83858 Mdot
.43987 .83752 Mdot
.55738 .83623 Mdot
.5706 .83598 Mdot
.58174 .83709 Mdot
.5971 .83999 Mdot
.61884 .8385 Mdot
.64018 .83749 Mdot
.65474 .83781 Mdot
.80912 .84655 Mdot
.2341 .84861 Mdot
.27394 .85162 Mdot
.2978 .85248 Mdot
.31323 .85001 Mdot
.32837 .85045 Mdot
.35076 .85426 Mdot
.37344 .85024 Mdot
.39613 .84883 Mdot
.42225 .85037 Mdot
.44444 .84754 Mdot
.45724 .8465 Mdot
.46917 .84664 Mdot
.482 .84906 Mdot
.51599 .84906 Mdot
.52883 .84664 Mdot
.54076 .8465 Mdot
.55281 .84897 Mdot
.56375 .85022 Mdot
.57654 .84875 Mdot
.59053 .84877 Mdot
.61106 .84808 Mdot
.66989 .84963 Mdot
.68476 .84562 Mdot
.72331 .84603 Mdot
.19311 .85935 Mdot
.22401 .86413 Mdot
.2576 .85584 Mdot
.32406 .86434 Mdot
.38013 .85733 Mdot
.40168 .85862 Mdot
.41754 .85923 Mdot
.43569 .8593 Mdot
.45128 .85907 Mdot
.46322 .85906 Mdot
.47515 .85905 Mdot
.48855 .85927 Mdot
.4982 .8581 Mdot
.51025 .85787 Mdot
.52285 .85905 Mdot
.53478 .85906 Mdot
.54936 .86065 Mdot
.56773 .86044 Mdot
.58253 .85912 Mdot
.59744 .8575 Mdot
.6196 .85901 Mdot
.63983 .8552 Mdot
.65826 .85763 Mdot
.68795 .86023 Mdot
.7061 .8546 Mdot
.29842 .86965 Mdot
.35987 .86844 Mdot
.37109 .86996 Mdot
.38943 .8696 Mdot
.40996 .87118 Mdot
.44364 .86923 Mdot
.45823 .87077 Mdot
.4682 .8711 Mdot
.48378 .87103 Mdot
.50314 .87234 Mdot
.51596 .87103 Mdot
.52979 .8708 Mdot
.5427 .87289 Mdot
.5756 .87151 Mdot
.58914 .87336 Mdot
.60085 .87143 Mdot
.61151 .86985 Mdot
.63303 .86954 Mdot
.65001 .87245 Mdot
.69229 .87646 Mdot
.71158 .87537 Mdot
.73581 .87184 Mdot
.22566 .88422 Mdot
.25396 .88108 Mdot
.27724 .88003 Mdot
.30677 .88139 Mdot
.34168 .87798 Mdot
.38032 .8831 Mdot
.40253 .88114 Mdot
.42508 .87641 Mdot
.43824 .87793 Mdot
.45338 .87979 Mdot
.47514 .88258 Mdot
.52333 .87965 Mdot
.56842 .87954 Mdot
.61615 .88167 Mdot
.63079 .88109 Mdot
.65765 .88245 Mdot
.32791 .88896 Mdot
.36128 .88824 Mdot
.41822 .88849 Mdot
.43335 .89017 Mdot
.44529 .89016 Mdot
.46084 .89045 Mdot
.49051 .88832 Mdot
.50465 .8869 Mdot
.51703 .89037 Mdot
.53211 .89191 Mdot
.5515 .88601 Mdot
.57795 .88804 Mdot
.63979 .89012 Mdot
.67301 .88269 Mdot
.27293 .90674 Mdot
.30304 .90351 Mdot
.35178 .90052 Mdot
.36978 .90184 Mdot
.38926 .89624 Mdot
.40503 .89925 Mdot
.41581 .90228 Mdot
.42734 .90565 Mdot
.43839 .90494 Mdot
.45163 .90245 Mdot
.47513 .89752 Mdot
.49726 .90399 Mdot
.51289 .90436 Mdot
.54351 .89871 Mdot
.56001 .89824 Mdot
.57005 .8995 Mdot
.58858 .90074 Mdot
.62901 .89862 Mdot
.66516 .89843 Mdot
.69256 .89459 Mdot
.32569 .91506 Mdot
.34539 .91007 Mdot
.38192 .91124 Mdot
.39782 .91468 Mdot
.45508 .91029 Mdot
.46873 .90918 Mdot
.48435 .90911 Mdot
.53668 .91261 Mdot
.55157 .91406 Mdot
.56311 .91358 Mdot
.58143 .91373 Mdot
.60868 .90996 Mdot
.6379 .91151 Mdot
.65455 .90946 Mdot
.6767 .91364 Mdot
.6854 .91558 Mdot
.70425 .91514 Mdot
.3536 .92529 Mdot
.37047 .92599 Mdot
.40784 .92529 Mdot
.46008 .92123 Mdot
.47626 .9232 Mdot
.48911 .92154 Mdot
.51166 .91881 Mdot
.57389 .92432 Mdot
.62936 .92172 Mdot
.66615 .92923 Mdot
.38561 .93617 Mdot
.452 .93044 Mdot
.47214 .93275 Mdot
.50319 .92876 Mdot
.52995 .92934 Mdot
.55162 .92884 Mdot
.62314 .9343 Mdot
.65051 .93393 Mdot
.43782 .93676 Mdot
.46331 .94419 Mdot
.48721 .94231 Mdot
.49755 .94197 Mdot
.51281 .94123 Mdot
.52308 .94277 Mdot
.55822 .94313 Mdot
.57441 .94203 Mdot
.60672 .94238 Mdot
.64255 .94791 Mdot
.43129 .94898 Mdot
.45558 .95425 Mdot
.48174 .95769 Mdot
.50496 .95902 Mdot
.52803 .95577 Mdot
.54048 .95235 Mdot
.55502 .95552 Mdot
.5886 .95506 Mdot
.42143 .96361 Mdot
.44216 .96655 Mdot
.46493 .96762 Mdot
.54837 .96738 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{286.875, 284.313},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006^0001ZR000`400?l00000o`00003oo`3IfMV_
0=WIf@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00
b`3IfMT4000000L0fMWI00<000000=WIf@3IfMT0e@3IfMT00<d0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@3E0=WIf@00c@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0
fMWI0=D0fMWI00390=WIf@H000001`3IfMT00`000000fMWI0=WIf@3E0=WIf@00`03IfMT6000000@0
fMWI00@000000=WIf@3IfMT00000203IfMT400000=@0fMWI003:0=WIf@040000003IfMT0fMWI0000
00P0fMWI00<000000=WIf@3IfMT0e@3IfMT00</0fMWI00<000000=WIf@000000203IfMT00`000000
fMWI0=WIf@3E0=WIf@00b`3IfMT00`000000fMWI000000080=WIf@030000003IfMT0fMWI0=D0fMWI
002Z0=WIf@030000003IfMT0fMWI01l0fMWI0P0000080=WIf@030000003IfMT0fMWI0=D0fMWI002Y
0=WIf@<00000:P3IfMT00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI0:H0fMWI002Z0=WI
f@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0:`3IfMT300000:L0fMWI003F0=WIf@03
0000003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0YP3IfMT00=H0fMWI00<000000=WIf@3IfMT0
e@3IfMT00=H0fMWI00<000000=WIf@3IfMT0e@3IfMT00=H0fMWI00<000000=WIf@3IfMT0e@3IfMT0
0=H0fMWI00<000000=WIf@3IfMT0e@3IfMT00=H0fMWI00<000000=WIf@3IfMT0e@3IfMT00=H0fMWI
00<000000=WIf@3IfMT0e@3IfMT00;80fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@3E0=WIf@00/@3IfMT300000280fMWI00<000000=WIf@3IfMT0e@3IfMT00;80fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@3E0=WIf@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00
eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00O@3IfMT00`000000fMWI0=WIf@1F0=WIf@030000003I
fMT0fMWI0=D0fMWI001l0=WIf@<00000E`3IfMT00`000000fMWI0000003E0=WIf@00O@3IfMT00`00
0000fMWI0=WIf@1F0=WIf@@00000A`3IfMT00`000000fMWI0=WIf@2:0=WIf@00eP3IfMT00`000000
fMWI000000170=WIf@<000004@3IfMT00`000000fMWI0=WIf@1g0=WIf@00eP3IfMT00`000000fMWI
0=WIf@180=WIf@030000003IfMT0fMWI00l0fMWI0`00001h0=WIf@00eP3IfMT00`000000fMWI0=WI
f@1K0=WIf@030000003IfMT0fMWI07L0fMWI003F0=WIf@800000eP3IfMT00=H0fMWI00<000000=WI
f@3IfMT0e@3IfMT00=H0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@2T0=WIf@00
eP3IfMT00`000000fMWI0=WIf@0]0=WIf@<00000Y@3IfMT00=H0fMWI00<000000=WIf@3IfMT0;P3I
fMT00`000000fMWI0=WIf@2T0=WIf@00]`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0
fMWI0=D0fMWI002f0=WIf@<000007@3IfMT00`000000fMWI0=WIf@3E0=WIf@00]`3IfMT00`000000
fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0fMWI0=D0fMWI
002H0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0K`3IfMT00`000000fMWI0=WI
f@1S0=WIf@00U`3IfMT3000003`0fMWI00<000000=WIf@3IfMT0KP3IfMT3000006@0fMWI002H0=WI
f@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0K`3IfMT00`000000fMWI0=WIf@1S0=WI
f@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@00eP3I
fMT00`000000fMWI0=WIf@3E0=WIf@00OP3IfMT00`000000fMWI0=WIf@1E0=WIf@030000003IfMT0
fMWI0=D0fMWI001m0=WIf@<00000EP3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI
0:/0fMWI001n0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000
fMWI0=WIf@0V0=WIf@<00000[03IfMT00;D0fMWI0`00000N0=WIf@030000003IfMT0fMWI02L0fMWI
00<000000=WIf@3IfMT0Z`3IfMT00;H0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WI
f@160=WIf@030000003IfMT0fMWI08`0fMWI003F0=WIf@030000003IfMT0fMWI04D0fMWI0`00002=
0=WIf@00eP3IfMT00`000000fMWI0=WIf@160=WIf@030000003IfMT0fMWI08`0fMWI003F0=WIf@03
0000003IfMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0fMWI0=D0fMWI003F0=WIf@030000003I
fMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0fMWI0=D0fMWI003F0=WIf@800000eP3IfMT00=H0
fMWI00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@1b0=WIf@00M@3IfMT00`000000fMWI
0=WIf@1D0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0G`3IfMT3000007<0fMWI
001d0=WIf@<00000E03IfMT3000000P0fMWI00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WI
f@0L0=WIf@030000003IfMT0fMWI05<0fMWI001e0=WIf@030000003IfMT0fMWI05@0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@1n0=WIf@<00000E03IfMT004P0fMWI00<000000=WI
f@3IfMT0R`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI07P0fMWI00<000000=WI
f@3IfMT0D`3IfMT004L0fMWI0`00002<0=WIf@030000003IfMT0fMWI00<0fMWI0`00003?0=WIf@00
B03IfMT00`000000fMWI0=WIf@1K0=WIf@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@3>0=WIf@00Y@3IfMT3000001<0fMWI00<000000=WIf@3IfMT0603I
fMT00`000000fMWI0=WIf@3E0=WIf@00T@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0
fMWI0140fMWI0`00000I0=WIf@030000003IfMT0fMWI0=D0fMWI002@0=WIf@<00000:03IfMT00`00
0000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0]03IfMT00940
fMWI00<000000=WIf@3IfMT0@P3IfMT00`000000fMWI0=WIf@0M0=WIf@<00000>@3IfMT00`000000
fMWI0=WIf@1i0=WIf@00eP3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI03L0fMWI
0`00001j0=WIf@00eP3IfMT00`000000fMWI0=WIf@1=0=WIf@030000003IfMT0fMWI00T0fMWI00<0
00000=WIf@3IfMT0N@3IfMT00=H0fMWI00<000000=WIf@3IfMT0C03IfMT3000008H0fMWI003F0=WI
f@030000003IfMT0fMWI04d0fMWI00<000000=WIf@3IfMT0Q@3IfMT00=H0fMWI00<000000=WIf@3I
fMT0e@3IfMT00=H0fMWI00<000000=WIf@3IfMT0e@3IfMT007h0fMWI00<000000=WIf@3IfMT0E@3I
fMT00`000000fMWI0=WIf@3E0=WIf@00O@3IfMT3000005H0fMWI00<000000=WIf@3IfMT0e@3IfMT0
07h0fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI
03h0fMWI00<000000=WIf@3IfMT0U03IfMT00;T0fMWI0`00000J0=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT0>03IfMT3000004L0fMWI00<000000=WIf@3IfMT0B`3IfMT005D0fMWI
00<000000=WIf@3IfMT0AP3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01T0fMWI
00@000000=WIf@3IfMT0fMWI0`00000j0=WIf@030000003IfMT0fMWI04D0fMWI0`00001<0=WIf@00
E03IfMT3000004H0fMWI0`00000f0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
9`3IfMT00`000000fMWI0=WIf@1H0=WIf@030000003IfMT0fMWI04/0fMWI000f0=WIf@030000003I
fMT0fMWI01`0fMWI00<000000=WIf@3IfMT0AP3IfMT00`000000fMWI0=WIf@0e0=WIf@030000003I
fMT0fMWI02/0fMWI0`00002W0=WIf@00=@3IfMT3000009h0fMWI00<000000=WIf@3IfMT0;03IfMT0
0`000000fMWI0=WIf@2V0=WIf@00=P3IfMT00`000000fMWI0=WIf@2M0=WIf@800000U@3IfMT00`00
0000fMWI0=WIf@0n0=WIf@00eP3IfMT00`000000fMWI0=WIf@2C0=WIf@<00000?`3IfMT00=H0fMWI
00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@1n0=WIf@030000003IfMT0fMWI03h0fMWI
003F0=WIf@030000003IfMT0fMWI0180fMWI0`0000300=WIf@00eP3IfMT00`000000fMWI0=WIf@0C
0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0N`3IfMT006h0fMWI00<000000=WI
f@3IfMT0I@3IfMT00`000000fMWI0=WIf@1F0=WIf@<00000O03IfMT00300fMWI00<000000=WIf@3I
fMT0403IfMT00`000000fMWI0=WIf@0W0=WIf@<00000IP3IfMT00`000000fMWI0=WIf@1G0=WIf@03
0000003IfMT0fMWI07/0fMWI000_0=WIf@<00000403IfMT3000002T0fMWI00<000000=WIf@3IfMT0
I@3IfMT00`000000fMWI0=WIf@3E0=WIf@00<03IfMT00`000000fMWI0=WIf@0@0=WIf@030000003I
fMT0fMWI07@0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@090=WIf@030000003I
fMT0fMWI0=D0fMWI002H0=WIf@030000003IfMT0fMWI01h0fMWI0`00000=0=WIf@<000002P3IfMT0
0`000000fMWI0=WIf@3E0=WIf@00QP3IfMT00`000000fMWI0=WIf@0>0=WIf@<00000803IfMT00`00
0000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00P0fMWI0`00001X0=WIf@030000003IfMT0fMWI
06/0fMWI00250=WIf@<00000403IfMT00`000000fMWI0=WIf@0k0=WIf@030000003IfMT0fMWI06H0
fMWI0`00000a0=WIf@030000003IfMT0fMWI03P0fMWI001Y0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT0C@3IfMT00`000000fMWI0=WIf@190=WIf@030000003IfMT0fMWI01/0fMWI
00<000000=WIf@3IfMT0;`3IfMT3000003T0fMWI001X0=WIf@<00000J`3IfMT00`000000fMWI0=WI
f@0d0=WIf@030000003IfMT0fMWI0140fMWI0`00001?0=WIf@030000003IfMT0fMWI03P0fMWI001Y
0=WIf@030000003IfMT0fMWI06X0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0G
0=WIf@<000004`3IfMT00`000000fMWI0=WIf@290=WIf@00eP3IfMT00`000000fMWI0=WIf@0H0=WI
f@<000006@3IfMT00`000000fMWI0=WIf@2N0=WIf@00Z@3IfMT00`000000fMWI0=WIf@0Z0=WIf@03
0000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0^@3IfMT003P0fMWI00<000000=WIf@3IfMT0
K@3IfMT3000002/0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@3<0=WIf@00=`3I
fMT3000006l0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@050=WIf@<00000c@3I
fMT003P0fMWI00<000000=WIf@3IfMT0V`3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0
fMWI0<`0fMWI003F0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0`@3IfMT00=H0
fMWI00<000000=WIf@3IfMT0403IfMT3000001H0fMWI00<000000=WIf@3IfMT0Z@3IfMT00;d0fMWI
00<000000=WIf@3IfMT02@3IfMT6000000L0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI
0=WIf@0D0=WIf@<00000ZP3IfMT006/0fMWI00<000000=WIf@3IfMT0CP3IfMT3000000X0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI000002/0fMWI
00<000000=WIf@3IfMT0Z@3IfMT006X0fMWI0`00001@0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT01@3IfMT3000000030=WIf@000000fMWI0=H0fMWI001;0=WIf@030000003IfMT0
fMWI01d0fMWI00<000000=WIf@3IfMT0<P3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT01000000n0=WIf@030000003IfMT0fMWI09<0fMWI001:0=WI
f@<00000DP3IfMT3000001h0fMWI1P0000060=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT0?P3IfMT3000009@0fMWI001;0=WIf@030000003IfMT0fMWI0580fMWI00<000000=WIf@3I
fMT0:P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI03l0fMWI00<000000=WIf@3I
fMT0T`3IfMT00<T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@050=WIf@030000
003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0a03IfMT009H0fMWI00<000000=WIf@3IfMT0<03I
fMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT03@3I
fMT300000<D0fMWI001m0=WIf@030000003IfMT0fMWI01D0fMWI0`00000L0=WIf@030000003IfMT0
fMWI01<0fMWI100000080=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0a03IfMT0
02l0fMWI00<000000=WIf@3IfMT0BP3IfMT3000001L0fMWI00<000000=WIf@3IfMT06P3IfMT30000
0200fMWI00@000000=WIf@3IfMT00000TP3IfMT00`000000fMWI0=WIf@0o0=WIf@00;P3IfMT30000
04`0fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT00000
00800000803IfMT00`000000fMWI0=WIf@1=0=WIf@030000003IfMT0fMWI01d0fMWI0`0000100=WI
f@00803IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0:@0fMWI00@000000=WIf@3I
fMT00000803IfMT3000003X0fMWI00<000000=WIf@3IfMT0403IfMT3000001l0fMWI00<000000=WI
f@3IfMT0?`3IfMT001l0fMWI0`00002d0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3I
fMT0>03IfMT300000180fMWI00<000000=WIf@3IfMT0H03IfMT00200fMWI00<000000=WIf@3IfMT0
/`3IfMT00`000000fMWI0=WIf@1N0=WIf@030000003IfMT0fMWI07@0fMWI003F0=WIf@030000003I
fMT0fMWI0=D0fMWI00240=WIf@030000003IfMT0fMWI04l0fMWI00<000000=WIf@3IfMT0e@3IfMT0
0640fMWI00<000000=WIf@3IfMT07`3IfMT300000500fMWI00<000000=WIf@3IfMT0e@3IfMT00600
fMWI0`00000Q0=WIf@030000003IfMT0fMWI04l0fMWI00D000000=WIf@3IfMT0fMWI000000150=WI
f@030000003IfMT0fMWI08/0fMWI001Q0=WIf@030000003IfMT0fMWI0780fMWI00<000000=WIf@3I
fMT00`00000=0=WIf@030000003IfMT0fMWI03<0fMWI0`00002<0=WIf@00eP3IfMT01@000000fMWI
0=WIf@3IfMT0000000d0fMWI0`00000e0=WIf@030000003IfMT0fMWI08/0fMWI002C0=WIf@030000
003IfMT0fMWI0400fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI0;P0fMWI001<0=WIf@030000003IfMT0fMWI04<0fMWI0`00000@0=WIf@030000003I
fMT0fMWI02h0fMWI00<000000=WIf@3IfMT06@3IfMT300000;T0fMWI001;0=WIf@<000002P3IfMT0
0`000000fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI00h0fMWI0`00000_0=WIf@030000003IfMT0
fMWI01X0fMWI00<000000=WIf@3IfMT0^03IfMT002<0fMWI00<000000=WIf@3IfMT09P3IfMT00`00
0000fMWI0=WIf@080=WIf@<000004@3IfMT00`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI
02h0fMWI00<000000=WIf@3IfMT0e@3IfMT00280fMWI0`00000c0=WIf@030000003IfMT0fMWI00l0
fMWI0`00001Y0=WIf@030000003IfMT0fMWI0800fMWI00<000000=WIf@3IfMT0DP3IfMT002<0fMWI
00<000000=WIf@3IfMT0A@3IfMT00`000000fMWI0=WIf@1X0=WIf@030000003IfMT0fMWI07l0fMWI
0`00000Q0=WIf@030000003IfMT0fMWI02l0fMWI003F0=WIf@030000003IfMT0fMWI0800fMWI00<0
00000=WIf@3IfMT07`3IfMT300000300fMWI003F0=WIf@030000003IfMT0fMWI02h0fMWI00<00000
0=WIf@3IfMT0LP3IfMT00`000000fMWI0=WIf@0_0=WIf@00]P3IfMT00`000000fMWI0=WIf@0M0=WI
f@030000003IfMT0fMWI02d0fMWI0`00002U0=WIf@00N03IfMT00`000000fMWI0=WIf@0j0=WIf@<0
00007P3IfMT2000001T0fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@2T0=WIf@00
M`3IfMT3000003`0fMWI00<000000=WIf@3IfMT06P3IfMT010000000fMWI0=WIf@0000060=WIf@03
0000003IfMT0fMWI0100fMWI0`00002k0=WIf@00N03IfMT00`000000fMWI0=WIf@0H0=WIf@030000
003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0:P3IfMT3000000030=WIf@000000fMWI00@0fMWI
0`00000B0=WIf@030000003IfMT0fMWI0;X0fMWI002B0=WIf@<000003`3IfMT3000002`0fMWI00@0
00000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@120=WIf@030000003IfMT0fMWI08T0fMWI
002C0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WI
f@180=WIf@<00000RP3IfMT00=H0fMWI00<000000=WIf@3IfMT0B@3IfMT00`000000fMWI0=WIf@29
0=WIf@00eP3IfMT00`000000fMWI0=WIf@3E0=WIf@005`3IfMT00`000000fMWI0=WIf@2l0=WIf@03
0000003IfMT0fMWI0=D0fMWI000F0=WIf@<00000GP3IfMT00`000000fMWI0=WIf@1L0=WIf@030000
003IfMT0fMWI07d0fMWI00<000000=WIf@3IfMT0E@3IfMT001L0fMWI00<000000=WIf@3IfMT0G03I
fMT3000000h0fMWI00<000000=WIf@3IfMT0C03IfMT00`000000fMWI0=WIf@080=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT0IP3IfMT3000005H0fMWI001g0=WIf@030000003IfMT0
fMWI00`0fMWI0`00001=0=WIf@030000003IfMT0fMWI00L0fMWI0`0000080=WIf@<000004@3IfMT0
0`000000fMWI0=WIf@1D0=WIf@030000003IfMT0fMWI05D0fMWI00270=WIf@030000003IfMT0fMWI
04`0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
00l0fMWI0`00002]0=WIf@00eP3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI0:`0
fMWI001S0=WIf@030000003IfMT0fMWI0680fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@1A0=WIf@030000003IfMT0fMWI0840fMWI001R0=WIf@<00000F03IfMT00`000000fMWI0=WI
f@070=WIf@<00000303IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0340fMWI0`00
00220=WIf@00H`3IfMT00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI01<0fMWI00<00000
0=WIf@3IfMT04@3IfMT3000000T0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0K
0=WIf@<00000<`3IfMT00`000000fMWI0=WIf@210=WIf@008P3IfMT00`000000fMWI0=WIf@0[0=WI
f@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT04`3IfMT3000001<0fMWI0`00000C0=WI
f@030000003IfMT0fMWI01D0fMWI0`00000M0=WIf@030000003IfMT0fMWI0;H0fMWI000Q0=WIf@<0
00004`3IfMT00`000000fMWI0=WIf@0E0=WIf@<00000:03IfMT3000001D0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI02/0fMWI00<000000=WIf@3I
fMT0MP3IfMT00`000000fMWI0=WIf@1L0=WIf@008P3IfMT00`000000fMWI0=WIf@0A0=WIf@<00000
5`3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI01X0fMWI0`00000k0=WIf@030000
003IfMT0fMWI02`0fMWI00<000000=WIf@3IfMT0AP3IfMT3000002l0fMWI00<000000=WIf@3IfMT0
:`3IfMT003L0fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003I
fMT0fMWI03X0fMWI00<000000=WIf@3IfMT0:`3IfMT3000003X0fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@0]0=WIf@<00000;03IfMT006`0fMWI0`00001L0=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@0h0=WIf@<00000:`3IfMT0
0`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI02/0fMWI001]0=WIf@030000003IfMT0fMWI
05X0fMWI0`0000090=WIf@030000003IfMT0fMWI05`0fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@0Y0=WIf@<00000?P3IfMT00</0fMWI00<000000=WIf@3IfMT0203IfMT00`000000
fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI03L0fMWI0`00000g0=WIf@030000003IfMT0fMWI03d0
fMWI003F0=WIf@030000003IfMT0fMWI0200fMWI0`00000C0=WIf@030000003IfMT0fMWI02<0fMWI
00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@1<0=WIf@00eP3IfMT00`000000fMWI0=WI
f@0Q0=WIf@030000003IfMT0fMWI0140fMWI0`00000C0=WIf@030000003IfMT0fMWI03L0fMWI0`00
001=0=WIf@00OP3IfMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI02L0fMWI00<00000
0=WIf@3IfMT01@3IfMT2000001D0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@0A
0=WIf@<00000>@3IfMT00`000000fMWI0=WIf@1<0=WIf@00O@3IfMT3000002<0fMWI0`00000F0=WI
f@030000003IfMT0fMWI00h0fMWI0`0000060=WIf@030000003IfMT0fMWI01<0fMWI0`00000e0=WI
f@030000003IfMT0fMWI08L0fMWI001n0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3I
fMT0503IfMT300000100fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0D0=WIf@03
0000003IfMT0fMWI09D0fMWI00<000000=WIf@3IfMT09P3IfMT006D0fMWI00<000000=WIf@3IfMT0
@03IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0
Z`3IfMT3000002L0fMWI001T0=WIf@<00000@03IfMT3000002`0fMWI00<000000=WIf@3IfMT0303I
fMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI08<0fMWI00<000000=WIf@3IfMT09P3I
fMT006D0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0
fMWI02/0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI0`00
00020=WIf@030000003IfMT0fMWI0180fMWI0`00002]0=WIf@00R`3IfMT3000004P0fMWI00<00000
0=WIf@3IfMT00P3IfMT3000000040=WIf@0000000000000000<0fMWI00<000000=WIf@3IfMT00`00
000D0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0B@3IfMT00`000000fMWI0=WI
f@0L0=WIf@030000003IfMT0fMWI02D0fMWI002<0=WIf@030000003IfMT0fMWI03l0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@000000203I
fMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI0280fMWI0`0000190=WIf@<00000703I
fMT3000002H0fMWI003=0=WIf@<000001P3IfMT00`000000fMWI0=WIf@0K0=WIf@<00000903IfMT0
0`000000fMWI0=WIf@190=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT09@3IfMT0
03`0fMWI00<000000=WIf@3IfMT0L`3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI
0300fMWI00<000000=WIf@3IfMT0KP3IfMT003/0fMWI0`00001c0=WIf@<000004`3IfMT00`000000
fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI0300fMWI0`00000`0=WIf@<00000G`3IfMT00`000000
fMWI0=WIf@0=0=WIf@00?03IfMT00`000000fMWI0=WIf@1c0=WIf@030000003IfMT0fMWI0140fMWI
0`00000=0=WIf@030000003IfMT0fMWI0340fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI
0=WIf@0D0=WIf@030000003IfMT0fMWI04H0fMWI0`00000>0=WIf@00DP3IfMT00`000000fMWI0=WI
f@1b0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0NP3IfMT3000004P0fMWI00<0
00000=WIf@3IfMT03@3IfMT001P0fMWI00<000000=WIf@3IfMT0=P3IfMT300000880fMWI00<00000
0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@1G0=WIf@005`3IfMT3000003P0fMWI00<000000=WI
f@3IfMT04P3IfMT00`000000fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WI
f@3IfMT03`3IfMT01@000000fMWI0=WIf@3IfMT000000=L0fMWI000H0=WIf@030000003IfMT0fMWI
04/0fMWI0`00000^0=WIf@<000007@3IfMT00`000000fMWI0=WIf@050=WIf@<000003`3IfMT30000
0080fMWI00<000000=WIf@3IfMT0D`3IfMT00`000000fMWI0=WIf@1o0=WIf@00I`3IfMT00`000000
fMWI0=WIf@0^0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT03@3IfMT3000000L0
fMWI00<000000=WIf@3IfMT03`3IfMT01@000000fMWI0=WIf@3IfMT0000002<0fMWI00<000000=WI
f@3IfMT0;P3IfMT300000200fMWI00<000000=WIf@3IfMT0?03IfMT00`000000fMWI0=WIf@0N0=WI
f@00Y@3IfMT3000000l0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@0P0=WIf@<0
0000<03IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI00L0fMWI0`00000>0=WIf@03
0000003IfMT0fMWI02/0fMWI0`00000O0=WIf@00YP3IfMT00`000000fMWI0=WIf@0]0=WIf@030000
003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0O0=WIf@<00000
2@3IfMT00`000000fMWI0=WIf@0<0=WIf@<00000;@3IfMT00`000000fMWI0=WIf@0N0=WIf@00=@3I
fMT00`000000fMWI0=WIf@2N0=WIf@030000003IfMT0fMWI04H0fMWI0`00000Q0=WIf@030000003I
fMT0fMWI01P0fMWI00<000000=WIf@3IfMT0C@3IfMT003@0fMWI0`00002=0=WIf@030000003IfMT0
fMWI00l0fMWI00<000000=WIf@3IfMT0A`3IfMT00`000000fMWI0=WIf@2;0=WIf@00=@3IfMT00`00
0000fMWI0=WIf@2;0=WIf@<000002P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT0a@3IfMT00<@0fMWI00<000000=WIf@3IfMT0203IfMT3000000@0
fMWI00<000000=WIf@3IfMT0303IfMT300000<H0fMWI003@0=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI09H0fMWI
001Z0=WIf@030000003IfMT0fMWI06T0fMWI00<000000=WIf@3IfMT0>`3IfMT3000009L0fMWI001Y
0=WIf@<000008`3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01d0fMWI00D00000
0=WIf@3IfMT0fMWI0000000V0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0103I
fMT00`000000fMWI0=WIf@2?0=WIf@007P3IfMT00`000000fMWI0=WIf@190=WIf@030000003IfMT0
fMWI0240fMWI0`00000P0=WIf@<00000503IfMT00`000000fMWI0=WIf@060=WIf@<000000P3IfMT2
000002@0fMWI0`00000L0=WIf@<00000J@3IfMT00`000000fMWI0=WIf@0T0=WIf@007@3IfMT30000
06l0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0B0=WIf@<00000203IfMT01@00
0000fMWI0=WIf@3IfMT0000002H0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@14
0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT03P3IfMT3000002D0fMWI000N0=WI
f@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@1=0=WI
f@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0R@3IfMT3000000l0fMWI0`00000@0=WI
f@030000003IfMT0fMWI02@0fMWI001G0=WIf@<000007@3IfMT3000004@0fMWI00<000000=WIf@3I
fMT05@3IfMT00`000000fMWI0=WIf@1R0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3I
fMT03`3IfMT00`000000fMWI0=WIf@0f0=WIf@00F03IfMT00`000000fMWI0=WIf@0M0=WIf@030000
003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0503IfMT3000001H0fMWI00<000000=WIf@3IfMT0
8P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT0
103IfMT00`000000fMWI0=WIf@040=WIf@<00000L@3IfMT002l0fMWI00<000000=WIf@3IfMT0?03I
fMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI00l0fMWI0`0000080=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT05@3IfMT010000000fMWI0=WIf@0000070=WIf@030000
003IfMT0fMWI01H0fMWI0`00000?0=WIf@<000004`3IfMT00`000000fMWI0=WIf@060=WIf@<00000
103IfMT3000000H0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@1I0=WIf@00;P3I
fMT3000003`0fMWI0`00000R0=WIf@<000004@3IfMT00`000000fMWI0=WIf@060=WIf@<000006P3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT00000008000001@3IfMT3000001P0fMWI00<0
00000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0A0=WIf@<00000203IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI01/0fMWI0`00000m0=WIf@030000003IfMT0fMWI01X0fMWI000_
0=WIf@030000003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0A
0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@0H
0=WIf@<00000203IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT0fMWI03h0fMWI00<0
00000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@0k0=WIf@<000006`3IfMT000`0fMWI1000001P
0=WIf@H00000203IfMT3000001X0fMWI0`0000060=WIf@030000003IfMT0fMWI02D0fMWI00<00000
0=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@1P0=WIf@H00000DP3IfMT00`000000fMWI0=WIf@0=
0=WIf@@000002@3IfMT000h0fMWI00<000000=WIf@3IfMT0G`3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@040=WI
f@<00000<03IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI04L0fMWI00<000000=WI
f@3IfMT00P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI05/0fMWI00<000000=WI
f@3IfMT0203IfMT000h0fMWI00<000000=WIf@3IfMT0H03IfMT00`000000fMWI0=WIf@0`0=WIf@03
0000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT05@3IfMT3000004T0fMWI00<000000=WIf@3I
fMT01`3IfMT3000005`0fMWI00<000000=WIf@3IfMT0203IfMT000X0fMWI1P00001R0=WIf@030000
003IfMT0fMWI05/0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0F0=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0@03IfMT00`000000fMWI0=WIf@070=WIf@030000
003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT0B`3IfMT6000000T0fMWI00000`3IfMT000000000
0004000000@0fMWI00@000000=WIf@3IfMT00000@P3IfMT00`000000fMWI0=WIf@0C0=WIf@H00000
1P3IfMT00`000000fMWI0=WIf@1I0=WIf@<00000103IfMT00`000000fMWI0=WIf@0N0=WIf@<00000
8`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0140fMWI0`00001=0=WIf@040000
003IfMT0fMWI000000X0fMWI000;0=WIf@040000003IfMT0fMWI000003D0fMWI00<000000=WIf@3I
fMT02@3IfMT300000240fMWI00<000000=WIf@3IfMT0F@3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0Q0=WIf@<0
00007P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0480fMWI00<000000=WIf@3I
fMT01`3IfMT010000000fMWI0=WIf@00000:0=WIf@00303IfMT00`000000fMWI0000000d0=WIf@<0
00002`3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT07`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3I
fMT01@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3I
fMT02`3IfMT3000003H0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI05@0fMWI0`0000090=WIf@030000003IfMT0000000X0fMWI000<0=WIf@030000
003IfMT0000002L0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT07P3IfMT3000000L0fMWI0`0000080=WIf@030000
003IfMT0fMWI00X0fMWI0`0000050=WIf@<000000P3IfMT3000000h0fMWI00<000000=WIf@3IfMT0
303IfMT00`000000fMWI0=WIf@1A0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
E@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0000000X0fMWI000=0=WIf@8000009P3I
fMT3000003T0fMWI1000000K0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01`3I
fMT00`000000fMWI0=WIf@060=WIf@<00000303IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@1Q0=WIf@@00000103I
fMT00`000000fMWI0=WIf@1M0=WIf@8000002P3IfMT003H0fMWI00<000000=WIf@3IfMT0=03IfMT0
0`000000fMWI0=WIf@0O0=WIf@<000006@3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0
fMWI00/0fMWI0P00001Z0=WIf@<00000JP3IfMT006`0fMWI0`00000;0=WIf@030000003IfMT0fMWI
00X0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0c0=WIf@<000002`3IfMT30000
01H0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI
01T0fMWI00<000000=WIf@3IfMT0J@3IfMT006d0fMWI00<000000=WIf@3IfMT02@3IfMT3000000X0
fMWI0`00000n0=WIf@030000003IfMT0fMWI00/0fMWI0P00000:0=WIf@030000003IfMT0fMWI00P0
fMWI0`00000D0=WIf@<000001P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00`0
fMWI0`00001O0=WIf@030000003IfMT0fMWI02@0fMWI001j0=WIf@030000003IfMT0fMWI00X0fMWI
00<000000=WIf@3IfMT0C03IfMT00`000000fMWI0=WIf@070=WIf@<000002P3IfMT00`000000fMWI
0=WIf@0D0=WIf@030000003IfMT0fMWI00@0fMWI0`0000070=WIf@<000003P3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0A@3IfMT3000002D0fMWI
000N0=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3IfMT0A`3IfMT00`000000fMWI0=WI
f@0S0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WI
f@0X0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT05P3IfMT3000000/0fMWI0`00
00170=WIf@030000003IfMT0fMWI02@0fMWI000M0=WIf@<00000>`3IfMT3000004L0fMWI0`00000B
0=WIf@030000003IfMT0fMWI00h0fMWI0`0000050=WIf@040000003IfMT0fMWI000001T0fMWI00<0
00000=WIf@3IfMT0?@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT0K@3IfMT001h0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI0=WIf@0m
0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0403IfMT3000000T0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@<0000000<0fMWI0000003IfMT05`3IfMT3
000004@0fMWI0`00000o0=WIf@030000003IfMT0fMWI03<0fMWI002K0=WIf@<00000703IfMT00`00
0000fMWI0=WIf@070=WIf@<00000303IfMT010000000fMWI0=WIf@00000I0=WIf@030000003IfMT0
fMWI00@0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0
fMWI0100fMWI00<000000=WIf@3IfMT0:P3IfMT3000003@0fMWI001Y0=WIf@030000003IfMT0fMWI
0300fMWI00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI
01d0fMWI0`0000040=WIf@030000003IfMT0fMWI0240fMWI0`00000U0=WIf@<00000;03IfMT00`00
0000fMWI0=WIf@0c0=WIf@00o`00002^00000040fMWI00090=WIf@030000003IfMT0fMWI01L0fMWI
00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0<0=WIf@<00000203IfMT00`000000fMWI
0=WIf@0@0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI
00000002000000/0fMWI0`0000070=WIf@030000003IfMT0fMWI00D0fMWI0`0000050=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@030=WIf@040000
003IfMT0fMWI0=WIf@<000001P3IfMT3000000T0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000
fMWI0=WIf@090=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000
fMWI0=WIf@0E0=WIf@030000003IfMT0000000P0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000
fMWI0=WIf@0G0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0203IfMT000T0fMWI
00<000000=WIf@3IfMT0@03IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01X0fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00<0fMWI
0`00000:0=WIf@030000003IfMT0fMWI00d0fMWI0`0000040=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@1E0=WIf@030000003IfMT0fMWI01@0fMWI
0`0000080=WIf@<00000@P3IfMT00`000000fMWI0=WIf@080=WIf@00N@3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0203IfMT300000080fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI04`0fMWI000g
0=WIf@030000003IfMT0fMWI03h0fMWI0`0000050=WIf@<000005@3IfMT00`000000fMWI0=WIf@0T
0=WIf@030000003IfMT0fMWI00<000000P3IfMT3000000`0fMWI00<000000=WIf@3IfMT0403IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT04P3IfMT0
0`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI08h0fMWI000f0=WIf@<00000@03IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI01<0fMWI0`00000Y0=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0?0=WIf@<000000P3IfMT30000
00@0fMWI0`0000070=WIf@030000003IfMT0fMWI00P0fMWI0`00000@0=WIf@<000003@3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI07P0fMWI000g0=WIf@030000003IfMT0fMWI05h0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI02/0
fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT01@3IfMT3000000X0fMWI00<000000=WIf@3IfMT0403IfMT00`000000
fMWI0=WIf@0;0=WIf@<00000103IfMT300000140fMWI00<000000=WIf@3IfMT0I@3IfMT00:40fMWI
0`0000030=WIf@<00000;03IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01/0fMWI
00<000000=WIf@3IfMT0:`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT01`3IfMT3000006H0fMWI001U0=WIf@030000003IfMT0fMWI01d0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00l0fMWI00<0
00000=WIf@3IfMT05@3IfMT01@000000fMWI0=WIf@3IfMT0000000P0fMWI0`00001H0=WIf@<00000
2@3IfMT00`000000fMWI0=WIf@1U0=WIf@00C`3IfMT00`000000fMWI0=WIf@0B0=WIf@<000007@3I
fMT3000000P0fMWI00<000000=WIf@3IfMT09`3IfMT3000000l0fMWI00<000000=WIf@3IfMT00`3I
fMT300000080fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0f0=WIf@030000003I
fMT0fMWI01l0fMWI00<000000=WIf@3IfMT0L03IfMT000X0fMWI00<000000=WIf@3IfMT0@@3IfMT3
000000X0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI0140fMWI00<000000=WIf@3IfMT01P3IfMT3000002T0fMWI00<000000=WIf@3IfMT03@3IfMT3
000000D0fMWI00@000000=WIf@3IfMT0fMWI0P00000>0=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00/0fMWI00<0
00000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@040=WIf@<00000T`3IfMT000T0fMWI0`000013
0=WIf@030000003IfMT0fMWI00P0fMWI0`00000C0=WIf@<00000703IfMT00`000000fMWI0=WIf@0i
0=WIf@030000003IfMT0fMWI00P0fMWI0`00000<0=WIf@<00000103IfMT300000080fMWI0`000003
0=WIf@<000000`3IfMT00`000000fMWI0=WIf@050=WIf@<00000203IfMT3000000H0fMWI00<00000
0=WIf@3IfMT0TP3IfMT000X0fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@0G0=WI
f@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0o0=WI
f@8000003P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT00`3IfMT010000000fMWI0=WIf@3IfMT3000000L0fMWI00<000000=WIf@3IfMT0203IfMT0
0`000000fMWI0=WIf@2J0=WIf@00@03IfMT300000500fMWI0`0000070=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@1m0=WIf@030000003IfMT0fMWI
02h0fMWI000U0=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0?P3IfMT00`000000
fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00D0fMWI0`0000080=WIf@<000001@3IfMT3000001<0
fMWI0`00000>0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0000000H0fMWI00<000000=WIf@3IfMT06P3IfMT00`000000
fMWI0=WIf@0_0=WIf@<00000;`3IfMT002@0fMWI0`00001J0=WIf@<000006@3IfMT00`000000fMWI
0=WIf@080=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI
0=WIf@060=WIf@<000008P3IfMT00`000000fMWI0=WIf@0E0=WIf@<00000103IfMT5000000@0fMWI
0`00000J0=WIf@<000007P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI0280fMWI
00<000000=WIf@3IfMT02@3IfMT002D0fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WI
f@0/0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@0W0=WIf@<000001`3IfMT3000001D0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0403IfMT3000001L0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI000000060=WIf@030000003IfMT0fMWI01X0fMWI00<0
00000=WIf@3IfMT0703IfMT3000003D0fMWI0`00000:0=WIf@00<`3IfMT00`000000fMWI0=WIf@0C
0=WIf@<00000;03IfMT3000000h0fMWI0`00000Y0=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@0?0=WIf@<00000103IfMT3000000<0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00h0fMWI00<00000
0=WIf@3IfMT0DP3IfMT00`000000fMWI0=WIf@0e0=WIf@030000003IfMT0fMWI00T0fMWI000b0=WI
f@<000005@3IfMT00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WI
f@3IfMT05`3IfMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI00H0fMWI00@000000=WI
f@3IfMT000004P3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@<000000P3I
fMT3000001P0fMWI0`00000S0=WIf@030000003IfMT0fMWI0740fMWI000c0=WIf@030000003IfMT0
fMWI06d0fMWI0`00000S0=WIf@<000001P3IfMT3000000030=WIf@000000fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0Q0=WIf@<000004P3IfMT00`000000fMWI0=WIf@0g
0=WIf@030000003IfMT0fMWI02<0fMWI00200=WIf@030000003IfMT0fMWI0240fMWI00<000000=WI
f@3IfMT08`3IfMT00`000000fMWI0=WIf@060=WIf@040000003IfMT0fMWI000000@0fMWI0`000004
0=WIf@<000008P3IfMT00`000000fMWI0=WIf@0W0=WIf@030000003IfMT0fMWI00H0fMWI00<00000
0=WIf@3IfMT0403IfMT3000003L0fMWI0`00000T0=WIf@00I@3IfMT00`000000fMWI0=WIf@0G0=WI
f@<00000303IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WI
f@3IfMT00`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WI
f@3IfMT05P3IfMT3000002L0fMWI0`00000K0=WIf@030000003IfMT0fMWI03L0fMWI00<000000=WI
f@3IfMT08`3IfMT005X0fMWI00<000000=WIf@3IfMT01`3IfMT3000000X0fMWI00<000000=WIf@3I
fMT0303IfMT00`000000fMWI0=WIf@0:0=WIf@<00000203IfMT00`000000fMWI0=WIf@0A0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT3000001T0fMWI00<000000=WIf@3I
fMT04`3IfMT3000001P0fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0E0=WIf@03
0000003IfMT0fMWI07X0fMWI000m0=WIf@030000003IfMT0fMWI01T0fMWI0`0000050=WIf@050000
003IfMT0fMWI0=WIf@0000002P3IfMT3000001/0fMWI00<000000=WIf@3IfMT01P3IfMT300000140
fMWI0`0000030=WIf@<000001`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00d0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00D0
fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI00<0
fMWI00<000000=WIf@3IfMT0103IfMT3000009<0fMWI000l0=WIf@<000006`3IfMT00`000000fMWI
0=WIf@030=WIf@<000003P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00D0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0403IfMT3000000h0fMWI00@000000=WIf@3IfMT0fMWI0`0000070=WIf@<0
00005P3IfMT3000000X0fMWI0`0000030=WIf@<000001P3IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@0I0=WIf@03
0000003IfMT0fMWI05<0fMWI000m0=WIf@030000003IfMT0fMWI0240fMWI00<000000=WIf@3IfMT0
:`3IfMT3000001@0fMWI0`00000M0=WIf@030000003IfMT0fMWI00d0fMWI0P0000030=WIf@030000
003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT300000080fMWI0`00000E0=WIf@<00000
6@3IfMT3000005@0fMWI00220=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0503I
fMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0603I
fMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT05@3I
fMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT0603I
fMT00840fMWI0`00000L0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT00P3IfMT0
10000000fMWI0=WIf@3IfMT3000000L0fMWI00<000000=WIf@3IfMT0103IfMT010000000fMWI0=WI
f@0000030=WIf@030000003IfMT0fMWI01L0fMWI0`0000050=WIf@030000003IfMT0fMWI09L0fMWI
0`00000I0=WIf@00C@3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0140fMWI00<0
00000=WIf@3IfMT06P3IfMT3000000`0fMWI00<000000=WIf@3IfMT00`3IfMT300000080fMWI0`00
00030=WIf@030000003IfMT0fMWI00D0fMWI0`0000040=WIf@H000000P3IfMT010000000fMWI0=WI
f@00000>0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT3000004X0fMWI
00<000000=WIf@3IfMT0C03IfMT00`000000fMWI0=WIf@0H0=WIf@006@3IfMT00`000000fMWI0=WI
f@0`0=WIf@<000007P3IfMT300000300fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@050=WIf@<000001@3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0fMWI00<0
00000=WIf@3IfMT0103IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0000000800000
303IfMT3000000h0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000
003IfMT0fMWI0100fMWI0`00001X0=WIf@00603IfMT300000380fMWI00<000000=WIf@3IfMT07P3I
fMT00`000000fMWI0=WIf@0c0=WIf@<000001`3IfMT00`000000fMWI0=WIf@0U0=WIf@040000003I
fMT0fMWI000000L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0Z0=WIf@<00000
5`3IfMT300000180fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@0c0=WIf@006@3I
fMT00`000000fMWI0=WIf@1/0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT04@3I
fMT00`000000fMWI0=WIf@070=WIf@<000001`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@140=WIf@<00000=03I
fMT00440fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@0L0=WIf@<000002`3IfMT3
000000D0fMWI0`00000G0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT3
00000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0
fMWI00P0fMWI00<000000=WIf@3IfMT01@3IfMT3000000<0fMWI00<000000=WIf@3IfMT0303IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0303IfMT3
000005X0fMWI00<000000=WIf@3IfMT0<`3IfMT002X0fMWI00<000000=WIf@3IfMT04`3IfMT30000
02@0fMWI0`00000N0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI0080fMWI0`0000020=WIf@<00000103IfMT00`00
0000fMWI0=WIf@03000000<0fMWI0`0000070=WIf@<000004P3IfMT010000000fMWI0=WIf@3IfMT3
000000@0fMWI00<000000=WIf@3IfMT01@3IfMT3000000@0fMWI0`0000040=WIf@<000001@3IfMT0
0`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0Q03IfMT0
02T0fMWI0`00000E0=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT0@@3IfMT01000
0000fMWI0=WIf@3IfMT3000000@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@07
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0F
0=WIf@030000003IfMT0fMWI0080fMWI0`0000070=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@030=WIf@<000004@3IfMT3000008D0fMWI000E0=WI
f@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0V0=WI
f@030000003IfMT0fMWI02h0fMWI00<000000=WIf@3IfMT0703IfMT3000000<0fMWI00<000000=WI
f@3IfMT08P3IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WI
f@3IfMT04@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI06H0fMWI000D0=WIf@<0
00006P3IfMT3000001l0fMWI00<000000=WIf@3IfMT0103IfMT3000002h0fMWI0`0000060=WIf@03
0000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0O0=WIf@03
0000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@090=WI
f@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0BP3IfMT3000006L0fMWI000E0=WIf@03
0000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT07@3IfMT3000000H0fMWI00<000000=WIf@3I
fMT05`3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI00@0fMWI0`0000050=WIf@03
0000003IfMT0fMWI0080fMWI0`0000040=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI0=WIf@<000000P3IfMT30000
00040=WIf@000000fMWI0=WIf@<000002@3IfMT3000000D0fMWI00<000000=WIf@3IfMT01P3IfMT3
000004`0fMWI00<000000=WIf@3IfMT0IP3IfMT005<0fMWI00<000000=WIf@3IfMT04`3IfMT00`00
0000fMWI0=WIf@080=WIf@<000007@3IfMT00`000000fMWI0=WIf@030=WIf@<00000103IfMT00`00
0000fMWI0=WIf@020=WIf@<000002`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0080fMWI0`0000020=WIf@<000000P3IfMT3000000<0fMWI00<000000=WIf@3IfMT00P3IfMT01000
0000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT00`3IfMT3
000000P0fMWI00<000000=WIf@3IfMT0X03IfMT00`000000fMWI0=WIf@0A0=WIf@00J03IfMT30000
00X0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI
00T0fMWI0`0000020=WIf@<00000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI
01T0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@1l0=WIf@<000004P3IfMT006T0
fMWI00<000000=WIf@3IfMT0B03IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01X0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI0=WI
f@<000000`3IfMT00`000000fMWI0=WIf@080=WIf@<000008`3IfMT00`000000fMWI0=WIf@0f0=WI
f@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT04@3IfMT000d0fMWI00<000000=WIf@3I
fMT0K@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<000000P3IfMT3000000<0
fMWI00<000000=WIf@3IfMT00P3IfMT300000080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@03000000<0fMWI0`0000030=WIf@040000003IfMT0fMWI0=WIf@<000000P3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT01@3IfMT30000
03H0fMWI0`00000d0=WIf@00303IfMT3000006<0fMWI00<000000=WIf@3IfMT01`3IfMT3000000L0
fMWI0`0000060=WIf@<00000103IfMT3000000D0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@060=WIf@<00000303IfMT00`000000fMWI0=WIf@020=WIf@<000000P3IfMT300000080
fMWI0`0000030=WIf@<000000P3IfMT3000000<0fMWI0`0000020=WIf@030000003IfMT0fMWI0080
fMWI00@000000=WIf@3IfMT0fMWI0`0000040=WIf@030000003IfMT0fMWI00<000000`3IfMT30000
0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
00<00000603IfMT00`000000fMWI0=WIf@060=WIf@<000001`3IfMT00`000000fMWI0=WIf@0N0=WI
f@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT0<`3IfMT000d0fMWI00<000000=WIf@3I
fMT0H@3IfMT3000000T0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@060=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00`3IfMT300000080fMWI0`0000080=WIf@03
0000003IfMT0fMWI00X0fMWI0`0000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI01H0fMWI0`0000080=WIf@03
0000003IfMT0fMWI02H0fMWI0`00001<0=WIf@00B@3IfMT00`000000fMWI0=WIf@0V0=WIf@030000
003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000
003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0D`3IfMT00`000000fMWI0=WIf@0a0=WIf@030000
003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0?@3IfMT004P0fMWI0`0000090=WIf@030000003I
fMT0fMWI00P0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003I
fMT0fMWI00d0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@070=WIf@030000003I
fMT0fMWI01h0fMWI00<000000=WIf@3IfMT0LP3IfMT00`000000fMWI0=WIf@0O0=WIf@<000006P3I
fMT00`000000fMWI0=WIf@0Q0=WIf@00B@3IfMT00`000000fMWI0=WIf@070=WIf@<00000203IfMT3
000000H0fMWI0`00000Z0=WIf@<000001@3IfMT00`000000fMWI0=WIf@050=WIf@<000000`3IfMT3
000000L0fMWI0`0000070=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000000P3I
fMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI
000000050=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0C0=WIf@030000003IfMT0fMWI0300fMWI0`00000Q0=WIf@030000003IfMT0fMWI01P0fMWI
0`00000R0=WIf@00E03IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT06P3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00<0fMWI0`00
00070=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WI
f@050=WIf@<000000P3IfMT3000000<0fMWI0`0000020=WIf@<000000P3IfMT3000000030=WIf@00
0000fMWI00<000001P3IfMT3000000<0fMWI0`000000103IfMT000000000000000030=WIf@<00000
0P3IfMT3000000L0fMWI0`0000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
1`3IfMT300000380fMWI00<000000=WIf@3IfMT0?03IfMT00`000000fMWI0=WIf@0Q0=WIf@00L03I
fMT00`000000fMWI0=WIf@0A0=WIf@<000001@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003I
fMT0fMWI01l0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WIf@030000003I
fMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000020=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@070=WIf@040000003IfMT0fMWI0=WI
f@<000000`3IfMT3000000T0fMWI00<000000=WIf@3IfMT0U03IfMT001@0fMWI00<000000=WIf@3I
fMT0F03IfMT3000001<0fMWI00<000000=WIf@3IfMT00`3IfMT3000001@0fMWI00<000000=WIf@3I
fMT0203IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3I
fMT05`3IfMT00`000000fMWI0=WIf@0V0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3I
fMT00`3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0;03IfMT00`000000fMWI0=WIf@1I0=WIf@004`3IfMT300000140fMWI00<000000=WIf@3IfMT0
AP3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@040=WIf@<00000103IfMT010000000fMWI0=WIf@3IfMT300000080
fMWI0`0000070=WIf@<000004`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080
fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00L0
fMWI00<000000=WIf@3IfMT00P3IfMT300000140fMWI00<000000=WIf@3IfMT0203IfMT300000080
fMWI0`00000J0=WIf@030000003IfMT0fMWI00l0fMWI0`00001J0=WIf@00503IfMT00`000000fMWI
0=WIf@0?0=WIf@<00000203IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI01<0fMWI
00<000000=WIf@3IfMT0=03IfMT3000000H0fMWI0`0000060=WIf@030000003IfMT0fMWI0080fMWI
0`0000030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT300000080fMWI
0`0000020=WIf@<000000P3IfMT3000000@0fMWI00<000000=WIf@3IfMT01@3IfMT3000000@0fMWI
00<000000=WIf@3IfMT00`0000040=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0
0`0000050=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@090=WIf@030000003IfMT0fMWI00`0fMWI0`00000A0=WIf@030000003IfMT0fMWI05T0fMWI
000W0=WIf@030000003IfMT0fMWI00H0fMWI0`00000?0=WIf@<000004`3IfMT3000003H0fMWI00<0
00000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI01X0fMWI0`00
00020=WIf@<00000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@<000001`3IfMT00`000000fMWI0=WI
f@020=WIf@<000000P3IfMT00`000000fMWI0=WIf@0A0=WIf@<000000P3IfMT00`000000fMWI0=WI
f@030=WIf@<000004`3IfMT3000000D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0AP3IfMT00340fMWI00<00000
0=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT0G`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00P0fMWI00<00000
0=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI01H0fMWI00<00000
0=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00@0fMWI00<00000
0=WIf@3IfMT00`3IfMT3000000h0fMWI0`00000K0=WIf@<00000A`3IfMT006<0fMWI0`00000j0=WI
f@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0R0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0I0=WI
f@<00000303IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WI
f@3IfMT04P3IfMT00`000000fMWI0=WIf@0a0=WIf@00I03IfMT00`000000fMWI0=WIf@0^0=WIf@03
0000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT0fMWI0`0000030=WIf@040000003IfMT0fMWI
0=WIf@<000000P3IfMT3000000<0fMWI0`0000020=WIf@<00000103IfMT00`000000fMWI0=WIf@0C
0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@05
0=WIf@<00000103IfMT300000080fMWI00@000000=WIf@3IfMT0fMWI0`00000K0=WIf@030000003I
fMT0fMWI04h0fMWI0`00000b0=WIf@00U03IfMT3000000<0fMWI0`0000030=WIf@040000003IfMT0
fMWI0=WIf@<000000`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@<00000503IfMT00`000000fMWI0=WI
f@0B0=WIf@<000000`3IfMT3000000L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WI
f@03000000<0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0o0=WIf@030000003I
fMT0fMWI01l0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0W0=WIf@006@3IfMT0
0`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI03l0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT04`3IfMT0
0`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT04@3IfMT0
0`000000fMWI0=WIf@0<0=WIf@<000007`3IfMT00`000000fMWI0=WIf@0M0=WIf@<00000:@3IfMT3
000002P0fMWI000B0=WIf@030000003IfMT0fMWI00<0fMWI0`00000g0=WIf@<000004@3IfMT00`00
0000fMWI0=WIf@1]0=WIf@030000003IfMT0fMWI03X0fMWI00@000000=WIf@3IfMT000001`3IfMT0
0`000000fMWI0=WIf@0E0=WIf@<000007`3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0
fMWI02L0fMWI000A0=WIf@<000001@3IfMT00`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI
00l0fMWI0`00000Z0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT08@3IfMT00`00
0000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@0@0=WIf@<00000203IfMT3000001L0fMWI00<000000=WIf@3IfMT0<03IfMT00`00
0000fMWI0=WIf@110=WIf@004P3IfMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI02@0
fMWI00<000000=WIf@3IfMT0:03IfMT3000000T0fMWI0`0000060=WIf@<000000`3IfMT300000080
fMWI0`0000040=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT06P3IfMT300000080
fMWI0`0000030=WIf@<00000303IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00P0
fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI01h0
fMWI0`0000120=WIf@00?P3IfMT300000540fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@060=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI
0=WIf@020=WIf@<00000703IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0080fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0:0=WIf@<00000703IfMT3000000@0fMWI
00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@040=WIf@<00000803IfMT00`000000fMWI
0=WIf@110=WIf@00?`3IfMT00`000000fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI01/0fMWI00<0
00000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0080fMWI0`00
00040=WIf@030000003IfMT0fMWI00@0fMWI0`0000060=WIf@030000003IfMT0fMWI06<0fMWI001k
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Y
0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT04@3IfMT01@000000fMWI0=WIf@3I
fMT0000000L0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@020=WIf@<000001P3I
fMT00`000000fMWI0=WIf@1[0=WIf@00H`3IfMT00`000000fMWI0=WIf@0D0=WIf@<000002@3IfMT3
000000/0fMWI00<000000=WIf@3IfMT00`3IfMT300000080fMWI0`0000020=WIf@<000000P3IfMT3
000000@0fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0
fMWI00<0fMWI0`00000A0=WIf@<0000000@0fMWI00000000000000001@3IfMT3000001@0fMWI00<0
00000=WIf@3IfMT0L`3IfMT00540fMWI00<000000=WIf@3IfMT03P3IfMT3000001H0fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@090=WIf@<000001@3IfMT00`000000fMWI0=WIf@02
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@02
0=WIf@<00000903IfMT00`000000fMWI0=WIf@0Q0=WIf@<000001@3IfMT00`000000fMWI0=WIf@0A
0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@290=WIf@00D03IfMT3
00000100fMWI00<000000=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0
fMWI02<0fMWI00<000000=WIf@3IfMT08P3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0
fMWI01T0fMWI00<000000=WIf@3IfMT0PP3IfMT00540fMWI00<000000=WIf@3IfMT02@3IfMT00`00
0000fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT01@3IfMT30000
00D0fMWI00<000000=WIf@3IfMT04@3IfMT3000001P0fMWI00<000000=WIf@3IfMT0C`3IfMT00`00
0000fMWI0=WIf@0F0=WIf@008@3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI01@0
fMWI0`00000i0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0:P3IfMT3000000L0
fMWI00<000000=WIf@3IfMT00`3IfMT3000001<0fMWI00<000000=WIf@3IfMT05P3IfMT3000001L0
fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0P0=WIf@<000005`3IfMT00200fMWI
0`00000Q0=WIf@<000005P3IfMT00`000000fMWI0=WIf@0g0=WIf@<000001`3IfMT3000000<0fMWI
0`0000030=WIf@<000009P3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI00d0fMWI
00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@060=WIf@<000004P3IfMT300000280fMWI
00<000000=WIf@3IfMT05P3IfMT00240fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@1@0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0@`3IfMT3000001D0fMWI0`00
00050=WIf@030000003IfMT0fMWI0180fMWI0`0000080=WIf@030000003IfMT0fMWI0180fMWI00<0
00000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0]0=WIf@00R`3IfMT00`000000fMWI0=WIf@18
0=WIf@030000003IfMT0fMWI0380fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT00`3IfMT3000001@0fMWI00<00000
0=WIf@3IfMT0:03IfMT3000002h0fMWI00170=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WI
f@3IfMT01@3IfMT3000000h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI02h0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI00<000002@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00@0fMWI0`00000F0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0=P3IfMT00`00
0000fMWI0=WIf@0]0=WIf@00AP3IfMT3000000`0fMWI00<000000=WIf@3IfMT0:@3IfMT3000000L0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@020=WIf@<000000P3IfMT300000080
fMWI0`0000040=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT09P3IfMT3000000@0
fMWI0`0000020=WIf@030000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT0fMWI0`0000030=WI
f@<000001P3IfMT00`000000fMWI0=WIf@0M0=WIf@<000008@3IfMT00`000000fMWI0=WIf@130=WI
f@00A`3IfMT00`000000fMWI0=WIf@0:0=WIf@<00000:`3IfMT00`000000fMWI0=WIf@0?0=WIf@<0
0000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT00P3IfMT3000002T0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00H0fMWI0`0000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3I
fMT09P3IfMT00`000000fMWI0=WIf@0O0=WIf@<00000A03IfMT005D0fMWI00<000000=WIf@3IfMT0
403IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT0
4`3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT0
603IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI03@0fMWI00<000000=WIf@3IfMT0
@`3IfMT006L0fMWI0`0000070=WIf@<000002`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003I
fMT0fMWI04@0fMWI0P00001C0=WIf@<000000P3IfMT3000000<0fMWI00<000000=WIf@3IfMT00`3I
fMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI05`0fMWI001X0=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT02@3IfMT3000000d0fMWI0`00000<0=WIf@030000003IfMT0
fMWI03H0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0
fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@3IfMT3000000<0fMWI0`00
000@0=WIf@<00000403IfMT00`000000fMWI0=WIf@1:0=WIf@00O`3IfMT00`000000fMWI0=WIf@0=
0=WIf@030000003IfMT0fMWI00X0fMWI0`0000040=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT0:`3IfMT00`000000fMWI0=WIf@0Y0=WIf@<000000`3IfMT3000000<0fMWI0`000006
0=WIf@<00000303IfMT3000000d0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@03
0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT03P3IfMT3000004/0fMWI002M0=WI
f@030000003IfMT0fMWI0080fMWI0`0000020=WIf@<00000;03IfMT00`000000fMWI0=WIf@0Z0=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT05`3IfMT3000001d0fMWI00<000000=WI
f@3IfMT0BP3IfMT003T0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0a0=WIf@03
0000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0@`3IfMT00`000000fMWI0=WIf@0S0=WIf@03
0000003IfMT0fMWI06T0fMWI000h0=WIf@<000007P3IfMT00`000000fMWI0=WIf@040=WIf@<00000
9`3IfMT00`000000fMWI0=WIf@070=WIf@<000000`3IfMT3000003T0fMWI00<000000=WIf@3IfMT0
;03IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
103IfMT300000140fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@1_0=WIf@00>@3I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01`3I
fMT3000000H0fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0;0=WIf@<000002@3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WIf@3IfMT0:`3I
fMT3000000@0fMWI0`0000050=WIf@<000001P3IfMT00`000000fMWI0=WIf@0?0=WIf@<000002P3I
fMT3000004T0fMWI00<000000=WIf@3IfMT0903IfMT004H0fMWI0`0000040=WIf@<000002@3IfMT0
0`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI00/0fMWI0`00000=0=WIf@030000003IfMT0
fMWI04T0fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI00D0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI01l0fMWI00<000000=WIf@3IfMT09@3IfMT3000002D0fMWI00170=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT06P3IfMT3000000d0fMWI00<000000=WIf@3IfMT0F03IfMT00`00
0000fMWI0=WIf@160=WIf@030000003IfMT0fMWI03/0fMWI0`00000W0=WIf@030000003IfMT0fMWI
02@0fMWI001/0=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000
fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI03H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@040=WIf@<00000503IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0503IfMT010000000fMWI0=WIf@00000A0=WIf@030000003IfMT0fMWI
03/0fMWI002>0=WIf@030000003IfMT0fMWI00`0fMWI0`0000020=WIf@<00000<@3IfMT00`000000
fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI00<0fMWI0`0000050=WIf@<000001P3IfMT00`000000
fMWI0=WIf@0B0=WIf@<000001@3IfMT3000000@0fMWI0`0000090=WIf@030000003IfMT0fMWI00P0
fMWI0`00000B0=WIf@<00000?03IfMT005D0fMWI00<000000=WIf@3IfMT0=@3IfMT3000000P0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI0300fMWI
00<000000=WIf@3IfMT0;P3IfMT3000000D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI
0=WIf@0G0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@040=WIf@03
0000003IfMT0fMWI00L0fMWI0`00000:0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3I
fMT0>`3IfMT005@0fMWI0`00000g0=WIf@030000003IfMT0fMWI00H0fMWI0`00000l0=WIf@030000
003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@020=WIf@<00000
703IfMT00`000000fMWI0=WIf@1L0=WIf@00E@3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@0k0=WIf@030000003I
fMT0fMWI03P0fMWI00<000000=WIf@3IfMT05P3IfMT3000000@0fMWI00<000000=WIf@3IfMT0NP3I
fMT002h0fMWI00<000000=WIf@3IfMT0@@3IfMT3000000H0fMWI0`00000R0=WIf@030000003IfMT0
fMWI03<0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@030=WIf@<000000`3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0P03IfMT0
02d0fMWI0`0000130=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04P3IfMT00`00
0000fMWI0=WIf@0;0=WIf@<00000=03IfMT00`000000fMWI0=WIf@0`0=WIf@<000001@3IfMT01000
0000fMWI0=WIf@3IfMT3000000<0fMWI00<000000=WIf@3IfMT00`3IfMT3000008X0fMWI000^0=WI
f@030000003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT09@3IfMT3000000d0fMWI00<000000=WI
f@3IfMT0<`3IfMT00`000000fMWI0=WIf@0a0=WIf@030000003IfMT0fMWI00T0fMWI00@000000=WI
f@3IfMT0fMWI0`0000050=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0J`3IfMT0
06L0fMWI0`00000W0=WIf@030000003IfMT0fMWI0480fMWI00<000000=WIf@3IfMT0@P3IfMT00`00
0000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00@0fMWI0`00000o0=WIf@030000003IfMT0fMWI
02X0fMWI001O0=WIf@030000003IfMT0fMWI00<0fMWI00@000000=WIf@3IfMT00000203IfMT00`00
0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT00`3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0=03IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0200fMWI0`0000060=WIf@030000003IfMT0fMWI
01D0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0K0=WIf@<00000:`3IfMT00440
fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0;0=WIf@<000000`3IfMT3000000T0
fMWI0`00000;0=WIf@<000005@3IfMT3000000<0fMWI0`0000030=WIf@<00000<@3IfMT00`000000
fMWI0=WIf@0c0=WIf@<00000103IfMT300000280fMWI00<000000=WIf@3IfMT0703IfMT3000000L0
fMWI0`00000M0=WIf@030000003IfMT0fMWI02X0fMWI00100=WIf@<00000303IfMT3000000d0fMWI
00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT05@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0d0=WIf@030000003IfMT0fMWI00@0fMWI
00<000000=WIf@3IfMT0@@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI04T0fMWI
00110=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0P`3IfMT00`000000fMWI0=WI
f@1B0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0?03IfMT00840fMWI00<00000
0=WIf@3IfMT0A@3IfMT6000000L0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@07
0=WIf@<000008@3IfMT00`000000fMWI0=WIf@0M0=WIf@<00000?@3IfMT006d0fMWI00<000000=WI
f@3IfMT0403IfMT3000001L0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0U0=WI
f@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0`0=WI
f@<00000103IfMT00`000000fMWI0=WIf@020=WIf@<000000P3IfMT300000080fMWI0`0000090=WI
f@030000003IfMT0fMWI01H0fMWI00<000000=WIf@3IfMT01P3IfMT3000001l0fMWI00<000000=WI
f@3IfMT0?03IfMT006`0fMWI0`00000B0=WIf@030000003IfMT0fMWI01D0fMWI0`0000040=WIf@<0
00009`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI0340fMWI00<000000=WIf@3I
fMT00P3IfMT3000000@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0200fMWI0`0000080=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3I
fMT0AP3IfMT005`0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@0Z0=WIf@030000
003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@080=WIf@030000
003IfMT0fMWI03L0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@0M0=WIf@<00000
A`3IfMT004l0fMWI00<000000=WIf@3IfMT02@3IfMT3000002`0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@0g0=WIf@030000003IfMT0fMWI00L0fMWI1000002;0=WIf@030000003I
fMT0fMWI04H0fMWI001>0=WIf@<000002`3IfMT00`000000fMWI0=WIf@0G0=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT00P3IfMT3000000D0fMWI0`0000040=WIf@030000003IfMT0
fMWI0380fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0
fMWI01D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0
fMWI06l0fMWI001?0=WIf@030000003IfMT0fMWI02<0fMWI0`00000;0=WIf@<00000103IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0080fMWI0`0000040=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT0;`3IfMT3000000<0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00D0fMWI0`0000030=WIf@<000004P3IfMT30000
03l0fMWI00<000000=WIf@3IfMT0;P3IfMT006T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000
fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT00P3IfMT300000080
fMWI0`00000T0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01@3IfMT00`000000
fMWI0=WIf@0`0=WIf@040000003IfMT0fMWI0=WIf@<000000P3IfMT300000080fMWI0`0000070=WI
f@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT04P3IfMT00`000000fMWI0=WIf@0m0=WI
f@<00000;`3IfMT006P0fMWI0`00000c0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3I
fMT0903IfMT4000000P0fMWI00<000000=WIf@3IfMT0=@3IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@0^0=WIf@00
B`3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@1Z0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0
>`3IfMT00`000000fMWI0=WIf@1C0=WIf@00=03IfMT00`000000fMWI0=WIf@0C0=WIf@<000002@3I
fMT3000000L0fMWI0`00000I0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT0A`3I
fMT00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI00/0fMWI0`0000050=WIf@030000003I
fMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003I
fMT0fMWI01l0fMWI0`00000F0=WIf@030000003IfMT0fMWI03/0fMWI000c0=WIf@<000005@3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT05`3IfMT3
000000d0fMWI0`0000080=WIf@030000003IfMT0fMWI03d0fMWI00<000000=WIf@3IfMT0<@3IfMT3
000000d0fMWI00<000000=WIf@3IfMT00`3IfMT3000000L0fMWI0`0000020=WIf@<000000P3IfMT3
00000240fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0=0=WIf@<00000?03IfMT0
03@0fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000=WIf@3IfMT01P3IfMT3000003h0fMWI00<000000=WIf@3IfMT0<P3IfMT00`00
0000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT02`3IfMT30000
00l0fMWI00<000000=WIf@3IfMT0>`3IfMT006`0fMWI0`00000W0=WIf@030000003IfMT0fMWI00X0
fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0f0=WIf@030000003IfMT0fMWI00D0
fMWI00<000000=WIf@3IfMT0=@3IfMT3000000d0fMWI00<000000=WIf@3IfMT0C03IfMT006d0fMWI
00<000000=WIf@3IfMT0<P3IfMT300000340fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI
0=WIf@030=WIf@<000001@3IfMT3000000D0fMWI00<000000=WIf@3IfMT0;`3IfMT00`000000fMWI
0=WIf@1K0=WIf@00P`3IfMT00`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0300fMWI00<0
00000=WIf@3IfMT0;P3IfMT3000000D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@030=WIf@<00000203IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI06X0fMWI001K
0=WIf@030000003IfMT0fMWI02@0fMWI0`00001A0=WIf@030000003IfMT0fMWI02l0fMWI00<00000
0=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@060=WIf@<000005P3IfMT3000000T0fMWI00<00000
0=WIf@3IfMT0G`3IfMT00480fMWI00<000000=WIf@3IfMT05@3IfMT3000002H0fMWI00<000000=WI
f@3IfMT03`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI03P0fMWI00<000000=WI
f@3IfMT0C`3IfMT00`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00L0fMWI0`00001P0=WI
f@00@@3IfMT3000001L0fMWI00<000000=WIf@3IfMT0=P3IfMT3000000<0fMWI0`0000030=WIf@03
0000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0>03IfMT00`000000fMWI0=WIf@020=WIf@03
0000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT0G`3IfMT00480fMWI00<000000=WIf@3IfMT0
3P3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@030=WIf@040000003IfMT0fMWI0=WIf@<00000=03IfMT00`000000
fMWI0=WIf@0a0=WIf@030000003IfMT0fMWI00<0fMWI0`0000020=WIf@<000002@3IfMT00`000000
fMWI0=WIf@140=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0<03IfMT00580fMWI
0`00000>0=WIf@<000009@3IfMT300000180fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000fMWI
0=WIf@0`0=WIf@<000001@3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@00
00001@3IfMT3000004@0fMWI0`00000@0=WIf@<00000<@3IfMT005<0fMWI00<000000=WIf@3IfMT0
3P3IfMT00`000000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI04L0fMWI00<000000=WIf@3IfMT0
<@3IfMT00`000000fMWI0=WIf@0<0=WIf@<000001@3IfMT00`000000fMWI0=WIf@140=WIf@030000
003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0<03IfMT006l0fMWI00<000000=WIf@3IfMT0<P3I
fMT00`000000fMWI0=WIf@0_0=WIf@030000003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@280=WIf@00KP3IfMT3000002d0fMWI00<000000=WIf@3IfMT00P3IfMT3
00000300fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@0B0=WIf@<000008P3IfMT0
0`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI05/0fMWI001@0=WIf@030000003IfMT0fMWI
01`0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
0080fMWI0`0000040=WIf@030000003IfMT0fMWI02l0fMWI00<000000=WIf@3IfMT0<`3IfMT30000
00D0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0P0=WIf@<000001P3IfMT30000
00T0fMWI00<000000=WIf@3IfMT0D03IfMT004l0fMWI0`00000=0=WIf@030000003IfMT0fMWI01h0
fMWI00<000000=WIf@3IfMT03P3IfMT3000000<0fMWI0`0000040=WIf@030000003IfMT0fMWI03D0
fMWI00<000000=WIf@3IfMT0=03IfMT00`000000fMWI0=WIf@030=WIf@<000006P3IfMT00`000000
fMWI0=WIf@0D0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT300000540
fMWI001@0=WIf@030000003IfMT0fMWI00/0fMWI0`00000N0=WIf@<000001P3IfMT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0>`3IfMT00`000000fMWI
0=WIf@0k0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI
0=WIf@020=WIf@<00000103IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI0500fMWI
001O0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@040=WIf@<000005P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI02d0fMWI00<0
00000=WIf@3IfMT0;@3IfMT00`000000fMWI0=WIf@0D0=WIf@<000001P3IfMT00`000000fMWI0=WI
f@03000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000003d0fMWI00<000000=WIf@3IfMT0=P3I
fMT007H0fMWI0`00000?0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT00P3IfMT3
000000<0fMWI0`00000^0=WIf@030000003IfMT0fMWI02`0fMWI0`0000030=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@040=WIf@<000000P3IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI03/0fMWI0`00000g0=WIf@00M`3IfMT00`00
0000fMWI0=WIf@0O0=WIf@<00000103IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
02d0fMWI00<000000=WIf@3IfMT0;@3IfMT010000000fMWI0=WIf@3IfMT3000000<0fMWI0`00000C
0=WIf@030000003IfMT0fMWI04`0fMWI00<000000=WIf@3IfMT0=P3IfMT004P0fMWI00<000000=WI
f@3IfMT05P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI02`0fMWI00<000000=WI
f@3IfMT0>@3IfMT2000003<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@2J0=WI
f@00?P3IfMT00`000000fMWI0=WIf@060=WIf@<000003`3IfMT00`000000fMWI0=WIf@040=WIf@<0
00001`3IfMT300000240fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0B0=WIf@03
0000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@0B0=WIf@03
0000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT04@3IfMT00`000000fMWI0=WIf@1F0=WIf@00
?@3IfMT3000000P0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@020=WIf@<00000
1P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0
3@3IfMT3000000<0fMWI0`0000060=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
0P3IfMT3000002/0fMWI00<000000=WIf@3IfMT0:@3IfMT300000180fMWI0`0000030=WIf@030000
003IfMT0fMWI0200fMWI0`00000A0=WIf@<00000E`3IfMT003h0fMWI00<000000=WIf@3IfMT04@3I
fMT3000000@0fMWI00<000000=WIf@3IfMT0803IfMT3000000H0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI0`0000040=WIf@<00000103I
fMT00`000000fMWI0=WIf@0Z0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT04P3I
fMT010000000fMWI0=WIf@3IfMT3000000@0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0A0=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT0EP3IfMT005<0fMWI00<0
00000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@040=WIf@<000005@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT0A03IfMT00`000000fMWI0=WI
f@020=WIf@<000001`3IfMT3000007l0fMWI00250=WIf@030000003IfMT0fMWI04h0fMWI00<00000
0=WIf@3IfMT0;P3IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00L0fMWI00<00000
0=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@1g0=WIf@00R`3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@030=WI
f@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@030=WI
f@<000001P3IfMT00`000000fMWI0=WIf@0Q0=WIf@<00000N03IfMT006<0fMWI00<000000=WIf@3I
fMT0903IfMT3000000P0fMWI0`0000060=WIf@<000000`3IfMT3000000<0fMWI0`00000Y0=WIf@03
0000003IfMT0fMWI02H0fMWI0`0000050=WIf@030000003IfMT0fMWI00@0fMWI0`0000050=WIf@03
0000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0M`3IfMT00680fMWI0`00000:0=WIf@030000
003IfMT0fMWI01T0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@060=WIf@030000
003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0X0=WIf@030000
003IfMT0fMWI02L0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@030=WIf@<00000
4P3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT0
A03IfMT006<0fMWI00<000000=WIf@3IfMT0203IfMT3000001h0fMWI00<000000=WIf@3IfMT0A03I
fMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI0100fMWI0`00000P0=WIf@<000005`3I
fMT3000004D0fMWI001_0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI0`00000;0=WIf@030000003IfMT0
fMWI00h0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI0200fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00l0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
fMWI0200fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@140=WIf@00M`3IfMT30000
00D0fMWI0`0000040=WIf@<000001P3IfMT00`000000fMWI0=WIf@090=WIf@<000001@3IfMT01@00
0000fMWI0=WIf@3IfMT0000000@0fMWI0`0000020=WIf@<000008P3IfMT00`000000fMWI0=WIf@0O
0=WIf@<000000P3IfMT3000000@0fMWI00<000000=WIf@3IfMT00P3IfMT3000000l0fMWI0`000005
0=WIf@<000004@3IfMT00`000000fMWI0=WIf@1d0=WIf@00@@3IfMT00`000000fMWI0=WIf@0E0=WI
f@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT00`3IfMT3000000040=WIf@0000000000
000000@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0
fMWI0200fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@<00000103IfMT0
0`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT03`3IfMT3
000000D0fMWI00<000000=WIf@3IfMT0K@3IfMT00400fMWI0`00000:0=WIf@030000003IfMT0fMWI
00P0fMWI0`0000180=WIf@050000003IfMT0fMWI0=WIf@000000;P3IfMT00`000000fMWI0=WIf@0[
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT00`3IfMT3000006h0fMWI00110=WI
f@030000003IfMT0fMWI00P0fMWI0`00000:0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WI
f@3IfMT0;@3IfMT00`000000fMWI0=WIf@020=WIf@050000003IfMT0fMWI0=WIf@0000006P3IfMT0
0`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0503IfMT0
0`000000fMWI0=WIf@1F0=WIf@00C@3IfMT00`000000fMWI0=WIf@0@0=WIf@<000009`3IfMT00`00
0000fMWI0=WIf@030=WIf@<000000P3IfMT3000000040=WIf@0000000000000000D0fMWI00<00000
0=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@020=WIf@<000007`3IfMT00`000000fMWI0=WIf@0R
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0A@3IfMT3000005L0fMWI001Q0=WI
f@030000003IfMT0fMWI02D0fMWI0`0000050=WIf@030000003IfMT0fMWI0080fMWI00D000000=WI
f@3IfMT0fMWI000000050=WIf@<000001P3IfMT00`000000fMWI0=WIf@020=WIf@<00000103IfMT0
0`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI0240fMWI0`0000050=WIf@030000003IfMT0
fMWI00H0fMWI0`00000B0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0903IfMT0
0`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI04H0fMWI002:0=WIf@030000003IfMT0fMWI
01@0fMWI00<000000=WIf@3IfMT0103IfMT3000000@0fMWI00<000000=WIf@3IfMT0903IfMT00`00
0000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI00<0fMWI0`0000080=WIf@030000003IfMT0fMWI
0100fMWI0`00000;0=WIf@<00000=03IfMT3000004L0fMWI001P0=WIf@030000003IfMT0fMWI01`0
fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003IfMT0fMWI02X0
fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00/0
fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI03@0
fMWI00<000000=WIf@3IfMT0AP3IfMT005l0fMWI0`00000F0=WIf@030000003IfMT0fMWI00<0fMWI
0`0000030=WIf@<00000<@3IfMT01@000000fMWI0=WIf@3IfMT0000001T0fMWI00<000000=WIf@3I
fMT05@3IfMT300000080fMWI0`0000030=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3I
fMT01P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI09<0fMWI001P0=WIf@030000
003IfMT0fMWI01@0fMWI0`0000050=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0
fMWI000000060=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@020=WIf@<0000000@0fMWI0000000000000000603IfMT00`000000fMWI0=WIf@0F0=WI
f@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT0fMWI0`0000050=WIf@030000003IfMT0
fMWI00D0fMWI0`0000060=WIf@<000000`3IfMT3000009@0fMWI001h0=WIf@030000003IfMT0fMWI
0140fMWI0`0000030=WIf@<000000`3IfMT3000000040=WIf@0000000000000000@0fMWI0`000005
0=WIf@<000000`3IfMT3000000@0fMWI00D000000=WIf@3IfMT0fMWI0000000I0=WIf@030000003I
fMT0fMWI0200fMWI00<000000=WIf@3IfMT00`3IfMT3000000L0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI09<0fMWI002=0=WIf@030000003IfMT0
fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0240fMWI00<0
00000=WIf@3IfMT09`3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI08H0fMWI002n
0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0:
0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@0K
0=WIf@030000003IfMT0fMWI01/0fMWI0`00000?0=WIf@030000003IfMT0fMWI0240fMWI00<00000
0=WIf@3IfMT0D@3IfMT006@0fMWI00<000000=WIf@3IfMT07`3IfMT00`000000fMWI0=WIf@040=WI
f@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@080=WI
f@030000003IfMT0fMWI00D0fMWI0`0000030=WIf@<000000P3IfMT3000000<0fMWI00<000000=WI
f@3IfMT01@3IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@<000000`3IfMT3
000000<0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT01@3IfMT3000001L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@0=0=WIf@<000008@3IfMT300000580fMWI001S0=WIf@<000003`3IfMT00`000000fMWI0=WIf@08
0=WIf@030000003IfMT0fMWI0080fMWI0`0000040=WIf@<00000403IfMT3000000L0fMWI0`000008
0=WIf@<000001`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0080fMWI00@00000
0=WIf@3IfMT0fMWI0`0000060=WIf@800000103IfMT3000000<0fMWI00<000000=WIf@3IfMT00`3I
fMT010000000fMWI0=WIf@3IfMT3000000040=WIf@0000000000000000<0fMWI0`0000030=WIf@<0
00001`3IfMT00`000000fMWI0=WIf@0E0=WIf@<000005@3IfMT00`000000fMWI0=WIf@0Q0=WIf@03
0000003IfMT0fMWI0540fMWI001T0=WIf@030000003IfMT0fMWI00d0fMWI0`0000080=WIf@<00000
103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
1`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
5P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0
3@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0303IfMT00`000000
fMWI0=WIf@1m0=WIf@00KP3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00P0fMWI
00<000000=WIf@3IfMT04P3IfMT3000000/0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI
0=WIf@0W0=WIf@030000003IfMT0fMWI00h0fMWI0`00000I0=WIf@<00000OP3IfMT005<0fMWI00<0
00000=WIf@3IfMT05`3IfMT3000002H0fMWI00<000000=WIf@3IfMT02@3IfMT3000000L0fMWI00<0
00000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00@0
00000=WIf@3IfMT0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI00<0fMWI0`0000070=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000
003IfMT0fMWI07d0fMWI001B0=WIf@<000006@3IfMT00`000000fMWI0=WIf@0b0=WIf@030000003I
fMT0fMWI00D0fMWI0`0000040=WIf@<000001@3IfMT3000000<0fMWI0`0000020=WIf@<000000P3I
fMT3000000<0fMWI0`000000103IfMT000000000000000030=WIf@<000000P3IfMT300000080fMWI
0`0000040=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT00P3IfMT3000000D0fMWI
00<000000=WIf@3IfMT01@3IfMT3000000h0fMWI0`00000;0=WIf@030000003IfMT0fMWI08@0fMWI
001C0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WI
f@0N0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WI
f@030=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WI
f@030=WIf@040000003IfMT0fMWI0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@030000
003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P3IfMT3000000D0fMWI0`0000040=WIf@030000
003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@090=WIf@<00000
Q@3IfMT005l0fMWI0`00000X0=WIf@<00000B@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003I
fMT0fMWI00D0fMWI00<000000=WIf@3IfMT0<@3IfMT00`000000fMWI0=WIf@240=WIf@00H03IfMT0
0`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI0=D0fMWI00200=WIf@030000003IfMT0fMWI
01H0fMWI0`0000030=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@0:0=WIf@<00000103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI
00<0fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI
0080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@2L0=WIf@00O`3IfMT3000001P0
fMWI00@000000=WIf@3IfMT0fMWI0`0000050=WIf@<000001P3IfMT3000000`0fMWI00<000000=WI
f@3IfMT00P3IfMT300000080fMWI0`0000030=WIf@<000001@3IfMT2000000@0fMWI0`0000030=WI
f@<000000`3IfMT00`000000fMWI0=WIf@0:0=WIf@<00000103IfMT010000000fMWI0=WIf@3IfMT3
00000080fMWI0`0000060=WIf@<000001@3IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0
fMWI0700fMWI00200=WIf@030000003IfMT0fMWI01`0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT00P3IfMT00`00
0000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00@0fMWI0`0000040=WIf@030000003IfMT0fMWI
00<0fMWI00@000000=WIf@3IfMT0fMWI0`00000<0=WIf@030000003IfMT0fMWI0080fMWI0`000003
0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@03
0=WIf@<000006@3IfMT00`000000fMWI0=WIf@060=WIf@<00000L@3IfMT00980fMWI00<000000=WI
f@3IfMT08@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI01L0fMWI0P00000@0=WI
f@030000003IfMT0fMWI0140fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@0?0=WI
f@030000003IfMT0fMWI00D0fMWI0`0000080=WIf@030000003IfMT0fMWI0700fMWI001g0=WIf@03
0000003IfMT0fMWI01L0fMWI0`00000Q0=WIf@<000000`3IfMT3000000@0fMWI00<000000=WIf@3I
fMT04@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3I
fMT0<@3IfMT3000000L0fMWI00<000000=WIf@3IfMT0NP3IfMT006d0fMWI00<000000=WIf@3IfMT0
1P3IfMT3000000X0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0>0=WIf@030000
003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0080fMWI0`0000070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
1P3IfMT300000100fMWI0`00000C0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
2@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0
P`3IfMT00640fMWI00<000000=WIf@3IfMT0203IfMT3000000P0fMWI00<000000=WIf@3IfMT0203I
fMT3000001d0fMWI0`0000060=WIf@<00000503IfMT00`000000fMWI0=WIf@050=WIf@<000002@3I
fMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT04@3I
fMT3000000<0fMWI0`0000090=WIf@<000000`3IfMT3000008`0fMWI001P0=WIf@<000002P3IfMT0
0`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT01P3IfMT0
0`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@0000004`3IfMT0
0`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT02@3IfMT0
0`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI08/0fMWI001Q0=WIf@030000003IfMT0fMWI
02P0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0@0=WIf@040000003IfMT0fMWI
0=WIf@@000004@3IfMT3000000T0fMWI00<000000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@2I
0=WIf@00R`3IfMT3000000`0fMWI0`00000E0=WIf@<00000103IfMT300000080fMWI0`0000040=WI
f@030000003IfMT0fMWI00T0fMWI0`0000020=WIf@030000003IfMT0000000@0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00L0fMWI0`00000H0=WI
f@<00000VP3IfMT008`0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0E0=WIf@03
0000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@020=WIf@<0
00002`3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI0`0000040=WIf@<000004@3IfMT00`00
0000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI01@0fMWI00<000000=WIf@3IfMT0PP3IfMT00:L0
fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@110=WIf@<00000P`3IfMT00:H0fMWI
0`0000040=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI
0=WIf@0@0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI0000000H0=WIf@03
0000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@220=WIf@00
U`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
0P3IfMT3000001/0fMWI0`0000090=WIf@030000003IfMT0fMWI00l0fMWI0`0000040=WIf@<00000
00@0fMWI00000000000000001P3IfMT00`000000fMWI0=WIf@0=0=WIf@<000003@3IfMT3000008l0
fMWI00220=WIf@030000003IfMT0fMWI0140fMWI0`0000040=WIf@<000003@3IfMT00`000000fMWI
0=WIf@020=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@070=WIf@8000004P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WIf@00
00001P3IfMT3000000l0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@2>0=WIf@00
P@3IfMT3000001<0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0@0=WIf@<00000
0`3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI0=WIf@<000004@3IfMT3000000D0
fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@2_0=WIf@00M@3IfMT00`000000fMWI
0=WIf@0:0=WIf@030000003IfMT0fMWI02d0fMWI00@000000=WIf@3IfMT0fMWI0`0000020=WIf@<0
00000`3IfMT00`000000fMWI0=WIf@0A0=WIf@800000103IfMT300000=00fMWI001d0=WIf@<00000
7@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0
0P3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0
9P3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI09<0fMWI001e0=WIf@030000003I
fMT0fMWI01/0fMWI0`00000=0=WIf@<00000703IfMT3000000<0fMWI0`0000030=WIf@<000001@3I
fMT2000000h0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@0@0=WIf@<000002P3I
fMT00`000000fMWI0=WIf@030=WIf@<00000203IfMT00`000000fMWI0=WIf@290=WIf@00S03IfMT0
0`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT00`3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00`0fMWI0`0000040=WIf@040000003IfMT0
fMWI0=WIf@<000001P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00P0fMWI0`00
00050=WIf@030000003IfMT0fMWI00H0fMWI0`0000000`3IfMT000000=WIf@070=WIf@030000003I
fMT0fMWI07d0fMWI002;0=WIf@<000006`3IfMT3000002X0fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000fMWI0=WIf@020=WIf@<000000`3IfMT00`000000fMWI0=WIf@040=WIf@<000005P3IfMT0
0`000000fMWI0=WIf@0>0=WIf@030000003IfMT00000008000001P3IfMT3000007h0fMWI002<0=WI
f@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0Y0=WI
f@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0O@3IfMT00<D0fMWI00<000000=WIf@3I
fMT02@3IfMT00`000000fMWI0=WIf@020=WIf@040000003IfMT0fMWI0=WIf@<00000<03IfMT00`00
0000fMWI0=WIf@2N0=WIf@00U`3IfMT00`000000fMWI0=WIf@0E0=WIf@030000003IfMT0fMWI0180
fMWI0`0000050=WIf@040000003IfMT0fMWI0=WIf@<000000`3IfMT00`000000fMWI0=WIf@020=WI
f@030000003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT04`3IfMT3000009l0fMWI002F0=WIf@<0
00001P3IfMT00`000000fMWI0=WIf@0<0=WIf@<00000503IfMT00`000000fMWI0=WIf@030=WIf@<0
00000`3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI01`0fMWI0`00000E0=WIf@03
0000003IfMT0fMWI09h0fMWI002G0=WIf@030000003IfMT0fMWI00@0fMWI0`00000>0=WIf@030000
003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT01`3IfMT2000000/0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI02@0fMWI00<000000=WIf@3IfMT0
SP3IfMT009l0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@0A0=WIf@<000002@3I
fMT3000000H0fMWI0`00000^0=WIf@<00000S`3IfMT00<40fMWI0`0000060=WIf@030000003IfMT0
fMWI00T0fMWI0P00000;0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0703IfMT0
0`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT0SP3IfMT0
0:D0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00@0fMWI0`00000:0=WIf@030000003IfMT0fMWI0340fMWI0`0000090=WIf@<00000U@3IfMT00:@0
fMWI0`00000D0=WIf@<00000303IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI0380
fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@2D0=WIf@00Y@3IfMT00`000000fMWI
0=WIf@0D0=WIf@030000003IfMT0fMWI01L0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI
0=WIf@3?0=WIf@00d@3IfMT010000000fMWI0=WIf@3IfMT2000000@0fMWI0`0000020=WIf@030000
003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0;0=WIf@030000
003IfMT0fMWI0:L0fMWI00360=WIf@030000003IfMT0fMWI00L0fMWI0`000000103IfMT000000000
000000050=WIf@030000003IfMT0fMWI00<00000303IfMT3000000@0fMWI0`00000;0=WIf@<00000
Z03IfMT00<D0fMWI0`0000090=WIf@040000003IfMT0fMWI0=WIf@8000002@3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI09P0fMWI002i0=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@0i0=WIf@<00000V@3IfMT00;P0fMWI0`00000K
0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@2H
0=WIf@00^@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI0100fMWI00<000000=WI
f@3IfMT03@3IfMT3000000D0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@2_0=WI
f@00`P3IfMT3000000T0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@090=WIf@03
0000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT3000000/0fMWI0`00002`0=WIf@00
``3IfMT00`000000fMWI0=WIf@070=WIf@<000001P3IfMT00`000000fMWI000000080=WIf@<00000
2P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0:l0fMWI003>0=WIf@030000003I
fMT0fMWI00D0fMWI100000080=WIf@030000003IfMT0fMWI0<T0fMWI002e0=WIf@030000003IfMT0
fMWI01<0fMWI100000070=WIf@030000003IfMT000000=D0fMWI002d0=WIf@<000001P3IfMT00`00
0000fMWI0=WIf@0=0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04P3IfMT00`00
0000fMWI0=WIf@300=WIf@00]@3IfMT00`000000fMWI0=WIf@040=WIf@<00000203IfMT00`000000
fMWI0=WIf@030=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT04@3IfMT300000<40
fMWI002m0=WIf@030000003IfMT0fMWI00H0fMWI2@0000070=WIf@@000004@3IfMT00`000000fMWI
0=WIf@300=WIf@00a`3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00H0fMWI
00<000000=WIf@3IfMT0e@3IfMT00<X0fMWI00@000000=WIf@3IfMT00000203IfMT00`000000fMWI
0=WIf@3E0=WIf@00b`3IfMT00`000000fMWI000000080=WIf@030000003IfMT0fMWI0=D0fMWI003;
0=WIf@030000003IfMT0000000P0fMWI00<000000=WIf@3IfMT0e@3IfMT00<`0fMWI0P0000080=WI
f@030000003IfMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0fMWI0=D0fMWI003F0=WIf@030000
003IfMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0fMWI0=D0fMWI003F0=WIf@030000003IfMT0
fMWI0=D0fMWI0000\
\>"],
  ImageRangeCache->{{{0, 429.313}, {425.438, 0}} -> {-4.18732, -4.13191, \
0.0292985, 0.0292985}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary and Discussion", "Section"],

Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook sets up an experiment environment for Persson and Strang's mesh \
generation algorithm. It also tries to document the program in a literate \
programming style. "
}], "Text"],

Cell[TextData[{
  "The translation from the original MATLAB code to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code is far from complete. It only touches the program in Figure 3.1 of \
the paper, though, I hope, it provides a good starting point for testing and \
understanding the algorithm. Various experiments can be run from this point, \
such as defining different distance functions or size functions, testing \
different scaling process or objective function, etc., especially when the \
optimization process gets stuck, you can try many places to shake."
}], "Text"],

Cell[TextData[{
  "There are multiple ways to program in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", thus to transcribe the original MATLAB code. The original MATLAB code \
makes good use of MATLAB's list processing ability and therefore is very \
concise. Here we adopted a somewhat functional programming style in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Like structure programming isn't really about getting rid of \"goto\"s, \
functional programming isn't really about getting rid of \"for\" loops. A \
functional program avoids relying on variables while builds up on definitions \
of functions. It then uses ",
  StyleBox["Map (/@), Apply (@@)",
    FontFamily->"Courier"],
  ", and ",
  StyleBox["Nest",
    FontFamily->"Courier"],
  ", etc., to glue these functions together. The advantage is that once these \
functions are declared, they won't change anymore. So testing or running the \
program becomes declarative rather than imperative, which means the order of \
which expressions are evaluated doesn't matter so much. Whereas the \
expressions that make heavy use of variables can have trouble (side-effects) \
brought by changing the evaluation order or reevaluating them, which is not \
favorable for testing and experimenting."
}], "Text"],

Cell[TextData[{
  "I am still learning to program in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". So the code here can certainly be improved both towards more elegant in \
style and faster in speed, not to mention the hidden bugs to squash. Like so \
many open software and open documents on the internet, future versions of \
this notebook will be better through suggestions and advice from readers like \
you."
}], "Text"],

Cell["My email address: huzhe@iit.edu", "Caption"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Packages Needed"
}], "Section",
  InitializationCell->True],

Cell[BoxData[
    \(<< NumericalMath`NLimit`\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True],

Cell[BoxData[
    \(<< DiscreteMath`ComputationalGeometry`\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell["\<\
[1] Per-Olof Persson and Gilbert Strang, \"A Simple Mesh Generator in MATLAB,\
\" SIAM Review (August, 2004)\
\>", "Reference"],

Cell[TextData[{
  "[2] Roman Maeder, \"Programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ",\" Addison-Wesley, 1997"
}], "Reference"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->None,
WindowToolbars->"EditBar",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->1.5,
StyleDefinitions -> "ArticleModern.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3309581561-6542075"->{
    Cell[1643309, 54213, 303, 5, 132, "Print",
      CellTags->"Info3309581561-6542075"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3309581561-6542075", 1760557, 56748}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 112, 4, 206, "Title"],
Cell[1891, 59, 31, 0, 56, "Subtitle"],
Cell[1925, 61, 95, 5, 137, "Author"],
Cell[2023, 68, 319, 7, 117, "Abstract"],

Cell[CellGroupData[{
Cell[2367, 79, 31, 0, 94, "Section"],
Cell[2401, 81, 410, 10, 90, "Text"],
Cell[2814, 93, 752, 14, 142, "Text"],
Cell[3569, 109, 374, 8, 90, "Text"],
Cell[3946, 119, 441, 7, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4424, 131, 27, 0, 94, "Section"],
Cell[4454, 133, 477, 13, 90, "Text"],
Cell[4934, 148, 1271, 29, 194, "Text"],
Cell[6208, 179, 75, 0, 37, "Program"],
Cell[6286, 181, 713, 20, 118, "Text"],
Cell[7002, 203, 656, 14, 116, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7695, 222, 117, 4, 94, "Section"],
Cell[7815, 228, 284, 5, 64, "Text"],
Cell[8102, 235, 145, 3, 65, "Input"],
Cell[8250, 240, 457, 11, 90, "Text"],
Cell[8710, 253, 174, 3, 90, "Input"],
Cell[8887, 258, 649, 17, 90, "Text"],
Cell[9539, 277, 275, 5, 173, "Input"],
Cell[9817, 284, 320, 11, 38, "Text"],

Cell[CellGroupData[{
Cell[10162, 299, 200, 4, 90, "Input"],
Cell[10365, 305, 58722, 1647, 237, 21163, 1178, "GraphicsData", "PostScript", \
"Graphics"],
Cell[69090, 1954, 154, 4, 63, "Output"]
}, Open  ]],
Cell[69259, 1961, 281, 9, 65, "Text"],
Cell[69543, 1972, 191, 4, 90, "Input"],
Cell[69737, 1978, 144, 5, 39, "Text"],

Cell[CellGroupData[{
Cell[69906, 1987, 231, 4, 90, "Input"],
Cell[70140, 1993, 21339, 492, 482, 4192, 275, "GraphicsData", "PostScript", \
"Graphics"],
Cell[91482, 2487, 154, 4, 63, "Output"]
}, Open  ]],
Cell[91651, 2494, 272, 7, 65, "Text"],

Cell[CellGroupData[{
Cell[91948, 2505, 267, 6, 90, "Input"],
Cell[92218, 2513, 25083, 704, 241, 7734, 485, "GraphicsData", "PostScript", \
"Graphics"],
Cell[117304, 3219, 154, 4, 63, "Output"]
}, Open  ]],
Cell[117473, 3226, 315, 7, 65, "Text"],
Cell[117791, 3235, 93, 2, 64, "Input"],
Cell[117887, 3239, 194, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[118106, 3248, 302, 6, 142, "Input"],
Cell[118411, 3256, 51033, 1422, 235, 17830, 1007, "GraphicsData", \
"PostScript", "Graphics"],
Cell[169447, 4680, 155, 4, 63, "Output"]
}, Open  ]],
Cell[169617, 4687, 290, 7, 64, "Text"],
Cell[169910, 4696, 291, 7, 65, "Text"],
Cell[170204, 4705, 138, 3, 64, "Input"],
Cell[170345, 4710, 363, 12, 65, "Text"],
Cell[170711, 4724, 247, 6, 116, "Input"],
Cell[170961, 4732, 117, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[171103, 4739, 226, 4, 90, "Input"],
Cell[171332, 4745, 58723, 1647, 237, 21163, 1178, "GraphicsData", \
"PostScript", "Graphics"],
Cell[230058, 6394, 155, 4, 63, "Output"]
}, Open  ]],
Cell[230228, 6401, 46, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[230299, 6405, 243, 5, 90, "Input"],
Cell[230545, 6412, 42742, 1451, 456, 21034, 1178, "GraphicsData", \
"PostScript", "Graphics"],
Cell[273290, 7865, 155, 4, 63, "Output"]
}, Open  ]],
Cell[273460, 7872, 149, 3, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[273646, 7880, 123, 4, 94, "Section"],
Cell[273772, 7886, 1195, 29, 142, "Text"],
Cell[274970, 7917, 101, 2, 76, "Input"],
Cell[275074, 7921, 838, 24, 118, "Text"],

Cell[CellGroupData[{
Cell[275937, 7949, 84, 2, 86, "Input"],
Cell[276024, 7953, 388, 6, 44, "Message"]
}, Open  ]],
Cell[276427, 7962, 63, 0, 38, "Text"],
Cell[276493, 7964, 430, 9, 174, "Input"],
Cell[276926, 7975, 869, 25, 116, "Text"],

Cell[CellGroupData[{
Cell[277820, 8004, 226, 4, 90, "Input"],
Cell[278049, 8010, 47067, 1313, 455, 16308, 928, "GraphicsData", \
"PostScript", "Graphics"],
Cell[325119, 9325, 155, 4, 63, "Output"]
}, Open  ]],
Cell[325289, 9332, 337, 8, 65, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325663, 9345, 41, 0, 94, "Section"],
Cell[325707, 9347, 194, 6, 38, "Text"],
Cell[325904, 9355, 91, 2, 64, "Input"],
Cell[325998, 9359, 338, 10, 64, "Text"],

Cell[CellGroupData[{
Cell[326361, 9373, 209, 5, 90, "Input"],
Cell[326573, 9380, 250386, 9333, 456, 86993, 7311, "GraphicsData", \
"PostScript", "Graphics"],
Cell[576962, 18715, 155, 4, 63, "Output"]
}, Open  ]],
Cell[577132, 18722, 214, 6, 65, "Text"],
Cell[577349, 18730, 288, 6, 116, "Input"],
Cell[577640, 18738, 120, 5, 38, "Text"],
Cell[577763, 18745, 80, 2, 64, "Input"],
Cell[577846, 18749, 187, 4, 90, "Input"],
Cell[578036, 18755, 50, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[578111, 18759, 78, 2, 64, "Input"],
Cell[578192, 18763, 249037, 8748, 447, 73550, 6576, "GraphicsData", \
"PostScript", "Graphics"],
Cell[827232, 27513, 155, 4, 63, "Output"]
}, Open  ]],
Cell[827402, 27520, 237, 4, 64, "Text"],
Cell[827642, 27526, 176, 4, 90, "Input"],

Cell[CellGroupData[{
Cell[827843, 27534, 217, 4, 90, "Input"],
Cell[828063, 27540, 42119, 1194, 187, 14774, 851, "GraphicsData", \
"PostScript", "Graphics"],
Cell[870185, 28736, 155, 4, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[870377, 28745, 129, 3, 64, "Input"],
Cell[870509, 28750, 159577, 6566, 187, 60242, 5334, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1030089, 35318, 155, 4, 63, "Output"]
}, Open  ]],
Cell[1030259, 35325, 314, 5, 90, "Text"],
Cell[1030576, 35332, 119, 3, 86, "Input"],
Cell[1030698, 35337, 68, 0, 38, "Text"],
Cell[1030769, 35339, 113, 2, 64, "Input"],

Cell[CellGroupData[{
Cell[1030907, 35345, 80, 2, 64, "Input"],
Cell[1030990, 35349, 156794, 6492, 187, 59740, 5289, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1187787, 41843, 155, 4, 63, "Output"]
}, Open  ]],
Cell[1187957, 41850, 509, 9, 117, "Text"],
Cell[1188469, 41861, 174, 4, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1188680, 41870, 37, 0, 94, "Section"],
Cell[1188720, 41872, 685, 19, 81, "Text"],
Cell[1189408, 41893, 274, 9, 65, "Text"],
Cell[1189685, 41904, 114, 2, 64, "Input"],
Cell[1189802, 41908, 1278, 35, 192, "Text"],
Cell[1191083, 41945, 188, 5, 98, "Input"],
Cell[1191274, 41952, 466, 15, 65, "Text"],

Cell[CellGroupData[{
Cell[1191765, 41971, 212, 6, 90, "Input"],
Cell[1191980, 41979, 389, 6, 44, "Message"]
}, Open  ]],
Cell[1192384, 41988, 174, 5, 38, "Text"],
Cell[1192561, 41995, 166, 4, 64, "Input"],
Cell[1192730, 42001, 190, 4, 64, "Text"],
Cell[1192923, 42007, 155, 4, 90, "Input"],
Cell[1193081, 42013, 1022, 25, 169, "Text"],
Cell[1194106, 42040, 269, 5, 116, "Input"],
Cell[1194378, 42047, 134, 5, 39, "Text"],
Cell[1194515, 42054, 213, 4, 90, "Input"],
Cell[1194731, 42060, 718, 21, 85, "Text"],
Cell[1195452, 42083, 221, 5, 38, "Text"],
Cell[1195676, 42090, 230, 6, 90, "Input"],
Cell[1195909, 42098, 45, 0, 38, "Text"],
Cell[1195957, 42100, 74, 2, 64, "Input"],
Cell[1196034, 42104, 86, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[1196145, 42110, 142, 3, 64, "Input"],
Cell[1196290, 42115, 47067, 1313, 455, 16308, 928, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1243360, 43430, 155, 4, 63, "Output"]
}, Open  ]],
Cell[1243530, 43437, 35, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[1243590, 43441, 166, 3, 90, "Input"],
Cell[1243759, 43446, 50893, 1359, 458, 16497, 929, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1294655, 44807, 155, 4, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1294847, 44816, 69, 2, 64, "Input"],
Cell[1294919, 44820, 78599, 2266, 458, 30295, 1664, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1373521, 47088, 155, 4, 63, "Output"]
}, Open  ]],
Cell[1373691, 47095, 195, 4, 64, "Text"],
Cell[1373889, 47101, 1095, 20, 440, "Input"],
Cell[1374987, 47123, 47, 0, 38, "Text"],
Cell[1375037, 47125, 540, 12, 241, "Input"],
Cell[1375580, 47139, 74, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[1375679, 47143, 168, 3, 90, "Input"],
Cell[1375850, 47148, 31125, 810, 454, 9009, 532, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1406978, 47960, 156, 4, 82, "Output"]
}, Open  ]],
Cell[1407149, 47967, 124, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[1407298, 47974, 212, 5, 90, "Input"],
Cell[1407513, 47981, 191732, 5162, 456, 39317, 3275, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1599248, 53145, 156, 4, 82, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1599453, 53155, 31, 0, 94, "Section"],
Cell[1599487, 53157, 92, 2, 38, "Text"],
Cell[1599582, 53161, 342, 9, 64, "Text"],
Cell[1599927, 53172, 194, 4, 90, "Input"],
Cell[1600124, 53178, 177, 4, 64, "Text"],
Cell[1600304, 53184, 161, 4, 64, "Input"],

Cell[CellGroupData[{
Cell[1600490, 53192, 168, 3, 90, "Input"],
Cell[1600661, 53197, 39815, 923, 422, 9045, 538, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1640479, 54122, 156, 4, 82, "Output"]
}, Open  ]],
Cell[1640650, 54129, 157, 3, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1640844, 54137, 121, 5, 95, "Section"],
Cell[1640968, 54144, 473, 9, 116, "Text"],
Cell[1641444, 54155, 1263, 34, 172, "Text"],
Cell[1642710, 54191, 57, 0, 38, "Text"],
Cell[1642770, 54193, 167, 4, 90, "Input"],
Cell[1642940, 54199, 265, 6, 142, "Input"],

Cell[CellGroupData[{
Cell[1643230, 54209, 76, 2, 64, "Input"],
Cell[1643309, 54213, 303, 5, 132, "Print",
  CellTags->"Info3309581561-6542075"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1643649, 54223, 80, 2, 64, "Input"],
Cell[1643732, 54227, 148, 3, 82, "Output"]
}, Open  ]],
Cell[1643895, 54233, 255, 6, 103, "Input"],
Cell[1644153, 54241, 217, 5, 90, "Input"],

Cell[CellGroupData[{
Cell[1644395, 54250, 101, 2, 64, "Input"],
Cell[1644499, 54254, 111635, 2361, 451, 22806, 1259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1756137, 56617, 155, 4, 63, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1756341, 56627, 41, 0, 94, "Section"],
Cell[1756385, 56629, 266, 7, 64, "Text"],
Cell[1756654, 56638, 594, 10, 116, "Text"],
Cell[1757251, 56650, 1292, 25, 247, "Text"],
Cell[1758546, 56677, 439, 9, 90, "Text"],
Cell[1758988, 56688, 50, 0, 31, "Caption"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1759075, 56693, 131, 5, 95, "Section",
  InitializationCell->True],
Cell[1759209, 56700, 109, 3, 64, "Input",
  InitializationCell->True],
Cell[1759321, 56705, 123, 3, 64, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[1759481, 56713, 29, 0, 94, "Section"],
Cell[1759513, 56715, 137, 3, 26, "Reference"],
Cell[1759653, 56720, 154, 5, 26, "Reference"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

